@@ -28,7 +28,7 @@ import java.util.concurrent.CountDownLatch;
  * Responsible for checking for a winner in a game of n-puzzle.
  * 
  * @author Lane Schwartz
- * @version $LastChangedDate: 2011-11-22 18:21:37 +0800 (Tue, 22 Nov 2011) $
+ * @version $LastChangedDate: 2012-07-25 16:15:00 +0800 (Wed, 25 Jul 2012) $
  */
 public class EndTurnDelegate extends BaseDelegate
 {
@@ -44,13 +44,13 @@ public class EndTurnDelegate extends BaseDelegate
 		if (gameOver(getData().getMap()))
 		{
 			signalGameOver("Board solved!");
-			try
+			/*try
 			{
 				m_waiting = new CountDownLatch(1);
 				m_waiting.await();
 			} catch (final InterruptedException e)
 			{
-			}
+			}*/
 		}
 	}
 	
@@ -131,6 +131,7 @@ public class EndTurnDelegate extends BaseDelegate
 		final INPuzzleDisplay display = (INPuzzleDisplay) m_bridge.getDisplayChannelBroadcaster();
 		display.setStatus(status);
 		display.setGameOver();
+		m_bridge.stopGameSequence();
 	}
 	
 	/**
@@ -146,9 +147,9 @@ public class EndTurnDelegate extends BaseDelegate
 }
 
 
-@SuppressWarnings("serial")
 class SlidingTilesEndTurnExtendedDelegateState implements Serializable
 {
+	private static final long serialVersionUID = 8240451114219646419L;
 	Serializable superState;
 	// add other variables here:
 }
