@@ -33,7 +33,7 @@ import java.util.Random;
  * Responsible for initializing an N-Puzzle game.
  * 
  * @author Lane Schwartz
- * @version $LastChangedDate: 2011-12-10 06:24:08 +0800 (Sat, 10 Dec 2011) $
+ * @version $LastChangedDate: 2012-04-19 18:13:58 +0800 (Thu, 19 Apr 2012) $
  */
 public class InitializationDelegate extends BaseDelegate
 {
@@ -138,9 +138,9 @@ public class InitializationDelegate extends BaseDelegate
 }
 
 
-@SuppressWarnings("serial")
 class SlidingTilesInitializationExtendedDelegateState implements Serializable
 {
+	private static final long serialVersionUID = -6612138982624223426L;
 	Serializable superState;
 	// add other variables here:
 }
