@@ -32,7 +32,7 @@ import java.io.Serializable;
  * Responsible for performing a move in a game of n-puzzle.
  * 
  * @author Lane Schwartz
- * @version $LastChangedDate: 2011-11-22 18:21:37 +0800 (Tue, 22 Nov 2011) $
+ * @version $LastChangedDate: 2012-04-19 18:13:58 +0800 (Thu, 19 Apr 2012) $
  */
 public class PlayDelegate extends BaseDelegate implements IPlayDelegate
 {
@@ -186,9 +186,9 @@ public class PlayDelegate extends BaseDelegate implements IPlayDelegate
 }
 
 
-@SuppressWarnings("serial")
 class SlidingTilesPlayExtendedDelegateState implements Serializable
 {
+	private static final long serialVersionUID = 2850777141854664044L;
 	Serializable superState;
 	// add other variables here:
 }
