@@ -27,7 +27,7 @@ import java.io.Serializable;
  * Responsible for checking for a winner in a game of Tic Tac Toe.
  * 
  * @author Lane Schwartz
- * @version $LastChangedDate: 2011-11-22 18:21:37 +0800 (Tue, 22 Nov 2011) $
+ * @version $LastChangedDate: 2012-07-25 16:15:00 +0800 (Wed, 25 Jul 2012) $
  */
 public class EndTurnDelegate extends BaseDelegate
 {
@@ -87,6 +87,7 @@ public class EndTurnDelegate extends BaseDelegate
 		final ITicTacToeDisplay display = (ITicTacToeDisplay) m_bridge.getDisplayChannelBroadcaster();
 		display.setStatus(status);
 		display.setGameOver();
+		m_bridge.stopGameSequence();
 	}
 	
 	/**
@@ -222,9 +223,9 @@ public class EndTurnDelegate extends BaseDelegate
 }
 
 
-@SuppressWarnings("serial")
 class TicTacToeEndTurnExtendedDelegateState implements Serializable
 {
+	private static final long serialVersionUID = 5491407308288449271L;
 	Serializable superState;
 	// add other variables here:
 }
