@@ -33,7 +33,7 @@ import java.util.Collection;
  * Responsible for performing a move in a game of Tic Tac Toe.
  * 
  * @author Lane Schwartz
- * @version $LastChangedDate: 2011-11-22 18:21:37 +0800 (Tue, 22 Nov 2011) $
+ * @version $LastChangedDate: 2012-05-28 17:03:10 +0800 (Mon, 28 May 2012) $
  */
 public class PlayDelegate extends BaseDelegate implements IPlayDelegate
 {
@@ -111,8 +111,7 @@ public class PlayDelegate extends BaseDelegate implements IPlayDelegate
 		final Collection<Unit> units = new ArrayList<Unit>(1);
 		units.add(getData().getUnitTypeList().getUnitType("ticmark").create(player));
 		final String transcriptText = player.getName() + " played in " + at.getName();
-		m_bridge.getHistoryWriter().startEvent(transcriptText);
-		m_bridge.getHistoryWriter().setRenderingData(units);
+		m_bridge.getHistoryWriter().startEvent(transcriptText, units);
 		final Change place = ChangeFactory.addUnits(at, units);
 		final Change owner = ChangeFactory.changeOwner(at, player);
 		final CompositeChange change = new CompositeChange();
@@ -136,9 +135,9 @@ public class PlayDelegate extends BaseDelegate implements IPlayDelegate
 }
 
 
-@SuppressWarnings("serial")
 class TicTacToePlayExtendedDelegateState implements Serializable
 {
+	private static final long serialVersionUID = 8544940313546397365L;
 	Serializable superState;
 	// add other variables here:
 }
