@@ -22,7 +22,7 @@ import games.strategy.engine.data.Territory;
  * Represents a human player of Tic Tac Toe.
  * 
  * @author Lane Schwartz
- * @version $LastChangedDate: 2011-11-22 18:21:37 +0800 (Tue, 22 Nov 2011) $
+ * @version $LastChangedDate: 2012-07-25 15:19:19 +0800 (Wed, 25 Jul 2012) $
  */
 public class TicTacToePlayer extends AbstractHumanPlayer<TicTacToeFrame> implements ITicTacToePlayer
 {
@@ -43,11 +43,11 @@ public class TicTacToePlayer extends AbstractHumanPlayer<TicTacToeFrame> impleme
 	private void play()
 	{
 		// Get the relevant delegate
-		final IPlayDelegate playDel = (IPlayDelegate) m_bridge.getRemote();
+		final IPlayDelegate playDel = (IPlayDelegate) getPlayerBridge().getRemote();
 		Territory play = null;
 		while (play == null)
 		{
-			play = m_ui.waitForPlay(m_id, m_bridge);
+			play = m_ui.waitForPlay(getPlayerID(), getPlayerBridge());
 			if (play == null)
 			{
 				// If play==null, the play was interrupted,
