@@ -57,8 +57,7 @@ public abstract class BaseDelegate implements IDelegate
 	/**
 	 * Called before the delegate will run.
 	 * All classes should call super.start if they override this.
-	 * The only exception is that persistent delegates like Edit Delegate should not call super.start(),
-	 * because we do not want to fire triggers for the edit delegate.
+	 * Persistent delegates like Edit Delegate should not extend BaseDelegate, because we do not want to fire triggers in the edit delegate.
 	 */
 	public void start(final IDelegateBridge bridge)
 	{
@@ -74,8 +73,7 @@ public abstract class BaseDelegate implements IDelegate
 	/**
 	 * Called before the delegate will stop running.
 	 * All classes should call super.end if they override this.
-	 * The only exception is that persistent delegates like Edit Delegate should not call super.end(),
-	 * because we do not want to fire triggers for the edit delegate.
+	 * Persistent delegates like Edit Delegate should not extend BaseDelegate, because we do not want to fire triggers in the edit delegate.
 	 */
 	public void end()
 	{
@@ -159,16 +157,15 @@ public abstract class BaseDelegate implements IDelegate
 }
 
 
-@SuppressWarnings("serial")
 class BaseDelegateState implements Serializable
 {
+	private static final long serialVersionUID = 7130686697155151908L;
 	public boolean m_startBaseStepsFinished = false;
 	public boolean m_endBaseStepsFinished = false;
 }
 /*
 All overriding classes should use the following format for saveState and loadState, in order to save and load the superstate
 
-@SuppressWarnings("serial")
 class ExtendedDelegateState implements Serializable
 {
 	Serializable superState;
