@@ -50,6 +50,7 @@ import com.apple.eawt.ApplicationEvent;
 
 public class BasicGameMenuBar<CustomGameFrame extends MainGameFrame> extends JMenuBar
 {
+	private static final long serialVersionUID = -1447295944297939539L;
 	protected final CustomGameFrame m_frame;
 	
 	public BasicGameMenuBar(final CustomGameFrame frame)
@@ -57,8 +58,8 @@ public class BasicGameMenuBar<CustomGameFrame extends MainGameFrame> extends JMe
 		m_frame = frame;
 		createFileMenu(this);
 		createGameSpecificMenus(this);
-		createNetworkMenu(this);
-		createLobbyMenu(this);
+		final InGameLobbyWatcher watcher = createLobbyMenu(this);
+		createNetworkMenu(this, watcher);
 		createWebHelpMenu(this);
 		createHelpMenu(this);
 	}
@@ -67,26 +68,27 @@ public class BasicGameMenuBar<CustomGameFrame extends MainGameFrame> extends JMe
 	{
 	}
 	
-	protected void createLobbyMenu(final JMenuBar menuBar)
+	protected InGameLobbyWatcher createLobbyMenu(final JMenuBar menuBar)
 	{
 		if (!(m_frame.getGame() instanceof ServerGame))
-			return;
+			return null;
 		final ServerGame serverGame = (ServerGame) m_frame.getGame();
 		final InGameLobbyWatcher watcher = serverGame.getInGameLobbyWatcher();
 		if (watcher == null || !watcher.isActive())
 		{
-			return;
+			return watcher;
 		}
 		final JMenu lobby = new JMenu("Lobby");
 		menuBar.add(lobby);
 		lobby.add(new EditGameCommentAction(watcher, m_frame));
 		lobby.add(new RemoveGameFromLobbyAction(watcher));
+		return watcher;
 	}
 	
 	/**
 	 * @param menuBar
 	 */
-	protected void createNetworkMenu(final JMenuBar menuBar)
+	protected void createNetworkMenu(final JMenuBar menuBar, final InGameLobbyWatcher watcher)
 	{
 		// revisit
 		// if we are not a client or server game
@@ -98,7 +100,7 @@ public class BasicGameMenuBar<CustomGameFrame extends MainGameFrame> extends JMe
 		addBootPlayer(menuNetwork);
 		addBanPlayer(menuNetwork);
 		addMutePlayer(menuNetwork);
-		addSetGamePassword(menuNetwork);
+		addSetGamePassword(menuNetwork, watcher);
 		addShowPlayers(menuNetwork);
 		menuBar.add(menuNetwork);
 	}
@@ -115,6 +117,8 @@ public class BasicGameMenuBar<CustomGameFrame extends MainGameFrame> extends JMe
 		allowObservers.setSelected(messeneger.isAcceptNewConnections());
 		allowObservers.addActionListener(new AbstractAction()
 		{
+			private static final long serialVersionUID = 6876563887595464809L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				messeneger.setAcceptNewConnections(allowObservers.isSelected());
@@ -166,12 +170,12 @@ public class BasicGameMenuBar<CustomGameFrame extends MainGameFrame> extends JMe
 	/**
 	 * @param menuGame
 	 */
-	protected void addSetGamePassword(final JMenu parentMenu)
+	protected void addSetGamePassword(final JMenu parentMenu, final InGameLobbyWatcher watcher)
 	{
 		if (!getGame().getMessenger().isServer())
 			return;
 		final IServerMessenger messenger = (IServerMessenger) getGame().getMessenger();
-		parentMenu.add(new SetPasswordAction(this, (ClientLoginValidator) messenger.getLoginValidator()));
+		parentMenu.add(new SetPasswordAction(this, watcher, (ClientLoginValidator) messenger.getLoginValidator()));
 	}
 	
 	/**
@@ -183,6 +187,8 @@ public class BasicGameMenuBar<CustomGameFrame extends MainGameFrame> extends JMe
 		{
 			final AbstractAction optionsAction = new AbstractAction("Show Who is Who...")
 			{
+				private static final long serialVersionUID = 5687214685515140202L;
+				
 				public void actionPerformed(final ActionEvent e)
 				{
 					PlayersPanel.showPlayers(getGame(), m_frame);
@@ -352,6 +358,8 @@ public class BasicGameMenuBar<CustomGameFrame extends MainGameFrame> extends JMe
 	{
 		parentMenu.add(new AbstractAction("Show Console...")
 		{
+			private static final long serialVersionUID = 6303760092518795718L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				Console.getConsole().setVisible(true);
@@ -381,6 +389,8 @@ public class BasicGameMenuBar<CustomGameFrame extends MainGameFrame> extends JMe
 			parentMenu.addSeparator();
 			parentMenu.add(new AbstractAction("About...")
 			{
+				private static final long serialVersionUID = 2861657714227435945L;
+				
 				public void actionPerformed(final ActionEvent e)
 				{
 					JOptionPane.showMessageDialog(m_frame, editorPane, "About " + m_frame.getGame().getData().getGameName(), JOptionPane.PLAIN_MESSAGE);
@@ -414,6 +424,8 @@ public class BasicGameMenuBar<CustomGameFrame extends MainGameFrame> extends JMe
 		{
 			parentMenu.add(new AbstractAction("Game Notes...")
 			{
+				private static final long serialVersionUID = -1817640666359299617L;
+				
 				public void actionPerformed(final ActionEvent e)
 				{
 					SwingUtilities.invokeLater(new Runnable()
@@ -426,14 +438,19 @@ public class BasicGameMenuBar<CustomGameFrame extends MainGameFrame> extends JMe
 							editorPane.setText(notes);
 							final JScrollPane scroll = new JScrollPane(editorPane);
 							final JDialog dialog = new JDialog(m_frame);
-							dialog.setModal(true);
+							dialog.setModal(false);
+							// dialog.setModalityType(ModalityType.MODELESS); // needs java 1.6 at least...
+							dialog.setAlwaysOnTop(true);
 							dialog.add(scroll, BorderLayout.CENTER);
 							final JPanel buttons = new JPanel();
 							final JButton button = new JButton(new AbstractAction("OK")
 							{
+								private static final long serialVersionUID = -6628015175043647980L;
+								
 								public void actionPerformed(final ActionEvent e)
 								{
 									dialog.setVisible(false);
+									dialog.dispose();
 								}
 							});
 							buttons.add(button);
@@ -468,7 +485,7 @@ public class BasicGameMenuBar<CustomGameFrame extends MainGameFrame> extends JMe
 								}
 							});
 							dialog.setVisible(true);
-							dialog.dispose();
+							// dialog.dispose();
 						}
 					});
 					// JOptionPane.showMessageDialog(m_frame, scroll, "Notes", JOptionPane.PLAIN_MESSAGE);
@@ -495,6 +512,8 @@ public class BasicGameMenuBar<CustomGameFrame extends MainGameFrame> extends JMe
 	{
 		final JMenuItem menuFileSave = new JMenuItem(new AbstractAction("Save...")
 		{
+			private static final long serialVersionUID = -8835148465905355231L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				// For some strange reason,
@@ -599,6 +618,8 @@ public class BasicGameMenuBar<CustomGameFrame extends MainGameFrame> extends JMe
 		final boolean isMac = GameRunner.isMac();
 		final JMenuItem leaveGameMenuExit = new JMenuItem(new AbstractAction("Leave Game")
 		{
+			private static final long serialVersionUID = 5438496165424252930L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				m_frame.leaveGame();
@@ -624,6 +645,8 @@ public class BasicGameMenuBar<CustomGameFrame extends MainGameFrame> extends JMe
 		{ // On non-Mac operating systems, we need to manually create an Exit menu item
 			final JMenuItem menuFileExit = new JMenuItem(new AbstractAction("Exit")
 			{
+				private static final long serialVersionUID = 2801394552918725137L;
+				
 				public void actionPerformed(final ActionEvent e)
 				{
 					m_frame.shutdown();
