@@ -23,4 +23,7 @@ public interface IChatChannel extends IChannelSubscribor
 	public void speakerRemoved(final INode node, final long version);
 	
 	public void speakerTagUpdated(final INode node, final Tag tag);
+	
+	// purely here to keep connections open and stop NATs and crap from thinking that our connection is closed when it is not.
+	public void ping();
 }
