@@ -209,9 +209,9 @@ public class ChangeFactory
 	/**
 	 * You don't want to clear the variable first unless you are setting some variable where the setting method is actually adding things to a list rather than overwriting.
 	 */
-	public static Change attachmentPropertyChange(final IAttachment attachment, final Object newValue, final String property, final boolean getRaw, final boolean clearFirst)
+	public static Change attachmentPropertyChange(final IAttachment attachment, final Object newValue, final String property, final boolean getRaw, final boolean resetFirst)
 	{
-		return new ChangeAttachmentChange(attachment, newValue, property, getRaw, clearFirst);
+		return new ChangeAttachmentChange(attachment, newValue, property, getRaw, resetFirst);
 	}
 	
 	/**
@@ -226,9 +226,9 @@ public class ChangeFactory
 	/**
 	 * You don't want to clear the variable first unless you are setting some variable where the setting method is actually adding things to a list rather than overwriting.
 	 */
-	public static Change attachmentPropertyClear(final IAttachment attachment, final String property, final boolean getRaw)
+	public static Change attachmentPropertyReset(final IAttachment attachment, final String property, final boolean getRaw)
 	{
-		return new AttachmentPropertyClear(attachment, property, getRaw);
+		return new AttachmentPropertyReset(attachment, property, getRaw);
 	}
 	
 	public static Change genericTechChange(final TechAttachment attachment, final Boolean value, final String property)
@@ -300,10 +300,9 @@ public class ChangeFactory
 
 
 /**
- * Clears the value from an attachment.
- * You don't want to clear the variable first unless you are setting some variable where the setting method is actually adding things to a list rather than overwriting.
+ * Resets the value to the default value.
  */
-class AttachmentPropertyClear extends Change
+class AttachmentPropertyReset extends Change
 {
 	private static final long serialVersionUID = 9208154387325299072L;
 	private final Attachable m_attachedTo;
@@ -311,10 +310,7 @@ class AttachmentPropertyClear extends Change
 	private final Object m_oldValue;
 	private final String m_property;
 	
-	/**
-	 * You don't want to clear the variable first unless you are setting some variable where the setting method is actually adding things to a list rather than overwriting.
-	 */
-	AttachmentPropertyClear(final IAttachment attachment, final String property, final boolean getRaw)
+	AttachmentPropertyReset(final IAttachment attachment, final String property, final boolean getRaw)
 	{
 		if (attachment == null)
 			throw new IllegalArgumentException("No attachment, property:" + property);
@@ -334,10 +330,7 @@ class AttachmentPropertyClear extends Change
 		}*/
 	}
 	
-	/**
-	 * You don't want to clear the variable first unless you are setting some variable where the setting method is actually adding things to a list rather than overwriting.
-	 */
-	AttachmentPropertyClear(final Attachable attachTo, final String attachmentName, final Object oldValue, final String property)
+	AttachmentPropertyReset(final Attachable attachTo, final String attachmentName, final Object oldValue, final String property)
 	{
 		m_attachmentName = attachmentName;
 		m_attachedTo = attachTo;
@@ -359,24 +352,24 @@ class AttachmentPropertyClear extends Change
 	public void perform(final GameData data)
 	{
 		final IAttachment attachment = m_attachedTo.getAttachment(m_attachmentName);
-		PropertyUtil.clear(m_property, attachment);
+		PropertyUtil.reset(m_property, attachment);
 	}
 	
 	@Override
 	public Change invert()
 	{
-		return new AttachmentPropertyClearUndo(m_attachedTo, m_attachmentName, m_oldValue, m_property);
+		return new AttachmentPropertyResetUndo(m_attachedTo, m_attachmentName, m_oldValue, m_property);
 	}
 	
 	@Override
 	public String toString()
 	{
-		return "AttachmentPropertyClear attached to:" + m_attachedTo + " name:" + m_attachmentName + ", cleared old value:" + m_oldValue;
+		return "AttachmentPropertyClear attached to:" + m_attachedTo + " name:" + m_attachmentName + ", reset old value:" + m_oldValue;
 	}
 }
 
 
-class AttachmentPropertyClearUndo extends Change
+class AttachmentPropertyResetUndo extends Change
 {
 	private static final long serialVersionUID = 5943939650116851332L;
 	private final Attachable m_attachedTo;
@@ -384,10 +377,7 @@ class AttachmentPropertyClearUndo extends Change
 	private final Object m_newValue;
 	private final String m_property;
 	
-	/**
-	 * You don't want to clear the variable first unless you are setting some variable where the setting method is actually adding things to a list rather than overwriting.
-	 */
-	AttachmentPropertyClearUndo(final Attachable attachTo, final String attachmentName, final Object newValue, final String property)
+	AttachmentPropertyResetUndo(final Attachable attachTo, final String attachmentName, final Object newValue, final String property)
 	{
 		m_attachmentName = attachmentName;
 		m_attachedTo = attachTo;
@@ -415,7 +405,7 @@ class AttachmentPropertyClearUndo extends Change
 	@Override
 	public Change invert()
 	{
-		return new AttachmentPropertyClear(m_attachedTo, m_attachmentName, m_newValue, m_property);
+		return new AttachmentPropertyReset(m_attachedTo, m_attachmentName, m_newValue, m_property);
 	}
 	
 	@Override
@@ -1061,7 +1051,7 @@ class AddAttachmentChange extends Change
 		/*if (m_attachment == null || m_originalAttachmentName == null || m_originalAttachable == null || m_attachable == null || m_name == null)
 			throw new IllegalStateException("AddAttachmentChange may not have null arguments");*/
 		m_attachable.addAttachment(m_name, m_attachment);
-		m_attachment.setData(data);
+		// m_attachment.setData(data); // why set the data again?
 		m_attachment.setName(m_name);
 		m_attachment.setAttachedTo(m_attachable);
 	}
@@ -1376,46 +1366,82 @@ class GenericTechChange extends Change
 class AddBattleRecordsChange extends Change
 {
 	private static final long serialVersionUID = -6927678548172402611L;
-	private final Map<Integer, BattleRecords> m_newRecords;
-	private final Map<Integer, BattleRecords> m_oldRecords;
+	private final BattleRecords m_recordsToAdd;
+	private final int m_round;
 	
 	AddBattleRecordsChange(final BattleRecords battleRecords, final GameData data)
 	{
-		// TODO: is this less network traffic, or more network traffic, to have the full records in the change object?
-		m_oldRecords = data.getBattleRecordsList().getBattleRecordsMap();
-		m_newRecords = data.getBattleRecordsList().getBattleRecordsMap();
-		BattleRecordsList.addRecords(m_newRecords, data.getSequence().getRound(), battleRecords);
-		/*if (m_newRecords == null || m_oldRecords == null)
-			throw new IllegalStateException("Records can not be null (most likely caused by improper or impossible serialization): " + m_newRecords + " and " + m_oldRecords);*/
+		m_round = data.getSequence().getRound();
+		m_recordsToAdd = new BattleRecords(battleRecords); // make a copy because this is only done once, and only externally from battle tracker, and the source will be cleared (battle tracker clears out the records each turn)
 	}
 	
-	AddBattleRecordsChange(final Map<Integer, BattleRecords> newList, final Map<Integer, BattleRecords> oldList)
+	AddBattleRecordsChange(final BattleRecords battleRecords, final int round)
 	{
-		m_oldRecords = oldList;
-		m_newRecords = newList;
-		/*if (m_newRecords == null || m_oldRecords == null)
-			throw new IllegalStateException("Records can not be null (most likely caused by improper or impossible serialization): " + m_newRecords + " and " + m_oldRecords);*/
+		m_round = round;
+		m_recordsToAdd = battleRecords; // do not make a copy, this is only called from RemoveBattleRecordsChange, and we make a copy when we perform, so no need for another copy.
 	}
 	
 	@Override
 	protected void perform(final GameData data)
 	{
-		data.getBattleRecordsList().setRecords(m_newRecords);
+		final Map<Integer, BattleRecords> currentRecords = data.getBattleRecordsList().getBattleRecordsMap();
+		BattleRecordsList.addRecords(currentRecords, m_round, new BattleRecords(m_recordsToAdd)); // make a copy because otherwise ours will be cleared when we RemoveBattleRecordsChange
 	}
 	
 	@Override
 	public Change invert()
 	{
-		return new AddBattleRecordsChange(m_oldRecords, m_newRecords);
+		return new RemoveBattleRecordsChange(m_recordsToAdd, m_round);
 	}
 	
 	@Override
 	public String toString()
 	{
 		// This only occurs when serialization went badly, or something can not be serialized.
-		if (m_newRecords == null || m_oldRecords == null)
-			throw new IllegalStateException("Records can not be null (most likely caused by improper or impossible serialization): " + m_newRecords + " and " + m_oldRecords);
-		return "New Battle Record: [" + m_newRecords + "] and Old Battle Record: [" + m_oldRecords + "]";
+		if (m_recordsToAdd == null)
+			throw new IllegalStateException("Records can not be null (most likely caused by improper or impossible serialization): " + m_recordsToAdd);
+		return "Adding Battle Records: " + m_recordsToAdd;
+	}
+}
+
+
+/**
+ * 
+ * @author veqryn
+ * 
+ */
+class RemoveBattleRecordsChange extends Change
+{
+	private static final long serialVersionUID = 3286634991233029854L;
+	private final BattleRecords m_recordsToRemove;
+	private final int m_round;
+	
+	RemoveBattleRecordsChange(final BattleRecords battleRecords, final int round)
+	{
+		m_round = round;
+		m_recordsToRemove = battleRecords; // do not make a copy, this is only called from AddBattleRecordsChange, and we make a copy when we perform, so no need for another copy.
+	}
+	
+	@Override
+	protected void perform(final GameData data)
+	{
+		final Map<Integer, BattleRecords> currentRecords = data.getBattleRecordsList().getBattleRecordsMap();
+		BattleRecordsList.removeRecords(currentRecords, m_round, new BattleRecords(m_recordsToRemove)); // make a copy else we will get a concurrent modification error
+	}
+	
+	@Override
+	public Change invert()
+	{
+		return new AddBattleRecordsChange(m_recordsToRemove, m_round);
+	}
+	
+	@Override
+	public String toString()
+	{
+		// This only occurs when serialization went badly, or something can not be serialized.
+		if (m_recordsToRemove == null)
+			throw new IllegalStateException("Records can not be null (most likely caused by improper or impossible serialization): " + m_recordsToRemove);
+		return "Adding Battle Records: " + m_recordsToRemove;
 	}
 }
 
