@@ -23,15 +23,19 @@ import games.strategy.triplea.Constants;
 import games.strategy.util.PropertyUtil;
 
 /**
- * Contains some utility methods that subclasses can use to make writing attachments easier
+ * Contains some utility methods that subclasses can use to make writing attachments easier.
+ * 
+ * FYI: You may never have a hashmap/linkedhashmap of any other "attachment" within an attachment.
+ * This is because there will be a circular reference from this hashmap -> attachment1 -> playerid -> attachment2 -> hashmap -> attachment1,
+ * and this causes major problems for Java's deserializing.
+ * When deserializing the attachments will not be resolved before their hashcode is taken, resulting in the wrong hashcode and the attachment going in the wrong bucket,
+ * so that a .get(attachment1) will result in a null instead of giving the key for attachment1. So just don't have maps of attachments, in an attachment. Thx, Veqryn.
  * 
  * @author Sean Bridges
  */
-@SuppressWarnings("serial")
-public abstract class DefaultAttachment implements IAttachment
+public abstract class DefaultAttachment extends GameDataComponent implements IAttachment
 {
-	@InternalDoNotExport
-	private GameData m_data;
+	private static final long serialVersionUID = -1985116207387301730L;
 	@InternalDoNotExport
 	private Attachable m_attachedTo;
 	@InternalDoNotExport
@@ -39,8 +43,8 @@ public abstract class DefaultAttachment implements IAttachment
 	
 	protected DefaultAttachment(final String name, final Attachable attachable, final GameData gameData)
 	{
+		super(gameData);
 		setName(name);
-		setData(gameData);
 		setAttachedTo(attachable);
 	}
 	
@@ -109,22 +113,6 @@ public abstract class DefaultAttachment implements IAttachment
 		return PropertyUtil.getPropertyFieldObject(property, this).toString();
 	}
 	
-	public Object getRawPropertyObject(final String property)
-	{
-		return PropertyUtil.getPropertyFieldObject(property, this);
-	}
-	
-	@InternalDoNotExport
-	public void setData(final GameData data)
-	{
-		m_data = data;
-	}
-	
-	protected GameData getData()
-	{
-		return m_data;
-	}
-	
 	public Attachable getAttachedTo()
 	{
 		return m_attachedTo;
@@ -160,6 +148,9 @@ public abstract class DefaultAttachment implements IAttachment
 	@Override
 	public int hashCode()
 	{
+		// System.out.println(toString() + "\n Right now its hash is: " + toString().hashCode() + "\n\n");
+		if (m_attachedTo == null && m_name == null)
+			return 0;
 		return toString().hashCode();
 	}
 	
