@@ -70,9 +70,9 @@ import java.util.concurrent.locks.ReentrantReadWriteLock;
  * @author Sean Bridges
  * @version 1.0
  */
-@SuppressWarnings("serial")
 public class GameData implements java.io.Serializable
 {
+	private static final long serialVersionUID = -2612710634080125728L;
 	public static final String GAME_UUID = "GAME_UUID";
 	private final ReadWriteLock m_readWriteLock = new ReentrantReadWriteLock();
 	private volatile transient boolean m_forceInSwingEventThread = false;
@@ -103,7 +103,7 @@ public class GameData implements java.io.Serializable
 	private IGameLoader m_loader;
 	private final History m_gameHistory = new History(this);
 	private volatile transient boolean m_testLockIsHeld = false;
-	private final List<Tuple<IAttachment, ArrayList<Tuple<String, String>>>> attachmentOrderAndValues = new ArrayList<Tuple<IAttachment, ArrayList<Tuple<String, String>>>>();
+	private final List<Tuple<IAttachment, ArrayList<Tuple<String, String>>>> m_attachmentOrderAndValues = new ArrayList<Tuple<IAttachment, ArrayList<Tuple<String, String>>>>();
 	private final Hashtable<String, TerritoryEffect> m_territoryEffectList = new Hashtable<String, TerritoryEffect>();
 	private final BattleRecordsList m_battleRecordsList = new BattleRecordsList(this);
 	
@@ -477,12 +477,12 @@ public class GameData implements java.io.Serializable
 	
 	public void addToAttachmentOrderAndValues(final Tuple<IAttachment, ArrayList<Tuple<String, String>>> attachmentAndValues)
 	{
-		attachmentOrderAndValues.add(attachmentAndValues);
+		m_attachmentOrderAndValues.add(attachmentAndValues);
 	}
 	
 	public List<Tuple<IAttachment, ArrayList<Tuple<String, String>>>> getAttachmentOrderAndValues()
 	{
-		return attachmentOrderAndValues;
+		return m_attachmentOrderAndValues;
 	}
 	
 	/**
