@@ -30,9 +30,12 @@ import games.strategy.engine.data.properties.StringProperty;
 import games.strategy.engine.delegate.IDelegate;
 import games.strategy.engine.framework.IGameLoader;
 import games.strategy.triplea.Constants;
+import games.strategy.triplea.attatchments.TechAbilityAttachment;
 import games.strategy.triplea.attatchments.TerritoryAttachment;
+import games.strategy.triplea.attatchments.UnitAttachment;
 import games.strategy.triplea.delegate.GenericTechAdvance;
 import games.strategy.triplea.delegate.TechAdvance;
+import games.strategy.triplea.formatter.MyFormatter;
 import games.strategy.util.Tuple;
 import games.strategy.util.Version;
 
@@ -61,7 +64,9 @@ import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
+import org.xml.sax.ErrorHandler;
 import org.xml.sax.SAXException;
+import org.xml.sax.SAXParseException;
 
 /**
  * 
@@ -75,6 +80,7 @@ public class GameParser
 {
 	private static final Class<?>[] SETTER_ARGS = { String.class };
 	private GameData data;
+	private final Collection<SAXParseException> errorsSAX = new ArrayList<SAXParseException>();
 	
 	// public static final String OPTION_SEPARATOR = "<>";
 	private static HashMap<String, String> newClassesForOldNames;
@@ -115,6 +121,15 @@ public class GameParser
 		parseInfo(getSingleChild("info", root));
 		parseGameLoader(getSingleChild("loader", root));
 		parseMinimumEngineVersionNumber(getSingleChild("triplea", root, true));
+		// if we manage to get this far, past the minimum engine version number test, AND we are still good, then check and see if we have any SAX errors we need to show
+		if (!errorsSAX.isEmpty())
+		{
+			for (final SAXParseException error : errorsSAX)
+			{
+				System.err.println("SAXParseException: game: " + (data == null ? "?" : (data.getGameName() == null ? "?" : data.getGameName())) + ", line: " + error.getLineNumber() + ", column: "
+							+ error.getColumnNumber() + ", error: " + error.getMessage());
+			}
+		}
 		parseDiceSides(getSingleChild("diceSides", root, true));
 		final Element playerListNode = getSingleChild("playerList", root);
 		parsePlayerList(playerListNode);
@@ -146,6 +161,8 @@ public class GameParser
 		final Element technology = getSingleChild("technology", root, true);
 		if (technology != null)
 			parseTechnology(technology);
+		else
+			TechAdvance.createDefaultTechAdvances(data);
 		final Element attachmentList = getSingleChild("attatchmentList", root, true);
 		if (attachmentList != null)
 			parseAttachments(attachmentList);
@@ -155,6 +172,12 @@ public class GameParser
 		// set & override default relationships
 		data.getRelationshipTracker().setNullPlayerRelations(); // sets the relationship between all players and the NullPlayer to NullRelation (with archeType War)
 		data.getRelationshipTracker().setSelfRelations(); // sets the relationship for all players with themselfs to the SelfRelation (with archeType Allied)
+		// set default tech attachments (comes after we parse all technologies, parse all attachments, and parse all game options/properties)
+		if (data.getGameLoader() instanceof games.strategy.triplea.TripleA)
+		{
+			checkThatAllUnitsHaveAttachments(data);
+			TechAbilityAttachment.setDefaultTechnologyAttachments(data);
+		}
 		try
 		{
 			validate();
@@ -179,7 +202,7 @@ public class GameParser
 		if (minimumVersion == null)
 			return;
 		final Version mapCompatibleWithTripleaVersion = new Version(((Element) minimumVersion).getAttribute("minimumVersion"));
-		if (mapCompatibleWithTripleaVersion.isGreaterThan(EngineVersion.VERSION))
+		if (mapCompatibleWithTripleaVersion.isGreaterThan(EngineVersion.VERSION, true))
 		{
 			throw new EngineVersionException("Trying to play a map made for a newer version of TripleA. Map named '" + data.getGameName() + "' requires at least TripleA version "
 						+ mapCompatibleWithTripleaVersion.toString());
@@ -213,6 +236,10 @@ public class GameParser
 		{
 			validateAttachments(r);
 		}
+		for (final TechAdvance r : data.getTechnologyFrontier().getTechs())
+		{
+			validateAttachments(r);
+		}
 		// if relationships are used, every player should have a relationship with every other player
 		validateRelationships();
 	}
@@ -249,6 +276,24 @@ public class GameParser
 		final URL url = GameParser.class.getResource("/games/strategy/engine/xml/");
 		final String system = url.toExternalForm();
 		final DocumentBuilder builder = factory.newDocumentBuilder();
+		final ErrorHandler myErrorHandler = new ErrorHandler()
+		{
+			public void fatalError(final SAXParseException exception) throws SAXException
+			{
+				errorsSAX.add(exception);
+			}
+			
+			public void error(final SAXParseException exception) throws SAXException
+			{
+				errorsSAX.add(exception);
+			}
+			
+			public void warning(final SAXParseException exception) throws SAXException
+			{
+				errorsSAX.add(exception);
+			}
+		};
+		builder.setErrorHandler(myErrorHandler);
 		return builder.parse(input, system);
 	}
 	
@@ -337,6 +382,20 @@ public class GameParser
 		return type;
 	}
 	
+	/**
+	 * If mustfind is true and cannot find the technology an exception will be thrown.
+	 */
+	private TechAdvance getTechnology(final Element element, final String attribute, final boolean mustFind) throws GameParseException
+	{
+		final String name = element.getAttribute(attribute);
+		TechAdvance type = data.getTechnologyFrontier().getAdvanceByName(name);
+		if (type == null)
+			type = data.getTechnologyFrontier().getAdvanceByProperty(name);
+		if (type == null && mustFind)
+			throw new GameParseException("Could not find technology. name:" + name);
+		return type;
+	}
+	
 	/**
 	 * If mustfind is true and cannot find the Delegate an exception will be thrown.
 	 */
@@ -993,7 +1052,7 @@ public class GameParser
 		}
 		else
 		{
-			throw new IllegalStateException("Unrecognized property type:" + childName);
+			throw new GameParseException("Unrecognized property type:" + childName);
 		}
 		data.getProperties().addEditableProperty(editableProperty);
 	}
@@ -1181,8 +1240,8 @@ public class GameParser
 	
 	private void parseTechnologies(final Node element)
 	{
-		final TechnologyFrontier techs = data.getTechnologyFrontier();
-		parseTechs(getChildren("techname", element), techs);
+		final TechnologyFrontier allTechs = data.getTechnologyFrontier();
+		parseTechs(getChildren("techname", element), allTechs);
 	}
 	
 	private void parsePlayerTech(final List<Element> elements) throws GameParseException
@@ -1247,7 +1306,7 @@ public class GameParser
 		}
 	}
 	
-	private void parseTechs(final List<Element> elements, final TechnologyFrontier frontier)
+	private void parseTechs(final List<Element> elements, final TechnologyFrontier allTechsFrontier)
 	{
 		for (final Element current : elements)
 		{
@@ -1256,19 +1315,19 @@ public class GameParser
 			TechAdvance ta;
 			if (tech.length() > 0)
 			{
-				ta = new GenericTechAdvance(name, TechAdvance.findDefinedAdvance(tech));
+				ta = new GenericTechAdvance(name, TechAdvance.findDefinedAdvanceAndCreateAdvance(tech, data), data);
 			}
 			else
 			{
 				try
 				{
-					ta = TechAdvance.findDefinedAdvance(name);
+					ta = TechAdvance.findDefinedAdvanceAndCreateAdvance(name, data);
 				} catch (final IllegalArgumentException e)
 				{
-					ta = new GenericTechAdvance(name, null);
+					ta = new GenericTechAdvance(name, null, data);
 				}
 			}
-			frontier.addAdvance(ta);
+			allTechsFrontier.addAdvance(ta);
 		}
 	}
 	
@@ -1308,7 +1367,7 @@ public class GameParser
 				{
 					final Class<?> objectClass = getClassByName(className);
 					if (!IAttachment.class.isAssignableFrom(objectClass))
-						throw new IllegalStateException(className + " does not implement IAttachable");
+						throw new GameParseException(className + " does not implement IAttachable");
 					constructors.put(className, objectClass.getConstructor(IAttachment.attachmentConstructorParameter));
 				} catch (final NoSuchMethodException exception)
 				{
@@ -1377,6 +1436,10 @@ public class GameParser
 		{
 			returnVal = this.getRelationshipType(element, name, true);
 		}
+		else if (type.equals("technology"))
+		{
+			returnVal = getTechnology(element, name, true);
+		}
 		else
 		{
 			throw new GameParseException("Type not found to attach to:" + type);
@@ -1519,4 +1582,17 @@ public class GameParser
 			player.getResources().addResource(resource, quantity);
 		}
 	}
+	
+	private void checkThatAllUnitsHaveAttachments(final GameData data) throws GameParseException
+	{
+		final Collection<UnitType> errors = new ArrayList<UnitType>();
+		for (final UnitType ut : data.getUnitTypeList().getAllUnitTypes())
+		{
+			final UnitAttachment ua = UnitAttachment.get(ut);
+			if (ua == null)
+				errors.add(ut);
+		}
+		if (!errors.isEmpty())
+			throw new GameParseException(data.getGameName() + " does not have unit attachments for: " + MyFormatter.asList(errors));
+	}
 }
