@@ -31,7 +31,7 @@ public interface IAttachment extends Serializable
 	@SuppressWarnings("rawtypes")
 	Class[] attachmentConstructorParameter = new Class[] { String.class, Attachable.class, GameData.class };
 	
-	public void setData(GameData m_data);
+	// public void setData(GameData m_data);
 	
 	/**
 	 * Called after ALL attachments are created. IF an error occurs should throw an exception to halt the parsing.
@@ -133,6 +133,7 @@ public interface IAttachment extends Serializable
 	static final String PROPERTY_UnitAttachment_BOMBARD = "bombard";
 	static final String PROPERTY_UnitAttachment_BOMBING_BONUS = "bombingBonus";
 	static final String PROPERTY_UnitAttachment_BOMBING_MAX_DIE_SIDES = "bombingMaxDieSides";
+	static final String PROPERTY_UnitAttachment_BOMBING_TARGETS = "bombingTargets"; // just added this 2
 	static final String PROPERTY_UnitAttachment_CAN_BE_CAPTURED_ON_ENTERING_BY = "canBeCapturedOnEnteringBy";
 	static final String PROPERTY_UnitAttachment_CAN_BE_DAMAGED = "canBeDamaged";
 	static final String PROPERTY_UnitAttachment_CAN_BE_GIVEN_BY_TERRITORY_TO = "canBeGivenByTerritoryTo";
@@ -328,5 +329,9 @@ public interface IAttachment extends Serializable
 	static final String PROPERTY_TriggerAttachment_UNIT_TYPE = "unitType"; // just added this
 	static final String PROPERTY_TriggerAttachment_VICTORY = "victory";
 	static final String PROPERTY_TriggerAttachment_ACTIVATE_TRIGGER = "activateTrigger"; // just added this 2
+	
+	// TechAbilityAttachment
+	static final String PROPERTY_TechAbilityAttachment_MOVEMENT_BONUS = "movementBonus";
+	
 	*/
 }
