@@ -31,6 +31,7 @@ import java.util.LinkedHashMap;
  */
 public class PlayerID extends NamedAttachable implements NamedUnitHolder, Serializable
 {
+	private static final long serialVersionUID = -2284878450555315947L;
 	private final boolean m_optional;
 	private final UnitCollection m_unitsHeld;
 	private final ResourceCollection m_resources;
@@ -160,11 +161,11 @@ public class PlayerID extends NamedAttachable implements NamedUnitHolder, Serial
 		boolean ownsLand = false;
 		for (final Territory t : data.getMap().getTerritories())
 		{
-			if (t.getUnits().someMatch(new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(this), Matches.unitHasAttackValueOfAtLeast(1), Matches.UnitIsNotStatic(this), Matches.UnitIsLand)))
+			if (t.getUnits().someMatch(new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(this), Matches.unitHasAttackValueOfAtLeast(1), Matches.UnitCanMove, Matches.UnitIsLand)))
 				return true;
 			if (t.getOwner().equals(this))
 				ownsLand = true;
-			if (t.getUnits().someMatch(new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(this), Matches.UnitIsFactoryOrCanProduceUnits)))
+			if (t.getUnits().someMatch(new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(this), Matches.UnitCanProduceUnits)))
 				hasFactory = true;
 			if (ownsLand && hasFactory)
 				return true;
