@@ -25,9 +25,9 @@ import games.strategy.util.IntegerMap;
  * @author Sean Bridges
  * @version 1.0
  */
-@SuppressWarnings("serial")
 public class ResourceCollection extends GameDataComponent
 {
+	private static final long serialVersionUID = -1247795977888113757L;
 	private final IntegerMap<Resource> m_resources = new IntegerMap<Resource>();
 	
 	/**
@@ -185,9 +185,35 @@ public class ResourceCollection extends GameDataComponent
 		}
 	}
 	
+	/**
+	 * Will apply a discount if giving a fractional float (ie: 0.5 = 50% discount). Will round up remainder.
+	 * 
+	 * @param multiplyBy
+	 */
+	public void discount(final float multiplyBy)
+	{
+		multiplyAllValuesBy(multiplyBy, 3);
+	}
+	
+	/**
+	 * Will multiply all values by a given float. Can be used to divide all numbers, if given a fractional float (ie: to divide by 2, use 0.5 as the float)
+	 * 
+	 * @param multiplyBy
+	 * @param roundType
+	 *            (1 = floor, 2 = round, 3 = ceil)
+	 */
+	public void multiplyAllValuesBy(final float multiplyBy, final int roundType)
+	{
+		m_resources.multiplyAllValuesBy(multiplyBy, roundType);
+	}
+	
+	/**
+	 * @param cost
+	 * @return will return 10000 if it can fit more times than 10000. will return Integer MaxValue if cost is zero.
+	 */
 	public int fitsHowOften(final IntegerMap<Resource> cost)
 	{
-		if (cost.size() == 0)
+		if (cost.size() == 0 || (cost.totalValues() <= 0 && cost.isPositive()))
 			return Integer.MAX_VALUE;
 		final ResourceCollection resources = new ResourceCollection(getData(), m_resources);
 		for (int i = 0; i <= 10000; i++)
@@ -200,7 +226,9 @@ public class ResourceCollection extends GameDataComponent
 				return i; // when the subtraction isn't possible it will throw an exception, which means we can return i;
 			}
 		}
-		throw new IllegalArgumentException("Unlimited purchases shouldn't be possible");
+		// throw new IllegalArgumentException("Unlimited purchases shouldn't be possible");
+		// System.out.println("Can purchase more than 10,000 of unit - Unlimited purchases shouldn't be possible");
+		return 10000;
 	}
 	
 	@Override
