@@ -129,10 +129,9 @@ public class GameDataExporter
 						final TechAdvance tech = techs.next();
 						String name = tech.getName();
 						final String cat = tech.getProperty();
-						final Iterator<TechAdvance> definedAdvances = TechAdvance.getDefinedAdvances().iterator();
-						while (definedAdvances.hasNext())
+						for (final String definedName : TechAdvance.s_allPreDefinedTechnologyNames)
 						{
-							if (definedAdvances.next().getName().equals(name))
+							if (definedName.equals(name))
 								name = cat;
 						}
 						returnValue.append("                <tech name=\"" + name + "\"/>\n");
@@ -159,10 +158,9 @@ public class GameDataExporter
 				final String cat = tech.getProperty();
 				// definedAdvances are handled differently by gameparser, they are set in xml with the category as the name but
 				// stored in java with the normal category and name, this causes an xml bug when exporting.
-				final Iterator<TechAdvance> definedAdvances = TechAdvance.getDefinedAdvances().iterator();
-				while (definedAdvances.hasNext())
+				for (final String definedName : TechAdvance.s_allPreDefinedTechnologyNames)
 				{
-					if (definedAdvances.next().getName().equals(name))
+					if (definedName.equals(name))
 						name = cat;
 				}
 				returnValue.append("            <techname name=\"" + name + "\"");
@@ -436,15 +434,26 @@ public class GameDataExporter
 		xmlfile.append("    </attatchmentList>\n");
 	}
 	
-	private String printAttachmentOptionsBasedOnOriginalXML(final ArrayList<Tuple<String, String>> attachmentPlusValues)
+	private String printAttachmentOptionsBasedOnOriginalXML(final ArrayList<Tuple<String, String>> attachmentPlusValues, final IAttachment attachment)
 	{
 		if (attachmentPlusValues.isEmpty())
 			return "";
 		final StringBuffer sb = new StringBuffer("");
+		boolean alreadyHasOccupiedTerrOf = false;
 		for (final Tuple<String, String> current : attachmentPlusValues)
 		{
 			sb.append("            <option name=\"" + current.getFirst() + "\" value=\"" + current.getSecond() + "\"/>\n");
+			if (current.getFirst().equals("occupiedTerrOf"))
+				alreadyHasOccupiedTerrOf = true;
 		}
+		// add occupiedTerrOf until we fix engine to only use originalOwner
+		if (!alreadyHasOccupiedTerrOf && attachment instanceof games.strategy.triplea.attatchments.TerritoryAttachment)
+		{
+			final games.strategy.triplea.attatchments.TerritoryAttachment ta = (games.strategy.triplea.attatchments.TerritoryAttachment) attachment;
+			if (ta.getOriginalOwner() != null)
+				sb.append("            <option name=\"occupiedTerrOf\" value=\"" + ta.getOriginalOwner().getName() + "\"/>\n");
+		}
+		
 		return sb.toString();
 	}
 	
@@ -462,7 +471,7 @@ public class GameDataExporter
 			}
 			else
 			{
-				attachmentOptions = printAttachmentOptionsBasedOnOriginalXML(attachmentPlusValues.getSecond());
+				attachmentOptions = printAttachmentOptionsBasedOnOriginalXML(attachmentPlusValues.getSecond(), attachment);
 			}
 			final NamedAttachable attachTo = (NamedAttachable) attachment.getAttachedTo();
 			// TODO: keep this list updated
@@ -479,6 +488,8 @@ public class GameDataExporter
 				type = "resource";
 			if (attachTo.getClass().equals(RelationshipType.class))
 				type = "relationship";
+			if (TechAdvance.class.isAssignableFrom(attachTo.getClass()))
+				type = "technology";
 			if (type.equals(""))
 				throw new AttachmentExportException("no attachmentType known for " + attachTo.getClass().getCanonicalName());
 			if (attachmentOptions.length() > 0)
