@@ -30,7 +30,7 @@ import javax.swing.SwingUtilities;
  * Presents a clickable label with the currently selected color, through which a color swatch panel is accessable to change the color.
  * 
  * @author Lane O.B. Schwartz
- * @version $LastChangedDate: 2011-12-08 20:15:09 +0800 (Thu, 08 Dec 2011) $
+ * @version $LastChangedDate: 2012-04-19 18:13:58 +0800 (Thu, 19 Apr 2012) $
  */
 public class ColorProperty extends AEditableProperty
 {
@@ -60,9 +60,10 @@ public class ColorProperty extends AEditableProperty
 	
 	public JComponent getEditorComponent()
 	{
-		@SuppressWarnings("serial")
 		final JLabel label = new JLabel(" ")
 		{
+			private static final long serialVersionUID = 3833935337866905836L;
+			
 			@Override
 			public void paintComponent(final Graphics g)
 			{
