@@ -59,6 +59,13 @@ public class ClientGame extends AbstractGame
 				m_data.getHistory().getHistoryWriter().addChange(aChange);
 			}
 			
+			public void startHistoryEvent(final String event, final Object renderingData)
+			{
+				startHistoryEvent(event);
+				if (renderingData != null)
+					setRenderingData(renderingData);
+			}
+			
 			public void startHistoryEvent(final String event)
 			{
 				m_data.getHistory().getHistoryWriter().startEvent(event);
@@ -69,7 +76,7 @@ public class ClientGame extends AbstractGame
 				m_data.getHistory().getHistoryWriter().addChildToEvent(new EventChild(text, renderingData));
 			}
 			
-			public void setRenderingData(final Object renderingData)
+			protected void setRenderingData(final Object renderingData)
 			{
 				m_data.getHistory().getHistoryWriter().setRenderingData(renderingData);
 			}
@@ -143,7 +150,7 @@ public class ClientGame extends AbstractGame
 					m_data.releaseReadLock();
 				}
 				m_gamePlayers.put(player, gp);
-				m_remoteMessenger.unregisterRemote(ServerGame.getRemoteName(gp.getID(), m_data));
+				m_remoteMessenger.unregisterRemote(ServerGame.getRemoteName(gp.getPlayerID(), m_data));
 				m_remoteMessenger.unregisterRemote(ServerGame.getRemoteRandomName(player));
 			}
 		} catch (final RuntimeException re)
