@@ -137,6 +137,13 @@ public class ServerGame extends AbstractGame
 				}
 			}
 			
+			public void startHistoryEvent(final String event, final Object renderingData)
+			{
+				startHistoryEvent(event);
+				if (renderingData != null)
+					setRenderingData(renderingData);
+			}
+			
 			public void startHistoryEvent(final String event)
 			{
 				assertCorrectCaller();
@@ -149,7 +156,7 @@ public class ServerGame extends AbstractGame
 				m_data.getHistory().getHistoryWriter().addChildToEvent(new EventChild(text, renderingData));
 			}
 			
-			public void setRenderingData(final Object renderingData)
+			protected void setRenderingData(final Object renderingData)
 			{
 				assertCorrectCaller();
 				m_data.getHistory().getHistoryWriter().setRenderingData(renderingData);
@@ -326,7 +333,7 @@ public class ServerGame extends AbstractGame
 			while (localPlayersIter.hasNext())
 			{
 				final IGamePlayer gp = localPlayersIter.next();
-				m_remoteMessenger.unregisterRemote(getRemoteName(gp.getID(), m_data));
+				m_remoteMessenger.unregisterRemote(getRemoteName(gp.getPlayerID(), m_data));
 			}
 			final Iterator<IDelegate> delegateIter = m_data.getDelegateList().iterator();
 			while (delegateIter.hasNext())
