@@ -22,6 +22,7 @@ import games.strategy.engine.framework.GameRunner;
 import games.strategy.engine.framework.ui.NewGameChooser;
 import games.strategy.engine.framework.ui.NewGameChooserEntry;
 import games.strategy.engine.framework.ui.NewGameChooserModel;
+import games.strategy.triplea.ai.Dynamix_AI.Dynamix_AI;
 
 import java.awt.Component;
 import java.io.File;
@@ -60,6 +61,10 @@ public class GameSelectorModel extends Observable
 	
 	public void load(final NewGameChooserEntry entry)
 	{
+		// we don't want to load anything if we are an older jar, because otherwise the user may get confused on which version of triplea they are using right now,
+		// and then start a game with an older jar when they should be using the newest jar (we want user to be using the normal default [newest] triplea.jar for new games)
+		if (GameRunner.areWeOldExtraJar())
+			return;
 		m_fileName = entry.getLocation();
 		setGameData(entry.getGameData());
 		final Preferences prefs = Preferences.userNodeForPackage(this.getClass());
@@ -101,8 +106,11 @@ public class GameSelectorModel extends Observable
 			{
 				newData = manager.loadGame(file);
 			}
-			m_fileName = file.getName();
-			setGameData(newData);
+			if (newData != null)
+			{
+				m_fileName = file.getName();
+				setGameData(newData);
+			}
 		} catch (final EngineVersionException e)
 		{
 			System.out.println(e.getMessage());
@@ -222,6 +230,8 @@ public class GameSelectorModel extends Observable
 	
 	public void loadDefaultGame(final Component ui)
 	{
+		// clear out dynamix's properties (this ended up being the best place to put it, as we have definitely left a game at this point)
+		Dynamix_AI.clearCachedGameDataAll();
 		loadDefaultGame(ui, false);
 	}
 	
@@ -244,18 +254,25 @@ public class GameSelectorModel extends Observable
 		NewGameChooserEntry selectedGame = null;
 		// just in case flush doesn't work, we still force it again here
 		final String userPreferredDefaultGameURI = (forceFactoryDefault ? DEFAULT_GAME_URI : prefs.get(DEFAULT_GAME_URI_PREF, DEFAULT_GAME_URI));
-		if (!forceFactoryDefault && userPreferredDefaultGameURI != null && userPreferredDefaultGameURI.length() > 0)
+		// we don't want to load a game file by default that is not within the map folders we can load. (ie: if a previous version of triplea was using running a game within its root folder, we shouldn't open it)
+		final String user = GameRunner.getUserRootFolder().toURI().toString();
+		final String root = GameRunner.getRootFolder().toURI().toString();
+		if (!forceFactoryDefault && userPreferredDefaultGameURI != null && userPreferredDefaultGameURI.length() > 0
+					&& (userPreferredDefaultGameURI.indexOf(root) != -1 || userPreferredDefaultGameURI.indexOf(user) != -1))
 		{
 			// if the user has a preferred URI, then we load it, and don't bother parsing or doing anything with the whole game model list
+			boolean refreshedAlready = false;
 			try
 			{
 				final URI defaultURI = new URI(userPreferredDefaultGameURI);
 				selectedGame = new NewGameChooserEntry(defaultURI);
 			} catch (final Exception e)
 			{
-				System.out.println(userPreferredDefaultGameURI + " could not be loaded.");
-				loadDefaultGame(ui, true);
-				return;
+				NewGameChooser.refreshNewGameChooserModel();
+				refreshedAlready = true;
+				selectedGame = selectByName(ui, forceFactoryDefault);
+				if (selectedGame == null)
+					return;
 			}
 			if (!selectedGame.isGameDataLoaded())
 			{
@@ -264,18 +281,26 @@ public class GameSelectorModel extends Observable
 					selectedGame.fullyParseGameData();
 				} catch (final GameParseException e)
 				{
+					if (!refreshedAlready)
+					{
+						NewGameChooser.refreshNewGameChooserModel();
+						refreshedAlready = true;
+					}
 					loadDefaultGame(ui, true);
 					return;
 				}
 			}
 			// since we are not forceFactoryDefault, and since we are loading purely from the URI without loading the new game chooser model, we might as well refresh it in a separate thread
-			new Thread(new Runnable()
+			if (!refreshedAlready)
 			{
-				public void run()
+				new Thread(new Runnable()
 				{
-					NewGameChooser.refreshNewGameChooserModel();
-				}
-			}).start();
+					public void run()
+					{
+						NewGameChooser.refreshNewGameChooserModel();
+					}
+				}).start();
+			}
 		}
 		else
 		{
@@ -284,37 +309,47 @@ public class GameSelectorModel extends Observable
 				// we would rather have their game data refreshed after leaving a game
 				NewGameChooser.refreshNewGameChooserModel();
 			}
-			// just in case flush doesn't work, we still force it again here
-			final String userPreferredDefaultGameName = (forceFactoryDefault ? DEFAULT_GAME_NAME : prefs.get(DEFAULT_GAME_NAME_PREF, DEFAULT_GAME_NAME));
-			final NewGameChooserModel model = NewGameChooser.getNewGameChooserModel();
-			selectedGame = model.findByName(userPreferredDefaultGameName);
+			selectedGame = selectByName(ui, forceFactoryDefault);
 			if (selectedGame == null)
-			{
-				selectedGame = model.findByName(DEFAULT_GAME_NAME);
-			}
-			if (selectedGame == null && model.size() > 0)
-			{
-				selectedGame = model.get(0);
-			}
-			if (selectedGame == null)
-			{
 				return;
-			}
-			if (!selectedGame.isGameDataLoaded())
-			{
-				try
-				{
-					selectedGame.fullyParseGameData();
-				} catch (final GameParseException e)
-				{
-					// Load real default game...
-					selectedGame.delayParseGameData();
-					model.removeEntry(selectedGame);
-					loadDefaultGame(ui, true);
-					return;
-				}
-			}
 		}
 		load(selectedGame);
 	}
+	
+	private NewGameChooserEntry selectByName(final Component ui, final boolean forceFactoryDefault)
+	{
+		NewGameChooserEntry selectedGame = null;
+		final Preferences prefs = Preferences.userNodeForPackage(this.getClass());
+		// just in case flush doesn't work, we still force it again here
+		final String userPreferredDefaultGameName = (forceFactoryDefault ? DEFAULT_GAME_NAME : prefs.get(DEFAULT_GAME_NAME_PREF, DEFAULT_GAME_NAME));
+		final NewGameChooserModel model = NewGameChooser.getNewGameChooserModel();
+		selectedGame = model.findByName(userPreferredDefaultGameName);
+		if (selectedGame == null)
+		{
+			selectedGame = model.findByName(DEFAULT_GAME_NAME);
+		}
+		if (selectedGame == null && model.size() > 0)
+		{
+			selectedGame = model.get(0);
+		}
+		if (selectedGame == null)
+		{
+			return null;
+		}
+		if (!selectedGame.isGameDataLoaded())
+		{
+			try
+			{
+				selectedGame.fullyParseGameData();
+			} catch (final GameParseException e)
+			{
+				// Load real default game...
+				selectedGame.delayParseGameData();
+				model.removeEntry(selectedGame);
+				loadDefaultGame(ui, true);
+				return null;
+			}
+		}
+		return selectedGame;
+	}
 }
