@@ -28,6 +28,7 @@ import javax.swing.SwingUtilities;
 
 public class LocalSetupPanel extends SetupPanel implements Observer
 {
+	private static final long serialVersionUID = 2284030734590389060L;
 	private final GameSelectorModel m_gameSelectorModel;
 	private final List<LocalPlayerComboBoxSelector> m_playerTypes = new ArrayList<LocalPlayerComboBoxSelector>();
 	
@@ -76,7 +77,8 @@ public class LocalSetupPanel extends SetupPanel implements Observer
 		m_gameSelectorModel.addObserver(this);
 	}
 	
-	private void setWidgetActivation()
+	@Override
+	public void setWidgetActivation()
 	{
 	}
 	
