@@ -23,6 +23,9 @@ import java.io.FileInputStream;
 import java.io.IOException;
 import java.net.MalformedURLException;
 import java.net.URL;
+import java.util.ArrayList;
+import java.util.Iterator;
+import java.util.List;
 import java.util.Properties;
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
@@ -40,6 +43,7 @@ public class MetaSetupPanel extends SetupPanel
 {
 	private static final long serialVersionUID = 3926503672972937677L;
 	private static final Logger s_logger = Logger.getLogger(MetaSetupPanel.class.getName());
+	private static String s_serverPropertiesName = "server_" + EngineVersion.VERSION.toString() + ".properties";
 	private JButton m_startLocal;
 	private JButton m_startPBEM;
 	private JButton m_hostGame;
@@ -224,7 +228,7 @@ public class MetaSetupPanel extends SetupPanel
 	private void about()
 	{
 		final String text = "<h2>TripleA</h2>" + "<p><b>Engine Version:</b> " + games.strategy.engine.EngineVersion.VERSION.toString()
-					+ "<br><b>Authors:</b> Sean Bridges, and many others. Current Developers: Veqryn (Chris Duncan), Edwin, Frigoref, Qwertgold."
+					+ "<br><b>Authors:</b> Sean Bridges, and many others. Current Developers: Veqryn (Chris Duncan)."
 					+ "<br>TripleA is an open-source game engine, allowing people to play many different games and maps." + "<br>For more information please visit:<br>"
 					+ "<b>Site:</b> <a hlink='http://triplea.sourceforge.net/'>http://triplea.sourceforge.net/</a><br>"
 					+ "<b>Forum:</b> <a hlink='http://triplea.sourceforge.net/mywiki/Forum'>http://triplea.sourceforge.net/mywiki/Forum</a><br>"
@@ -265,7 +269,9 @@ public class MetaSetupPanel extends SetupPanel
 		LobbyServerProperties props = getLobbyServerProperties();
 		if (props == null)
 		{
-			props = new LobbyServerProperties(null, -1, "Server Lookup failed, try again later", null);
+			props = new LobbyServerProperties(null, -1, "<html>Server Lookup failed, try again later. "
+						+ "<br>Either TripleA could not reach the internet, or the server host is down. "
+						+ "<br>Please make sure you are using the latest version of TripleA: http://triplea.sourceforge.net/</html>", null);
 		}
 		// for development, ignore what we read,
 		// connect instead to localhost
@@ -301,18 +307,26 @@ public class MetaSetupPanel extends SetupPanel
 				throw new IllegalStateException(e);
 			}
 		}
-		final URL serverPropsURL;
-		try
+		final List<URL> serverPropsList = getServerLookupURL();
+		if (serverPropsList == null || serverPropsList.isEmpty())
+			throw new IllegalStateException("No Server Properties Found!");
+		final Iterator<URL> iter = serverPropsList.iterator();
+		LobbyServerProperties props = null;
+		while (iter.hasNext() && (props == null || props.getPort() == -1))
 		{
-			serverPropsURL = getServerLookupURL();
-			if (s_logger.isLoggable(Level.FINE))
-			{
-				s_logger.log(Level.FINE, "lobby url:" + serverPropsURL);
-			}
-		} catch (final MalformedURLException e)
+			final URL serverPropertiesURL = iter.next();
+			// System.out.println("Trying to connect to: " + serverPropertiesURL);
+			props = contactServerForLobbyServerProperties(serverPropertiesURL);
+			// System.out.println("Finished connecting to: " + serverPropertiesURL);
+		}
+		return props;
+	}
+	
+	private LobbyServerProperties contactServerForLobbyServerProperties(final URL serverPropsURL)
+	{
+		if (s_logger.isLoggable(Level.FINE))
 		{
-			e.printStackTrace();
-			throw new IllegalStateException(e);
+			s_logger.log(Level.FINE, "lobby url:" + serverPropsURL);
 		}
 		// sourceforge sometimes takes a long while
 		// to return results
@@ -372,18 +386,51 @@ public class MetaSetupPanel extends SetupPanel
 	 * we look for a system property triplea.lobby.server.lookup.url, if that is not defined
 	 * we default to looking on sourceforge, with a version dependent url
 	 */
-	private URL getServerLookupURL() throws MalformedURLException
+	private List<URL> getServerLookupURL()
 	{
-		// step 2 check for a system property
-		// step 3 default
-		final URL serverPropsURL;
-		final String defaultURL = "http://triplea.sourceforge.net/lobby/server_" + EngineVersion.VERSION.toString() + ".properties";
-		serverPropsURL = new URL(System.getProperties().getProperty("triplea.lobby.server.lookup.url", defaultURL));
-		return serverPropsURL;
+		final List<URL> rVal = new ArrayList<URL>();
+		final String propertyString = System.getProperties().getProperty("triplea.lobby.server.lookup.url");
+		if (propertyString != null)
+		{
+			try
+			{
+				final URL propertyURL = new URL(propertyString);
+				rVal.add(propertyURL);
+			} catch (final MalformedURLException e)
+			{
+				e.printStackTrace();
+			}
+			// if we set it as a system property, then we don't want to try other ones, only this one.
+			return rVal;
+		}
+		try
+		{
+			// first is the default, rest are backups. Do NOT add too many backups, as we want to maintain control over all of them.
+			rVal.add(new URL("http://triplea.sourceforge.net/lobby/" + s_serverPropertiesName));
+			// rVal.add(new URL("http://tripleamaps.sourceforge.net/lobby/" + s_serverPropertiesName));
+			rVal.add(new URL("http://www.tripleawarclub.org/lobby/" + s_serverPropertiesName));
+		} catch (final MalformedURLException e)
+		{
+			e.printStackTrace();
+		}
+		return rVal;
 	}
 	
-	private void setWidgetActivation()
+	@Override
+	public void setWidgetActivation()
 	{
+		if (m_model == null || m_model.getGameSelectorModel() == null || m_model.getGameSelectorModel().getGameData() == null)
+		{
+			m_startLocal.setEnabled(false);
+			m_startPBEM.setEnabled(false);
+			m_hostGame.setEnabled(false);
+		}
+		else
+		{
+			m_startLocal.setEnabled(true);
+			m_startPBEM.setEnabled(true);
+			m_hostGame.setEnabled(true);
+		}
 	}
 	
 	@Override
