@@ -18,6 +18,8 @@
  */
 package games.strategy.engine.framework.startup.ui;
 
+import games.strategy.engine.framework.GameRunner;
+import games.strategy.engine.framework.GameRunner2;
 import games.strategy.ui.IntTextField;
 
 import java.awt.BorderLayout;
@@ -48,6 +50,7 @@ import javax.swing.JTextField;
  */
 public class ServerOptions extends JDialog
 {
+	private static final long serialVersionUID = -9074816386666798281L;
 	private JTextField m_nameField;
 	private IntTextField m_portField;
 	private JPasswordField m_passwordField;
@@ -190,10 +193,16 @@ public class ServerOptions extends JDialog
 		m_passwordField.setEnabled(m_requirePasswordCheckBox.isSelected());
 		final Color backGround = m_passwordField.isEnabled() ? m_portField.getBackground() : getBackground();
 		m_passwordField.setBackground(backGround);
+		if (GameRunner.areWeOldExtraJar() && System.getProperty(GameRunner2.TRIPLEA_SERVER_PROPERTY, "false").equalsIgnoreCase("true"))
+		{
+			setNameEditable(false);
+		}
 	}
 	
 	private final Action m_okAction = new AbstractAction("OK")
 	{
+		private static final long serialVersionUID = -479176526245850045L;
+		
 		public void actionPerformed(final ActionEvent e)
 		{
 			setVisible(false);
@@ -202,6 +211,8 @@ public class ServerOptions extends JDialog
 	};
 	private final Action m_cancelAction = new AbstractAction("Cancel")
 	{
+		private static final long serialVersionUID = 6591074291179846696L;
+		
 		public void actionPerformed(final ActionEvent e)
 		{
 			setVisible(false);
