@@ -54,9 +54,9 @@ import javax.swing.JScrollPane;
 import javax.swing.JTextField;
 import javax.swing.SwingUtilities;
 
-@SuppressWarnings("serial")
 public class ServerSetupPanel extends SetupPanel implements IRemoteModelListener
 {
+	private static final long serialVersionUID = -2849872641665561807L;
 	private final ServerModel m_model;
 	private JTextField m_portField;
 	private JTextField m_addressField;
@@ -203,7 +203,8 @@ public class ServerSetupPanel extends SetupPanel implements IRemoteModelListener
 	{
 	}
 	
-	private void setWidgetActivation()
+	@Override
+	public void setWidgetActivation()
 	{
 	}
 	
@@ -405,7 +406,7 @@ public class ServerSetupPanel extends SetupPanel implements IRemoteModelListener
 		rVal.add(new BootPlayerAction(this, m_model.getMessenger()));
 		rVal.add(new BanPlayerAction(this, m_model.getMessenger()));
 		rVal.add(new MutePlayerAction(this, m_model.getMessenger()));
-		rVal.add(new SetPasswordAction(this, (ClientLoginValidator) m_model.getMessenger().getLoginValidator()));
+		rVal.add(new SetPasswordAction(this, m_lobbyWatcher, (ClientLoginValidator) m_model.getMessenger().getLoginValidator()));
 		if (m_lobbyWatcher != null && m_lobbyWatcher.isActive())
 		{
 			rVal.add(new EditGameCommentAction(m_lobbyWatcher, ServerSetupPanel.this));
