@@ -28,6 +28,8 @@ import org.xml.sax.SAXParseException;
 
 public class NewGameChooserModel extends DefaultListModel
 {
+	private static final long serialVersionUID = -2044689419834812524L;
+	
 	public NewGameChooserModel()
 	{
 		populate();
@@ -65,7 +67,7 @@ public class NewGameChooserModel extends DefaultListModel
 		return rVal;
 	}
 	
-	private static File getDefaultMapsDir()
+	public static File getDefaultMapsDir()
 	{
 		return new File(GameRunner.getRootFolder(), "maps");
 	}
