@@ -1,12 +1,12 @@
 package games.strategy.engine.lobby.client.login;
 
 import java.io.ByteArrayInputStream;
-import java.io.IOException;
 import java.net.URL;
 import java.util.Properties;
 import java.util.logging.Level;
 import java.util.logging.Logger;
 
+import org.apache.commons.httpclient.HostConfiguration;
 import org.apache.commons.httpclient.HttpClient;
 import org.apache.commons.httpclient.methods.GetMethod;
 
@@ -70,7 +70,11 @@ public class LobbyServerProperties
 	{
 		final Properties props = new Properties();
 		final HttpClient client = new HttpClient();
-		client.getHostConfiguration().setHost(url.getHost());
+		final HostConfiguration config = client.getHostConfiguration();
+		config.setHost(url.getHost());
+		// add the proxy
+		// GameRunner2.addProxy(config); // since lobby actually uses a different port, we should not use a proxy for the properties file until we allow the lobby to accept proxy connections
+		
 		final GetMethod method = new GetMethod(url.getPath());
 		// pretend to be ie
 		method.setRequestHeader("User-Agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0)");
@@ -79,7 +83,7 @@ public class LobbyServerProperties
 			client.executeMethod(method);
 			final String propsString = method.getResponseBodyAsString();
 			props.load(new ByteArrayInputStream(propsString.getBytes()));
-		} catch (final IOException ioe)
+		} catch (final Exception ioe)
 		{
 			s_logger.log(Level.WARNING, ioe.getMessage(), ioe);
 			props.put("ERROR_MESSAGE", ioe.getMessage());
