@@ -53,6 +53,7 @@ import javax.swing.SpinnerNumberModel;
 
 public class LobbyFrame extends JFrame
 {
+	private static final long serialVersionUID = -388371674076362572L;
 	private final LobbyClient m_client;
 	private final ChatMessagePanel m_chatMessagePanel;
 	
@@ -133,6 +134,8 @@ public class LobbyFrame extends JFrame
 		final List<Action> rVal = new ArrayList<Action>();
 		rVal.add(new AbstractAction("Boot " + clickedOn.getName())
 		{
+			private static final long serialVersionUID = -114807409972939767L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				if (!confirm("Boot " + clickedOn.getName()))
@@ -144,19 +147,23 @@ public class LobbyFrame extends JFrame
 		});
 		rVal.add(new AbstractAction("Ban Player")
 		{
+			private static final long serialVersionUID = -762959953993138146L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				final List<String> banTypes = new ArrayList<String>();
-				banTypes.add("IP Address");
-				banTypes.add("Mac Address");
-				banTypes.add("Username");
-				banTypes.add("IP, Mac");
-				banTypes.add("Name, IP");
-				banTypes.add("Name, Mac");
+				// too many choices is confusing our mods, just give them 3 choices: name, everything, or cancel.
+				// banTypes.add("IP Address");
+				// banTypes.add("Mac Address");
+				banTypes.add("Username only");
+				// banTypes.add("IP, Mac");
+				// banTypes.add("Name, IP");
+				// banTypes.add("Name, Mac");
 				banTypes.add("Name, IP, Mac");
 				banTypes.add("Cancel");
-				final int resultBT = JOptionPane.showOptionDialog(LobbyFrame.this, "Select the type of ban: ", "Select Ban Type", JOptionPane.OK_CANCEL_OPTION, JOptionPane.QUESTION_MESSAGE, null,
-							banTypes.toArray(), banTypes.toArray()[7]);
+				final int resultBT = JOptionPane.showOptionDialog(LobbyFrame.this,
+							"<html>Select the type of ban: <br>Please consult other admins before banning longer than 1 day. <br>And please remember to report this ban.</html>",
+							"Select Ban Type", JOptionPane.OK_CANCEL_OPTION, JOptionPane.QUESTION_MESSAGE, null, banTypes.toArray(), banTypes.toArray()[banTypes.size() - 1]);
 				if (resultBT < 0)
 					return;
 				final String selectedBanType = (String) banTypes.toArray()[resultBT];
@@ -172,7 +179,7 @@ public class LobbyFrame extends JFrame
 				timeUnits.add("Forever");
 				timeUnits.add("Cancel");
 				final int resultTU = JOptionPane.showOptionDialog(LobbyFrame.this, "Select the unit of measurement: ", "Select Timespan Unit", JOptionPane.OK_CANCEL_OPTION,
-							JOptionPane.QUESTION_MESSAGE, null, timeUnits.toArray(), timeUnits.toArray()[7]);
+							JOptionPane.QUESTION_MESSAGE, null, timeUnits.toArray(), timeUnits.toArray()[timeUnits.size() - 1]);
 				if (resultTU < 0)
 					return;
 				final String selectedTimeUnit = (String) timeUnits.toArray()[resultTU];
@@ -220,19 +227,23 @@ public class LobbyFrame extends JFrame
 		});
 		rVal.add(new AbstractAction("Mute Player")
 		{
+			private static final long serialVersionUID = -4909591469708896401L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				final List<String> muteTypes = new ArrayList<String>();
-				muteTypes.add("IP Address");
-				muteTypes.add("Mac Address");
-				muteTypes.add("Username");
-				muteTypes.add("IP, Mac");
-				muteTypes.add("Name, IP");
-				muteTypes.add("Name, Mac");
+				// too many choices is confusing our mods, just give them 3 choices: name, everything, or cancel.
+				// muteTypes.add("IP Address");
+				// muteTypes.add("Mac Address");
+				muteTypes.add("Username only");
+				// muteTypes.add("IP, Mac");
+				// muteTypes.add("Name, IP");
+				// muteTypes.add("Name, Mac");
 				muteTypes.add("Name, IP, Mac");
 				muteTypes.add("Cancel");
-				final int resultMT = JOptionPane.showOptionDialog(LobbyFrame.this, "Select the type of mute: ", "Select Mute Type", JOptionPane.OK_CANCEL_OPTION, JOptionPane.QUESTION_MESSAGE, null,
-							muteTypes.toArray(), muteTypes.toArray()[7]);
+				final int resultMT = JOptionPane.showOptionDialog(LobbyFrame.this,
+							"<html>Select the type of mute: <br>Please consult other admins before muting longer than 1 day.</html>",
+							"Select Mute Type", JOptionPane.OK_CANCEL_OPTION, JOptionPane.QUESTION_MESSAGE, null, muteTypes.toArray(), muteTypes.toArray()[muteTypes.size() - 1]);
 				if (resultMT < 0)
 					return;
 				final String selectedMuteType = (String) muteTypes.toArray()[resultMT];
@@ -248,7 +259,7 @@ public class LobbyFrame extends JFrame
 				timeUnits.add("Forever");
 				timeUnits.add("Cancel");
 				final int resultTU = JOptionPane.showOptionDialog(LobbyFrame.this, "Select the unit of measurement: ", "Select Timespan Unit", JOptionPane.OK_CANCEL_OPTION,
-							JOptionPane.QUESTION_MESSAGE, null, timeUnits.toArray(), timeUnits.toArray()[7]);
+							JOptionPane.QUESTION_MESSAGE, null, timeUnits.toArray(), timeUnits.toArray()[timeUnits.size() - 1]);
 				if (resultTU < 0)
 					return;
 				final String selectedTimeUnit = (String) timeUnits.toArray()[resultTU];
@@ -294,10 +305,12 @@ public class LobbyFrame extends JFrame
 		});
 		rVal.add(new AbstractAction("Quick Mute")
 		{
+			private static final long serialVersionUID = -6078034907743976564L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				final JLabel label = new JLabel("How many minutes should this player be muted?");
-				final JSpinner spinner = new JSpinner(new SpinnerNumberModel(10, 0, 60 * 24 * 7, 1));
+				final JSpinner spinner = new JSpinner(new SpinnerNumberModel(10, 0, 60 * 24 * 2, 1));
 				final JPanel panel = new JPanel();
 				panel.setLayout(new BoxLayout(panel, BoxLayout.X_AXIS));
 				panel.add(label);
@@ -320,6 +333,8 @@ public class LobbyFrame extends JFrame
 		});
 		rVal.add(new AbstractAction("Show player information")
 		{
+			private static final long serialVersionUID = -4065242030670291163L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				final String text = controller.getInformationOn(clickedOn);
@@ -331,6 +346,8 @@ public class LobbyFrame extends JFrame
 		});
 		rVal.add(new AbstractAction("Reset password")
 		{
+			private static final long serialVersionUID = -7778103570619930775L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				final String newPassword = JOptionPane.showInputDialog(JOptionPane.getFrameForComponent(LobbyFrame.this), "Enter new password");
