@@ -32,9 +32,12 @@ import javax.swing.table.AbstractTableModel;
 
 public class LobbyGameTableModel extends AbstractTableModel
 {
+	private static final long serialVersionUID = 6399458368730633993L;
+	
+	
 	enum Column
 	{
-		Host, Name, Round, Players, Started, Status, Comments, GUID
+		Host, Name, GV, Round, Players, PW, EV, Started, Status, Comments, GUID
 	}
 	
 	private final IMessenger m_messenger;
@@ -171,6 +174,12 @@ public class LobbyGameTableModel extends AbstractTableModel
 				return description.getGameName();
 			case Players:
 				return description.getPlayerCount();
+			case PW:
+				return (description.getPassworded() ? "Y" : "");
+			case GV:
+				return description.getGameVersion();
+			case EV:
+				return description.getEngineVersion();
 			case Status:
 				return description.getStatus();
 			case Comments:
