@@ -26,5 +26,11 @@ public interface IRandomStats extends IRemote
 {
 	public static final RemoteName RANDOM_STATS_REMOTE_NAME = new RemoteName("games.strategy.engine.random.RandomStats.RANDOM_STATS_REMOTE_NAME", IRandomStats.class);
 	
-	public RandomStatsDetails getRandomStats();
+	
+	public enum DiceType
+	{
+		COMBAT, BOMBING, NONCOMBAT, TECH, ENGINE
+	}
+	
+	public RandomStatsDetails getRandomStats(final int diceSides);
 }
