@@ -30,7 +30,7 @@ import java.io.Serializable;
  * Responsible for checking for a winner in a game of King's Table.
  * 
  * @author Lane Schwartz
- * @version $LastChangedDate: 2012-01-18 19:52:58 +0800 (Wed, 18 Jan 2012) $
+ * @version $LastChangedDate: 2012-07-25 16:15:00 +0800 (Wed, 25 Jul 2012) $
  */
 public class EndTurnDelegate extends BaseDelegate// implements IEndTurnDelegate
 {
@@ -47,7 +47,6 @@ public class EndTurnDelegate extends BaseDelegate// implements IEndTurnDelegate
 		{
 			// CountDownLatch waitToLeaveGame = new CountDownLatch(1);
 			signalGameOver(winner.getName() + " wins!");// , waitToLeaveGame);
-			bridge.stopGameSequence();
 			// gameOver = true;
 			/*
 			try {
@@ -102,6 +101,7 @@ public class EndTurnDelegate extends BaseDelegate// implements IEndTurnDelegate
 		final IKingsTableDisplay display = (IKingsTableDisplay) m_bridge.getDisplayChannelBroadcaster();
 		display.setStatus(status);
 		display.setGameOver();
+		m_bridge.stopGameSequence();
 	}
 	
 	/**
@@ -168,9 +168,9 @@ public class EndTurnDelegate extends BaseDelegate// implements IEndTurnDelegate
 }
 
 
-@SuppressWarnings("serial")
 class KingsTableEndTurnExtendedDelegateState implements Serializable
 {
+	private static final long serialVersionUID = 1054956757425820238L;
 	Serializable superState;
 	// add other variables here:
 }
