@@ -27,7 +27,7 @@ import java.io.Serializable;
  * Responsible for initializing a game of King's Table.
  * 
  * @author Lane Schwartz
- * @version $LastChangedDate: 2012-01-17 20:15:42 +0800 (Tue, 17 Jan 2012) $
+ * @version $LastChangedDate: 2012-04-19 18:13:58 +0800 (Thu, 19 Apr 2012) $
  */
 public class InitializationDelegate extends BaseDelegate
 {
@@ -111,9 +111,9 @@ public class InitializationDelegate extends BaseDelegate
 }
 
 
-@SuppressWarnings("serial")
 class KingsTableInitializationExtendedDelegateState implements Serializable
 {
+	private static final long serialVersionUID = -3197858177470882249L;
 	Serializable superState;
 	// add other variables here:
 }
