@@ -38,7 +38,7 @@ import java.util.HashSet;
  * Responsible for performing a move in a game of King's Table.
  * 
  * @author Lane Schwartz
- * @version $LastChangedDate: 2012-01-18 19:52:58 +0800 (Wed, 18 Jan 2012) $
+ * @version $LastChangedDate: 2012-05-28 17:03:10 +0800 (Mon, 28 May 2012) $
  */
 @AutoSave(beforeStepStart = false, afterStepEnd = true)
 public class PlayDelegate extends BaseDelegate implements IPlayDelegate
@@ -309,8 +309,7 @@ public class PlayDelegate extends BaseDelegate implements IPlayDelegate
 	{
 		final Collection<Unit> units = start.getUnits().getUnits();
 		final String transcriptText = player.getName() + " moved from " + start.getName() + " to " + end.getName();
-		m_bridge.getHistoryWriter().startEvent(transcriptText);
-		m_bridge.getHistoryWriter().setRenderingData(units);
+		m_bridge.getHistoryWriter().startEvent(transcriptText, units);
 		final Change removeUnit = ChangeFactory.removeUnits(start, units);
 		final Change removeStartOwner = ChangeFactory.changeOwner(start, PlayerID.NULL_PLAYERID);
 		final Change addUnit = ChangeFactory.addUnits(end, units);
@@ -502,9 +501,9 @@ public class PlayDelegate extends BaseDelegate implements IPlayDelegate
 }
 
 
-@SuppressWarnings("serial")
 class KingsTablePlayExtendedDelegateState implements Serializable
 {
+	private static final long serialVersionUID = 8227905090355825327L;
 	Serializable superState;
 	// add other variables here:
 }
