@@ -5,13 +5,12 @@
  * (at your option) any later version.
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-
 package games.strategy.net.nio;
 
 import java.io.ByteArrayOutputStream;
@@ -20,25 +19,22 @@ import java.io.ByteArrayOutputStream;
  * Povide access to the raw buffer.
  * 
  * @author sgb
- *
+ * 
  */
 class ByteArrayOutputStream2 extends ByteArrayOutputStream
 {
-
-
-    
-    public ByteArrayOutputStream2()
-    {
-        super();
-    }
-
-    public ByteArrayOutputStream2(int size)
-    {
-        super(size);
-    }
-
-    public byte[] getBuffer()
-    {
-        return buf;
-    }
+	public ByteArrayOutputStream2()
+	{
+		super();
+	}
+	
+	public ByteArrayOutputStream2(final int size)
+	{
+		super(size);
+	}
+	
+	public byte[] getBuffer()
+	{
+		return buf;
+	}
 }
