@@ -38,6 +38,7 @@ public interface Constants
 	public static final String UNIT_ATTACHMENT_NAME = "unitAttatchment";
 	public static final String INF_ATTACHMENT_NAME = "infAttatchment";
 	public static final String TECH_ATTACHMENT_NAME = "techAttatchment";
+	public static final String TECH_ABILITY_ATTACHMENT_NAME = "techAbilityAttachment";
 	public static final String RESOURCE_ATTACHMENT_NAME = "resourceAttatchment";
 	public static final String TERRITORY_ATTACHMENT_NAME = "territoryAttatchment";
 	public static final String RULES_ATTACHMENT_NAME = "rulesAttatchment";
@@ -89,8 +90,7 @@ public interface Constants
 	public static final String TRANSPORT_UNLOAD_RESTRICTED = "Transport Restricted Unload";
 	public static final String RANDOM_AA_CASUALTIES = "Random AA Casualties";
 	public static final String ROLL_AA_INDIVIDUALLY = "Roll AA Individually";
-	public static final String LIMIT_SBR_DAMAGE_TO_PRODUCTION = "Limit SBR Damage To Factory Production";
-	public static final String LIMIT_ROCKET_DAMAGE_TO_PRODUCTION = "Limit SBR Damage To Factory Production";
+	public static final String LIMIT_ROCKET_AND_SBR_DAMAGE_TO_PRODUCTION = "Limit SBR Damage To Factory Production";
 	public static final String SBR_VICTORY_POINTS = "SBR Victory Points";
 	public static final String ROCKET_ATTACK_PER_FACTORY_RESTRICTED = "Rocket Attack Per Factory Restricted";
 	public static final String LIMIT_SBR_DAMAGE_PER_TURN = "Limit SBR Damage Per Turn";
@@ -214,6 +214,14 @@ public interface Constants
 	public static final String KAMIKAZE_SUICIDE_ATTACKS_DONE_BY_CURRENT_TERRITORY_OWNER = "Kamikaze Suicide Attacks Done By Current Territory Owner";
 	public static final String FORCE_AA_ATTACKS_FOR_LAST_STEP_OF_FLY_OVER = "Force AA Attacks For Last Step Of Fly Over";
 	public static final String PARATROOPERS_CAN_ATTACK_DEEP_INTO_ENEMY_TERRITORY = "Paratroopers Can Attack Deep Into Enemy Territory";
+	public static final String USE_BOMBING_MAX_DICE_SIDES_AND_BONUS = "Use Bombing Max Dice Sides And Bonus";
+	public static final String CONVOY_BLOCKADES_ROLL_DICE_FOR_COST = "Convoy Blockades Roll Dice For Cost";
+	public static final String AIRBORNE_ATTACKS_ONLY_IN_EXISTING_BATTLES = "Airborne Attacks Only In Existing Battles";
+	public static final String AIRBORNE_ATTACKS_ONLY_IN_ENEMY_TERRITORIES = "Airborne Attacks Only In Enemy Territories";
+	public static final String SUBS_CAN_END_NONCOMBAT_MOVE_WITH_ENEMIES = "Subs Can End NonCombat Move With Enemies";
+	public static final String REMOVE_ALL_TECH_TOKENS_AT_END_OF_TURN = "Remove All Tech Tokens At End Of Turn";
+	public static final String KAMIKAZE_SUICIDE_ATTACKS_ONLY_WHERE_BATTLES_ARE = "Kamikaze Suicide Attacks Only Where Battles Are";
+	public static final String SUBMARINES_PREVENT_UNESCORTED_AMPHIBIOUS_ASSAULTS = "Submarines Prevent Unescorted Amphibious Assaults";
 	
 	// relationships stuff (Edwin, with help from Veqryn and Frig)
 	public static final String RELATIONSHIP_TYPE_SELF = "self_relation";
