@@ -180,20 +180,12 @@ public class Properties implements Constants
 	}
 	
 	/*
-	 * Limit the damage caused by each bomber on Strategic Bomb Raids to
+	 * Limit the damage caused by each bomber on rockets and Strategic Bomb Raids to
 	 * production of territory
 	 */
-	public static boolean getLimitSBRDamageToProduction(final GameData data)
+	public static boolean getLimitRocketAndSBRDamageToProduction(final GameData data)
 	{
-		return data.getProperties().get(LIMIT_SBR_DAMAGE_TO_PRODUCTION, false);
-	}
-	
-	/*
-	 * Limit the damage caused on Rocket attacks to production of territory
-	 */
-	public static boolean getLimitRocketDamageToProduction(final GameData data)
-	{
-		return data.getProperties().get(LIMIT_ROCKET_DAMAGE_TO_PRODUCTION, false);
+		return data.getProperties().get(LIMIT_ROCKET_AND_SBR_DAMAGE_TO_PRODUCTION, false);
 	}
 	
 	/*
@@ -813,6 +805,46 @@ public class Properties implements Constants
 		return data.getProperties().get(PARATROOPERS_CAN_ATTACK_DEEP_INTO_ENEMY_TERRITORY, false);
 	}
 	
+	public static boolean getUseBombingMaxDiceSidesAndBonus(final GameData data)
+	{
+		return data.getProperties().get(USE_BOMBING_MAX_DICE_SIDES_AND_BONUS, false);
+	}
+	
+	public static boolean getConvoyBlockadesRollDiceForCost(final GameData data)
+	{
+		return data.getProperties().get(CONVOY_BLOCKADES_ROLL_DICE_FOR_COST, false);
+	}
+	
+	public static boolean getAirborneAttacksOnlyInExistingBattles(final GameData data)
+	{
+		return data.getProperties().get(AIRBORNE_ATTACKS_ONLY_IN_EXISTING_BATTLES, false);
+	}
+	
+	public static boolean getAirborneAttacksOnlyInEnemyTerritories(final GameData data)
+	{
+		return data.getProperties().get(AIRBORNE_ATTACKS_ONLY_IN_ENEMY_TERRITORIES, false);
+	}
+	
+	public static boolean getSubsCanEndNonCombatMoveWithEnemies(final GameData data)
+	{
+		return data.getProperties().get(SUBS_CAN_END_NONCOMBAT_MOVE_WITH_ENEMIES, false);
+	}
+	
+	public static boolean getRemoveAllTechTokensAtEndOfTurn(final GameData data)
+	{
+		return data.getProperties().get(REMOVE_ALL_TECH_TOKENS_AT_END_OF_TURN, false);
+	}
+	
+	public static boolean getKamikazeSuicideAttacksOnlyWhereBattlesAre(final GameData data)
+	{
+		return data.getProperties().get(KAMIKAZE_SUICIDE_ATTACKS_ONLY_WHERE_BATTLES_ARE, false);
+	}
+	
+	public static boolean getSubmarinesPreventUnescortedAmphibiousAssaults(final GameData data)
+	{
+		return data.getProperties().get(SUBMARINES_PREVENT_UNESCORTED_AMPHIBIOUS_ASSAULTS, false);
+	}
+	
 	private Properties()
 	{
 	}
