@@ -22,7 +22,7 @@ import games.strategy.engine.data.Territory;
 import games.strategy.engine.data.Unit;
 import games.strategy.engine.data.UnitType;
 import games.strategy.engine.data.annotations.GameProperty;
-import games.strategy.triplea.attatchments.TechAttachment;
+import games.strategy.triplea.attatchments.TechAbilityAttachment;
 import games.strategy.triplea.attatchments.TerritoryAttachment;
 import games.strategy.triplea.attatchments.UnitAttachment;
 import games.strategy.triplea.delegate.Matches;
@@ -63,9 +63,12 @@ public class TripleAUnit extends Unit
 	public static final String UNLOADED_AMPHIBIOUS = "wasAmphibious";
 	public static final String ORIGINATED_FROM = "originatedFrom";
 	public static final String WAS_SCRAMBLED = "wasScrambled";
+	public static final String MAX_SCRAMBLE_COUNT = "maxScrambleCount";
 	public static final String WAS_IN_AIR_BATTLE = "wasInAirBattle";
 	public static final String UNIT_DAMAGE = "unitDamage";
 	public static final String DISABLED = "disabled";
+	public static final String LAUNCHED = "launched";
+	public static final String AIRBORNE = "airborne";
 	
 	private TripleAUnit m_transportedBy = null; // the transport that is currently transporting us
 	private List<Unit> m_unloaded = Collections.emptyList(); // the units we have unloaded this turn
@@ -86,9 +89,13 @@ public class TripleAUnit extends Unit
 	
 	private Territory m_originatedFrom = null; // the territory this unit started in (for use with scrambling)
 	private boolean m_wasScrambled = false;
+	private int m_maxScrambleCount = -1;
 	private boolean m_wasInAirBattle = false;
 	private boolean m_disabled = false;
 	
+	private int m_launched = 0; // the number of airborne units launched by this unit this turn
+	private boolean m_airborne = false; // was this unit airborne and launched this turn
+	
 	public static TripleAUnit get(final Unit u)
 	{
 		return (TripleAUnit) u;
@@ -120,18 +127,32 @@ public class TripleAUnit extends Unit
 			if (t.getUnits().getUnits().contains(this))
 			{
 				return t.getUnits().getMatches(new Match<Unit>()
-				{
-					@Override
-					public boolean match(final Unit o)
 					{
-						return TripleAUnit.get(o).getTransportedBy() == TripleAUnit.this;
-					}
-				});
+						@Override
+						public boolean match(final Unit o)
+						{
+							return TripleAUnit.get(o).getTransportedBy() == TripleAUnit.this;
+						}
+					});
 			}
 		}
 		return Collections.emptyList();
 	}
 	
+	public List<Unit> getTransporting(final Collection<Unit> transportedUnitsPossible)
+	{
+		// we don't store the units we are transporting
+		// rather we look at the transported by property of units
+		return Match.getMatches(transportedUnitsPossible, new Match<Unit>()
+			{
+				@Override
+				public boolean match(final Unit o)
+				{
+					return TripleAUnit.get(o).getTransportedBy() == TripleAUnit.this;
+				}
+			});
+	}
+	
 	public List<Unit> getUnloaded()
 	{
 		return m_unloaded;
@@ -284,6 +305,39 @@ public class TripleAUnit extends Unit
 		m_wasScrambled = Boolean.valueOf(value.booleanValue());
 	}
 	
+	public int getMaxScrambleCount()
+	{
+		return m_maxScrambleCount;
+	}
+	
+	@GameProperty(xmlProperty = false, gameProperty = true, adds = false)
+	public void setMaxScrambleCount(final Integer value)
+	{
+		m_maxScrambleCount = value;
+	}
+	
+	public int getLaunched()
+	{
+		return m_launched;
+	}
+	
+	@GameProperty(xmlProperty = false, gameProperty = true, adds = false)
+	public void setLaunched(final Integer value)
+	{
+		m_launched = value;
+	}
+	
+	public boolean getAirborne()
+	{
+		return m_airborne;
+	}
+	
+	@GameProperty(xmlProperty = false, gameProperty = true, adds = false)
+	public void setAirborne(final Boolean value)
+	{
+		m_airborne = value;
+	}
+	
 	@GameProperty(xmlProperty = false, gameProperty = true, adds = false)
 	public void setWasInAirBattle(final Boolean value)
 	{
@@ -347,7 +401,7 @@ public class TripleAUnit extends Unit
 	 */
 	public int getHowMuchMoreDamageCanThisUnitTake(final Unit u, final Territory t)
 	{
-		if (!Matches.UnitIsFactoryOrCanBeDamaged.match(u))
+		if (!Matches.UnitCanBeDamaged.match(u))
 			return 0;
 		final TripleAUnit taUnit = (TripleAUnit) u;
 		if (games.strategy.triplea.Properties.getSBRAffectsUnitProduction(u.getData()))
@@ -372,7 +426,7 @@ public class TripleAUnit extends Unit
 	 */
 	public int getHowMuchDamageCanThisUnitTakeTotal(final Unit u, final Territory t)
 	{
-		if (!Matches.UnitIsFactoryOrCanBeDamaged.match(u))
+		if (!Matches.UnitCanBeDamaged.match(u))
 			return -1;
 		final UnitAttachment ua = UnitAttachment.get(u.getType());
 		final TerritoryAttachment ta = TerritoryAttachment.get(t);
@@ -395,7 +449,7 @@ public class TripleAUnit extends Unit
 			}
 			else
 			{
-				if (Matches.UnitIsFactoryOrCanProduceUnits.match(u))
+				if (Matches.UnitCanProduceUnits.match(u))
 				{
 					if (ua.getCanProduceXUnits() < 0)
 					{
@@ -463,7 +517,7 @@ public class TripleAUnit extends Unit
 	{
 		if (u == null)
 			return 0;
-		if (!Matches.UnitIsFactoryOrCanProduceUnits.match(u))
+		if (!Matches.UnitCanProduceUnits.match(u))
 			return 0;
 		int productionCapacity = 0;
 		final UnitAttachment ua = UnitAttachment.get(u.getType());
@@ -512,12 +566,8 @@ public class TripleAUnit extends Unit
 				productionCapacity = 1;
 		}
 		// Increase production if have industrial technology
-		boolean isIncreasedFactoryProduction = false;
-		final TechAttachment techa = (TechAttachment) player.getAttachment(Constants.TECH_ATTACHMENT_NAME);
-		if (techa != null && techa.getIncreasedFactoryProduction())
-			isIncreasedFactoryProduction = true;
-		if (isIncreasedFactoryProduction && territoryProduction > 2)
-			productionCapacity += 2;
+		if (territoryProduction >= TechAbilityAttachment.getMinimumTerritoryValueForProductionBonus(player, data))
+			productionCapacity += TechAbilityAttachment.getProductionBonus(u.getType(), player, data);
 		if (mathMaxZero)
 			return Math.max(0, productionCapacity);
 		else
