@@ -26,9 +26,11 @@ import games.strategy.triplea.ai.Dynamix_AI.Code.Place;
 import games.strategy.triplea.ai.Dynamix_AI.Code.Purchase;
 import games.strategy.triplea.ai.Dynamix_AI.Code.SelectCasualties;
 import games.strategy.triplea.ai.Dynamix_AI.Code.Tech;
+import games.strategy.triplea.ai.Dynamix_AI.CommandCenter.CachedCalculationCenter;
 import games.strategy.triplea.ai.Dynamix_AI.CommandCenter.CachedInstanceCenter;
 import games.strategy.triplea.ai.Dynamix_AI.CommandCenter.FactoryCenter;
 import games.strategy.triplea.ai.Dynamix_AI.CommandCenter.GlobalCenter;
+import games.strategy.triplea.ai.Dynamix_AI.CommandCenter.KnowledgeCenter;
 import games.strategy.triplea.ai.Dynamix_AI.CommandCenter.ReconsiderSignalCenter;
 import games.strategy.triplea.ai.Dynamix_AI.CommandCenter.StatusCenter;
 import games.strategy.triplea.ai.Dynamix_AI.CommandCenter.StrategyCenter;
@@ -116,19 +118,42 @@ public class Dynamix_AI extends AbstractAI implements IGamePlayer, ITripleaPlaye
 		return s_dAIInstances;
 	}
 	
-	public static void Initialize(final TripleAFrame frame)
+	/**
+	 * Only call after we have left or quit a game.
+	 */
+	public static void clearCachedGameDataAll()
 	{
-		UI.Initialize(frame); // Must be done first
-		DUtils.Log(Level.FINE, "Initializing Dynamix_AI...");
-		GlobalCenter.Initialize(CachedInstanceCenter.CachedGameData);
+		CachedInstanceCenter.clearCachedDelegatesAndData();
+		UI.clearCachedInstances();
+		clearStaticInstances();
+	}
+	
+	/**
+	 * Call before starting a game, and after leaving.
+	 */
+	public static void clearStaticInstances()
+	{
+		GlobalCenter.clearStaticInstances();
 		FactoryCenter.ClearStaticInstances();
+		KnowledgeCenter.ClearStaticInstances();
 		TacticalCenter.ClearStaticInstances();
 		StatusCenter.ClearStaticInstances();
 		ThreatInvalidationCenter.ClearStaticInstances();
 		ReconsiderSignalCenter.ClearStaticInstances();
 		StrategyCenter.ClearStaticInstances();
-		CachedInstanceCenter.CachedBattleTracker = DelegateFinder.battleDelegate(CachedInstanceCenter.CachedGameData).getBattleTracker();
 		UnitGroup.ClearBufferedMoves();
+		DOddsCalculator.clearCachedStaticData();
+		CachedCalculationCenter.clearCachedStaticData();
+		UnitGroup.clearCachedInstances();
+	}
+	
+	public static void Initialize(final TripleAFrame frame)
+	{
+		UI.Initialize(frame); // Must be done first
+		DUtils.Log(Level.FINE, "Initializing Dynamix_AI...");
+		clearStaticInstances();
+		GlobalCenter.Initialize(CachedInstanceCenter.CachedGameData);
+		CachedInstanceCenter.CachedBattleTracker = DelegateFinder.battleDelegate(CachedInstanceCenter.CachedGameData).getBattleTracker();
 	}
 	
 	public static void ShowSettingsWindow()
@@ -355,12 +380,12 @@ public class Dynamix_AI extends AbstractAI implements IGamePlayer, ITripleaPlaye
 		return null;
 	}*/
 
-	public HashMap<Territory, Collection<Unit>> scrambleUnitsQuery(final Territory scrambleTo, final Map<Territory, Tuple<Integer, Collection<Unit>>> possibleScramblers)
+	public HashMap<Territory, Collection<Unit>> scrambleUnitsQuery(final Territory scrambleTo, final Map<Territory, Tuple<Collection<Unit>, Collection<Unit>>> possibleScramblers)
 	{
 		return null;
 	}
 	
-	public Territory retreatQuery(final GUID battleID, final boolean submerge, final Collection<Territory> possibleTerritories, final String message)
+	public Territory retreatQuery(final GUID battleID, final boolean submerge, final Territory battleTerritory, final Collection<Territory> possibleTerritories, final String message)
 	{
 		DUtils.Log(Level.FINE, "Retreat query starting. Battle Ter: {0} Possible retreat locations: {1}", getBattleTerritory(), possibleTerritories);
 		final GameData data = getPlayerBridge().getGameData();
@@ -370,15 +395,15 @@ public class Dynamix_AI extends AbstractAI implements IGamePlayer, ITripleaPlaye
 		// PossibleTerritories will be empty if subs move in our sub ter, and our sub is 'attacking'
 		if (battleTer == null || possibleTerritories.isEmpty())
 			return null; // Don't submerge
-		final List<Unit> attackers = battleTer.getUnits().getMatches(Matches.unitIsOwnedBy(getID()));
-		final List<Unit> defenders = battleTer.getUnits().getMatches(Matches.unitIsEnemyOf(data, getID()));
+		final List<Unit> attackers = battleTer.getUnits().getMatches(Matches.unitIsOwnedBy(getPlayerID()));
+		final List<Unit> defenders = battleTer.getUnits().getMatches(Matches.unitIsEnemyOf(data, getPlayerID()));
 		final AggregateResults simulatedAttack = DUtils.GetBattleResults(attackers, defenders, battleTer, data, DSettings.LoadSettings().CA_Retreat_determinesIfAIShouldRetreat, true);
 		float chanceNeededToContinue = .6F;
-		if (TacticalCenter.get(data, getID()).BattleRetreatChanceAssignments.containsKey(battleTer))
+		if (TacticalCenter.get(data, getPlayerID()).BattleRetreatChanceAssignments.containsKey(battleTer))
 		{
 			DUtils.Log(Level.FINER, "Found specific battle retreat chance assignment for territory '{0}'. Retreat Chance: {1}", battleTer,
 						TacticalCenter.get(data, player).BattleRetreatChanceAssignments.get(battleTer));
-			chanceNeededToContinue = TacticalCenter.get(data, getID()).BattleRetreatChanceAssignments.get(battleTer);
+			chanceNeededToContinue = TacticalCenter.get(data, getPlayerID()).BattleRetreatChanceAssignments.get(battleTer);
 			if (simulatedAttack.getAttackerWinPercent() < chanceNeededToContinue)
 			{
 				// Calculate best retreat ter and retreat to it
@@ -442,24 +467,22 @@ public class Dynamix_AI extends AbstractAI implements IGamePlayer, ITripleaPlaye
 	
 	public boolean shouldBomberBomb(final Territory territory)
 	{
-		final List<Unit> nonBomberAttackingUnits = Match.getMatches(territory.getUnits().getUnits(), new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(getWhoAmI()), Matches.UnitIsNotStrategicBomber));
+		final List<Unit> nonBomberAttackingUnits = Match.getMatches(territory.getUnits().getUnits(),
+					new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(getPlayerID()), Matches.UnitIsNotStrategicBomber));
 		if (nonBomberAttackingUnits.isEmpty())
 			return true;
 		else
 			return false;
 	}
 	
-	public Unit whatShouldBomberBomb(final Territory territory, final Collection<Unit> units)
+	public Unit whatShouldBomberBomb(final Territory territory, final Collection<Unit> potentialTargets, final Collection<Unit> bombers)
 	{
-		// wisc, the ai is only asked this question after it is asked if it should bomb at all or not. so this only is asked if the ai says yes to bombing. therefore, we should never return null, as there is a chance we are both attacking and bombing.
-		if (units == null || units.isEmpty())
+		if (potentialTargets == null || potentialTargets.isEmpty())
 			return null;
-		if (!Match.someMatch(units, Matches.UnitIsFactoryOrCanProduceUnits))
-			return units.iterator().next();
-		if (Match.someMatch(units, Matches.UnitIsFactory))
-			return Match.getMatches(units, Matches.UnitIsFactory).iterator().next();
-		else
-			return Match.getMatches(units, Matches.UnitCanProduceUnits).iterator().next();
+		final Collection<Unit> factories = Match.getMatches(potentialTargets, Matches.UnitCanProduceUnitsAndCanBeDamaged);
+		if (factories.isEmpty())
+			return potentialTargets.iterator().next();
+		return factories.iterator().next();
 	}
 	
 	public int[] selectFixedDice(final int numRolls, final int hitAt, final boolean hitOnlyIfEquals, final String message, final int diceSides)
