@@ -211,8 +211,8 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 		final Territory capitol = TerritoryAttachment.getCapital(player, data);
 		if (capitol == null || !capitol.getOwner().equals(player))
 			return;
-		List<Unit> unitsToLoad = capitol.getUnits().getMatches(Matches.UnitIsFactoryOrIsInfrastructure.invert());
-		unitsToLoad = Match.getMatches(unitsToLoad, Matches.unitIsOwnedBy(getWhoAmI()));
+		List<Unit> unitsToLoad = capitol.getUnits().getMatches(Matches.UnitIsInfrastructure.invert());
+		unitsToLoad = Match.getMatches(unitsToLoad, Matches.unitIsOwnedBy(getPlayerID()));
 		for (final Territory neighbor : data.getMap().getNeighbors(capitol))
 		{
 			if (!neighbor.isWater())
@@ -527,8 +527,8 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 			moveOfType.add(Matches.unitIsOwnedBy(player));
 			moveOfType.add(Matches.UnitIsNotAA);
 			// we can never move factories
-			moveOfType.add(Matches.UnitIsNotStatic(player));
-			moveOfType.add(Matches.UnitIsNotFactory);
+			moveOfType.add(Matches.UnitCanMove);
+			moveOfType.add(Matches.UnitIsNotInfrastructure);
 			moveOfType.add(Matches.UnitIsLand);
 			final CompositeMatchAnd<Territory> moveThrough = new CompositeMatchAnd<Territory>(new InverseMatch<Territory>(Matches.TerritoryIsImpassable), new InverseMatch<Territory>(
 						Matches.TerritoryIsNeutralButNotWater), Matches.TerritoryIsLand);
@@ -633,10 +633,16 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 		final List<Territory> enemyOwned = Match.getMatches(data.getMap().getTerritories(), walkInto);
 		Collections.sort(enemyOwned, new Comparator<Territory>()
 		{
-			private final Map<Territory, Integer> randomInts = new HashMap<Territory, Integer>();
+			// private final Map<Territory, Integer> randomInts = new HashMap<Territory, Integer>();
 			
 			public int compare(final Territory o1, final Territory o2)
 			{
+				if (o1 == o2 || (o1 == null && o2 == null))
+					return 0;
+				if (o1 == null)
+					return 1;
+				if (o2 == null)
+					return -1;
 				if (o1.equals(o2))
 					return 0;
 				final TerritoryAttachment ta1 = TerritoryAttachment.get(o1);
@@ -649,20 +655,28 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 					if (!ta1.isCapital() && ta2.isCapital())
 						return 1; // -1;
 				}
-				final boolean factoryInT1 = o1.getUnits().someMatch(Matches.UnitIsFactory);
-				final boolean factoryInT2 = o2.getUnits().someMatch(Matches.UnitIsFactory);
-				// next take territories with factories
+				final boolean factoryInT1 = o1.getUnits().someMatch(Matches.UnitCanProduceUnits);
+				final boolean factoryInT2 = o2.getUnits().someMatch(Matches.UnitCanProduceUnits);
+				// next take territories which can produce
 				if (factoryInT1 && !factoryInT2)
 					return -1; // 1;
 				if (!factoryInT1 && factoryInT2)
 					return 1; // -1;
+				final boolean infrastructureInT1 = o1.getUnits().someMatch(Matches.UnitIsInfrastructure);
+				final boolean infrastructureInT2 = o2.getUnits().someMatch(Matches.UnitIsInfrastructure);
+				// next take territories with infrastructure
+				if (infrastructureInT1 && !infrastructureInT2)
+					return -1; // 1;
+				if (!infrastructureInT1 && infrastructureInT2)
+					return 1; // -1;
 				// randomness is a better guide than any other metric
 				// sort the remaining randomly
-				if (!randomInts.containsKey(o1))
+				/*if (!randomInts.containsKey(o1))
 					randomInts.put(o1, (int) (Math.random() * 1000));
 				if (!randomInts.containsKey(o2))
 					randomInts.put(o2, (int) (Math.random() * 1000));
-				return randomInts.get(o1) - randomInts.get(o2);
+				return randomInts.get(o1) - randomInts.get(o2);*/
+				return 0;
 			}
 		});
 		final List<Territory> isWaterTerr = Utils.onlyWaterTerr(data, enemyOwned);
@@ -683,8 +697,8 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 					Collections.sort(unitsSortedByCost, AIUtils.getCostComparator());
 					for (final Unit unit : unitsSortedByCost)
 					{
-						final Match<Unit> match = new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(player), Matches.UnitIsLand, Matches.UnitIsNotFactory, Matches.UnitIsNotStatic(player),
-									Matches.UnitIsNotAA);
+						final Match<Unit> match = new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(player), Matches.UnitIsLand, Matches.UnitIsNotInfrastructure, Matches.UnitCanMove,
+									Matches.UnitIsNotAA, Matches.UnitCanNotMoveDuringCombatMove.invert());
 						if (!unitsAlreadyMoved.contains(unit) && match.match(unit))
 						{
 							moveRoutes.add(data.getMap().getRoute(attackFrom, enemy));
@@ -725,8 +739,9 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 					}
 				});
 				attackable.add(Matches.UnitIsNotAA);
-				attackable.add(Matches.UnitIsNotStatic(player));
-				attackable.add(Matches.UnitIsNotFactory);
+				attackable.add(Matches.UnitCanMove);
+				attackable.add(Matches.UnitIsNotInfrastructure);
+				attackable.add(Matches.UnitCanNotMoveDuringCombatMove.invert());
 				attackable.add(Matches.UnitIsNotSea);
 				final Set<Territory> dontMoveFrom = new HashSet<Territory>();
 				// find our strength that we can attack with
@@ -773,7 +788,7 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 	
 	private void populateBomberCombat(final GameData data, final List<Collection<Unit>> moveUnits, final List<Route> moveRoutes, final PlayerID player)
 	{
-		final Match<Territory> enemyFactory = Matches.territoryHasEnemyFactory(getPlayerBridge().getGameData(), player);
+		final Match<Territory> enemyFactory = Matches.territoryIsEnemyNonNeutralAndHasEnemyUnitMatching(getPlayerBridge().getGameData(), player, Matches.UnitCanProduceUnitsAndCanBeDamaged);
 		final Match<Unit> ownBomber = new CompositeMatchAnd<Unit>(Matches.UnitIsStrategicBomber, Matches.unitIsOwnedBy(player));
 		for (final Territory t : data.getMap().getTerritories())
 		{
@@ -829,9 +844,9 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 				for (final ProductionRule rule : rules)
 				{
 					final UnitType results = (UnitType) rule.getResults().keySet().iterator().next();
-					if (Matches.UnitTypeIsSea.match(results) || Matches.UnitTypeIsAir.match(results) || Matches.UnitTypeIsFactoryOrIsInfrastructure.match(results)
+					if (Matches.UnitTypeIsSea.match(results) || Matches.UnitTypeIsAir.match(results) || Matches.UnitTypeIsInfrastructure.match(results)
 								|| Matches.UnitTypeIsAAforAnything.match(results)
-								|| Matches.UnitTypeHasMaxBuildRestrictions.match(results) || Matches.UnitTypeConsumesUnitsOnCreation.match(results) || Matches.unitTypeIsStatic(player).match(results))
+								|| Matches.UnitTypeHasMaxBuildRestrictions.match(results) || Matches.UnitTypeConsumesUnitsOnCreation.match(results) || Matches.UnitTypeIsStatic(player).match(results))
 					{
 						continue;
 					}
@@ -877,8 +892,8 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 		final List<ProductionRule> rules = player.getProductionFrontier().getRules();
 		final IntegerMap<ProductionRule> purchase = new IntegerMap<ProductionRule>();
 		List<RepairRule> rrules = Collections.emptyList();
-		final CompositeMatch<Unit> ourFactories = new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(player), Matches.UnitIsFactory);
-		final List<Territory> rfactories = Utils.findUnitTerr(data, player, ourFactories);
+		final CompositeMatch<Unit> ourFactories = new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(player), Matches.UnitCanProduceUnits);
+		final List<Territory> rfactories = Match.getMatches(Utils.findUnitTerr(data, player, ourFactories), Matches.isTerritoryOwnedBy(player));
 		if (player.getRepairFrontier() != null && games.strategy.triplea.Properties.getSBRAffectsUnitProduction(data)) // figure out if anything needs to be repaired
 		{
 			rrules = player.getRepairFrontier().getRules();
@@ -893,7 +908,7 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 			int maxProduction = 0;
 			for (final Territory fixTerr : rfactories)
 			{
-				if (!Matches.territoryHasOwnedFactory(data, player).match(fixTerr))
+				if (!Matches.territoryIsOwnedAndHasOwnedUnitMatching(data, player, Matches.UnitCanProduceUnitsAndCanBeDamaged).match(fixTerr))
 					continue;
 				final TerritoryAttachment ta = TerritoryAttachment.get(fixTerr);
 				maxProduction += ta.getProduction();
@@ -912,7 +927,7 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 			{
 				for (final RepairRule rrule : rrules)
 				{
-					if (!Matches.territoryHasOwnedFactory(data, player).match(capitol))
+					if (!Matches.territoryIsOwnedAndHasOwnedUnitMatching(data, player, Matches.UnitCanProduceUnitsAndCanBeDamaged).match(capitol))
 						continue;
 					final TerritoryAttachment ta = TerritoryAttachment.get(capitol);
 					diff = ta.getProduction() - ta.getUnitProduction();
@@ -928,7 +943,7 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 						else
 							currentProduction += diff + ta.getUnitProduction();
 						repairMap.add(rrule, diff);
-						repair.put(Match.getMatches(capitol.getUnits().getUnits(), Matches.UnitIsFactoryOrCanBeDamaged).iterator().next(), repairMap);
+						repair.put(Match.getMatches(capitol.getUnits().getUnits(), Matches.UnitCanBeDamaged).iterator().next(), repairMap);
 						leftToSpend -= diff;
 						purchaseDelegate.purchaseRepair(repair);
 						repair.clear();
@@ -944,7 +959,7 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 				{
 					for (final Territory fixTerr : rfactories)
 					{
-						if (!Matches.territoryHasOwnedFactory(data, player).match(fixTerr))
+						if (!Matches.territoryIsOwnedAndHasOwnedUnitMatching(data, player, Matches.UnitCanProduceUnitsAndCanBeDamaged).match(fixTerr))
 							continue;
 						// we will repair the first territories in the list as much as we can, until we fulfill the condition, then skip all other territories
 						if (currentProduction >= maxUnits)
@@ -966,7 +981,7 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 							else
 								currentProduction += diff + ta.getUnitProduction();
 							repairMap.add(rrule, diff);
-							repair.put(Match.getMatches(fixTerr.getUnits().getUnits(), Matches.UnitIsFactoryOrCanBeDamaged).iterator().next(), repairMap);
+							repair.put(Match.getMatches(fixTerr.getUnits().getUnits(), Matches.UnitCanBeDamaged).iterator().next(), repairMap);
 							leftToSpend -= diff;
 							purchaseDelegate.purchaseRepair(repair);
 							repair.clear();
@@ -999,7 +1014,7 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 			Collections.shuffle(rfactories); // we should sort this
 			for (final Territory fixTerr : rfactories)
 			{
-				if (!Matches.territoryHasOwnedFactory(data, player).match(fixTerr))
+				if (!Matches.territoryIsOwnedAndHasOwnedUnitMatching(data, player, Matches.UnitCanProduceUnitsAndCanBeDamaged).match(fixTerr))
 					continue;
 				final Unit possibleFactoryNeedingRepair = TripleAUnit.getBiggestProducer(Match.getMatches(fixTerr.getUnits().getUnits(), ourFactories), fixTerr, player, data, false);
 				if (Matches.UnitHasSomeUnitDamage().match(possibleFactoryNeedingRepair))
@@ -1027,7 +1042,7 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 				{
 					if (capUnit == null || !capUnit.getUnitType().equals(rrule.getResults().keySet().iterator().next()))
 						continue;
-					if (!Matches.territoryHasOwnedFactory(data, player).match(capitol))
+					if (!Matches.territoryIsOwnedAndHasOwnedUnitMatching(data, player, Matches.UnitCanProduceUnitsAndCanBeDamaged).match(capitol))
 						continue;
 					final TripleAUnit taUnit = (TripleAUnit) capUnit;
 					diff = taUnit.getUnitDamage();
@@ -1062,7 +1077,7 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 					{
 						if (fixUnit == null || !fixUnit.getType().equals(rrule.getResults().keySet().iterator().next()))
 							continue;
-						if (!Matches.territoryHasOwnedFactory(data, player).match(fixUnit.getTerritoryUnitIsIn()))
+						if (!Matches.territoryIsOwnedAndHasOwnedUnitMatching(data, player, Matches.UnitCanProduceUnitsAndCanBeDamaged).match(fixUnit.getTerritoryUnitIsIn()))
 							continue;
 						// we will repair the first territories in the list as much as we can, until we fulfill the condition, then skip all other territories
 						if (currentProduction >= maxUnits)
@@ -1108,8 +1123,8 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 			for (final ProductionRule rule : rules)
 			{
 				final UnitType results = (UnitType) rule.getResults().keySet().iterator().next();
-				if (Matches.UnitTypeIsAir.match(results) || Matches.UnitTypeIsFactoryOrIsInfrastructure.match(results) || Matches.UnitTypeIsAAforAnything.match(results)
-							|| Matches.UnitTypeHasMaxBuildRestrictions.match(results) || Matches.UnitTypeConsumesUnitsOnCreation.match(results) || Matches.unitTypeIsStatic(player).match(results))
+				if (Matches.UnitTypeIsAir.match(results) || Matches.UnitTypeIsInfrastructure.match(results) || Matches.UnitTypeIsAAforAnything.match(results)
+							|| Matches.UnitTypeHasMaxBuildRestrictions.match(results) || Matches.UnitTypeConsumesUnitsOnCreation.match(results) || Matches.UnitTypeIsStatic(player).match(results))
 				{
 					continue;
 				}
@@ -1176,7 +1191,7 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 		Collections.shuffle(randomTerritories);
 		for (final Territory t : randomTerritories)
 		{
-			if (t != capitol && t.getOwner().equals(player) && t.getUnits().someMatch(Matches.UnitIsFactory))
+			if (t != capitol && t.getOwner().equals(player) && t.getUnits().someMatch(Matches.UnitCanProduceUnits))
 			{
 				placeAllWeCanOn(data, t, placeDelegate, player);
 			}
@@ -1276,16 +1291,14 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 	/*
 	 * @see games.strategy.triplea.player.ITripleaPlayer#shouldBomberBomb(games.strategy.engine.data.Territory)
 	 */
-	public Unit whatShouldBomberBomb(final Territory territory, final Collection<Unit> units)
+	public Unit whatShouldBomberBomb(final Territory territory, final Collection<Unit> potentialTargets, final Collection<Unit> bombers)
 	{
-		if (units == null || units.isEmpty())
+		if (potentialTargets == null || potentialTargets.isEmpty())
 			return null;
-		if (!Match.someMatch(units, Matches.UnitIsFactoryOrCanProduceUnits))
-			return units.iterator().next();
-		if (Match.someMatch(units, Matches.UnitIsFactory))
-			return Match.getMatches(units, Matches.UnitIsFactory).iterator().next();
-		else
-			return Match.getMatches(units, Matches.UnitCanProduceUnits).iterator().next();
+		final Collection<Unit> factories = Match.getMatches(potentialTargets, Matches.UnitCanProduceUnitsAndCanBeDamaged);
+		if (factories.isEmpty())
+			return potentialTargets.iterator().next();
+		return factories.iterator().next();
 	}
 	
 	/*
@@ -1315,7 +1328,7 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 		return true;
 	}
 	
-	public Territory retreatQuery(final GUID battleID, final boolean submerge, final Collection<Territory> possibleTerritories, final String message)
+	public Territory retreatQuery(final GUID battleID, final boolean submerge, final Territory battleTerritory, final Collection<Territory> possibleTerritories, final String message)
 	{
 		return null;
 	}
@@ -1325,7 +1338,7 @@ public class WeakAI extends AbstractAI implements IGamePlayer, ITripleaPlayer
 		return null;
 	}*/
 
-	public HashMap<Territory, Collection<Unit>> scrambleUnitsQuery(final Territory scrambleTo, final Map<Territory, Tuple<Integer, Collection<Unit>>> possibleScramblers)
+	public HashMap<Territory, Collection<Unit>> scrambleUnitsQuery(final Territory scrambleTo, final Map<Territory, Tuple<Collection<Unit>, Collection<Unit>>> possibleScramblers)
 	{
 		return null;
 	}
