@@ -33,6 +33,7 @@ import games.strategy.engine.data.UnitType;
 import games.strategy.engine.data.annotations.GameProperty;
 import games.strategy.engine.data.annotations.InternalDoNotExport;
 import games.strategy.engine.delegate.IDelegateBridge;
+import games.strategy.engine.random.IRandomStats.DiceType;
 import games.strategy.triplea.Constants;
 import games.strategy.triplea.delegate.Matches;
 import games.strategy.triplea.delegate.TechAdvance;
@@ -74,15 +75,15 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 	private ArrayList<Tuple<String, ArrayList<Territory>>> m_battle = new ArrayList<Tuple<String, ArrayList<Territory>>>(); // condition for having had a battle in some territory, attacker or defender, win or lost, etc.
 	
 	// these next 9 variables use m_territoryCount for determining the number needed.
-	private String[] m_alliedOwnershipTerritories; // ownership related
-	private String[] m_directOwnershipTerritories;
-	private String[] m_alliedExclusionTerritories; // exclusion of units
-	private String[] m_directExclusionTerritories;
-	private String[] m_enemyExclusionTerritories;
-	private String[] m_enemySurfaceExclusionTerritories;
-	private String[] m_directPresenceTerritories; // presence of units
-	private String[] m_alliedPresenceTerritories;
-	private String[] m_enemyPresenceTerritories;
+	private String[] m_alliedOwnershipTerritories = null; // ownership related
+	private String[] m_directOwnershipTerritories = null;
+	private String[] m_alliedExclusionTerritories = null; // exclusion of units
+	private String[] m_directExclusionTerritories = null;
+	private String[] m_enemyExclusionTerritories = null;
+	private String[] m_enemySurfaceExclusionTerritories = null;
+	private String[] m_directPresenceTerritories = null; // presence of units
+	private String[] m_alliedPresenceTerritories = null;
+	private String[] m_enemyPresenceTerritories = null;
 	private IntegerMap<String> m_unitPresence = new IntegerMap<String>(); // used with above 3 to determine the type of unit that must be present
 	
 	/** Creates new RulesAttachment */
@@ -160,6 +161,11 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 		return m_destroyedTUV;
 	}
 	
+	public void resetDestroyedTUV()
+	{
+		m_destroyedTUV = null;
+	}
+	
 	/**
 	 * Adds to, not sets. Anything that adds to instead of setting needs a clear function as well.
 	 * 
@@ -220,6 +226,11 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 		m_battle.clear();
 	}
 	
+	public void resetBattle()
+	{
+		m_battle = new ArrayList<Tuple<String, ArrayList<Territory>>>();
+	}
+	
 	/**
 	 * Condition to check if a certain relationship exists between 2 players.
 	 * Adds to, not sets. Anything that adds to instead of setting needs a clear function as well.
@@ -262,6 +273,11 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 		m_relationship.clear();
 	}
 	
+	public void resetRelationship()
+	{
+		m_relationship = new ArrayList<String>();
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setAlliedOwnershipTerritories(final String value) throws GameParseException
 	{
@@ -285,6 +301,11 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 		return m_alliedOwnershipTerritories;
 	}
 	
+	public void resetAlliedOwnershipTerritories()
+	{
+		m_alliedOwnershipTerritories = null;
+	}
+	
 	// exclusion types = controlled, controlledNoWater, original, all, or list
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setAlliedExclusionTerritories(final String value) throws GameParseException
@@ -309,6 +330,11 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 		return m_alliedExclusionTerritories;
 	}
 	
+	public void resetAlliedExclusionTerritories()
+	{
+		m_alliedExclusionTerritories = null;
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setDirectExclusionTerritories(final String value) throws GameParseException
 	{
@@ -332,6 +358,11 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 		return m_directExclusionTerritories;
 	}
 	
+	public void resetDirectExclusionTerritories()
+	{
+		m_directExclusionTerritories = null;
+	}
+	
 	// exclusion types = original or list
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setEnemyExclusionTerritories(final String value) throws GameParseException
@@ -356,6 +387,11 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 		return m_enemyExclusionTerritories;
 	}
 	
+	public void resetEnemyExclusionTerritories()
+	{
+		m_enemyExclusionTerritories = null;
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setDirectPresenceTerritories(final String value) throws GameParseException
 	{
@@ -379,6 +415,11 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 		return m_directPresenceTerritories;
 	}
 	
+	public void resetDirectPresenceTerritories()
+	{
+		m_directPresenceTerritories = null;
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setAlliedPresenceTerritories(final String value) throws GameParseException
 	{
@@ -402,6 +443,11 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 		return m_alliedPresenceTerritories;
 	}
 	
+	public void resetAlliedPresenceTerritories()
+	{
+		m_alliedPresenceTerritories = null;
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setEnemyPresenceTerritories(final String value) throws GameParseException
 	{
@@ -425,6 +471,12 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 		return m_enemyPresenceTerritories;
 	}
 	
+	public void resetEnemyPresenceTerritories()
+	{
+		m_enemyPresenceTerritories = null;
+		
+	}
+	
 	// exclusion types = original or list
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setEnemySurfaceExclusionTerritories(final String value) throws GameParseException
@@ -449,6 +501,11 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 		return m_enemySurfaceExclusionTerritories;
 	}
 	
+	public void resetEnemySurfaceExclusionTerritories()
+	{
+		m_enemySurfaceExclusionTerritories = null;
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setDirectOwnershipTerritories(final String value) throws GameParseException
 	{
@@ -472,6 +529,11 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 		return m_directOwnershipTerritories;
 	}
 	
+	public void resetDirectOwnershipTerritories()
+	{
+		m_directOwnershipTerritories = null;
+	}
+	
 	/**
 	 * Adds to, not sets. Anything that adds to instead of setting needs a clear function as well.
 	 * 
@@ -515,6 +577,11 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 		m_unitPresence.clear();
 	}
 	
+	public void resetUnitPresence()
+	{
+		m_unitPresence = new IntegerMap<String>();
+	}
+	
 	public int getAtWarCount()
 	{
 		return m_atWarCount;
@@ -568,6 +635,11 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 		return m_atWarPlayers;
 	}
 	
+	public void resetAtWarPlayers()
+	{
+		m_atWarPlayers = null;
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setTechs(final String techs) throws GameParseException
 	{
@@ -613,6 +685,11 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 		return m_techs;
 	}
 	
+	public void resetTechs()
+	{
+		m_techs = null;
+	}
+	
 	@Override
 	public boolean isSatisfied(final HashMap<ICondition, Boolean> testedConditions)
 	{
@@ -644,6 +721,11 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 			objectiveMet = areConditionsMet(new ArrayList<ICondition>(m_conditions), testedConditions, m_conditionType);
 		}
 		//
+		// check switch (on/off)
+		//
+		if (objectiveMet)
+			objectiveMet = m_switch;
+		//
 		// check turn limits
 		//
 		if (objectiveMet && m_turns != null)
@@ -899,7 +981,7 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 		final int diceSides = getInt(m_chance.split(":")[1]);
 		if (objectiveMet && hitTarget != diceSides)
 		{
-			final int rollResult = aBridge.getRandom(diceSides, "Attempting the Condition: " + MyFormatter.attachmentNameToText(this.getName())) + 1;
+			final int rollResult = aBridge.getRandom(diceSides, null, DiceType.ENGINE, "Attempting the Condition: " + MyFormatter.attachmentNameToText(this.getName())) + 1;
 			objectiveMet = rollResult <= hitTarget;
 			final String notificationMessage = "Rolling (" + hitTarget + " out of " + diceSides + ") result: " + rollResult + " = " + (objectiveMet ? "Success!" : "Failure!") + " (for "
 						+ MyFormatter.attachmentNameToText(this.getName()) + ")";
@@ -1190,7 +1272,7 @@ public class RulesAttachment extends AbstractPlayerRulesAttachment implements IC
 	private boolean checkTechs(final PlayerID player, final GameData data)
 	{
 		int found = 0;
-		for (final TechAdvance a : TechTracker.getTechAdvances(player, data))
+		for (final TechAdvance a : TechTracker.getCurrentTechAdvances(player, data))
 			if (m_techs.contains(a))
 				found++;
 		if (m_techCount == 0)
