@@ -43,9 +43,10 @@ import java.util.Set;
  * @author Sean Bridges
  * @version 1.0
  */
-@SuppressWarnings("serial")
 public class TerritoryAttachment extends DefaultAttachment
 {
+	private static final long serialVersionUID = 9102862080104655281L;
+	
 	public static Territory getCapital(final PlayerID player, final GameData data)
 	{
 		for (final Territory current : data.getMap().getTerritories())
@@ -200,6 +201,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		m_resources = new ResourceCollection(getData());
 	}
 	
+	public void resetResources()
+	{
+		m_resources = null;
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setIsImpassible(final String value)
 	{
@@ -217,6 +223,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		return m_isImpassible;
 	}
 	
+	public void resetIsImpassible()
+	{
+		m_isImpassible = false;
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setCapital(final String value) throws GameParseException
 	{
@@ -241,6 +252,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		return m_capital;
 	}
 	
+	public void resetCapital()
+	{
+		m_capital = null;
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setVictoryCity(final String value)
 	{
@@ -258,6 +274,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		return m_victoryCity;
 	}
 	
+	public void resetVictoryCity()
+	{
+		m_victoryCity = false;
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setOriginalFactory(final String value)
 	{
@@ -275,6 +296,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		return m_originalFactory;
 	}
 	
+	public void resetOriginalFactory()
+	{
+		m_originalFactory = false;
+	}
+	
 	/**
 	 * setProduction (or just "production" in a map xml) sets both the m_production AND the m_unitProduction of a territory to be equal to the String value passed.
 	 * 
@@ -294,6 +320,12 @@ public class TerritoryAttachment extends DefaultAttachment
 		m_unitProduction = m_production; // do NOT remove. unitProduction should always default to production
 	}
 	
+	public void resetProduction()
+	{
+		m_production = 0;
+		m_unitProduction = 0;
+	}
+	
 	/**
 	 * Sets only m_production
 	 * 
@@ -322,6 +354,22 @@ public class TerritoryAttachment extends DefaultAttachment
 		return m_production;
 	}
 	
+	/**
+	 * Use getProduction() instead.
+	 * 
+	 * @return
+	 */
+	@Deprecated
+	public int getProductionOnly()
+	{
+		return getProduction();
+	}
+	
+	public void resetProductionOnly()
+	{
+		m_production = 0;
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setUnitProduction(final Integer value)
 	{
@@ -339,6 +387,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		return m_unitProduction;
 	}
 	
+	public void resetUnitProduction()
+	{
+		m_unitProduction = 0;
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setOccupiedTerrOf(final String value)
 	{
@@ -361,6 +414,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		return m_occupiedTerrOf;
 	}
 	
+	public void resetOccupiedTerrOf()
+	{
+		m_occupiedTerrOf = null;
+	}
+	
 	/**
 	 * Should not be set by a game xml during attachment parsing, but CAN be set by initialization parsing and/or Property Utils.
 	 * 
@@ -372,11 +430,27 @@ public class TerritoryAttachment extends DefaultAttachment
 		m_originalOwner = player;
 	}
 	
+	@GameProperty(xmlProperty = false, gameProperty = true, adds = false)
+	public void setOriginalOwner(final String player) throws GameParseException
+	{
+		if (player == null)
+			m_originalOwner = null;
+		final PlayerID tempPlayer = getData().getPlayerList().getPlayerID(player);
+		if (tempPlayer == null)
+			throw new GameParseException("No player named: " + player + thisErrorMsg());
+		m_originalOwner = tempPlayer;
+	}
+	
 	public PlayerID getOriginalOwner()
 	{
 		return m_originalOwner;
 	}
 	
+	public void resetOriginalOwner()
+	{
+		m_originalOwner = null;
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setConvoyRoute(final String value)
 	{
@@ -394,6 +468,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		return m_convoyRoute;
 	}
 	
+	public void resetConvoyRoute()
+	{
+		m_convoyRoute = false;
+	}
+	
 	/**
 	 * Adds to, not sets. Anything that adds to instead of setting needs a clear function as well.
 	 * 
@@ -432,6 +511,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		m_changeUnitOwners.clear();
 	}
 	
+	public void resetChangeUnitOwners()
+	{
+		m_changeUnitOwners = new ArrayList<PlayerID>();
+	}
+	
 	/**
 	 * Adds to, not sets. Anything that adds to instead of setting needs a clear function as well.
 	 * 
@@ -468,6 +552,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		m_captureUnitOnEnteringBy.clear();
 	}
 	
+	public void resetCaptureUnitOnEnteringBy()
+	{
+		m_captureUnitOnEnteringBy = new ArrayList<PlayerID>();
+	}
+	
 	/**
 	 * Adds to, not sets. Anything that adds to instead of setting needs a clear function as well.
 	 * 
@@ -505,6 +594,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		m_whenCapturedByGoesTo.clear();
 	}
 	
+	public void resetWhenCapturedByGoesTo()
+	{
+		m_whenCapturedByGoesTo = new ArrayList<String>();
+	}
+	
 	/**
 	 * Adds to, not sets. Anything that adds to instead of setting needs a clear function as well.
 	 * 
@@ -540,6 +634,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		m_territoryEffect.clear();
 	}
 	
+	public void resetTerritoryEffect()
+	{
+		m_territoryEffect = new ArrayList<TerritoryEffect>();
+	}
+	
 	/**
 	 * Adds to, not sets. Anything that adds to instead of setting needs a clear function as well.
 	 * 
@@ -576,6 +675,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		m_convoyAttached.clear();
 	}
 	
+	public void resetConvoyAttached()
+	{
+		m_convoyAttached = new HashSet<Territory>();
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setNavalBase(final String value)
 	{
@@ -593,6 +697,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		return m_navalBase;
 	}
 	
+	public void resetNavalBase()
+	{
+		m_navalBase = false;
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setAirBase(final String value)
 	{
@@ -610,6 +719,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		return m_airBase;
 	}
 	
+	public void resetAirBase()
+	{
+		m_airBase = false;
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setKamikazeZone(final String value)
 	{
@@ -627,6 +741,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		return m_kamikazeZone;
 	}
 	
+	public void resetKamikazeZone()
+	{
+		m_kamikazeZone = false;
+	}
+	
 	@GameProperty(xmlProperty = true, gameProperty = true, adds = false)
 	public void setBlockadeZone(final String value)
 	{
@@ -644,6 +763,11 @@ public class TerritoryAttachment extends DefaultAttachment
 		return m_blockadeZone;
 	}
 	
+	public void resetBlockadeZone()
+	{
+		m_blockadeZone = false;
+	}
+	
 	public static Set<Territory> getWhatTerritoriesThisIsUsedInConvoysFor(final Territory t, final GameData data)
 	{
 		final Set<Territory> rVal = new HashSet<Territory>();
