@@ -115,16 +115,28 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 		final GameData data = getData();
 		if (!Properties.getUnplacedUnitsLive(data) && !units.isEmpty())
 		{
-			m_bridge.getHistoryWriter().startEvent(MyFormatter.unitsToTextNoOwner(units) + " were produced but were not placed");
-			m_bridge.getHistoryWriter().setRenderingData(units);
+			m_bridge.getHistoryWriter().startEvent(MyFormatter.unitsToTextNoOwner(units) + " were produced but were not placed", units);
 			final Change change = ChangeFactory.removeUnits(player, units);
 			m_bridge.addChange(change);
 		}
 		// reset ourselves for next turn
 		m_produced = new HashMap<Territory, Collection<Unit>>();
 		m_placements.clear();
-		// only for lhtr rules
-		new AirThatCantLandUtil(m_bridge).removeAirThatCantLand(m_player, false);
+		removeAirThatCantLand();
+	}
+	
+	protected void removeAirThatCantLand()
+	{
+		// for LHTR type games
+		final GameData data = getData();
+		final AirThatCantLandUtil util = new AirThatCantLandUtil(m_bridge);
+		util.removeAirThatCantLand(m_player, false);
+		// if edit mode has been on, we need to clean up after all players
+		for (final PlayerID player : data.getPlayerList())
+		{
+			if (!player.equals(m_player))
+				util.removeAirThatCantLand(player, false);
+		}
 	}
 	
 	@Override
@@ -214,7 +226,7 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 		if (error != null)
 			return new PlaceableUnits(error);
 		final Collection<Unit> placeableUnits = getUnitsToBePlaced(to, units, m_player);
-		final int maxUnits = getMaxUnitsToBePlaced(units, to, m_player, true);
+		final int maxUnits = getMaxUnitsToBePlaced(placeableUnits, to, m_player, true);
 		return new PlaceableUnits(placeableUnits, maxUnits);
 	}
 	
@@ -289,10 +301,10 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 		final boolean didIt = canWeConsumeUnits(placeableUnits, at, true, change);
 		if (!didIt)
 			throw new IllegalStateException("Something wrong with consuming/upgrading units");
-		final Collection<Unit> factoryAndInfrastructure = Match.getMatches(placeableUnits, Matches.UnitIsFactoryOrIsInfrastructure);
+		final Collection<Unit> factoryAndInfrastructure = Match.getMatches(placeableUnits, Matches.UnitIsInfrastructure);
 		change.add(DelegateFinder.battleDelegate(getData()).getOriginalOwnerTracker().addOriginalOwnerChange(factoryAndInfrastructure, player));
 		// can we move planes to land there
-		final String movedAirTranscriptTextForHistory = moveAirOntoNewCarriers(at, placeableUnits, player, change);
+		final String movedAirTranscriptTextForHistory = moveAirOntoNewCarriers(at, producer, placeableUnits, player, change);
 		
 		final Change remove = ChangeFactory.removeUnits(player, placeableUnits);
 		final Change place = ChangeFactory.addUnits(at, placeableUnits);
@@ -302,8 +314,7 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 		m_placements.add(current_placement);
 		updateUndoablePlacementIndexes();
 		final String transcriptText = MyFormatter.unitsToTextNoOwner(placeableUnits) + " placed in " + at.getName();
-		m_bridge.getHistoryWriter().startEvent(transcriptText);
-		m_bridge.getHistoryWriter().setRenderingData(current_placement.getDescriptionObject());
+		m_bridge.getHistoryWriter().startEvent(transcriptText, current_placement.getDescriptionObject());
 		if (movedAirTranscriptTextForHistory != null)
 			m_bridge.getHistoryWriter().addChildToEvent(movedAirTranscriptTextForHistory);
 		m_bridge.addChange(change);
@@ -382,6 +393,7 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 				int leftToPlace = getMaxUnitsToBePlacedFrom(potentialNewProducerTerritory, unitsPlacedInTerritorySoFar(placeTerritory), placeTerritory, player);
 				if (leftToPlace == -1)
 					leftToPlace = maxProductionThatCanBeTakenOverFromThisPlacement;
+				// TODO: should we continue if leftToPlace is zero or less, now?
 				// find placements of the producer the potentialNewProducerTerritory can take over
 				for (final UndoablePlacement placement : redoPlacements)
 				{
@@ -413,12 +425,19 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 			if (foundSpaceTotal >= freeSize)
 				break;
 		}
+		boolean unusedSplitPlacments = false; // we had a bug where we tried to split the same undoable placement twice (it can only be undone once!)
+		final Collection<UndoablePlacement> usedUnoablePlacements = new ArrayList<UndoablePlacement>();
 		if (foundSpaceTotal < freeSize)
 		{
 			// we need to split some placement moves
 			for (final Tuple<UndoablePlacement, Territory> tuple : splitPlacements)
 			{
 				final UndoablePlacement placement = tuple.getFirst();
+				if (usedUnoablePlacements.contains(placement))
+				{
+					unusedSplitPlacments = true;
+					continue;
+				}
 				final Territory newProducer = tuple.getSecond();
 				int leftToPlace = getMaxUnitsToBePlacedFrom(newProducer, unitsLeftToPlace, at, player);
 				foundSpaceTotal += leftToPlace;
@@ -436,19 +455,24 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 				// split move, by undo and creating two new ones
 				if (!unitsForNewProducer.isEmpty())
 				{
+					// there is a chance we have 2 or more splitPlacements that are using the same placement (trying to split the same placement).
+					// So we must make sure that after we undo it the first time, it can never be undone again.
+					usedUnoablePlacements.add(placement);
 					undoMove(placement.getIndex());
 					performPlaceFrom(newProducer, unitsForNewProducer, placement.getPlaceTerritory(), player);
 					performPlaceFrom(producer, unitsForOldProducer, placement.getPlaceTerritory(), player);
 				}
 			}
 		}
+		if (foundSpaceTotal < freeSize && unusedSplitPlacments)
+			freePlacementCapacity(producer, (freeSize - foundSpaceTotal), unitsLeftToPlace, at, player);
 	}
 	
 	// TODO Here's the spot for special air placement rules
-	private String moveAirOntoNewCarriers(final Territory territory, final Collection<Unit> units, final PlayerID player, final CompositeChange placeChange)
+	private String moveAirOntoNewCarriers(final Territory at, final Territory producer, final Collection<Unit> units, final PlayerID player, final CompositeChange placeChange)
 	{
 		// not water, dont bother
-		if (!territory.isWater())
+		if (!at.isWater())
 			return null;
 		// not enabled
 		// if (!canProduceFightersOnCarriers())
@@ -457,15 +481,38 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 		if (Match.noneMatch(units, Matches.UnitIsCarrier))
 			return null;
 		// do we have any spare carrier capacity
-		int capacity = AirMovementValidator.carrierCapacity(units, territory);
+		int capacity = AirMovementValidator.carrierCapacity(units, at);
 		// subtract fighters that have already been produced with this carrier
 		// this turn.
 		capacity -= AirMovementValidator.carrierCost(units);
 		if (capacity <= 0)
 			return null;
-		final Collection<Territory> neighbors = getData().getMap().getNeighbors(territory, 1);
-		final Iterator<Territory> iter = neighbors.iterator();
+		if (!Matches.TerritoryIsLand.match(producer))
+			return null;
+		if (!producer.getUnits().someMatch(Matches.UnitCanProduceUnits))
+			return null;
 		final CompositeMatch<Unit> ownedFighters = new CompositeMatchAnd<Unit>(Matches.UnitCanLandOnCarrier, Matches.unitIsOwnedBy(player));
+		if (!producer.getUnits().someMatch(ownedFighters))
+			return null;
+		if (wasConquered(producer))
+			return null;
+		if (Match.someMatch(getAlreadyProduced(producer), Matches.UnitCanProduceUnits))
+			return null;
+		final List<Unit> fighters = producer.getUnits().getMatches(ownedFighters);
+		while (fighters.size() > 0 && AirMovementValidator.carrierCost(fighters) > capacity)
+		{
+			fighters.remove(0);
+		}
+		if (fighters.size() == 0)
+			return null;
+		final Collection<Unit> movedFighters = getRemotePlayer().getNumberOfFightersToMoveToNewCarrier(fighters, producer);
+		final Change change = ChangeFactory.moveUnits(producer, at, movedFighters);
+		placeChange.add(change);
+		final String transcriptText = MyFormatter.unitsToTextNoOwner(movedFighters) + " moved from " + producer.getName() + " to " + at.getName();
+		return transcriptText;
+		/*
+		final Collection<Territory> neighbors = getData().getMap().getNeighbors(at, 1);
+		final Iterator<Territory> iter = neighbors.iterator();
 		while (iter.hasNext())
 		{
 			final Territory neighbor = iter.next();
@@ -474,14 +521,14 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 			// check to see if we have a factory, only fighters from territories
 			// that could
 			// have produced the carrier can move there
-			if (!neighbor.getUnits().someMatch(Matches.UnitIsFactoryOrCanProduceUnits))
+			if (!neighbor.getUnits().someMatch(Matches.UnitCanProduceUnits))
 				continue;
 			// are there some fighers there that can be moved?
 			if (!neighbor.getUnits().someMatch(ownedFighters))
 				continue;
 			if (wasConquered(neighbor))
 				continue;
-			if (Match.someMatch(getAlreadyProduced(neighbor), Matches.UnitIsFactoryOrCanProduceUnits))
+			if (Match.someMatch(getAlreadyProduced(neighbor), Matches.UnitCanProduceUnits))
 				continue;
 			final List<Unit> fighters = neighbor.getUnits().getMatches(ownedFighters);
 			while (fighters.size() > 0 && AirMovementValidator.carrierCost(fighters) > capacity)
@@ -491,16 +538,16 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 			if (fighters.size() == 0)
 				continue;
 			final Collection<Unit> movedFighters = getRemotePlayer().getNumberOfFightersToMoveToNewCarrier(fighters, neighbor);
-			final Change change = ChangeFactory.moveUnits(neighbor, territory, movedFighters);
+			final Change change = ChangeFactory.moveUnits(neighbor, at, movedFighters);
 			placeChange.add(change);
-			final String transcriptText = MyFormatter.unitsToTextNoOwner(movedFighters) + " moved from " + neighbor.getName() + " to " + territory.getName();
+			final String transcriptText = MyFormatter.unitsToTextNoOwner(movedFighters) + " moved from " + neighbor.getName() + " to " + at.getName();
 			// only allow 1 movement
 			// technically only the territory that produced the
 			// carrier should be able to move fighters to the new
 			// territory
 			return transcriptText;
 		}
-		return null;
+		return null;*/
 	}
 	
 	/**
@@ -612,8 +659,8 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 		if (!producer.getUnits().someMatch(Matches.UnitIsOwnedAndIsFactoryOrCanProduceUnits(player)))
 		{
 			// check to see if we are producing a factory
-			if (Match.someMatch(testUnits, Matches.UnitIsFactory))
-				return null;
+			/*if (Match.someMatch(testUnits, Matches.UnitIsFactory))
+				return null;*/
 			if (Match.someMatch(testUnits, Matches.UnitIsConstruction))
 			{
 				if (howManyOfEachConstructionCanPlace(to, testUnits, player).totalValues() > 0) // No error, Construction to place
@@ -623,7 +670,7 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 			return "No Factory in " + producer.getName();
 		}
 		// check we havent just put a factory there (should we be checking producer?)
-		if (Match.someMatch(getAlreadyProduced(producer), Matches.UnitIsFactoryOrCanProduceUnits) || Match.someMatch(getAlreadyProduced(to), Matches.UnitIsFactoryOrCanProduceUnits))
+		if (Match.someMatch(getAlreadyProduced(producer), Matches.UnitCanProduceUnits) || Match.someMatch(getAlreadyProduced(to), Matches.UnitCanProduceUnits))
 		{
 			if (Match.someMatch(testUnits, Matches.UnitIsConstruction) && howManyOfEachConstructionCanPlace(to, testUnits, player).totalValues() > 0) // you can still place a Construction
 				return null;
@@ -701,13 +748,13 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 			return "Cannot place these units in " + to.getName();
 		}
 		final IntegerMap<String> constructionMap = howManyOfEachConstructionCanPlace(to, units, player);
-		for (final Unit currentUnit : Match.getMatches(units, Matches.UnitIsFactoryOrConstruction))
+		for (final Unit currentUnit : Match.getMatches(units, Matches.UnitIsConstruction))
 		{
 			final UnitAttachment ua = UnitAttachment.get(currentUnit.getUnitType());
-			if (ua.getIsFactory() && !ua.getIsConstruction())
+			/*if (ua.getIsFactory() && !ua.getIsConstruction())
 				constructionMap.add("factory", -1);
-			else
-				constructionMap.add(ua.getConstructionType(), -1);
+			else*/
+			constructionMap.add(ua.getConstructionType(), -1);
 		}
 		if (!constructionMap.isPositive())
 			return "Too many constructions in " + to.getName();
@@ -835,16 +882,16 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 		final boolean wasFactoryThereAtStart = wasOwnedUnitThatCanProduceUnitsOrIsFactoryInTerritoryAtStartOfStep(to, player);
 		if (wasFactoryThereAtStart || isPlayerAllowedToPlacementAnyTerritoryOwnedLand(player))
 		{
-			final CompositeMatch<Unit> groundUnits = new CompositeMatchAnd<Unit>(Matches.UnitIsLand, Matches.UnitIsNotFactoryOrConstruction); // we add factories and constructions later
-			final CompositeMatch<Unit> airUnits = new CompositeMatchAnd<Unit>(Matches.UnitIsAir, Matches.UnitIsNotFactoryOrConstruction);
+			final CompositeMatch<Unit> groundUnits = new CompositeMatchAnd<Unit>(Matches.UnitIsLand, Matches.UnitIsNotConstruction); // we add factories and constructions later
+			final CompositeMatch<Unit> airUnits = new CompositeMatchAnd<Unit>(Matches.UnitIsAir, Matches.UnitIsNotConstruction);
 			placeableUnits.addAll(Match.getMatches(units, groundUnits));
 			placeableUnits.addAll(Match.getMatches(units, airUnits));
 		}
-		if (Match.someMatch(units, Matches.UnitIsFactoryOrConstruction))
+		if (Match.someMatch(units, Matches.UnitIsConstruction))
 		{
 			final IntegerMap<String> constructionsMap = howManyOfEachConstructionCanPlace(to, units, player);
 			final Collection<Unit> skipUnit = new ArrayList<Unit>();
-			for (final Unit currentUnit : Match.getMatches(units, Matches.UnitIsFactoryOrConstruction))
+			for (final Unit currentUnit : Match.getMatches(units, Matches.UnitIsConstruction))
 			{
 				final int maxUnits = howManyOfConstructionUnit(currentUnit, constructionsMap);
 				if (maxUnits > 0)
@@ -936,8 +983,7 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 		if (weCanConsume && actuallyDoIt && change != null && !change.isEmpty())
 		{
 			// m_bridge.addChange(change);
-			m_bridge.getHistoryWriter().startEvent("Units in " + to.getName() + " being upgraded or consumed: " + MyFormatter.unitsToTextNoOwner(removedUnits));
-			m_bridge.getHistoryWriter().setRenderingData(removedUnits);
+			m_bridge.getHistoryWriter().startEvent("Units in " + to.getName() + " being upgraded or consumed: " + MyFormatter.unitsToTextNoOwner(removedUnits), removedUnits);
 		}
 		return weCanConsume;
 	}
@@ -1054,7 +1100,7 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 		// return 0 if less than 0
 		if (production < 0)
 			return 0;
-		production += Match.countMatches(alreadProducedUnits, Matches.UnitIsFactoryOrConstruction);
+		production += Match.countMatches(alreadProducedUnits, Matches.UnitIsConstruction);
 		
 		// Now we check if units we have already produced here could be produced by a different producer
 		int unitCountHaveToAndHaveBeenBeProducedHere = unitCountAlreadyProduced;
@@ -1153,7 +1199,7 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 	 */
 	public IntegerMap<String> howManyOfEachConstructionCanPlace(final Territory to, final Collection<Unit> units, final PlayerID player)
 	{
-		if (units == null || units.isEmpty() || !Match.someMatch(units, Matches.UnitIsFactoryOrConstruction))
+		if (units == null || units.isEmpty() || !Match.someMatch(units, Matches.UnitIsConstruction))
 			return new IntegerMap<String>();
 		final Collection<Unit> unitsAtStartOfTurnInTO = unitsAtStartOfStepInTerritory(to);
 		final Collection<Unit> unitsInTO = to.getUnits().getUnits();
@@ -1163,7 +1209,7 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 		final IntegerMap<String> unitMapMaxType = new IntegerMap<String>();
 		final IntegerMap<String> unitMapTypePerTurn = new IntegerMap<String>();
 		final int maxFactory = games.strategy.triplea.Properties.getFactoriesPerCountry(getData());
-		final Iterator<Unit> unitHeldIter = Match.getMatches(units, Matches.UnitIsFactoryOrConstruction).iterator();
+		final Iterator<Unit> unitHeldIter = Match.getMatches(units, Matches.UnitIsConstruction).iterator();
 		final TerritoryAttachment terrAttachment = TerritoryAttachment.get(to);
 		int toProduction = 0;
 		if (terrAttachment != null)
@@ -1187,18 +1233,12 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 			// remove any units that require other units to be consumed on creation (veqryn)
 			if (Matches.UnitConsumesUnitsOnCreation.match(currentUnit) && Matches.UnitWhichConsumesUnitsHasRequiredUnits(unitsAtStartOfTurnInTO, to).invert().match(currentUnit))
 				continue;
-			if (Matches.UnitIsFactory.match(currentUnit) && !ua.getIsConstruction())
-			{
-				unitMapHeld.add("factory", 1);
-				unitMapMaxType.put("factory", maxFactory);
-				unitMapTypePerTurn.put("factory", 1);
-			}
+			unitMapHeld.add(ua.getConstructionType(), 1);
+			unitMapTypePerTurn.put(ua.getConstructionType(), ua.getConstructionsPerTerrPerTypePerTurn());
+			if (ua.getConstructionType().equals("factory"))
+				unitMapMaxType.put(ua.getConstructionType(), maxFactory);
 			else
-			{
-				unitMapHeld.add(ua.getConstructionType(), 1);
 				unitMapMaxType.put(ua.getConstructionType(), ua.getMaxConstructionsPerTypePerTerr());
-				unitMapTypePerTurn.put(ua.getConstructionType(), ua.getConstructionsPerTerrPerTypePerTurn());
-			}
 		}
 		final boolean moreWithoutFactory = games.strategy.triplea.Properties.getMoreConstructionsWithoutFactory(getData());
 		final boolean moreWithFactory = games.strategy.triplea.Properties.getMoreConstructionsWithFactory(getData());
@@ -1206,15 +1246,15 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 		final boolean wasFactoryThereAtStart = wasOwnedUnitThatCanProduceUnitsOrIsFactoryInTerritoryAtStartOfStep(to, player);
 		// build an integer map of each construction unit in the territory
 		final IntegerMap<String> unitMapTO = new IntegerMap<String>();
-		if (Match.someMatch(unitsInTO, Matches.UnitIsFactoryOrConstruction))
+		if (Match.someMatch(unitsInTO, Matches.UnitIsConstruction))
 		{
-			for (final Unit currentUnit : Match.getMatches(unitsInTO, Matches.UnitIsFactoryOrConstruction))
+			for (final Unit currentUnit : Match.getMatches(unitsInTO, Matches.UnitIsConstruction))
 			{
 				final UnitAttachment ua = UnitAttachment.get(currentUnit.getUnitType());
-				if (Matches.UnitIsFactory.match(currentUnit) && !ua.getIsConstruction())
+				/*if (Matches.UnitIsFactory.match(currentUnit) && !ua.getIsConstruction())
 					unitMapTO.add("factory", 1);
-				else
-					unitMapTO.add(ua.getConstructionType(), 1);
+				else*/
+				unitMapTO.add(ua.getConstructionType(), 1);
 			}
 			// account for units already in the territory, based on max
 			final Iterator<String> mapString = unitMapHeld.keySet().iterator();
@@ -1230,7 +1270,7 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 			}
 		}
 		// deal with already placed units
-		final Iterator<Unit> unitAlready = Match.getMatches(unitsPlacedAlready, Matches.UnitIsFactoryOrConstruction).iterator();
+		final Iterator<Unit> unitAlready = Match.getMatches(unitsPlacedAlready, Matches.UnitIsConstruction).iterator();
 		while (unitAlready.hasNext())
 		{
 			final Unit currentUnit = unitAlready.next();
@@ -1254,12 +1294,11 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 	public int howManyOfConstructionUnit(final Unit unit, final IntegerMap<String> constructionsMap)
 	{
 		final UnitAttachment ua = UnitAttachment.get(unit.getUnitType());
-		if (!ua.getIsFactory()
-					&& (!ua.getIsConstruction() || ua.getConstructionsPerTerrPerTypePerTurn() < 1 || ua.getMaxConstructionsPerTypePerTerr() < 1 || constructionsMap.getInt(ua.getConstructionType()) == 0))
+		if (/*!ua.getIsFactory() &&*/(!ua.getIsConstruction() || ua.getConstructionsPerTerrPerTypePerTurn() < 1 || ua.getMaxConstructionsPerTypePerTerr() < 1))
 			return 0;
-		if (ua.getIsFactory() && !ua.getIsConstruction())
-			return constructionsMap.getInt("factory");
-		return constructionsMap.getInt(ua.getConstructionType());
+		/*if (ua.getIsFactory() && !ua.getIsConstruction())
+			return constructionsMap.getInt("factory");*/
+		return Math.max(0, constructionsMap.getInt(ua.getConstructionType()));
 	}
 	
 	/**
@@ -1397,9 +1436,7 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 					return -1;
 				if (ua1 == null && ua2 != null)
 					return 1;
-				@SuppressWarnings("null")
 				final ArrayList<String[]> ru1 = ua1.getRequiresUnits();
-				@SuppressWarnings("null")
 				final ArrayList<String[]> ru2 = ua2.getRequiresUnits();
 				final int rus1 = (ru1 == null ? Integer.MAX_VALUE : (ru1.isEmpty() ? Integer.MAX_VALUE : ru1.size()));
 				final int rus2 = (ru2 == null ? Integer.MAX_VALUE : (ru2.isEmpty() ? Integer.MAX_VALUE : ru2.size()));
@@ -1465,7 +1502,7 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 	 */
 	private PlayerID getOriginalFactoryOwner(final Territory territory)
 	{
-		final Collection<Unit> factoryUnits = territory.getUnits().getMatches(Matches.UnitIsFactoryOrCanProduceUnits);
+		final Collection<Unit> factoryUnits = territory.getUnits().getMatches(Matches.UnitCanProduceUnits);
 		if (factoryUnits.size() == 0)
 			throw new IllegalStateException("No factory in territory:" + territory);
 		final Iterator<Unit> iter = factoryUnits.iterator();
@@ -1672,9 +1709,9 @@ public abstract class AbstractPlaceDelegate extends BaseDelegate implements IAbs
 }
 
 
-@SuppressWarnings("serial")
 class PlaceExtendedDelegateState implements Serializable
 {
+	private static final long serialVersionUID = -4926754941623641735L;
 	Serializable superState;
 	// add other variables here:
 	public Map<Territory, Collection<Unit>> m_produced;
