@@ -31,6 +31,7 @@ import games.strategy.engine.data.UnitType;
 import games.strategy.engine.delegate.AutoSave;
 import games.strategy.engine.delegate.IDelegateBridge;
 import games.strategy.engine.message.IRemote;
+import games.strategy.engine.random.IRandomStats.DiceType;
 import games.strategy.triplea.TripleA;
 import games.strategy.triplea.TripleAUnit;
 import games.strategy.triplea.ai.weakAI.WeakAI;
@@ -39,7 +40,7 @@ import games.strategy.triplea.attatchments.TerritoryAttachment;
 import games.strategy.triplea.attatchments.UnitAttachment;
 import games.strategy.triplea.delegate.IBattle.WhoWon;
 import games.strategy.triplea.delegate.dataObjects.BattleListing;
-import games.strategy.triplea.delegate.dataObjects.BattleRecords;
+import games.strategy.triplea.delegate.dataObjects.BattleRecord;
 import games.strategy.triplea.delegate.remote.IBattleDelegate;
 import games.strategy.triplea.formatter.MyFormatter;
 import games.strategy.triplea.oddsCalculator.ta.BattleResults;
@@ -73,6 +74,12 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 	private BattleTracker m_battleTracker = new BattleTracker();
 	private OriginalOwnerTracker m_originalOwnerTracker = new OriginalOwnerTracker();
 	private boolean m_needToInitialize = true;
+	private boolean m_needToScramble = true;
+	private boolean m_needToKamikazeSuicideAttacks = true;
+	private boolean m_needToAddBombardmentSources = true;
+	private boolean m_needToRecordBattleStatistics = true;
+	private boolean m_needToCheckDefendingPlanesCanLand = true;
+	private boolean m_needToCleanup = true;
 	private IBattle m_currentBattle = null;
 	
 	/**
@@ -86,14 +93,26 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 		// only initialize once
 		if (m_needToInitialize)
 		{
-			setupUnitsInSameTerritoryBattles();
-			m_battleTracker.clearFinishedBattles(m_bridge); // these are "blitzed" and "conquered" territories without a fight, without a pending battle
-			// do pre-combat stuff, like scrambling, after we have setup all battles, but before we have bombardment, etc.
-			doScrambling();
-			doKamikazeSuicideAttacks();
-			addBombardmentSources();
+			doInitialize(m_battleTracker, m_bridge);
 			m_needToInitialize = false;
 		}
+		// do pre-combat stuff, like scrambling, after we have setup all battles, but before we have bombardment, etc.
+		// the order of all of this stuff matters quite a bit.
+		if (m_needToScramble)
+		{
+			doScrambling();
+			m_needToScramble = false;
+		}
+		if (m_needToKamikazeSuicideAttacks)
+		{
+			doKamikazeSuicideAttacks();
+			m_needToKamikazeSuicideAttacks = false;
+		}
+		if (m_needToAddBombardmentSources)
+		{
+			addBombardmentSources();
+			m_needToAddBombardmentSources = false;
+		}
 	}
 	
 	/**
@@ -102,13 +121,31 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 	@Override
 	public void end()
 	{
-		getBattleTracker().sendBattleRecordsToGameData(m_bridge);
-		getBattleTracker().clearBattleRecords();
-		scramblingCleanup();
-		airBattleCleanup();
-		checkDefendingPlanesCanLand();
+		if (m_needToRecordBattleStatistics)
+		{
+			getBattleTracker().sendBattleRecordsToGameData(m_bridge);
+			m_needToRecordBattleStatistics = false;
+		}
+		if (m_needToCleanup)
+		{
+			getBattleTracker().clearBattleRecords();
+			scramblingCleanup();
+			airBattleCleanup();
+			m_needToCleanup = false;
+		}
+		if (m_needToCheckDefendingPlanesCanLand)
+		{
+			checkDefendingPlanesCanLand();
+			m_needToCheckDefendingPlanesCanLand = false;
+		}
 		super.end();
 		m_needToInitialize = true;
+		m_needToScramble = true;
+		m_needToKamikazeSuicideAttacks = true;
+		m_needToAddBombardmentSources = true;
+		m_needToRecordBattleStatistics = true;
+		m_needToCleanup = true;
+		m_needToCheckDefendingPlanesCanLand = true;
 	}
 	
 	@Override
@@ -120,6 +157,12 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 		state.m_battleTracker = m_battleTracker;
 		state.m_originalOwnerTracker = m_originalOwnerTracker;
 		state.m_needToInitialize = m_needToInitialize;
+		state.m_needToScramble = m_needToScramble;
+		state.m_needToKamikazeSuicideAttacks = m_needToKamikazeSuicideAttacks;
+		state.m_needToAddBombardmentSources = m_needToAddBombardmentSources;
+		state.m_needToRecordBattleStatistics = m_needToRecordBattleStatistics;
+		state.m_needToCheckDefendingPlanesCanLand = m_needToCheckDefendingPlanesCanLand;
+		state.m_needToCleanup = m_needToCleanup;
 		state.m_currentBattle = m_currentBattle;
 		return state;
 	}
@@ -133,9 +176,33 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 		m_battleTracker = s.m_battleTracker;
 		m_originalOwnerTracker = s.m_originalOwnerTracker;
 		m_needToInitialize = s.m_needToInitialize;
+		m_needToScramble = s.m_needToScramble;
+		m_needToKamikazeSuicideAttacks = s.m_needToKamikazeSuicideAttacks;
+		m_needToAddBombardmentSources = s.m_needToAddBombardmentSources;
+		m_needToRecordBattleStatistics = s.m_needToRecordBattleStatistics;
+		m_needToCheckDefendingPlanesCanLand = s.m_needToCheckDefendingPlanesCanLand;
+		m_needToCleanup = s.m_needToCleanup;
 		m_currentBattle = s.m_currentBattle;
 	}
 	
+	public static void doInitialize(final BattleTracker battleTracker, final IDelegateBridge aBridge)
+	{
+		setupUnitsInSameTerritoryBattles(battleTracker, aBridge);
+		battleTracker.clearFinishedBattles(aBridge); // these are "blitzed" and "conquered" territories without a fight, without a pending battle
+		resetMaxScrambleCount(aBridge);
+	}
+	
+	public String fightCurrentBattle()
+	{
+		if (m_currentBattle == null)
+			return null;
+		// fight the battle
+		m_currentBattle.fight(m_bridge);
+		m_currentBattle = null;
+		// and were done
+		return null;
+	}
+	
 	public String fightBattle(final Territory territory, final boolean bombing)
 	{
 		final IBattle battle = m_battleTracker.getPendingBattle(territory, bombing);
@@ -283,6 +350,9 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 			while (bombardingTerritories.hasNext())
 			{
 				final Territory neighbor = bombardingTerritories.next();
+				// we do not allow bombarding from certain sea zones (like if there was a kamikaze suicide attack there, etc)
+				if (m_battleTracker.noBombardAllowedFromHere(neighbor))
+					continue;
 				// If all units from a territory are air- no bombard
 				if (Match.allMatch(attackingFromMap.get(neighbor), Matches.UnitIsAir))
 				{
@@ -342,23 +412,49 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 		return null; // User elected not to bombard with this unit
 	}
 	
+	private static void landParatroopers(final PlayerID player, final Territory battleSite, final GameData data, final IDelegateBridge bridge)
+	{
+		if (TechTracker.hasParatroopers(player))
+		{
+			final Collection<Unit> airTransports = Match.getMatches(battleSite.getUnits().getUnits(), Matches.UnitIsAirTransport);
+			final Collection<Unit> paratroops = Match.getMatches(battleSite.getUnits().getUnits(), Matches.UnitIsAirTransportable);
+			if (!airTransports.isEmpty() && !paratroops.isEmpty())
+			{
+				final CompositeChange change = new CompositeChange();
+				for (final Unit u : paratroops)
+				{
+					final TripleAUnit taUnit = (TripleAUnit) u;
+					final Unit transport = taUnit.getTransportedBy();
+					if (transport == null || !airTransports.contains(transport))
+						continue;
+					change.add(DelegateFinder.moveDelegate(data).getTransportTracker().unloadAirTransportChange(taUnit, battleSite, player, false));
+				}
+				if (!change.isEmpty())
+				{
+					bridge.getHistoryWriter().startEvent(player.getName() + " lands units in " + battleSite.getName());
+					bridge.addChange(change);
+				}
+			}
+		}
+	}
+	
 	/**
 	 * Setup the battles where the battle occurs because units are in the
 	 * same territory. This happens when subs emerge (after being submerged), and
 	 * when naval units are placed in enemy occupied sea zones, and also
 	 * when political relationships change and potentially leave units in now-hostile territories.
 	 */
-	private void setupUnitsInSameTerritoryBattles()
+	private static void setupUnitsInSameTerritoryBattles(final BattleTracker battleTracker, final IDelegateBridge aBridge)
 	{
-		final PlayerID player = m_bridge.getPlayerID();
-		final GameData data = getData();
+		final PlayerID player = aBridge.getPlayerID();
+		final GameData data = aBridge.getData();
 		final boolean ignoreTransports = isIgnoreTransportInMovement(data);
 		final boolean ignoreSubs = isIgnoreSubInMovement(data);
 		final CompositeMatchAnd<Unit> seaTransports = new CompositeMatchAnd<Unit>(Matches.UnitIsTransportButNotCombatTransport, Matches.UnitIsSea);
 		final CompositeMatchOr<Unit> seaTranportsOrSubs = new CompositeMatchOr<Unit>(seaTransports, Matches.UnitIsSub);
 		// we want to match all sea zones with our units and enemy units
 		final CompositeMatch<Territory> anyTerritoryWithOwnAndEnemy = new CompositeMatchAnd<Territory>(Matches.territoryHasUnitsOwnedBy(player), Matches.territoryHasEnemyUnits(player, data));
-		final CompositeMatch<Territory> enemyTerritoryAndOwnUnits = new CompositeMatchAnd<Territory>(Matches.isTerritoryEnemyAndNotUnownedWater(player, getData()),
+		final CompositeMatch<Territory> enemyTerritoryAndOwnUnits = new CompositeMatchAnd<Territory>(Matches.isTerritoryEnemyAndNotUnownedWater(player, data),
 					Matches.territoryHasUnitsOwnedBy(player));
 		final CompositeMatch<Territory> enemyUnitsOrEnemyTerritory = new CompositeMatchOr<Territory>(anyTerritoryWithOwnAndEnemy, enemyTerritoryAndOwnUnits);
 		final Iterator<Territory> battleTerritories = Match.getMatches(data.getMap().getTerritories(), enemyUnitsOrEnemyTerritory).iterator();
@@ -367,26 +463,29 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 			final Territory territory = battleTerritories.next();
 			final List<Unit> attackingUnits = territory.getUnits().getMatches(Matches.unitIsOwnedBy(player));
 			final List<Unit> enemyUnits = territory.getUnits().getMatches(Matches.enemyUnit(player, data));
-			final IBattle bombingBattle = m_battleTracker.getPendingBattle(territory, true);
+			final IBattle bombingBattle = battleTracker.getPendingBattle(territory, true);
 			if (bombingBattle != null)
 			{
 				// we need to remove any units which are participating in bombing raids
 				attackingUnits.removeAll(bombingBattle.getAttackingUnits());
 			}
-			if (attackingUnits.isEmpty() || Match.allMatch(attackingUnits, Matches.UnitIsFactoryOrIsInfrastructure))
+			if (attackingUnits.isEmpty() || Match.allMatch(attackingUnits, Matches.UnitIsInfrastructure))
 				continue;
-			IBattle battle = m_battleTracker.getPendingBattle(territory, false);
+			IBattle battle = battleTracker.getPendingBattle(territory, false);
 			if (battle == null)
 			{
-				m_bridge.getHistoryWriter().startEvent(player.getName() + " creates battle in territory " + territory.getName());
-				m_battleTracker.addBattle(new RouteScripted(territory), attackingUnits, false, player, m_bridge, null);
-				battle = m_battleTracker.getPendingBattle(territory, false);
+				// we must land any paratroopers here, but only if there is not going to be a battle (cus battles land them separately, after aa fires)
+				if (enemyUnits.isEmpty() || Match.allMatch(enemyUnits, Matches.UnitIsInfrastructure))
+					landParatroopers(player, territory, data, aBridge);
+				aBridge.getHistoryWriter().startEvent(player.getName() + " creates battle in territory " + territory.getName());
+				battleTracker.addBattle(new RouteScripted(territory), attackingUnits, false, player, aBridge, null, null);
+				battle = battleTracker.getPendingBattle(territory, false);
 			}
 			if (battle == null)
 				continue;
 			if (battle != null && bombingBattle != null)
 			{
-				m_battleTracker.addDependency(battle, bombingBattle);
+				battleTracker.addDependency(battle, bombingBattle);
 			}
 			if (battle != null && battle.isEmpty())
 				battle.addAttackChange(new RouteScripted(territory), attackingUnits, null);
@@ -407,24 +506,24 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 			if (battle != null && (ignoreTransports && Match.allMatch(attackingUnits, seaTransports) && Match.allMatch(enemyUnits, seaTransports))
 						|| ((Match.allMatch(attackingUnits, Matches.unitHasAttackValueOfAtLeast(1).invert())) && Match.allMatch(enemyUnits, Matches.unitHasDefendValueOfAtLeast(1).invert())))
 			{
-				final BattleResults results = new BattleResults(battle, WhoWon.DRAW);
-				m_battleTracker.getBattleRecords().addResultToBattle(player, battle.getBattleID(), null, 0, 0, BattleRecords.BattleResultDescription.STALEMATE, results, 0);
-				m_battleTracker.removeBattle(battle);
+				final BattleResults results = new BattleResults(battle, WhoWon.DRAW, data);
+				battleTracker.getBattleRecords(data).addResultToBattle(player, battle.getBattleID(), null, 0, 0, BattleRecord.BattleResultDescription.STALEMATE, results, 0);
+				battleTracker.removeBattle(battle);
 				continue;
 			}
 			// Check for ignored units
 			if (battle != null && !attackingUnits.isEmpty() && (ignoreTransports || ignoreSubs))
 			{
 				// TODO check if incoming units can attack before asking
-				final ITripleaPlayer remotePlayer = (ITripleaPlayer) m_bridge.getRemote();
+				final ITripleaPlayer remotePlayer = (ITripleaPlayer) aBridge.getRemote();
 				// if only enemy transports... attack them?
 				if (ignoreTransports && Match.allMatch(enemyUnits, seaTransports))
 				{
 					if (!remotePlayer.selectAttackTransports(territory))
 					{
-						final BattleResults results = new BattleResults(battle, WhoWon.ATTACKER);
-						m_battleTracker.getBattleRecords().addResultToBattle(player, battle.getBattleID(), null, 0, 0, BattleRecords.BattleResultDescription.WON_WITH_ENEMY_LEFT, results, 0);
-						m_battleTracker.removeBattle(battle);
+						final BattleResults results = new BattleResults(battle, WhoWon.ATTACKER, data);
+						battleTracker.getBattleRecords(data).addResultToBattle(player, battle.getBattleID(), null, 0, 0, BattleRecord.BattleResultDescription.WON_WITH_ENEMY_LEFT, results, 0);
+						battleTracker.removeBattle(battle);
 						// TODO perhaps try to reverse the setting of 0 movement left
 						/*CompositeChange change = new CompositeChange();
 						Iterator<Unit> attackIter = attackingUnits.iterator();
@@ -442,9 +541,9 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 				{
 					if (!remotePlayer.selectAttackSubs(territory))
 					{
-						final BattleResults results = new BattleResults(battle, WhoWon.ATTACKER);
-						m_battleTracker.getBattleRecords().addResultToBattle(player, battle.getBattleID(), null, 0, 0, BattleRecords.BattleResultDescription.WON_WITH_ENEMY_LEFT, results, 0);
-						m_battleTracker.removeBattle(battle);
+						final BattleResults results = new BattleResults(battle, WhoWon.ATTACKER, data);
+						battleTracker.getBattleRecords(data).addResultToBattle(player, battle.getBattleID(), null, 0, 0, BattleRecord.BattleResultDescription.WON_WITH_ENEMY_LEFT, results, 0);
+						battleTracker.removeBattle(battle);
 					}
 					continue;
 				}
@@ -453,9 +552,9 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 				{
 					if (!remotePlayer.selectAttackUnits(territory))
 					{
-						final BattleResults results = new BattleResults(battle, WhoWon.ATTACKER);
-						m_battleTracker.getBattleRecords().addResultToBattle(player, battle.getBattleID(), null, 0, 0, BattleRecords.BattleResultDescription.WON_WITH_ENEMY_LEFT, results, 0);
-						m_battleTracker.removeBattle(battle);
+						final BattleResults results = new BattleResults(battle, WhoWon.ATTACKER, data);
+						battleTracker.getBattleRecords(data).addResultToBattle(player, battle.getBattleID(), null, 0, 0, BattleRecord.BattleResultDescription.WON_WITH_ENEMY_LEFT, results, 0);
+						battleTracker.removeBattle(battle);
 					}
 					continue;
 				}
@@ -481,9 +580,10 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 			if (ua.getCanScramble() && maxScrambleDistance < ua.getMaxScrambleDistance())
 				maxScrambleDistance = ua.getMaxScrambleDistance();
 		}
+		final Match<Unit> airbasesCanScramble = new CompositeMatchAnd<Unit>(Matches.unitIsEnemyOf(data, m_player), Matches.UnitIsAirBase, Matches.UnitIsDisabled().invert());
 		final CompositeMatchAnd<Territory> canScramble = new CompositeMatchAnd<Territory>(new CompositeMatchOr<Territory>(Matches.TerritoryIsWater, Matches.isTerritoryEnemy(m_player, data)),
 					Matches.territoryHasUnitsThatMatch(new CompositeMatchAnd<Unit>(Matches.UnitCanScramble, Matches.unitIsEnemyOf(data, m_player), Matches.UnitIsDisabled().invert())),
-					Matches.territoryHasUnitsThatMatch(new CompositeMatchAnd<Unit>(Matches.UnitIsAirBase, Matches.unitIsEnemyOf(data, m_player), Matches.UnitIsDisabled().invert())));
+					Matches.territoryHasUnitsThatMatch(airbasesCanScramble));
 		if (fromIslandOnly)
 			canScramble.add(Matches.TerritoryIsIsland);
 		final HashMap<Territory, HashSet<Territory>> scrambleTerrs = new HashMap<Territory, HashSet<Territory>>();
@@ -519,7 +619,25 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 						if (canScrambleFrom == null)
 							canScrambleFrom = new HashSet<Territory>();
 						if (toAnyAmphibious)
-							canScrambleFrom.addAll(Match.getMatches(data.getMap().getNeighbors(battleTerr, maxScrambleDistance), canScramble));
+							canScrambleFrom.addAll(Match.getMatches(data.getMap().getNeighbors(amphibFrom, maxScrambleDistance), canScramble));
+						else if (canScramble.match(battleTerr))
+							canScrambleFrom.add(battleTerr);
+						if (!canScrambleFrom.isEmpty())
+							scrambleTerrs.put(amphibFrom, canScrambleFrom);
+					}
+				}
+				if (battle instanceof NonFightingBattle)
+				{
+					final NonFightingBattle nfb = (NonFightingBattle) battle;
+					final Collection<Territory> amphibFromTerrs = nfb.getAmphibiousAttackTerritories();
+					amphibFromTerrs.removeAll(territoriesWithBattlesWater);
+					for (final Territory amphibFrom : amphibFromTerrs)
+					{
+						HashSet<Territory> canScrambleFrom = scrambleTerrs.get(amphibFrom);
+						if (canScrambleFrom == null)
+							canScrambleFrom = new HashSet<Territory>();
+						if (toAnyAmphibious)
+							canScrambleFrom.addAll(Match.getMatches(data.getMap().getNeighbors(amphibFrom, maxScrambleDistance), canScramble));
 						else if (canScramble.match(battleTerr))
 							canScrambleFrom.add(battleTerr);
 						if (!canScrambleFrom.isEmpty())
@@ -532,45 +650,35 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 		// now scrambleTerrs is a list of places we can scramble from
 		if (scrambleTerrs.isEmpty())
 			return;
-		final HashMap<Tuple<Territory, PlayerID>, Collection<HashMap<Territory, Tuple<Integer, Collection<Unit>>>>> scramblersByTerritoryPlayer = new HashMap<Tuple<Territory, PlayerID>, Collection<HashMap<Territory, Tuple<Integer, Collection<Unit>>>>>();
+		final HashMap<Tuple<Territory, PlayerID>, Collection<HashMap<Territory, Tuple<Collection<Unit>, Collection<Unit>>>>> scramblersByTerritoryPlayer = new HashMap<Tuple<Territory, PlayerID>, Collection<HashMap<Territory, Tuple<Collection<Unit>, Collection<Unit>>>>>();
 		for (final Territory to : scrambleTerrs.keySet())
 		{
-			final HashMap<Territory, Tuple<Integer, Collection<Unit>>> scramblers = new HashMap<Territory, Tuple<Integer, Collection<Unit>>>();
+			final HashMap<Territory, Tuple<Collection<Unit>, Collection<Unit>>> scramblers = new HashMap<Territory, Tuple<Collection<Unit>, Collection<Unit>>>();
 			// find who we should ask
 			PlayerID defender = null;
 			if (m_battleTracker.hasPendingBattle(to, false))
 				defender = MustFightBattle.findDefender(to, m_player, data);
 			for (final Territory from : scrambleTerrs.get(to))
 			{
-				final Collection<Unit> airbases = from.getUnits().getMatches(
-							new CompositeMatchAnd<Unit>(Matches.unitIsEnemyOf(data, m_player), Matches.UnitIsAirBase, Matches.UnitIsDisabled().invert()));
 				if (defender == null)
 				{
 					defender = MustFightBattle.findDefender(from, m_player, data);
 				}
-				
 				// find how many is the max this territory can scramble
-				int maxScrambled = 0;
-				for (final Unit base : airbases)
-				{
-					int tempMax = UnitAttachment.get(base.getType()).getMaxScrambleCount();
-					if (tempMax == -1)
-						tempMax = Integer.MAX_VALUE;
-					if (tempMax > maxScrambled)
-						maxScrambled = tempMax;
-				}
+				final Collection<Unit> airbases = from.getUnits().getMatches(airbasesCanScramble);
+				final int maxCanScramble = getMaxScrambleCount(airbases);
 				final Route toBattleRoute = data.getMap().getRoute_IgnoreEnd(from, to, Matches.TerritoryIsNotImpassable);
 				final Collection<Unit> canScrambleAir = from.getUnits().getMatches(new CompositeMatchAnd<Unit>(Matches.unitIsEnemyOf(data, m_player), Matches.UnitCanScramble,
 							Matches.UnitIsDisabled().invert(), Matches.UnitWasScrambled.invert(), Matches.unitCanScrambleOnRouteDistance(toBattleRoute)));
-				if (maxScrambled > 0 && !canScrambleAir.isEmpty())
-					scramblers.put(from, new Tuple<Integer, Collection<Unit>>(maxScrambled, canScrambleAir));
+				if (maxCanScramble > 0 && !canScrambleAir.isEmpty())
+					scramblers.put(from, new Tuple<Collection<Unit>, Collection<Unit>>(airbases, canScrambleAir));
 			}
 			if (defender == null || scramblers.isEmpty())
 				continue;
 			final Tuple<Territory, PlayerID> terrPlayer = new Tuple<Territory, PlayerID>(to, defender);
-			Collection<HashMap<Territory, Tuple<Integer, Collection<Unit>>>> tempScrambleList = scramblersByTerritoryPlayer.get(terrPlayer);
+			Collection<HashMap<Territory, Tuple<Collection<Unit>, Collection<Unit>>>> tempScrambleList = scramblersByTerritoryPlayer.get(terrPlayer);
 			if (tempScrambleList == null)
-				tempScrambleList = new ArrayList<HashMap<Territory, Tuple<Integer, Collection<Unit>>>>();
+				tempScrambleList = new ArrayList<HashMap<Territory, Tuple<Collection<Unit>, Collection<Unit>>>>();
 			tempScrambleList.add(scramblers);
 			scramblersByTerritoryPlayer.put(terrPlayer, tempScrambleList);
 		}
@@ -583,7 +691,7 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 			if (defender == null || defender.isNull())
 				continue;
 			boolean scrambledHere = false;
-			for (final HashMap<Territory, Tuple<Integer, Collection<Unit>>> scramblers : scramblersByTerritoryPlayer.get(terrPlayer))
+			for (final HashMap<Territory, Tuple<Collection<Unit>, Collection<Unit>>> scramblers : scramblersByTerritoryPlayer.get(terrPlayer))
 			{
 				// verify that we didn't already scramble any of these units
 				final Iterator<Territory> tIter = scramblers.keySet().iterator();
@@ -608,7 +716,7 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 				{
 					if (toScramble.get(t) == null)
 						continue;
-					if (toScramble.get(t).size() > scramblers.get(t).getFirst())
+					if (toScramble.get(t).size() > getMaxScrambleCount(scramblers.get(t).getFirst()))
 						throw new IllegalStateException("Trying to scramble " + toScramble.get(t).size() + " out of " + t.getName() + ", but max allowed is " + scramblers.get(t).getFirst());
 				}
 				
@@ -618,6 +726,34 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 					final Collection<Unit> scrambling = toScramble.get(t);
 					if (scrambling == null || scrambling.isEmpty())
 						continue;
+					int numberScrambled = scrambling.size();
+					final Collection<Unit> airbases = t.getUnits().getMatches(airbasesCanScramble);
+					final int maxCanScramble = getMaxScrambleCount(airbases);
+					if (maxCanScramble != Integer.MAX_VALUE)
+					{
+						// TODO: maybe sort from biggest to smallest first?
+						for (final Unit airbase : airbases)
+						{
+							final int allowedScramble = ((TripleAUnit) airbase).getMaxScrambleCount();
+							int newAllowed = allowedScramble;
+							if (allowedScramble > 0)
+							{
+								if (allowedScramble >= numberScrambled)
+								{
+									newAllowed = allowedScramble - numberScrambled;
+									numberScrambled = 0;
+								}
+								else
+								{
+									newAllowed = 0;
+									numberScrambled -= allowedScramble;
+								}
+								change.add(ChangeFactory.unitPropertyChange(airbase, newAllowed, TripleAUnit.MAX_SCRAMBLE_COUNT));
+							}
+							if (numberScrambled <= 0)
+								break;
+						}
+					}
 					for (final Unit u : scrambling)
 					{
 						change.add(ChangeFactory.unitPropertyChange(u, t, TripleAUnit.ORIGINATED_FROM));
@@ -625,8 +761,7 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 					}
 					change.add(ChangeFactory.moveUnits(t, to, scrambling)); // should we mark combat, or call setupUnitsInSameTerritoryBattles again?
 					m_bridge.getHistoryWriter()
-								.startEvent(defender.getName() + " scrambles " + scrambling.size() + " units out of " + t.getName() + " to defend against the attack in " + to.getName());
-					m_bridge.getHistoryWriter().setRenderingData(scrambling);
+								.startEvent(defender.getName() + " scrambles " + scrambling.size() + " units out of " + t.getName() + " to defend against the attack in " + to.getName(), scrambling);
 					scrambledHere = true;
 				}
 				if (!change.isEmpty())
@@ -641,9 +776,72 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 			{
 				final List<Unit> attackingUnits = to.getUnits().getMatches(Matches.unitIsOwnedBy(m_player));
 				m_bridge.getHistoryWriter().startEvent(defender.getName() + " scrambles to create a battle in territory " + to.getName());
-				// TODO: the attacking sea units do not remember where they came from, so they can not retreat anywhere. Need to fix
-				m_battleTracker.addBattle(new RouteScripted(to), attackingUnits, false, m_player, m_bridge, null);
+				// TODO: the attacking sea units do not remember where they came from, so they can not retreat anywhere. Need to fix.
+				m_battleTracker.addBattle(new RouteScripted(to), attackingUnits, false, m_player, m_bridge, null, null);
 				battle = m_battleTracker.getPendingBattle(to, false);
+				if (battle instanceof MustFightBattle)
+				{
+					// this is an ugly mess of hacks, but will have to stay here till all transport related code is gutted and refactored.
+					final MustFightBattle mfb = (MustFightBattle) battle;
+					final Collection<Territory> neighborsLand = data.getMap().getNeighbors(to, Matches.TerritoryIsLand);
+					if (Match.someMatch(attackingUnits, Matches.UnitIsTransport))
+					{
+						// first, we have to reset the "transportedBy" setting for all the land units that were offloaded
+						final CompositeChange change1 = new CompositeChange();
+						mfb.reLoadTransports(attackingUnits, change1);
+						if (!change1.isEmpty())
+							m_bridge.addChange(change1);
+						// after that is applied, we have to make a map of all dependencies
+						final TransportTracker tt = new TransportTracker();
+						final Map<Territory, Map<Unit, Collection<Unit>>> dependencies = new HashMap<Territory, Map<Unit, Collection<Unit>>>();
+						final Map<Unit, Collection<Unit>> dependenciesForMFB = tt.transporting(attackingUnits, attackingUnits);
+						for (final Unit transport : Match.getMatches(attackingUnits, Matches.UnitIsTransport))
+						{
+							// however, the map we add to the newly created battle, can not hold any units that are NOT in this territory.
+							// BUT it must still hold all transports
+							if (!dependenciesForMFB.containsKey(transport))
+								dependenciesForMFB.put(transport, new ArrayList<Unit>());
+						}
+						dependencies.put(to, dependenciesForMFB);
+						for (final Territory t : neighborsLand)
+						{
+							// All other maps, must hold only the transported units that in their territory
+							final Collection<Unit> allNeighborUnits = new ArrayList<Unit>(Match.getMatches(attackingUnits, Matches.UnitIsTransport));
+							allNeighborUnits.addAll(t.getUnits().getMatches(Matches.unitIsLandAndOwnedBy(m_player)));
+							final Map<Unit, Collection<Unit>> dependenciesForNeighbors = tt.transporting(
+										Match.getMatches(allNeighborUnits, Matches.UnitIsTransport), Match.getMatches(allNeighborUnits, Matches.UnitIsTransport.invert()));
+							dependencies.put(t, dependenciesForNeighbors);
+						}
+						mfb.addDependentUnits(dependencies.get(to));
+						for (final Territory territoryNeighborToNewBattle : neighborsLand)
+						{
+							final IBattle battleInTerritoryNeighborToNewBattle = m_battleTracker.getPendingBattle(territoryNeighborToNewBattle, false);
+							if (battleInTerritoryNeighborToNewBattle != null && battleInTerritoryNeighborToNewBattle instanceof MustFightBattle)
+							{
+								final MustFightBattle mfbattleInTerritoryNeighborToNewBattle = (MustFightBattle) battleInTerritoryNeighborToNewBattle;
+								mfbattleInTerritoryNeighborToNewBattle.addDependentUnits(dependencies.get(territoryNeighborToNewBattle));
+							}
+							else if (battleInTerritoryNeighborToNewBattle != null && battleInTerritoryNeighborToNewBattle instanceof NonFightingBattle)
+							{
+								final NonFightingBattle nfbattleInTerritoryNeighborToNewBattle = (NonFightingBattle) battleInTerritoryNeighborToNewBattle;
+								nfbattleInTerritoryNeighborToNewBattle.addDependentUnits(dependencies.get(territoryNeighborToNewBattle));
+							}
+						}
+					}
+					if (Match.someMatch(attackingUnits, Matches.UnitIsAir.invert()))
+					{
+						// for now, we will hack and say that the attackers came from Everywhere, and hope the user will choose the correct place to retreat to! (TODO: Fix this)
+						final Map<Territory, Collection<Unit>> attackingFromMap = new HashMap<Territory, Collection<Unit>>();
+						final Collection<Territory> neighbors = data.getMap().getNeighbors(to, (Matches.TerritoryIsLand.match(to) ? Matches.TerritoryIsLand : Matches.TerritoryIsWater));
+						neighbors.removeAll(territoriesWithBattles);
+						neighbors.removeAll(Match.getMatches(neighbors, Matches.territoryHasEnemyUnits(m_player, data)));
+						for (final Territory t : neighbors)
+						{
+							attackingFromMap.put(t, attackingUnits);
+						}
+						mfb.setAttackingFromAndMap(attackingFromMap);
+					}
+				}
 			}
 			else if (battle instanceof MustFightBattle)
 			{
@@ -670,6 +868,22 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 		}
 	}
 	
+	public static int getMaxScrambleCount(final Collection<Unit> airbases)
+	{
+		if (!Match.allMatch(airbases, new CompositeMatchAnd<Unit>(Matches.UnitIsAirBase, Matches.UnitIsDisabled().invert())))
+			throw new IllegalStateException("All units must be viable airbases");
+		// find how many is the max this territory can scramble
+		int maxScrambled = 0;
+		for (final Unit base : airbases)
+		{
+			final int baseMax = ((TripleAUnit) base).getMaxScrambleCount();
+			if (baseMax == -1)
+				return Integer.MAX_VALUE;
+			maxScrambled += baseMax;
+		}
+		return maxScrambled;
+	}
+	
 	private void scramblingCleanup()
 	{
 		// return scrambled units to their original territories, or let them move 1 or x to a new territory.
@@ -715,14 +929,39 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 				change.add(ChangeFactory.unitPropertyChange(u, false, TripleAUnit.WAS_SCRAMBLED));
 				if (!change.isEmpty())
 				{
-					m_bridge.getHistoryWriter().startEvent(historyText);
-					m_bridge.getHistoryWriter().setRenderingData(u);
+					m_bridge.getHistoryWriter().startEvent(historyText, u);
 					m_bridge.addChange(change);
 				}
 			}
 		}
 	}
 	
+	private static void resetMaxScrambleCount(final IDelegateBridge aBridge)
+	{
+		// reset the tripleaUnit property for all airbases that were used
+		final GameData data = aBridge.getData();
+		if (!games.strategy.triplea.Properties.getScramble_Rules_In_Effect(data))
+			return;
+		final CompositeChange change = new CompositeChange();
+		for (final Territory t : data.getMap().getTerritories())
+		{
+			final Collection<Unit> airbases = t.getUnits().getMatches(Matches.UnitIsAirBase);
+			for (final Unit u : airbases)
+			{
+				final UnitAttachment ua = UnitAttachment.get(u.getType());
+				final int currentMax = ((TripleAUnit) u).getMaxScrambleCount();
+				final int allowedMax = ua.getMaxScrambleCount();
+				if (currentMax != allowedMax)
+					change.add(ChangeFactory.unitPropertyChange(u, allowedMax, TripleAUnit.MAX_SCRAMBLE_COUNT));
+			}
+		}
+		if (!change.isEmpty())
+		{
+			aBridge.getHistoryWriter().startEvent("Preparing Airbases for Possible Scrambling");
+			aBridge.addChange(change);
+		}
+	}
+	
 	private void airBattleCleanup()
 	{
 		final GameData data = getData();
@@ -898,6 +1137,8 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 		final Match<Unit> canBeAttackedDefault = new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(m_player), Matches.UnitIsSea,
 					Matches.UnitIsNotTransportButCouldBeCombatTransport, Matches.UnitIsNotSub);
 		
+		final boolean onlyWhereThereAreBattlesOrAmphibious = games.strategy.triplea.Properties.getKamikazeSuicideAttacksOnlyWhereBattlesAre(data);
+		final Collection<Territory> pendingBattles = m_battleTracker.getPendingBattleSites(false);
 		// create a list of all kamikaze zones, listed by enemy
 		final HashMap<PlayerID, Collection<Territory>> kamikazeZonesByEnemy = new HashMap<PlayerID, Collection<Territory>>();
 		for (final Territory t : data.getMap().getTerritories())
@@ -926,6 +1167,40 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 			{
 				if (Match.noneMatch(t.getUnits().getUnits(), Matches.unitIsOwnedBy(m_player)))
 					continue;
+				if (onlyWhereThereAreBattlesOrAmphibious)
+				{
+					// if no battle or amphibious from here, ignore it
+					if (!pendingBattles.contains(t))
+					{
+						if (!Matches.TerritoryIsWater.match(t))
+							continue;
+						boolean amphib = false;
+						final Collection<Territory> landNeighbors = data.getMap().getNeighbors(t, Matches.TerritoryIsLand);
+						for (final Territory neighbor : landNeighbors)
+						{
+							final IBattle battle = m_battleTracker.getPendingBattle(neighbor, false);
+							if (battle == null)
+							{
+								final Map<Territory, Collection<Unit>> whereFrom = m_battleTracker.getFinishedBattlesUnitAttackFromMap().get(neighbor);
+								if (whereFrom != null && whereFrom.containsKey(t))
+								{
+									amphib = true;
+									break;
+								}
+								continue;
+							}
+							if (battle.isAmphibious() &&
+										((battle instanceof MustFightBattle && ((MustFightBattle) battle).getAmphibiousAttackTerritories().contains(t))
+													|| (battle instanceof NonFightingBattle && ((NonFightingBattle) battle).getAmphibiousAttackTerritories().contains(t))))
+							{
+								amphib = true;
+								break;
+							}
+						}
+						if (amphib == false)
+							continue;
+					}
+				}
 				Collection<Territory> currentTerrs = kamikazeZonesByEnemy.get(owner);
 				if (currentTerrs == null)
 					currentTerrs = new ArrayList<Territory>();
@@ -1035,7 +1310,7 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 				final int remainder = power % diceSides;
 				if (remainder > 0)
 				{
-					rolls = m_bridge.getRandom(diceSides, 1, "Rolling for remainder in Kamikaze Suicide Attack on unit: " + unitUnderFire.getType().getName());
+					rolls = m_bridge.getRandom(diceSides, 1, firingEnemy, DiceType.COMBAT, "Rolling for remainder in Kamikaze Suicide Attack on unit: " + unitUnderFire.getType().getName());
 					if (remainder > rolls[0])
 						hits++;
 				}
@@ -1045,7 +1320,7 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 		{
 			// avoid multiple calls of getRandom, so just do it once at the beginning
 			final int numTokens = numberOfAttacks.totalValues();
-			rolls = m_bridge.getRandom(diceSides, numTokens, "Rolling for Kamikaze Suicide Attack on unit: " + unitUnderFire.getType().getName());
+			rolls = m_bridge.getRandom(diceSides, numTokens, firingEnemy, DiceType.COMBAT, "Rolling for Kamikaze Suicide Attack on unit: " + unitUnderFire.getType().getName());
 			final int[] powerOfTokens = new int[numTokens];
 			int j = 0;
 			for (final Entry<Resource, Integer> entry : numberOfAttacks.entrySet())
@@ -1069,8 +1344,7 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 		}
 		final String title = "Kamikaze Suicide Attack attacks " + MyFormatter.unitsToText(Collections.singleton(unitUnderFire));
 		final String dice = " scoring " + hits + " hits.  Rolls: " + MyFormatter.asDice(rolls);
-		m_bridge.getHistoryWriter().startEvent(title + dice);
-		m_bridge.getHistoryWriter().setRenderingData(unitUnderFire);
+		m_bridge.getHistoryWriter().startEvent(title + dice, unitUnderFire);
 		if (hits > 0)
 		{
 			final UnitAttachment ua = UnitAttachment.get(unitUnderFire.getType());
@@ -1092,6 +1366,8 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 		{
 			m_bridge.addChange(change);
 		}
+		// kamikaze suicide attacks, even if unsuccessful, deny the ability to bombard from this sea zone
+		m_battleTracker.addNoBombardAllowedFromHere(location);
 		// TODO: display this as actual dice for both players
 		// TODO: display to all players, and only once per physical machine
 		getRemote(m_player, m_bridge).reportMessage(title + dice, title);
@@ -1223,7 +1499,7 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 		return (ITripleaPlayer) bridge.getRemote(player);
 	}
 	
-	public Territory getCurentBattle()
+	public Territory getCurrentBattleTerritory()
 	{
 		final IBattle b = m_currentBattle;
 		if (b != null)
@@ -1235,16 +1511,27 @@ public class BattleDelegate extends BaseDelegate implements IBattleDelegate
 			return null;
 		}
 	}
+	
+	public IBattle getCurrentBattle()
+	{
+		return m_currentBattle;
+	}
 }
 
 
-@SuppressWarnings("serial")
 class BattleExtendedDelegateState implements Serializable
 {
+	private static final long serialVersionUID = 7899007486408723505L;
 	Serializable superState;
 	// add other variables here:
 	public BattleTracker m_battleTracker = new BattleTracker();
 	public OriginalOwnerTracker m_originalOwnerTracker = new OriginalOwnerTracker();
 	public boolean m_needToInitialize;
+	public boolean m_needToScramble;
+	public boolean m_needToKamikazeSuicideAttacks;
+	public boolean m_needToAddBombardmentSources;
+	public boolean m_needToRecordBattleStatistics;
+	public boolean m_needToCheckDefendingPlanesCanLand;
+	public boolean m_needToCleanup;
 	public IBattle m_currentBattle;
 }
