@@ -24,12 +24,15 @@ import games.strategy.engine.data.CompositeChange;
 import games.strategy.engine.data.GameData;
 import games.strategy.engine.data.PlayerID;
 import games.strategy.engine.data.RelationshipTracker;
+import games.strategy.engine.data.RelationshipType;
 import games.strategy.engine.data.Resource;
 import games.strategy.engine.data.Route;
 import games.strategy.engine.data.Territory;
 import games.strategy.engine.data.Unit;
 import games.strategy.engine.data.UnitType;
 import games.strategy.engine.delegate.IDelegateBridge;
+import games.strategy.sound.ClipPlayer;
+import games.strategy.sound.SoundPath;
 import games.strategy.triplea.Constants;
 import games.strategy.triplea.TripleAUnit;
 import games.strategy.triplea.attatchments.PlayerAttachment;
@@ -37,8 +40,8 @@ import games.strategy.triplea.attatchments.TerritoryAttachment;
 import games.strategy.triplea.attatchments.UnitAttachment;
 import games.strategy.triplea.delegate.IBattle.BattleType;
 import games.strategy.triplea.delegate.IBattle.WhoWon;
+import games.strategy.triplea.delegate.dataObjects.BattleRecord;
 import games.strategy.triplea.delegate.dataObjects.BattleRecords;
-import games.strategy.triplea.delegate.dataObjects.BattleRecords.BattleResultDescription;
 import games.strategy.triplea.formatter.MyFormatter;
 import games.strategy.triplea.oddsCalculator.ta.BattleResults;
 import games.strategy.util.CompositeMatch;
@@ -86,9 +89,14 @@ public class BattleTracker implements java.io.Serializable
 	// these territories have had battleships bombard during a naval invasion
 	// used to make sure that the same battleship doesn't bombard twice
 	private final Set<Territory> m_bombardedFromTerritories = new HashSet<Territory>();
+	// list of territory we have conquered in a FinishedBattle and where from and if amphibious
+	private final HashMap<Territory, Map<Territory, Collection<Unit>>> m_finishedBattlesUnitAttackFromMap = new HashMap<Territory, Map<Territory, Collection<Unit>>>();
+	// things like kamikaze suicide attacks disallow bombarding from that sea zone for that turn
+	private final Set<Territory> m_noBombardAllowed = new HashSet<Territory>();
 	private final Map<Territory, Collection<Unit>> m_defendingAirThatCanNotLand = new HashMap<Territory, Collection<Unit>>();
-	
-	private final BattleRecords m_battleRecords = new BattleRecords();
+	private BattleRecords m_battleRecords = null;
+	// to keep track of all relationships that have changed this turn (so we can validate things like transports loading in newly created hostile zones)
+	private final Collection<Tuple<Tuple<PlayerID, PlayerID>, Tuple<RelationshipType, RelationshipType>>> m_relationshipChangesThisTurn = new ArrayList<Tuple<Tuple<PlayerID, PlayerID>, Tuple<RelationshipType, RelationshipType>>>();
 	
 	/**
 	 * @param t
@@ -144,13 +152,80 @@ public class BattleTracker implements java.io.Serializable
 		return m_foughBattles.contains(t);
 	}
 	
+	public boolean noBombardAllowedFromHere(final Territory t)
+	{
+		return m_noBombardAllowed.contains(t);
+	}
+	
+	public void addNoBombardAllowedFromHere(final Territory t)
+	{
+		m_noBombardAllowed.add(t);
+	}
+	
+	public HashMap<Territory, Map<Territory, Collection<Unit>>> getFinishedBattlesUnitAttackFromMap()
+	{
+		return m_finishedBattlesUnitAttackFromMap;
+	}
+	
+	public void addRelationshipChangesThisTurn(final PlayerID p1, final PlayerID p2, final RelationshipType oldRelation, final RelationshipType newRelation)
+	{
+		
+		m_relationshipChangesThisTurn.add(new Tuple<Tuple<PlayerID, PlayerID>, Tuple<RelationshipType, RelationshipType>>(
+					new Tuple<PlayerID, PlayerID>(p1, p2), new Tuple<RelationshipType, RelationshipType>(oldRelation, newRelation)));
+	}
+	
+	public boolean didAllThesePlayersJustGoToWarThisTurn(final PlayerID p1, final Collection<Unit> enemyUnits, final GameData data)
+	{
+		final Set<PlayerID> enemies = new HashSet<PlayerID>();
+		for (final Unit u : Match.getMatches(enemyUnits, Matches.unitIsEnemyOf(data, p1)))
+		{
+			enemies.add(u.getOwner());
+		}
+		for (final PlayerID e : enemies)
+		{
+			if (!didThesePlayersJustGoToWarThisTurn(p1, e))
+				return false;
+		}
+		return true;
+	}
+	
+	public boolean didThesePlayersJustGoToWarThisTurn(final PlayerID p1, final PlayerID p2)
+	{
+		// check all relationship changes that are p1 and p2, to make sure that oldRelation is not war, and newRelation is war
+		for (final Tuple<Tuple<PlayerID, PlayerID>, Tuple<RelationshipType, RelationshipType>> t : m_relationshipChangesThisTurn)
+		{
+			final Tuple<PlayerID, PlayerID> players = t.getFirst();
+			if (players.getFirst().equals(p1))
+			{
+				if (!players.getSecond().equals(p2))
+					continue;
+			}
+			else if (players.getSecond().equals(p1))
+			{
+				if (!players.getFirst().equals(p2))
+					continue;
+			}
+			else
+				continue;
+			final Tuple<RelationshipType, RelationshipType> relations = t.getSecond();
+			if (!Matches.RelationshipTypeIsAtWar.match(relations.getFirst()))
+			{
+				if (Matches.RelationshipTypeIsAtWar.match(relations.getSecond()))
+					return true;
+			}
+		}
+		return false;
+	}
+	
 	void clearFinishedBattles(final IDelegateBridge bridge)
 	{
 		for (final IBattle battle : new ArrayList<IBattle>(m_pendingBattles))
 		{
 			if (FinishedBattle.class.isAssignableFrom(battle.getClass()))
 			{
-				((FinishedBattle) battle).fight(bridge);
+				final FinishedBattle finished = (FinishedBattle) battle;
+				m_finishedBattlesUnitAttackFromMap.put(finished.getTerritory(), finished.getAttackingFromMap());
+				finished.fight(bridge);
 			}
 		}
 	}
@@ -191,7 +266,10 @@ public class BattleTracker implements java.io.Serializable
 	
 	private void removeBattleForUndo(final PlayerID player, final IBattle battle)
 	{
-		m_battleRecords.removeBattle(player, battle.getBattleID());
+		if (m_battleRecords != null)
+		{
+			m_battleRecords.removeBattle(player, battle.getBattleID());
+		}
 		m_pendingBattles.remove(battle);
 		m_dependencies.remove(battle);
 		for (final Collection<IBattle> battles : m_dependencies.values())
@@ -200,13 +278,14 @@ public class BattleTracker implements java.io.Serializable
 		}
 	}
 	
-	public void addBattle(final Route route, final Collection<Unit> units, final boolean bombing, final PlayerID id, final IDelegateBridge bridge, final UndoableMove changeTracker)
+	public void addBattle(final Route route, final Collection<Unit> units, final boolean bombing, final PlayerID id, final IDelegateBridge bridge, final UndoableMove changeTracker,
+				final Collection<Unit> unitsNotUnloadedTilEndOfRoute)
 	{
-		this.addBattle(route, units, bombing, id, bridge, changeTracker, null, false);
+		this.addBattle(route, units, bombing, id, bridge, changeTracker, unitsNotUnloadedTilEndOfRoute, null, false);
 	}
 	
 	public void addBattle(final Route route, final Collection<Unit> units, final boolean bombing, final PlayerID id, final IDelegateBridge bridge, final UndoableMove changeTracker,
-				final HashMap<Unit, HashSet<Unit>> targets, final boolean airBattleCompleted)
+				final Collection<Unit> unitsNotUnloadedTilEndOfRoute, final HashMap<Unit, HashSet<Unit>> targets, final boolean airBattleCompleted)
 	{
 		final GameData data = bridge.getData();
 		if (bombing)
@@ -228,7 +307,7 @@ public class BattleTracker implements java.io.Serializable
 				changeTracker.addChange(change);
 			}
 			if (games.strategy.util.Match.someMatch(units, Matches.UnitIsLand) || games.strategy.util.Match.someMatch(units, Matches.UnitIsSea))
-				addEmptyBattle(route, units, id, bridge, changeTracker);
+				addEmptyBattle(route, units, id, bridge, changeTracker, unitsNotUnloadedTilEndOfRoute);
 		}
 	}
 	
@@ -261,7 +340,7 @@ public class BattleTracker implements java.io.Serializable
 		{
 			battle = new StrategicBombingRaidBattle(route.getEnd(), data, attacker, this);
 			m_pendingBattles.add(battle);
-			m_battleRecords.addBattle(attacker, battle.getBattleID(), route.getEnd(), battle.getBattleType());
+			getBattleRecords(data).addBattle(attacker, battle.getBattleID(), route.getEnd(), battle.getBattleType(), data);
 		}
 		final Change change = battle.addAttackChange(route, units, targets);
 		// when state is moved to the game data, this will change
@@ -282,7 +361,7 @@ public class BattleTracker implements java.io.Serializable
 		{
 			battle = new StrategicBombingRaidPreBattle(route.getEnd(), data, attacker, this);
 			m_pendingBattles.add(battle);
-			m_battleRecords.addBattle(attacker, battle.getBattleID(), route.getEnd(), battle.getBattleType());
+			getBattleRecords(data).addBattle(attacker, battle.getBattleID(), route.getEnd(), battle.getBattleType(), data);
 		}
 		final Change change = battle.addAttackChange(route, units, null);
 		// when state is moved to the game data, this will change
@@ -299,17 +378,30 @@ public class BattleTracker implements java.io.Serializable
 	/**
 	 * No enemies.
 	 */
-	private void addEmptyBattle(final Route route, final Collection<Unit> units, final PlayerID id, final IDelegateBridge bridge, final UndoableMove changeTracker)
+	private void addEmptyBattle(final Route route, final Collection<Unit> units, final PlayerID id, final IDelegateBridge bridge, final UndoableMove changeTracker,
+				final Collection<Unit> unitsNotUnloadedTilEndOfRoute)
 	{
 		final GameData data = bridge.getData();
+		final Collection<Unit> canConquer = Match.getMatches(units, Matches.unitIsBeingTransportedByOrIsDependentOfSomeUnitInThisList(units, route, id, data, false).invert());
+		if (Match.noneMatch(canConquer, Matches.UnitIsNotAir))
+			return;
+		final Collection<Unit> presentFromStartTilEnd = new ArrayList<Unit>(canConquer);
+		if (unitsNotUnloadedTilEndOfRoute != null)
+			presentFromStartTilEnd.removeAll(unitsNotUnloadedTilEndOfRoute);
+		final boolean canConquerMiddleSteps = Match.someMatch(presentFromStartTilEnd, Matches.UnitIsNotAir);
+		final boolean scramblingEnabled = games.strategy.triplea.Properties.getScramble_Rules_In_Effect(data);
 		final CompositeMatch<Territory> conquerable = new CompositeMatchAnd<Territory>();
 		conquerable.add(Matches.territoryIsEmptyOfCombatUnits(data, id));
 		conquerable.add(new CompositeMatchOr<Territory>(Matches.territoryIsOwnedByPlayerWhosRelationshipTypeCanTakeOverOwnedTerritoryAndPassableAndNotWater(id),
 					Matches.isTerritoryEnemyAndNotUnownedWaterOrImpassibleOrRestricted(id, data)));
-		final Collection<Territory> conquered = route.getMatches(conquerable);
-		// in case we begin in enemy territory, and blitz out of it, check the first territory
-		if (route.getStart() != route.getEnd() && conquerable.match(route.getStart()))
-			conquered.add(route.getStart());
+		final Collection<Territory> conquered = new ArrayList<Territory>();
+		if (canConquerMiddleSteps)
+		{
+			conquered.addAll(route.getMatches(conquerable));
+			// in case we begin in enemy territory, and blitz out of it, check the first territory
+			if (route.getStart() != route.getEnd() && conquerable.match(route.getStart()))
+				conquered.add(route.getStart());
+		}
 		// we handle the end of the route later
 		conquered.remove(route.getEnd());
 		final Collection<Territory> blitzed = Match.getMatches(conquered, Matches.TerritoryIsBlitzable(id, data));
@@ -318,15 +410,38 @@ public class BattleTracker implements java.io.Serializable
 		for (final Territory current : conquered)
 		{
 			IBattle nonFight = getPendingBattle(current, false);
+			// TODO: if we ever want to scramble to a blitzed territory, then we need to fix this stuff (currently doesn't work because then the territory is never conquered because the units have left the territory by the time we fight)
+			/*if (scramblingEnabled)
+			{
+				if (nonFight == null)
+				{
+					nonFight = new NonFightingBattle(current, id, this, data);
+					m_pendingBattles.add(nonFight);
+					getBattleRecords(data).addBattle(id, nonFight.getBattleID(), current, nonFight.getBattleType(), data);
+				}
+				final Change change = nonFight.addAttackChange(Route.subRoute(route, current), units, null);
+				bridge.addChange(change);
+				if (changeTracker != null)
+				{
+					changeTracker.addChange(change);
+				}
+			}
+			else
+			{*/
 			if (nonFight == null)
 			{
-				nonFight = new FinishedBattle(current, id, this, false, BattleType.NORMAL, data, BattleResultDescription.CONQUERED, WhoWon.ATTACKER, units);
+				nonFight = new FinishedBattle(current, id, this, false, BattleType.NORMAL, data, BattleRecord.BattleResultDescription.CONQUERED, WhoWon.ATTACKER, units);
 				m_pendingBattles.add(nonFight);
-				m_battleRecords.addBattle(id, nonFight.getBattleID(), current, nonFight.getBattleType());
-				// nonFight.fight(bridge);
-				// m_battleRecords.addResultToBattle(id, nonFight.getBattleID(), AbstractBattle.findDefender(current, id, data), 0, 0, nonFight.getBattleResultDescription(), new BattleResults(nonFight), 0);
+				getBattleRecords(data).addBattle(id, nonFight.getBattleID(), current, nonFight.getBattleType(), data);
+			}
+			final Change change = nonFight.addAttackChange(route, units, null);
+			bridge.addChange(change);
+			if (changeTracker != null)
+			{
+				changeTracker.addChange(change);
 			}
 			takeOver(current, id, bridge, changeTracker, units);
+			// }
 		}
 		// check the last territory
 		if (conquerable.match(route.getEnd()))
@@ -336,7 +451,27 @@ public class BattleTracker implements java.io.Serializable
 			{
 				precede = getPendingBattle(route.getEnd(), true);
 			}
-			if (precede == null)
+			// if we have a preceding battle, then we must use a non-fighting-battle
+			// if we have scrambling on, and this is an amphibious attack, we may wish to scramble to kill the transports, so must use non-fighting-battle also
+			if (precede != null || (scramblingEnabled && route.isUnload() && route.hasExactlyOneStep()))
+			{
+				IBattle nonFight = getPendingBattle(route.getEnd(), false);
+				if (nonFight == null)
+				{
+					nonFight = new NonFightingBattle(route.getEnd(), id, this, data);
+					m_pendingBattles.add(nonFight);
+					getBattleRecords(data).addBattle(id, nonFight.getBattleID(), route.getEnd(), nonFight.getBattleType(), data);
+				}
+				final Change change = nonFight.addAttackChange(route, units, null);
+				bridge.addChange(change);
+				if (changeTracker != null)
+				{
+					changeTracker.addChange(change);
+				}
+				if (precede != null)
+					addDependency(nonFight, precede);
+			}
+			else
 			{
 				if (Matches.isTerritoryEnemy(id, data).match(route.getEnd()))
 				{
@@ -349,20 +484,9 @@ public class BattleTracker implements java.io.Serializable
 				IBattle nonFight = getPendingBattle(route.getEnd(), false);
 				if (nonFight == null)
 				{
-					nonFight = new FinishedBattle(route.getEnd(), id, this, false, BattleType.NORMAL, data, BattleResultDescription.CONQUERED, WhoWon.ATTACKER, units);
+					nonFight = new FinishedBattle(route.getEnd(), id, this, false, BattleType.NORMAL, data, BattleRecord.BattleResultDescription.CONQUERED, WhoWon.ATTACKER, units);
 					m_pendingBattles.add(nonFight);
-					m_battleRecords.addBattle(id, nonFight.getBattleID(), route.getEnd(), nonFight.getBattleType());
-				}
-				takeOver(route.getEnd(), id, bridge, changeTracker, units);
-			}
-			else
-			{
-				IBattle nonFight = getPendingBattle(route.getEnd(), false);
-				if (nonFight == null)
-				{
-					nonFight = new NonFightingBattle(route.getEnd(), id, this, data);
-					m_pendingBattles.add(nonFight);
-					m_battleRecords.addBattle(id, nonFight.getBattleID(), route.getEnd(), nonFight.getBattleType());
+					getBattleRecords(data).addBattle(id, nonFight.getBattleID(), route.getEnd(), nonFight.getBattleType(), data);
 				}
 				final Change change = nonFight.addAttackChange(route, units, null);
 				bridge.addChange(change);
@@ -370,7 +494,7 @@ public class BattleTracker implements java.io.Serializable
 				{
 					changeTracker.addChange(change);
 				}
-				addDependency(nonFight, precede);
+				takeOver(route.getEnd(), id, bridge, changeTracker, units);
 			}
 		}
 		// TODO: else what?
@@ -379,11 +503,12 @@ public class BattleTracker implements java.io.Serializable
 	public void takeOver(final Territory territory, final PlayerID id, final IDelegateBridge bridge, final UndoableMove changeTracker, final Collection<Unit> arrivingUnits)
 	{
 		final GameData data = bridge.getData();
+		final Collection<Unit> arrivedUnits = (arrivingUnits == null ? null : new ArrayList<Unit>(arrivingUnits));
 		final OriginalOwnerTracker origOwnerTracker = DelegateFinder.battleDelegate(data).getOriginalOwnerTracker();
 		final RelationshipTracker relationshipTracker = data.getRelationshipTracker();
 		final boolean isTerritoryOwnerAnEnemy = relationshipTracker.canTakeOverOwnedTerritory(id, territory.getOwner()); // .isAtWar(id, territory.getOwner());
 		// If this is a convoy (we wouldn't be in this method otherwise) check to make sure attackers have more than just transports. If they don't, exit here.
-		if (territory.isWater() && arrivingUnits != null)
+		if (territory.isWater() && arrivedUnits != null)
 		{
 			int totalMatches = 0;
 			// 0 production waters aren't to be taken over
@@ -392,18 +517,18 @@ public class BattleTracker implements java.io.Serializable
 				return;
 			// Total Attacking Sea units = all units - land units - air units - submerged subs
 			// Also subtract transports & subs (if they can't control sea zones)
-			totalMatches = arrivingUnits.size() - Match.countMatches(arrivingUnits, Matches.UnitIsLand) - Match.countMatches(arrivingUnits, Matches.UnitIsAir)
-						- Match.countMatches(arrivingUnits, Matches.unitIsSubmerged(data));
+			totalMatches = arrivedUnits.size() - Match.countMatches(arrivedUnits, Matches.UnitIsLand) - Match.countMatches(arrivedUnits, Matches.UnitIsAir)
+						- Match.countMatches(arrivedUnits, Matches.unitIsSubmerged(data));
 			// If transports are restricted from controlling sea zones, subtract them
 			final CompositeMatch<Unit> transportsCanNotControl = new CompositeMatchAnd<Unit>();
 			transportsCanNotControl.add(Matches.UnitIsTransportAndNotDestroyer);
 			transportsCanNotControl.add(Matches.UnitIsTransportButNotCombatTransport);
 			if (!games.strategy.triplea.Properties.getTransportControlSeaZone(data))
-				totalMatches -= Match.countMatches(arrivingUnits, transportsCanNotControl);
+				totalMatches -= Match.countMatches(arrivedUnits, transportsCanNotControl);
 			// TODO check if istrn and NOT isDD
 			// If subs are restricted from controlling sea zones, subtract them
 			if (games.strategy.triplea.Properties.getSubControlSeaZoneRestricted(data))
-				totalMatches -= Match.countMatches(arrivingUnits, Matches.UnitIsSub);
+				totalMatches -= Match.countMatches(arrivedUnits, Matches.UnitIsSub);
 			if (totalMatches == 0)
 				return;
 		}
@@ -481,6 +606,8 @@ public class BattleTracker implements java.io.Serializable
 					{
 						final Change changeVP = ChangeFactory.attachmentPropertyChange(pa, (capturedPUCount + pa.getCaptureVps()), "captureVps");
 						bridge.addChange(changeVP);
+						if (changeTracker != null)
+							changeTracker.addChange(changeVP);
 					}
 				}
 				final Change remove = ChangeFactory.changeResourcesChange(whoseCapital, PUs, -capturedPUCount);
@@ -570,6 +697,8 @@ public class BattleTracker implements java.io.Serializable
 			final Change takeOver = ChangeFactory.changeOwner(territory, newOwner);
 			bridge.getHistoryWriter().addChildToEvent(takeOver.toString());
 			bridge.addChange(takeOver);
+			// play a sound
+			ClipPlayer.play(SoundPath.CLIP_CAPTURE);
 			if (changeTracker != null)
 			{
 				changeTracker.addChange(takeOver);
@@ -578,18 +707,18 @@ public class BattleTracker implements java.io.Serializable
 		}
 		// Remove any bombing raids against captured territory
 		// TODO: see if necessary
-		if (Match.someMatch(territory.getUnits().getUnits(), new CompositeMatchAnd<Unit>(Matches.unitIsEnemyOf(data, id), Matches.UnitIsFactoryOrCanBeDamaged)))
+		if (Match.someMatch(territory.getUnits().getUnits(), new CompositeMatchAnd<Unit>(Matches.unitIsEnemyOf(data, id), Matches.UnitCanBeDamaged)))
 		{
 			final IBattle bombingBattle = getPendingBattle(territory, true);
 			if (bombingBattle != null)
 			{
-				final BattleResults results = new BattleResults(bombingBattle, WhoWon.DRAW);
-				getBattleRecords().addResultToBattle(id, bombingBattle.getBattleID(), null, 0, 0, BattleRecords.BattleResultDescription.NO_BATTLE, results, 0);
+				final BattleResults results = new BattleResults(bombingBattle, WhoWon.DRAW, data);
+				getBattleRecords(data).addResultToBattle(id, bombingBattle.getBattleID(), null, 0, 0, BattleRecord.BattleResultDescription.NO_BATTLE, results, 0);
 				removeBattle(bombingBattle);
 				throw new IllegalStateException("Bombing Raids should be dealt with first! Be sure the battle has dependencies set correctly!");
 			}
 		}
-		captureOrDestroyUnits(territory, id, newOwner, bridge, changeTracker, arrivingUnits);
+		captureOrDestroyUnits(territory, id, newOwner, bridge, changeTracker, arrivedUnits);
 		// is this territory our capitol or a capitol of our ally
 		// Also check to make sure playerAttachment even HAS a capital to fix abend
 		if (isTerritoryOwnerAnEnemy && terrOrigOwner != null && ta.getCapital() != null && TerritoryAttachment.getCapital(terrOrigOwner, data).equals(territory)
@@ -608,7 +737,7 @@ public class BattleTracker implements java.io.Serializable
 				bridge.getHistoryWriter().addChildToEvent(takeOverFriendlyTerritories.toString());
 				if (changeTracker != null)
 					changeTracker.addChange(takeOverFriendlyTerritories);
-				final Collection<Unit> units = Match.getMatches(item.getUnits().getUnits(), Matches.UnitIsFactoryOrIsInfrastructure);
+				final Collection<Unit> units = Match.getMatches(item.getUnits().getUnits(), Matches.UnitIsInfrastructure);
 				if (!units.isEmpty())
 				{
 					final Change takeOverNonComUnits = ChangeFactory.changeOwner(units, terrOrigOwner, territory);
@@ -620,9 +749,9 @@ public class BattleTracker implements java.io.Serializable
 		}
 		// say they were in combat
 		// if the territory being taken over is water, then do not say any land units were in combat (they may want to unload from the transport and attack)
-		if (Matches.TerritoryIsWater.match(territory) && arrivingUnits != null)
-			arrivingUnits.removeAll(Match.getMatches(arrivingUnits, Matches.UnitIsLand));
-		markWasInCombat(arrivingUnits, bridge, changeTracker);
+		if (Matches.TerritoryIsWater.match(territory) && arrivedUnits != null)
+			arrivedUnits.removeAll(Match.getMatches(arrivedUnits, Matches.UnitIsLand));
+		markWasInCombat(arrivedUnits, bridge, changeTracker);
 	}
 	
 	public static void captureOrDestroyUnits(final Territory territory, final PlayerID id, final PlayerID newOwner, final IDelegateBridge bridge, final UndoableMove changeTracker,
@@ -659,8 +788,7 @@ public class BattleTracker implements java.io.Serializable
 		// destroy any disabled units owned by the enemy that are NOT infrastructure or factories
 		if (true)
 		{
-			final CompositeMatch<Unit> enemyToBeDestroyed = new CompositeMatchAnd<Unit>(Matches.enemyUnit(id, data), Matches.UnitIsDisabled(), Matches.UnitIsInfrastructure.invert(),
-						Matches.UnitIsFactory.invert());
+			final CompositeMatch<Unit> enemyToBeDestroyed = new CompositeMatchAnd<Unit>(Matches.enemyUnit(id, data), Matches.UnitIsDisabled(), Matches.UnitIsInfrastructure.invert());
 			final Collection<Unit> destroyed = territory.getUnits().getMatches(enemyToBeDestroyed);
 			if (!destroyed.isEmpty())
 			{
@@ -672,7 +800,7 @@ public class BattleTracker implements java.io.Serializable
 			}
 		}
 		// take over non combatants
-		final CompositeMatch<Unit> enemyNonCom = new CompositeMatchAnd<Unit>(Matches.enemyUnit(id, data), Matches.UnitIsFactoryOrIsInfrastructure);
+		final CompositeMatch<Unit> enemyNonCom = new CompositeMatchAnd<Unit>(Matches.enemyUnit(id, data), Matches.UnitIsInfrastructure);
 		final CompositeMatch<Unit> willBeCaptured = new CompositeMatchOr<Unit>(enemyNonCom, Matches.UnitCanBeCapturedOnEnteringToInThisTerritory(id, territory, data));
 		final Collection<Unit> nonCom = territory.getUnits().getMatches(willBeCaptured);
 		// change any units that change unit types on capture
@@ -748,7 +876,7 @@ public class BattleTracker implements java.io.Serializable
 			return ChangeFactory.EMPTY_CHANGE;
 		// if just an enemy factory &/or AA then no battle
 		final Collection<Unit> enemyUnits = Match.getMatches(site.getUnits().getUnits(), Matches.enemyUnit(id, data));
-		if (route.getEnd() != null && Match.allMatch(enemyUnits, Matches.UnitIsFactoryOrIsInfrastructure))
+		if (route.getEnd() != null && Match.allMatch(enemyUnits, Matches.UnitIsInfrastructure))
 			return ChangeFactory.EMPTY_CHANGE;
 		IBattle battle = getPendingBattle(site, false);
 		// If there are no pending battles- add one for units already in the combat zone
@@ -756,7 +884,7 @@ public class BattleTracker implements java.io.Serializable
 		{
 			battle = new MustFightBattle(site, id, data, this);
 			m_pendingBattles.add(battle);
-			m_battleRecords.addBattle(id, battle.getBattleID(), site, battle.getBattleType());
+			getBattleRecords(data).addBattle(id, battle.getBattleID(), site, battle.getBattleType(), data);
 		}
 		// Add the units that moved into the battle
 		final Change change = battle.addAttackChange(route, units, null);
@@ -809,10 +937,11 @@ public class BattleTracker implements java.io.Serializable
 	 */
 	public Collection<Territory> getPendingBattleSites(final boolean bombing)
 	{
-		final Collection<Territory> battles = new ArrayList<Territory>(m_pendingBattles.size());
-		for (final IBattle battle : m_pendingBattles)
+		final Collection<IBattle> pending = new HashSet<IBattle>(m_pendingBattles);
+		final Collection<Territory> battles = new ArrayList<Territory>();
+		for (final IBattle battle : pending)
 		{
-			if (!battle.isEmpty() && battle.isBombingRun() == bombing)
+			if (battle != null && !battle.isEmpty() && battle.isBombingRun() == bombing)
 				battles.add(battle.getTerritory());
 		}
 		return battles;
@@ -908,6 +1037,7 @@ public class BattleTracker implements java.io.Serializable
 	
 	public void clear()
 	{
+		m_finishedBattlesUnitAttackFromMap.clear();
 		m_bombardedFromTerritories.clear();
 		m_pendingBattles.clear();
 		m_blitzed.clear();
@@ -915,6 +1045,8 @@ public class BattleTracker implements java.io.Serializable
 		m_conquered.clear();
 		m_dependencies.clear();
 		m_defendingAirThatCanNotLand.clear();
+		m_noBombardAllowed.clear();
+		m_relationshipChangesThisTurn.clear();
 	}
 	
 	public void addToDefendingAirThatCanNotLand(final Collection<Unit> units, final Territory szTerritoryTheyAreIn)
@@ -933,11 +1065,19 @@ public class BattleTracker implements java.io.Serializable
 	
 	public void clearBattleRecords()
 	{
-		m_battleRecords.clear();
+		if (m_battleRecords != null)
+		{
+			m_battleRecords.clear();
+			m_battleRecords = null;
+		}
 	}
 	
-	public BattleRecords getBattleRecords()
+	public BattleRecords getBattleRecords(final GameData data)
 	{
+		if (m_battleRecords == null)
+		{
+			m_battleRecords = new BattleRecords(data);
+		}
 		return m_battleRecords;
 	}
 	
@@ -946,7 +1086,7 @@ public class BattleTracker implements java.io.Serializable
 		if (m_battleRecords != null && !m_battleRecords.isEmpty())
 		{
 			aBridge.getHistoryWriter().startEvent("Recording Battle Statistics");
-			aBridge.addChange(ChangeFactory.addBattleRecords((new BattleRecords(m_battleRecords)), aBridge.getData()));
+			aBridge.addChange(ChangeFactory.addBattleRecords(m_battleRecords, aBridge.getData()));
 		}
 	}
 	
