@@ -46,9 +46,9 @@ public class DelegateFinder
 		return (BattleDelegate) findDelegate(data, "battle");
 	}
 	
-	public static final MoveDelegate moveDelegate(final GameData data)
+	public static final AbstractMoveDelegate moveDelegate(final GameData data)
 	{
-		return (MoveDelegate) findDelegate(data, "move");
+		return (AbstractMoveDelegate) findDelegate(data, "move");
 	}
 	
 	public static final AbstractPlaceDelegate placeDelegate(final GameData data)
@@ -56,6 +56,11 @@ public class DelegateFinder
 		return (AbstractPlaceDelegate) findDelegate(data, "place");
 	}
 	
+	public static final AbstractPlaceDelegate placeNoAirCheckDelegate(final GameData data)
+	{
+		return (AbstractPlaceDelegate) findDelegate(data, "placeNoAirCheck");
+	}
+	
 	// TODO: this is a really shitty way of figuring out what step / delegate we are in....
 	public static final BidPlaceDelegate bidPlaceDelegate(final GameData data)
 	{
@@ -67,8 +72,8 @@ public class DelegateFinder
 		return (TechnologyDelegate) findDelegate(data, "tech");
 	}
 	
-	public static final GivePUsDelegate givePUsDelegate(final GameData data)
+	/*public static final AbstractEndTurnDelegate endTurnDelegate(final GameData data)
 	{
-		return (GivePUsDelegate) findDelegate(data, "givePUs");
-	}
+		return (AbstractEndTurnDelegate) findDelegate(data, "endTurn");
+	}*/
 }
