@@ -16,11 +16,12 @@ package games.strategy.triplea.delegate;
 import games.strategy.engine.data.GameData;
 import games.strategy.engine.data.PlayerID;
 import games.strategy.engine.data.Territory;
+import games.strategy.engine.data.TerritoryEffect;
 import games.strategy.engine.data.Unit;
 import games.strategy.engine.data.UnitType;
 import games.strategy.engine.delegate.IDelegateBridge;
+import games.strategy.engine.random.IRandomStats.DiceType;
 import games.strategy.triplea.Constants;
-import games.strategy.triplea.Properties;
 import games.strategy.triplea.TripleAUnit;
 import games.strategy.triplea.attatchments.RulesAttachment;
 import games.strategy.triplea.attatchments.TechAttachment;
@@ -31,6 +32,7 @@ import games.strategy.triplea.formatter.MyFormatter;
 import games.strategy.util.CompositeMatchAnd;
 import games.strategy.util.IntegerMap;
 import games.strategy.util.Match;
+import games.strategy.util.Triple;
 import games.strategy.util.Tuple;
 
 import java.io.Externalizable;
@@ -51,15 +53,44 @@ import java.util.Set;
  * # of rolls at 5, at 4, etc.
  * <p>
  * 
- * Externalizble so we can efficiently write out our dice as ints rather than as full objects.
+ * Externalizable so we can efficiently write out our dice as ints rather than as full objects.
  */
 public class DiceRoll implements Externalizable
 {
+	private static final long serialVersionUID = -1167204061937566271L;
 	private List<Die> m_rolls;
 	// this does not need to match the Die with isHit true
 	// since for low luck we get many hits with few dice
 	private int m_hits;
 	
+	public static void sortAAHighToLow(final List<Unit> units, final GameData data)
+	{
+		final Comparator<Unit> comparator = new Comparator<Unit>()
+		{
+			public int compare(final Unit u1, final Unit u2)
+			{
+				final Tuple<Integer, Integer> tuple1 = getAAattackAndMaxDiceSides(Collections.singleton(u1), data);
+				final Tuple<Integer, Integer> tuple2 = getAAattackAndMaxDiceSides(Collections.singleton(u2), data);
+				if (tuple1.getFirst() == 0)
+				{
+					if (tuple2.getFirst() == 0)
+						return 0;
+					return 1;
+				}
+				else if (tuple2.getFirst() == 0)
+					return -1;
+				final float value1 = ((float) tuple1.getFirst()) / ((float) tuple1.getSecond());
+				final float value2 = ((float) tuple2.getFirst()) / ((float) tuple2.getSecond());
+				if (value1 < value2)
+					return 1;
+				else if (value1 > value2)
+					return -1;
+				return 0;
+			}
+		};
+		Collections.sort(units, comparator);
+	}
+	
 	/**
 	 * Returns a Tuple with 2 values, the first is the max attack, the second is the max dice sides for the AA unit with that attack value
 	 */
@@ -74,9 +105,7 @@ public class DiceRoll implements Externalizable
 			int uaDiceSides = ua.getAttackAAmaxDieSides();
 			if (uaDiceSides < 1)
 				uaDiceSides = diceSize;
-			int attack = ua.getAttackAA();
-			if (attack > 0 && Matches.UnitIsRadarAA.match(u))
-				attack++; // TODO: this may cause major problems with Low Luck, if they have diceSides equal to something other than 6
+			int attack = ua.getAttackAA(u.getOwner());
 			if (attack > uaDiceSides)
 				attack = uaDiceSides;
 			if ((((float) attack) / ((float) uaDiceSides)) > (((float) highestAttack) / ((float) chosenDiceSize)))
@@ -111,53 +140,64 @@ public class DiceRoll implements Externalizable
 		return totalAAattacksNormal + totalAAattacksSurplus;
 	}
 	
-	public static DiceRoll rollAA(final Collection<Unit> attackingUnitsAll, final Collection<Unit> defendingAA, final Set<UnitType> targetUnitTypesForThisTypeAA, final IDelegateBridge bridge,
-				final Territory location)
+	public static DiceRoll rollAA(final Collection<Unit> validAttackingUnitsForThisRoll, final Collection<Unit> defendingAAForThisRoll, final IDelegateBridge bridge, final Territory location)
 	{
-		final Collection<Unit> validAttackingUnitsForThisRoll = Match.getMatches(attackingUnitsAll, Matches.unitIsOfTypes(targetUnitTypesForThisTypeAA));
+		final List<Unit> defendingAA = Match.getMatches(defendingAAForThisRoll, Matches.UnitAttackAAisGreaterThanZeroAndMaxAAattacksIsNotZero);
+		if (defendingAA.size() <= 0)
+			return new DiceRoll(new ArrayList<Die>(0), 0);
 		final GameData data = bridge.getData();
+		final int totalAAattacksTotal = getTotalAAattacks(defendingAA, validAttackingUnitsForThisRoll, data);
+		// determine dicesides for everyone (we are not going to consider the possibility of different dicesides within the same typeAA)
+		final Tuple<Integer, Integer> attackThenDiceSidesForAll = getAAattackAndMaxDiceSides(defendingAA, data);
+		// final int highestAttackPower = attackThenDiceSidesForAll.getFirst();
+		final int chosenDiceSizeForAll = attackThenDiceSidesForAll.getSecond();
 		int hits = 0;
 		final List<Die> sortedDice = new ArrayList<Die>();
-		final Tuple<Integer, Integer> attackThenDiceSides = getAAattackAndMaxDiceSides(defendingAA, data);
-		int totalAAattacks = getTotalAAattacks(defendingAA, validAttackingUnitsForThisRoll, data);
-		final int highestAttack = attackThenDiceSides.getFirst();
-		final int chosenDiceSize = attackThenDiceSides.getSecond();
-		final int hitAt = highestAttack - 1; // zero based
-		final int power = highestAttack; // not zero based
+		
 		// LOW LUCK
-		if (highestAttack > 0 && (games.strategy.triplea.Properties.getLow_Luck(data) || games.strategy.triplea.Properties.getLL_AA_ONLY(data)))
+		if (games.strategy.triplea.Properties.getLow_Luck(data) || games.strategy.triplea.Properties.getLL_AA_ONLY(data))
 		{
 			final String annotation = "Roll AA guns in " + location.getName();
-			final int groupSize = chosenDiceSize / power;
-			if (Properties.getChoose_AA_Casualties(data))
+			final Triple<Integer, Integer, Boolean> triple = getTotalAAPowerThenHitsAndFillSortedDiceThenIfAllUseSameAttack(null, null, defendingAA,
+						validAttackingUnitsForThisRoll, data, false);
+			final int totalPower = triple.getFirst();
+			hits += getLowLuckHits(bridge, sortedDice, totalPower, chosenDiceSizeForAll, defendingAA.get(0).getOwner(), annotation);
+			/* Turns out all this junk below is not actually needed, because in this method we are only determining the number of hits, and any die rolls we need to do. 
+			final boolean allSameAttackPower = triple.getThird();
+			// if we have a group of 6 fighters and 2 bombers, and dicesides is 6, and attack was 1, then we would want 1 fighter to die for sure. this is what groupsize is for.
+			// if the attack is greater than 1 though, and all use the same attack power, then the group size can be smaller (ie: attack is 2, and we have 3 fighters and 2 bombers, we would want 1 fighter to die for sure).
+			final int groupSize;
+			if (allSameAttackPower)
 			{
-				hits += getLowLuckHits(bridge, sortedDice, power, chosenDiceSize, annotation, totalAAattacks);
+				groupSize = chosenDiceSizeForAll / highestAttackPower;
 			}
 			else
 			{
-				final Tuple<List<Unit>, List<Unit>> airSplit = BattleCalculator.categorizeLowLuckAirUnits(validAttackingUnitsForThisRoll, location, chosenDiceSize, groupSize);
+				groupSize = chosenDiceSizeForAll;
+			}
+			if (Properties.getChoose_AA_Casualties(data))
+			{
+				hits += getLowLuckHits(bridge, sortedDice, power, chosenDiceSizeForAll, annotation, totalAAattacksTotal);
+			}
+			else
+			{
+				final Tuple<List<Unit>, List<Unit>> airSplit = BattleCalculator.categorizeLowLuckAirUnits(validAttackingUnitsForThisRoll, location, chosenDiceSizeForAll, groupSize);
 				// this will not roll any dice, since the first group is
 				// a multiple of 3 or 6
 				final int firstGroupSize = airSplit.getFirst().size();
-				hits += getLowLuckHits(bridge, sortedDice, power, chosenDiceSize, annotation, Math.min(firstGroupSize, totalAAattacks));
-				totalAAattacks = Math.max(0, totalAAattacks - firstGroupSize);
+				hits += getLowLuckHits(bridge, sortedDice, power, chosenDiceSizeForAll, annotation, Math.min(firstGroupSize, totalAAattacksTotal));
+				totalAAattacksTotal = Math.max(0, totalAAattacksTotal - firstGroupSize);
 				// this will roll dice, unless it is empty
 				final int secondGroupSize = airSplit.getSecond().size();
-				hits += getLowLuckHits(bridge, sortedDice, power, chosenDiceSize, annotation, Math.min(secondGroupSize, totalAAattacks));
-				totalAAattacks = Math.max(0, totalAAattacks - secondGroupSize);
-			}
+				hits += getLowLuckHits(bridge, sortedDice, power, chosenDiceSizeForAll, annotation, Math.min(secondGroupSize, totalAAattacksTotal));
+				totalAAattacksTotal = Math.max(0, totalAAattacksTotal - secondGroupSize);
+			}*/
 		}
-		else if (highestAttack > 0) // Normal rolling
+		else
 		{
 			final String annotation = "Roll AA guns in " + location.getName();
-			final int[] dice = bridge.getRandom(chosenDiceSize, totalAAattacks, annotation);
-			for (int i = 0; i < dice.length; i++)
-			{
-				final boolean hit = dice[i] <= hitAt;
-				sortedDice.add(new Die(dice[i], hitAt + 1, hit ? DieType.HIT : DieType.MISS));
-				if (hit)
-					hits++;
-			}
+			final int[] dice = bridge.getRandom(chosenDiceSizeForAll, totalAAattacksTotal, defendingAA.get(0).getOwner(), DiceType.COMBAT, annotation);
+			hits += getTotalAAPowerThenHitsAndFillSortedDiceThenIfAllUseSameAttack(dice, sortedDice, defendingAA, validAttackingUnitsForThisRoll, data, true).getSecond();
 		}
 		final DiceRoll roll = new DiceRoll(sortedDice, hits);
 		final String annotation = "AA guns fire in " + location + " : " + MyFormatter.asDice(roll);
@@ -165,13 +205,141 @@ public class DiceRoll implements Externalizable
 		return roll;
 	}
 	
-	private static int getLowLuckHits(final IDelegateBridge bridge, final List<Die> sortedDice, final int power, final int chosenDiceSize, final String annotation, final int numberOfAirUnits)
+	/**
+	 * Basically I wanted 1 single method for both Low Luck and Dice, because if we have 2 methods then there is a chance they will go out of sync.
+	 * 
+	 * @param dice
+	 *            = Rolled Dice numbers from bridge. Can be null if we do not want to return hits or fill the sortedDice
+	 * @param sortedDice
+	 *            List of dice we are recording. Can be null if we do not want to return hits or fill the sortedDice
+	 * @param defendingAA
+	 * @param validAttackingUnitsForThisRoll
+	 * @param data
+	 * @param fillInSortedDiceAndRecordHits
+	 * @return an object containing 3 things: first is the total power of the defendingAA who will be rolling, second is number of hits,
+	 *         third is true/false are all rolls using the same hitAt (example: if all the rolls are at 1, we would return true, but if one roll is at 1 and another roll is at 2, then we return false)
+	 */
+	public static Triple<Integer, Integer, Boolean> getTotalAAPowerThenHitsAndFillSortedDiceThenIfAllUseSameAttack(final int[] dice, final List<Die> sortedDice,
+				final Collection<Unit> defendingAAForThisRoll, final Collection<Unit> validAttackingUnitsForThisRoll, final GameData data, final boolean fillInSortedDiceAndRecordHits)
 	{
-		int hits = (numberOfAirUnits * power) / chosenDiceSize;
-		final int hitsFractional = (numberOfAirUnits * power) % chosenDiceSize;
+		final List<Unit> defendingAA = Match.getMatches(defendingAAForThisRoll, Matches.UnitAttackAAisGreaterThanZeroAndMaxAAattacksIsNotZero);
+		if (defendingAA.size() <= 0)
+			return new Triple<Integer, Integer, Boolean>(0, 0, false);
+		sortAAHighToLow(defendingAA, data); // we want to make sure the higher powers fire
+		
+		// this is confusing, but what we want to do is the following:
+		// any aa that are NOT infinite attacks, and NOT overstack, will fire first individually ((because their power/dicesides might be different [example: radar tech on a german aa gun, in the same territory as an italian aagun without radar, neither is infinite])
+		// all aa that have "infinite attacks" will have the one with the highest power/dicesides of them all, fire at whatever aa units have not yet been fired at
+		// HOWEVER, if the non-infinite attackers are less powerful than the infinite attacker, then the non-infinite will not fire, and the infinite one will do all the attacks for both groups.
+		// the total number of shots from these first 2 groups can not exceed the number of air units being shot at
+		// last, any aa that can overstack will fire after, individually
+		// (an aa guns that is both infinite, and overstacks, ignores the overstack part because that totally doesn't make any sense)
+		
+		// set up all 3 groups of aa guns
+		final List<Unit> normalNonInfiniteAA = new ArrayList<Unit>(defendingAA);
+		final List<Unit> infiniteAA = Match.getMatches(defendingAA, Matches.UnitMaxAAattacksIsInfinite);
+		final List<Unit> overstackAA = Match.getMatches(defendingAA, Matches.UnitMayOverStackAA);
+		overstackAA.removeAll(infiniteAA);
+		normalNonInfiniteAA.removeAll(infiniteAA);
+		normalNonInfiniteAA.removeAll(overstackAA);
+		// determine maximum total attacks
+		final int totalAAattacksTotal = getTotalAAattacks(defendingAA, validAttackingUnitsForThisRoll, data);
+		// determine individual totals
+		final int normalNonInfiniteAAtotalAAattacks = getTotalAAattacks(normalNonInfiniteAA, validAttackingUnitsForThisRoll, data);
+		final int infiniteAAtotalAAattacks = Math.min((validAttackingUnitsForThisRoll.size() - normalNonInfiniteAAtotalAAattacks), getTotalAAattacks(infiniteAA, validAttackingUnitsForThisRoll, data));
+		final int overstackAAtotalAAattacks = getTotalAAattacks(overstackAA, validAttackingUnitsForThisRoll, data);
+		if (totalAAattacksTotal != (normalNonInfiniteAAtotalAAattacks + infiniteAAtotalAAattacks + overstackAAtotalAAattacks))
+			throw new IllegalStateException("Total attacks should be: " + totalAAattacksTotal + " but instead is: "
+						+ (normalNonInfiniteAAtotalAAattacks + infiniteAAtotalAAattacks + overstackAAtotalAAattacks));
+		// determine dicesides for everyone (we are not going to consider the possibility of different dicesides within the same typeAA)
+		// final Tuple<Integer, Integer> attackThenDiceSidesForAll = getAAattackAndMaxDiceSides(defendingAA, data);
+		// final int chosenDiceSizeForAll = attackThenDiceSidesForAll.getSecond();
+		
+		// determine highest attack for infinite group
+		final Tuple<Integer, Integer> attackThenDiceSidesForInfinite = getAAattackAndMaxDiceSides(infiniteAA, data);
+		final int hitAtForInfinite = attackThenDiceSidesForInfinite.getFirst(); // not zero based
+		// final int powerForInfinite = highestAttackForInfinite; // not zero based
+		
+		// if we are low luck, we only want to know the power and total attacks, while if we are dice we will be filling the sorted dice
+		final boolean recordSortedDice = fillInSortedDiceAndRecordHits && dice != null && dice.length > 0 && sortedDice != null;
+		int totalPower = 0;
+		int hits = 0;
+		int i = 0;
+		final Set<Integer> rolledAt = new HashSet<Integer>();
+		// non-infinite, non-overstack aa
+		int runningMaximum = normalNonInfiniteAAtotalAAattacks;
+		final Iterator<Unit> normalAAiter = normalNonInfiniteAA.iterator();
+		while (i < runningMaximum && normalAAiter.hasNext())
+		{
+			final Unit aaGun = normalAAiter.next();
+			int numAttacks = UnitAttachment.get(aaGun.getType()).getMaxAAattacks(); // should be > 0 at this point
+			final int hitAt = getAAattackAndMaxDiceSides(Collections.singleton(aaGun), data).getFirst();
+			if (hitAt < hitAtForInfinite)
+				continue;
+			while (i < runningMaximum && numAttacks > 0)
+			{
+				if (recordSortedDice)
+				{
+					final boolean hit = dice[i] < hitAt; // dice are zero based
+					sortedDice.add(new Die(dice[i], hitAt, hit ? DieType.HIT : DieType.MISS));
+					if (hit)
+						hits++;
+				}
+				i++;
+				numAttacks--;
+				totalPower += hitAt;
+				rolledAt.add(hitAt);
+			}
+		}
+		// infinite aa
+		runningMaximum += infiniteAAtotalAAattacks;
+		while (i < runningMaximum)
+		{
+			// we use the highest attack of this group, since each is infinite. (this is the default behavior in revised)
+			if (recordSortedDice)
+			{
+				final boolean hit = dice[i] < hitAtForInfinite; // dice are zero based
+				sortedDice.add(new Die(dice[i], hitAtForInfinite, hit ? DieType.HIT : DieType.MISS));
+				if (hit)
+					hits++;
+			}
+			i++;
+			totalPower += hitAtForInfinite;
+			rolledAt.add(hitAtForInfinite);
+		}
+		// overstack aa
+		runningMaximum += overstackAAtotalAAattacks;
+		final Iterator<Unit> overstackAAiter = overstackAA.iterator();
+		while (i < runningMaximum && overstackAAiter.hasNext())
+		{
+			final Unit aaGun = overstackAAiter.next();
+			int numAttacks = UnitAttachment.get(aaGun.getType()).getMaxAAattacks(); // should be > 0 at this point
+			final int hitAt = getAAattackAndMaxDiceSides(Collections.singleton(aaGun), data).getFirst(); // zero based, so subtract 1
+			while (i < runningMaximum && numAttacks > 0)
+			{
+				if (recordSortedDice)
+				{
+					final boolean hit = dice[i] < hitAt; // dice are zero based
+					sortedDice.add(new Die(dice[i], hitAt, hit ? DieType.HIT : DieType.MISS));
+					if (hit)
+						hits++;
+				}
+				i++;
+				numAttacks--;
+				totalPower += hitAt;
+				rolledAt.add(hitAt);
+			}
+		}
+		return new Triple<Integer, Integer, Boolean>(totalPower, hits, (rolledAt.size() == 1));
+	}
+	
+	private static int getLowLuckHits(final IDelegateBridge bridge, final List<Die> sortedDice, final int totalPower, final int chosenDiceSize, final PlayerID playerRolling, final String annotation)
+	{
+		int hits = totalPower / chosenDiceSize;
+		final int hitsFractional = totalPower % chosenDiceSize;
 		if (hitsFractional > 0)
 		{
-			final int[] dice = bridge.getRandom(chosenDiceSize, 1, annotation);
+			final int[] dice = bridge.getRandom(chosenDiceSize, 1, playerRolling, DiceType.COMBAT, annotation);
 			final boolean hit = hitsFractional > dice[0];
 			if (hit)
 			{
@@ -189,16 +357,17 @@ public class DiceRoll implements Externalizable
 	 * @param annotation
 	 * 
 	 */
-	public static DiceRoll rollDice(final List<Unit> units, final boolean defending, final PlayerID player, final IDelegateBridge bridge, final IBattle battle, final String annotation)
+	public static DiceRoll rollDice(final List<Unit> units, final boolean defending, final PlayerID player, final IDelegateBridge bridge, final IBattle battle, final String annotation,
+				final Collection<TerritoryEffect> territoryEffects)
 	{
 		// Decide whether to use low luck rules or normal rules.
 		if (games.strategy.triplea.Properties.getLow_Luck(bridge.getData()))
 		{
-			return rollDiceLowLuck(units, defending, player, bridge, battle, annotation);
+			return rollDiceLowLuck(units, defending, player, bridge, battle, annotation, territoryEffects);
 		}
 		else
 		{
-			return rollDiceNormal(units, defending, player, bridge, battle, annotation);
+			return rollDiceNormal(units, defending, player, bridge, battle, annotation, territoryEffects);
 		}
 	}
 	
@@ -208,14 +377,14 @@ public class DiceRoll implements Externalizable
 	 * @param annotation
 	 *            0 based, add 1 to get actual die roll
 	 */
-	public static DiceRoll rollNDice(final IDelegateBridge bridge, final int rollCount, final int sides, final String annotation)
+	public static DiceRoll rollNDice(final IDelegateBridge bridge, final int rollCount, final int sides, final PlayerID playerRolling, final DiceType diceType, final String annotation)
 	{
 		if (rollCount == 0)
 		{
 			return new DiceRoll(new ArrayList<Die>(), 0);
 		}
 		int[] random;
-		random = bridge.getRandom(sides, rollCount, annotation);
+		random = bridge.getRandom(sides, rollCount, playerRolling, diceType, annotation);
 		final List<Die> dice = new ArrayList<Die>();
 		int diceIndex = 0;
 		for (int i = 0; i < rollCount; i++)
@@ -228,20 +397,22 @@ public class DiceRoll implements Externalizable
 	}
 	
 	/**
-	 * Roll dice for units using low luck rules. Low luck rules based on rules
-	 * in DAAK.
+	 * Roll dice for units using low luck rules. Low luck rules based on rules in DAAK.
 	 */
-	private static DiceRoll rollDiceLowLuck(final List<Unit> units, final boolean defending, final PlayerID player, final IDelegateBridge bridge, final IBattle battle, final String annotation)
+	private static DiceRoll rollDiceLowLuck(final List<Unit> units, final boolean defending, final PlayerID player, final IDelegateBridge bridge, final IBattle battle, final String annotation,
+				final Collection<TerritoryEffect> territoryEffects)
 	{
 		final GameData data = bridge.getData();
 		final boolean lhtrBombers = games.strategy.triplea.Properties.getLHTR_Heavy_Bombers(data);
+		final int extraRollBonus = Math.max(1, data.getDiceSides() / 6); // bonus is normally 1 for most games
 		// int artillerySupportAvailable = getArtillerySupportAvailable(units, defending, player);
 		final Set<List<UnitSupportAttachment>> supportRules = new HashSet<List<UnitSupportAttachment>>();
 		final IntegerMap<UnitSupportAttachment> supportLeft = new IntegerMap<UnitSupportAttachment>();
 		getSupport(units, supportRules, supportLeft, data, defending);
 		final Territory location = battle.getTerritory();
 		// make a copy to send to getRolls (due to need to know number of rolls based on support, as zero attack units will or will not get a roll depending)
-		final int rollCount = BattleCalculator.getRolls(units, location, player, defending, new HashSet<List<UnitSupportAttachment>>(supportRules), new IntegerMap<UnitSupportAttachment>(supportLeft));
+		final int rollCount = BattleCalculator.getRolls(units, location, player, defending, new HashSet<List<UnitSupportAttachment>>(supportRules), new IntegerMap<UnitSupportAttachment>(supportLeft),
+					territoryEffects);
 		if (rollCount == 0)
 		{
 			return new DiceRoll(new ArrayList<Die>(0), 0);
@@ -256,16 +427,18 @@ public class DiceRoll implements Externalizable
 			final UnitAttachment ua = UnitAttachment.get(current.getType());
 			// make a copy for getRolls
 			final int rolls = BattleCalculator.getRolls(current, location, player, defending, new HashSet<List<UnitSupportAttachment>>(supportRules),
-						new IntegerMap<UnitSupportAttachment>(supportLeft));
+						new IntegerMap<UnitSupportAttachment>(supportLeft), territoryEffects);
 			int totalStr = 0;
 			for (int i = 0; i < rolls; i++)
 			{
-				if (i > 1 && lhtrBombers && ua.getIsStrategicBomber())
+				if (i > 1 && (lhtrBombers || ua.getChooseBestRoll()))
 				{
+					// LHTR means pick the best dice roll, which doesn't really make sense in LL. So instead, we will just add +1 onto the power to simulate the gains of having the best die picked.
 					if (totalStr < data.getDiceSides())
 					{
-						power += 1;
-						totalStr += 1;
+						final int maxToAdd = Math.min(extraRollBonus, (data.getDiceSides() - totalStr));
+						power += maxToAdd;
+						totalStr += maxToAdd;
 					}
 					continue;
 				}
@@ -294,10 +467,9 @@ public class DiceRoll implements Externalizable
 						strength = ua.getBombard(current.getOwner());
 					strength += getSupport(current.getType(), supportRules, supportLeft);
 				}
-				strength += TerritoryEffectHelper.getTerritoryCombatBonus(current.getType(), location, defending);
+				strength += TerritoryEffectHelper.getTerritoryCombatBonus(current.getType(), territoryEffects, defending);
 				totalStr += strength;
 				power += Math.min(Math.max(strength, 0), data.getDiceSides());
-				;
 			}
 		}
 		// Get number of hits
@@ -308,7 +480,7 @@ public class DiceRoll implements Externalizable
 		power = power % data.getDiceSides();
 		if (power != 0)
 		{
-			random = bridge.getRandom(data.getDiceSides(), 1, annotation);
+			random = bridge.getRandom(data.getDiceSides(), 1, player, DiceType.COMBAT, annotation);
 			final boolean hit = power > random[0];
 			if (hit)
 			{
@@ -396,6 +568,8 @@ public class DiceRoll implements Externalizable
 				int numSupport = supporters.size();
 				if (rule.getImpArtTech())
 					numSupport += Match.getMatches(supporters, Matches.unitOwnerHasImprovedArtillerySupportTech()).size();
+				if (numSupport <= 0)
+					continue;
 				final String bonusType = rule.getBonusType();
 				supportLeft.put(rule, numSupport * rule.getNumber());
 				final Iterator<List<UnitSupportAttachment>> iter2 = support.iterator();
@@ -471,19 +645,32 @@ public class DiceRoll implements Externalizable
 	
 	private static void sortSupportRules(final Set<List<UnitSupportAttachment>> support)
 	{
-		final Comparator<UnitSupportAttachment> comp = new Comparator<UnitSupportAttachment>()
+		// first, sort the lists inside each set
+		final Comparator<UnitSupportAttachment> compList = new Comparator<UnitSupportAttachment>()
 		{
 			public int compare(final UnitSupportAttachment u1, final UnitSupportAttachment u2)
 			{
+				// we want to apply the biggest bonus first
 				final Integer v1 = Integer.valueOf(Math.abs(u1.getBonus()));
 				final Integer v2 = Integer.valueOf(Math.abs(u2.getBonus()));
-				return v2.compareTo(v1);
+				final int compareTo = v2.compareTo(v1);
+				if (compareTo != 0)
+					return compareTo;
+				// if the bonuses are the same, we want to make sure any support which only supports 1 single unittype goes first
+				// the reason being that we could have Support1 which supports both infantry and mech infantry, and Support2 which only supports mech infantry
+				// if the Support1 goes first, and the mech infantry is first in the unit list (highly probable), then Support1 will end up using all of itself up on the mech infantry
+				// then when the Support2 comes up, all the mech infantry are used up, and it does nothing.
+				// instead, we want Support2 to come first, support all mech infantry that it can, then have Support1 come in and support whatever is left, that way no support is wasted
+				// TODO: this breaks down completely if we have Support1 having a higher bonus than Support2, because it will come first. It should come first, unless we would have support wasted otherwise. This ends up being a pretty tricky math puzzle.
+				final Integer s1 = u1.getUnitType().size();
+				final Integer s2 = u2.getUnitType().size();
+				return s1.compareTo(s2);
 			}
 		};
 		final Iterator<List<UnitSupportAttachment>> iter = support.iterator();
 		while (iter.hasNext())
 		{
-			Collections.sort(iter.next(), comp);
+			Collections.sort(iter.next(), compList);
 		}
 	}
 	
@@ -501,6 +688,7 @@ public class DiceRoll implements Externalizable
 	public static DiceRoll airBattle(final List<Unit> unitsList, final boolean defending, final PlayerID player, final IDelegateBridge bridge, final IBattle battle, final String annotation)
 	{
 		final GameData data = bridge.getData();
+		final boolean lhtrBombers = games.strategy.triplea.Properties.getLHTR_Heavy_Bombers(data);
 		final List<Unit> units = new ArrayList<Unit>(unitsList);
 		final int rollCount = StrategicBombingRaidPreBattle.getAirBattleRolls(unitsList, defending);
 		if (rollCount == 0)
@@ -512,6 +700,7 @@ public class DiceRoll implements Externalizable
 		int hitCount = 0;
 		if (games.strategy.triplea.Properties.getLow_Luck(data))
 		{
+			final int extraRollBonus = Math.max(1, data.getDiceSides() / 6); // bonus is normally 1 for most games
 			final Iterator<Unit> iter = units.iterator();
 			int power = 0;
 			// We iterate through the units to find the total strength of the units
@@ -519,8 +708,20 @@ public class DiceRoll implements Externalizable
 			{
 				final Unit current = iter.next();
 				final UnitAttachment ua = UnitAttachment.get(current.getType());
-				final int strength = (defending ? ua.getAirDefense(current.getOwner()) : ua.getAirAttack(current.getOwner()));
-				power += Math.min(Math.max(strength, 0), data.getDiceSides());
+				final int rolls = StrategicBombingRaidPreBattle.getAirBattleRolls(current, defending);
+				int totalStrength = 0;
+				final int strength = Math.min(data.getDiceSides(), Math.max(0, (defending ? ua.getAirDefense(current.getOwner()) : ua.getAirAttack(current.getOwner()))));
+				for (int i = 0; i < rolls; i++)
+				{
+					// LHTR means pick the best dice roll, which doesn't really make sense in LL. So instead, we will just add +1 onto the power to simulate the gains of having the best die picked.
+					if (i > 1 && (lhtrBombers || ua.getChooseBestRoll()))
+					{
+						totalStrength += extraRollBonus;
+						continue;
+					}
+					totalStrength += strength;
+				}
+				power += Math.min(Math.max(totalStrength, 0), data.getDiceSides());
 			}
 			// Get number of hits
 			hitCount = power / data.getDiceSides();
@@ -529,7 +730,7 @@ public class DiceRoll implements Externalizable
 			power = power % data.getDiceSides();
 			if (power != 0)
 			{
-				random = bridge.getRandom(data.getDiceSides(), 1, annotation);
+				random = bridge.getRandom(data.getDiceSides(), 1, player, DiceType.COMBAT, annotation);
 				final boolean hit = power > random[0];
 				if (hit)
 				{
@@ -540,22 +741,49 @@ public class DiceRoll implements Externalizable
 		}
 		else
 		{
-			random = bridge.getRandom(data.getDiceSides(), rollCount, annotation);
+			random = bridge.getRandom(data.getDiceSides(), rollCount, player, DiceType.COMBAT, annotation);
 			final Iterator<Unit> iter = units.iterator();
 			int diceIndex = 0;
 			while (iter.hasNext())
 			{
 				final Unit current = iter.next();
 				final UnitAttachment ua = UnitAttachment.get(current.getType());
-				int strength = (defending ? ua.getAirDefense(current.getOwner()) : ua.getAirAttack(current.getOwner()));
-				strength = Math.min(Math.max(strength, 0), data.getDiceSides());
-				if (strength > 0)
+				final int strength = Math.min(data.getDiceSides(), Math.max(0, (defending ? ua.getAirDefense(current.getOwner()) : ua.getAirAttack(current.getOwner()))));
+				final int rolls = StrategicBombingRaidPreBattle.getAirBattleRolls(current, defending);
+				// lhtr heavy bombers take best of n dice for both attack and defense
+				if (rolls > 1 && (lhtrBombers || ua.getChooseBestRoll()))
 				{
-					final boolean hit = strength > random[diceIndex];
-					dice.add(new Die(random[diceIndex], strength, hit ? DieType.HIT : DieType.MISS));
+					int minIndex = 0;
+					int min = data.getDiceSides();
+					for (int i = 0; i < rolls; i++)
+					{
+						if (random[diceIndex + i] < min)
+						{
+							min = random[diceIndex + i];
+							minIndex = i;
+						}
+					}
+					final boolean hit = strength > random[diceIndex + minIndex];
+					dice.add(new Die(random[diceIndex + minIndex], strength, hit ? DieType.HIT : DieType.MISS));
+					for (int i = 0; i < rolls; i++)
+					{
+						if (i != minIndex)
+							dice.add(new Die(random[diceIndex + i], strength, DieType.IGNORED));
+					}
 					if (hit)
 						hitCount++;
-					diceIndex++;
+					diceIndex += rolls;
+				}
+				else
+				{
+					for (int i = 0; i < rolls; i++)
+					{
+						final boolean hit = strength > random[diceIndex];
+						dice.add(new Die(random[diceIndex], strength, hit ? DieType.HIT : DieType.MISS));
+						if (hit)
+							hitCount++;
+						diceIndex++;
+					}
 				}
 			}
 		}
@@ -567,7 +795,8 @@ public class DiceRoll implements Externalizable
 	/**
 	 * Roll dice for units per normal rules.
 	 */
-	private static DiceRoll rollDiceNormal(final List<Unit> unitsList, final boolean defending, final PlayerID player, final IDelegateBridge bridge, final IBattle battle, final String annotation)
+	private static DiceRoll rollDiceNormal(final List<Unit> unitsList, final boolean defending, final PlayerID player, final IDelegateBridge bridge, final IBattle battle, final String annotation,
+				final Collection<TerritoryEffect> territoryEffects)
 	{
 		final GameData data = bridge.getData();
 		final List<Unit> units = new ArrayList<Unit>(unitsList);
@@ -579,13 +808,14 @@ public class DiceRoll implements Externalizable
 		final IntegerMap<UnitSupportAttachment> supportLeft = new IntegerMap<UnitSupportAttachment>();
 		getSupport(units, supportRules, supportLeft, data, defending);
 		// make a copy to send to getRolls (due to need to know number of rolls based on support, as zero attack units will or will not get a roll depending)
-		final int rollCount = BattleCalculator.getRolls(units, location, player, defending, new HashSet<List<UnitSupportAttachment>>(supportRules), new IntegerMap<UnitSupportAttachment>(supportLeft));
+		final int rollCount = BattleCalculator.getRolls(units, location, player, defending, new HashSet<List<UnitSupportAttachment>>(supportRules), new IntegerMap<UnitSupportAttachment>(supportLeft),
+					territoryEffects);
 		if (rollCount == 0)
 		{
 			return new DiceRoll(new ArrayList<Die>(), 0);
 		}
 		int[] random;
-		random = bridge.getRandom(data.getDiceSides(), rollCount, annotation);
+		random = bridge.getRandom(data.getDiceSides(), rollCount, player, DiceType.COMBAT, annotation);
 		final List<Die> dice = new ArrayList<Die>();
 		final Iterator<Unit> iter = units.iterator();
 		int hitCount = 0;
@@ -596,9 +826,9 @@ public class DiceRoll implements Externalizable
 			final UnitAttachment ua = UnitAttachment.get(current.getType());
 			// make a copy for getRolls
 			final int rolls = BattleCalculator.getRolls(current, location, player, defending, new HashSet<List<UnitSupportAttachment>>(supportRules),
-						new IntegerMap<UnitSupportAttachment>(supportLeft));
+						new IntegerMap<UnitSupportAttachment>(supportLeft), territoryEffects);
 			// lhtr heavy bombers take best of n dice for both attack and defense
-			if (rolls > 1 && lhtrBombers && ua.getIsStrategicBomber())
+			if (rolls > 1 && (lhtrBombers || ua.getChooseBestRoll()))
 			{
 				int strength;
 				if (defending)
@@ -606,7 +836,7 @@ public class DiceRoll implements Externalizable
 				else
 					strength = ua.getAttack(current.getOwner());
 				strength += getSupport(current.getType(), supportRules, supportLeft);
-				strength += TerritoryEffectHelper.getTerritoryCombatBonus(current.getType(), location, defending);
+				strength += TerritoryEffectHelper.getTerritoryCombatBonus(current.getType(), territoryEffects, defending);
 				strength = Math.min(Math.max(strength, 0), data.getDiceSides());
 				int minIndex = 0;
 				int min = data.getDiceSides();
@@ -658,7 +888,7 @@ public class DiceRoll implements Externalizable
 							strength = ua.getBombard(current.getOwner());
 						strength += getSupport(current.getType(), supportRules, supportLeft);
 					}
-					strength += TerritoryEffectHelper.getTerritoryCombatBonus(current.getType(), location, defending);
+					strength += TerritoryEffectHelper.getTerritoryCombatBonus(current.getType(), territoryEffects, defending);
 					strength = Math.min(Math.max(strength, 0), data.getDiceSides());
 					final boolean hit = strength > random[diceIndex];
 					dice.add(new Die(random[diceIndex], strength, hit ? DieType.HIT : DieType.MISS));
