@@ -11,8 +11,9 @@
  */
 package games.strategy.triplea.delegate;
 
-import games.strategy.common.delegate.BaseDelegate;
+import games.strategy.common.delegate.BasePersistentDelegate;
 import games.strategy.engine.data.ChangeFactory;
+import games.strategy.engine.data.CompositeChange;
 import games.strategy.engine.data.GameData;
 import games.strategy.engine.data.PlayerID;
 import games.strategy.engine.data.Resource;
@@ -25,15 +26,18 @@ import games.strategy.engine.history.HistoryNode;
 import games.strategy.engine.history.Step;
 import games.strategy.engine.message.IRemote;
 import games.strategy.triplea.Constants;
+import games.strategy.triplea.TripleAUnit;
 import games.strategy.triplea.attatchments.TerritoryAttachment;
 import games.strategy.triplea.delegate.remote.IEditDelegate;
 import games.strategy.triplea.formatter.MyFormatter;
 import games.strategy.triplea.player.ITripleaPlayer;
 import games.strategy.util.CompositeMatch;
 import games.strategy.util.CompositeMatchAnd;
+import games.strategy.util.IntegerMap;
 
-import java.io.Serializable;
+import java.util.ArrayList;
 import java.util.Collection;
+import java.util.Map.Entry;
 
 /**
  * 
@@ -41,13 +45,10 @@ import java.util.Collection;
  * 
  * @author Tony Clayton
  */
-public class EditDelegate extends BaseDelegate implements IEditDelegate
+public class EditDelegate extends BasePersistentDelegate implements IEditDelegate
 {
-	
-	public void initialize(final String name)
-	{
-		initialize(name, name);
-	}
+	public static String EDITMODE_ON = "Turning on Edit Mode";
+	public static String EDITMODE_OFF = "Turning off Edit Mode";
 	
 	/**
 	 * Called before the delegate will run.
@@ -55,37 +56,12 @@ public class EditDelegate extends BaseDelegate implements IEditDelegate
 	@Override
 	public void start(final IDelegateBridge bridge)
 	{
-		// we do not want to do super.start() on this delegate because it is a persistent delegate
-		// the reason being that we do not want to do stuff like "triggerWhenTriggerAttachments", etc.
-		// super.start(new TripleADelegateBridge(bridge));
-		m_bridge = new TripleADelegateBridge(bridge);
-		m_player = bridge.getPlayerID();
+		super.start(new TripleADelegateBridge(bridge));
 	}
 	
 	@Override
 	public void end()
 	{
-		// we do not want to do super.end() on this delegate because it is a persistent delegate
-		// the reason being that we do not want to do stuff like "triggerWhenTriggerAttachments", etc.
-		// super.end();
-		// so, nothing to do here.
-	}
-	
-	@Override
-	public Serializable saveState()
-	{
-		final EditExtendedDelegateState state = new EditExtendedDelegateState();
-		state.superState = super.saveState();
-		// add other variables to state here:
-		return state;
-	}
-	
-	@Override
-	public void loadState(final Serializable state)
-	{
-		final EditExtendedDelegateState s = (EditExtendedDelegateState) state;
-		super.loadState(s.superState);
-		// load other variables from state here:
 	}
 	
 	public static boolean getEditMode(final GameData data)
@@ -101,7 +77,7 @@ public class EditDelegate extends BaseDelegate implements IEditDelegate
 	private String checkPlayerID()
 	{
 		final ITripleaPlayer remotePlayer = (ITripleaPlayer) m_bridge.getRemote();
-		if (!m_bridge.getPlayerID().equals(remotePlayer.getID()))
+		if (!m_bridge.getPlayerID().equals(remotePlayer.getPlayerID()))
 			return "Edit actions can only be performed during players turn";
 		return null;
 	}
@@ -119,10 +95,10 @@ public class EditDelegate extends BaseDelegate implements IEditDelegate
 	public String setEditMode(final boolean editMode)
 	{
 		final ITripleaPlayer remotePlayer = (ITripleaPlayer) m_bridge.getRemote();
-		if (!m_bridge.getPlayerID().equals(remotePlayer.getID()))
+		if (!m_bridge.getPlayerID().equals(remotePlayer.getPlayerID()))
 			return "Edit Mode can only be toggled during players turn";
-		logEvent("Turning " + (editMode ? "on" : "off") + " Edit Mode", null);
-		m_bridge.addChange(ChangeFactory.setProperty(Constants.EDIT_MODE, Boolean.valueOf(editMode), getData()));
+		logEvent((editMode ? EDITMODE_ON : EDITMODE_OFF), null);
+		m_bridge.addChange(ChangeFactory.setProperty(Constants.EDIT_MODE, new Boolean(editMode), getData()));
 		return null;
 	}
 	
@@ -140,8 +116,7 @@ public class EditDelegate extends BaseDelegate implements IEditDelegate
 			return result;
 		if (units == null || units.isEmpty())
 			return null;
-		logEvent(m_bridge.getPlayerID().getName() + " player Removing units owned by " + units.iterator().next().getOwner() + " from " + territory.getName() + ": "
-					+ MyFormatter.unitsToTextNoOwner(units), units);
+		logEvent("Removing units owned by " + units.iterator().next().getOwner().getName() + " from " + territory.getName() + ": " + MyFormatter.unitsToTextNoOwner(units), units);
 		m_bridge.addChange(ChangeFactory.removeUnits(territory, units));
 		return null;
 	}
@@ -155,15 +130,13 @@ public class EditDelegate extends BaseDelegate implements IEditDelegate
 			return result;
 		if (units == null || units.isEmpty())
 			return null;
-		logEvent(m_bridge.getPlayerID().getName() + " player Adding units owned by " + units.iterator().next().getOwner() + " to " + territory.getName() + ": " + MyFormatter.unitsToTextNoOwner(units),
-					units);
+		logEvent("Adding units owned by " + units.iterator().next().getOwner().getName() + " to " + territory.getName() + ": " + MyFormatter.unitsToTextNoOwner(units), units);
 		m_bridge.addChange(ChangeFactory.addUnits(territory, units));
 		return null;
 	}
 	
 	/**
-	 * @return gets the production of the territory, ignores wether the
-	 *         territory was an original factory
+	 * @return gets the production of the territory, ignores whether the territory was an original factory
 	 */
 	protected int getProduction(final Territory territory)
 	{
@@ -171,7 +144,6 @@ public class EditDelegate extends BaseDelegate implements IEditDelegate
 		if (ta != null)
 			return ta.getProduction();
 		return 0;
-		// throw new UnsupportedOperationException("Not implemented");
 	}
 	
 	public String changeTerritoryOwner(final Territory territory, final PlayerID player)
@@ -183,25 +155,29 @@ public class EditDelegate extends BaseDelegate implements IEditDelegate
 		// validate this edit
 		if (null != (result = EditValidator.validateChangeTerritoryOwner(data, territory, player)))
 			return result;
-		logEvent(m_bridge.getPlayerID().getName() + " player Changing ownership of " + territory.getName() + " from " + territory.getOwner().getName() + " to " + player.getName(), territory);
-		if (data.getRelationshipTracker().isAllied(territory.getOwner(), player))
+		logEvent("Changing ownership of " + territory.getName() + " from " + territory.getOwner().getName() + " to " + player.getName(), territory);
+		if (!data.getRelationshipTracker().isAtWar(territory.getOwner(), player))
 		{
 			// change ownership of friendly factories
-			final Collection<Unit> units = territory.getUnits().getMatches(Matches.UnitIsFactory);
+			final Collection<Unit> units = territory.getUnits().getMatches(Matches.UnitIsInfrastructure);
 			for (final Unit unit : units)
+			{
 				m_bridge.addChange(ChangeFactory.changeOwner(unit, player, territory));
+			}
 		}
 		else
 		{
 			final CompositeMatch<Unit> enemyNonCom = new CompositeMatchAnd<Unit>();
-			enemyNonCom.add(Matches.UnitIsFactoryOrIsInfrastructure);
+			enemyNonCom.add(Matches.UnitIsInfrastructure);
 			enemyNonCom.add(Matches.enemyUnit(player, data));
 			final Collection<Unit> units = territory.getUnits().getMatches(enemyNonCom);
 			// mark no movement for enemy units
 			m_bridge.addChange(ChangeFactory.markNoMovementChange(units));
 			// change ownership of enemy AA and factories
 			for (final Unit unit : units)
+			{
 				m_bridge.addChange(ChangeFactory.changeOwner(unit, player, territory));
+			}
 		}
 		// change ownership of territory
 		m_bridge.addChange(ChangeFactory.changeOwner(territory, player));
@@ -219,7 +195,7 @@ public class EditDelegate extends BaseDelegate implements IEditDelegate
 			return "New PUs total is unchanged";
 		if (newTotal < 0)
 			return "New PUs total is invalid";
-		logEvent(m_bridge.getPlayerID().getName() + " player Changing PUs for " + player.getName() + " from " + oldTotal + " to " + newTotal, null);
+		logEvent("Changing PUs for " + player.getName() + " from " + oldTotal + " to " + newTotal, null);
 		m_bridge.addChange(ChangeFactory.changeResourcesChange(player, PUs, (newTotal - oldTotal)));
 		return null;
 	}
@@ -235,11 +211,135 @@ public class EditDelegate extends BaseDelegate implements IEditDelegate
 			return "New token total is unchanged";
 		if (newTotal < 0)
 			return "New token total is invalid";
-		logEvent(m_bridge.getPlayerID().getName() + " player Changing tech tokens for " + player.getName() + " from " + oldTotal + " to " + newTotal, null);
+		logEvent("Changing tech tokens for " + player.getName() + " from " + oldTotal + " to " + newTotal, null);
 		m_bridge.addChange(ChangeFactory.changeResourcesChange(player, techTokens, (newTotal - oldTotal)));
 		return null;
 	}
 	
+	public String addTechAdvance(final PlayerID player, final TechAdvance advance)
+	{
+		String result = null;
+		if (null != (result = checkEditMode()))
+			return result;
+		if (null != (result = EditValidator.validateAddTech(getData(), advance, player)))
+			return result;
+		logEvent("Adding Technology " + advance.getName() + " for " + player.getName(), null);
+		TechTracker.addAdvance(player, m_bridge, advance);
+		return null;
+	}
+	
+	public String removeTechAdvance(final PlayerID player, final TechAdvance advance)
+	{
+		String result = null;
+		if (null != (result = checkEditMode()))
+			return result;
+		if (null != (result = EditValidator.validateRemoveTech(getData(), advance, player)))
+			return result;
+		logEvent("Removing Technology " + advance.getName() + " for " + player.getName(), null);
+		TechTracker.removeAdvance(player, m_bridge, advance);
+		return null;
+	}
+	
+	public String changeUnitHitDamage(final IntegerMap<Unit> unitDamageMap, final Territory territory)
+	{
+		String result = null;
+		if (null != (result = checkEditMode()))
+			return result;
+		if (null != (result = EditValidator.validateChangeHitDamage(getData(), unitDamageMap, territory)))
+			return result;
+		// remove anyone who is the same
+		final Collection<Unit> units = new ArrayList<Unit>(unitDamageMap.keySet());
+		for (final Unit u : units)
+		{
+			final int dmg = unitDamageMap.getInt(u);
+			if (u.getHits() == dmg)
+				unitDamageMap.removeKey(u);
+		}
+		if (unitDamageMap.isEmpty())
+			return null;
+		final Collection<Unit> unitsFinal = new ArrayList<Unit>(unitDamageMap.keySet());
+		logEvent("Changing unit hit damage for these " + unitsFinal.iterator().next().getOwner().getName() + " owned units to: " + MyFormatter.integerUnitMapToString(unitDamageMap), unitsFinal);
+		m_bridge.addChange(ChangeFactory.unitsHit(unitDamageMap));
+		territory.notifyChanged();
+		return null;
+	}
+	
+	public String changeUnitBombingDamage(final IntegerMap<Unit> unitDamageMap, final Territory territory)
+	{
+		String result = null;
+		if (null != (result = checkEditMode()))
+			return result;
+		if (null != (result = EditValidator.validateChangeBombingDamage(getData(), unitDamageMap, territory)))
+			return result;
+		final CompositeChange changes = new CompositeChange();
+		final IntegerMap<Unit> unitHitDamageMap = new IntegerMap<Unit>();
+		final TerritoryAttachment ta = TerritoryAttachment.get(territory);
+		// remove anyone who is the same
+		final Collection<Unit> units = new ArrayList<Unit>(unitDamageMap.keySet());
+		if (games.strategy.triplea.Properties.getSBRAffectsUnitProduction(getData()))
+		{
+			// we are damaging the territory, not the unit
+			if (ta == null)
+				return null;
+			final int production = ta.getProduction();
+			final int unitProduction = ta.getUnitProduction();
+			final int currentDamage = production - unitProduction;
+			final int damageToPut = unitDamageMap.highestValue();
+			if (currentDamage == damageToPut)
+				return null;
+			for (final Unit u : units)
+			{
+				if (damageToPut == 0 && currentDamage > 0)
+					unitHitDamageMap.put(u, 0);
+				else if (currentDamage == 0 && damageToPut > 0)
+					unitHitDamageMap.put(u, 1); // mark as damaged so we get the _hit picture
+				// else both must be greater than zero, so we are already marked
+			}
+		}
+		else
+		// if (games.strategy.triplea.Properties.getDamageFromBombingDoneToUnitsInsteadOfTerritories(getData()))
+		{
+			for (final Unit u : units)
+			{
+				final int dmg = unitDamageMap.getInt(u);
+				final int currentDamage = ((TripleAUnit) u).getUnitDamage();
+				if (currentDamage == dmg)
+					unitDamageMap.removeKey(u);
+				else
+				{
+					if (dmg == 0 && currentDamage > 0)
+						unitHitDamageMap.put(u, 0);
+					else if (currentDamage == 0 && dmg > 0)
+						unitHitDamageMap.put(u, 1); // mark as damaged so we get the _hit picture
+					// else both must be greater than zero, so we are already marked
+				}
+			}
+		}
+		if (unitDamageMap.isEmpty())
+			return null;
+		changes.add(ChangeFactory.unitsHit(unitHitDamageMap));
+		if (games.strategy.triplea.Properties.getSBRAffectsUnitProduction(getData()))
+		{
+			// we do damage to the territory (use the largest value)
+			// remember to subtract it from the current production value (not the current unit production value) because we are setting the total damage, not adding more damage.
+			changes.add(ChangeFactory.attachmentPropertyChange(ta, Integer.toString(ta.getProduction() - unitDamageMap.highestValue()), "unitProduction"));
+		}
+		else
+		// if (games.strategy.triplea.Properties.getDamageFromBombingDoneToUnitsInsteadOfTerritories(getData()))
+		{
+			// we do damage to the unit
+			for (final Entry<Unit, Integer> entry : unitDamageMap.entrySet())
+			{
+				changes.add(ChangeFactory.unitPropertyChange(entry.getKey(), entry.getValue(), TripleAUnit.UNIT_DAMAGE));
+			}
+		}
+		final Collection<Unit> unitsFinal = new ArrayList<Unit>(unitDamageMap.keySet());
+		logEvent("Changing unit bombing damage for these " + unitsFinal.iterator().next().getOwner().getName() + " owned units to: " + MyFormatter.integerUnitMapToString(unitDamageMap), unitsFinal);
+		m_bridge.addChange(changes);
+		territory.notifyChanged();
+		return null;
+	}
+	
 	public String addComment(final String message)
 	{
 		String result = null;
@@ -253,7 +353,7 @@ public class EditDelegate extends BaseDelegate implements IEditDelegate
 	// out whether it makes more sense to log a new event or a child.
 	// If any child events came before us, then we'll log a child event.
 	// Otherwise, we'll log a new event.
-	private void logEvent(final String message, final Object data)
+	private void logEvent(final String message, final Object renderingObject)
 	{
 		// find last event node
 		boolean foundChild = false;
@@ -276,11 +376,10 @@ public class EditDelegate extends BaseDelegate implements IEditDelegate
 			game_data.releaseReadLock();
 		}
 		if (foundChild)
-			m_bridge.getHistoryWriter().addChildToEvent(message, game_data);
+			m_bridge.getHistoryWriter().addChildToEvent(message, renderingObject);
 		else
 		{
-			m_bridge.getHistoryWriter().startEvent(message);
-			m_bridge.getHistoryWriter().setRenderingData(game_data);
+			m_bridge.getHistoryWriter().startEvent(message, renderingObject);
 		}
 	}
 	
@@ -293,11 +392,3 @@ public class EditDelegate extends BaseDelegate implements IEditDelegate
 		return IEditDelegate.class;
 	}
 }
-
-
-@SuppressWarnings("serial")
-class EditExtendedDelegateState implements Serializable
-{
-	Serializable superState;
-	// add other variables here:
-}
