@@ -382,9 +382,9 @@ public class EndRoundDelegate extends BaseDelegate
 }
 
 
-@SuppressWarnings("serial")
 class EndRoundExtendedDelegateState implements Serializable
 {
+	private static final long serialVersionUID = 8770361633528374127L;
 	Serializable superState;
 	// add other variables here:
 	public boolean m_gameOver = false;
