@@ -129,7 +129,7 @@ public class InitializationDelegate extends BaseDelegate
 		while (players.hasNext())
 		{
 			final PlayerID player = players.next();
-			final Iterator<TechAdvance> advances = TechTracker.getTechAdvances(player, data).iterator();
+			final Iterator<TechAdvance> advances = TechTracker.getCurrentTechAdvances(player, data).iterator();
 			if (advances.hasNext())
 			{
 				bridge.getHistoryWriter().startEvent("Initializing " + player.getName() + " with tech advances");
@@ -259,7 +259,7 @@ public class InitializationDelegate extends BaseDelegate
 			if (!current.getOwner().isNull())
 			{
 				changes.add(origOwnerTracker.addOriginalOwnerChange(current, current.getOwner()));
-				final Collection<Unit> factoryAndInfrastructure = current.getUnits().getMatches(Matches.UnitIsFactoryOrIsInfrastructure);
+				final Collection<Unit> factoryAndInfrastructure = current.getUnits().getMatches(Matches.UnitIsInfrastructure);
 				changes.add(origOwnerTracker.addOriginalOwnerChange(factoryAndInfrastructure, current.getOwner()));
 				final TerritoryAttachment territoryAttachment = TerritoryAttachment.get(current);
 				if (territoryAttachment == null)
@@ -282,9 +282,9 @@ public class InitializationDelegate extends BaseDelegate
 }
 
 
-@SuppressWarnings("serial")
 class InitializationExtendedDelegateState implements Serializable
 {
+	private static final long serialVersionUID = -9000446777655823735L;
 	Serializable superState;
 	// add other variables here:
 }
