@@ -41,11 +41,13 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.Map;
+import java.util.Map.Entry;
+import java.util.Set;
 
-@SuppressWarnings("serial")
 public class MovePerformer implements Serializable
 {
-	private transient MoveDelegate m_moveDelegate;
+	private static final long serialVersionUID = 3752242292777658310L;
+	private transient AbstractMoveDelegate m_moveDelegate;
 	private transient IDelegateBridge m_bridge;
 	private transient PlayerID m_player;
 	private AAInMoveUtil m_aaInMoveUtil;
@@ -62,7 +64,7 @@ public class MovePerformer implements Serializable
 		return DelegateFinder.battleDelegate(m_bridge.getData()).getBattleTracker();
 	}
 	
-	void initialize(final MoveDelegate delegate)
+	void initialize(final AbstractMoveDelegate delegate)
 	{
 		m_moveDelegate = delegate;
 		m_bridge = delegate.getBridge();
@@ -102,6 +104,8 @@ public class MovePerformer implements Serializable
 	{
 		final IExecutable preAAFire = new IExecutable()
 		{
+			private static final long serialVersionUID = -7945930782650355037L;
+			
 			public void execute(final ExecutionStack stack, final IDelegateBridge bridge)
 			{
 				// if we are moving out of a battle zone, mark it
@@ -130,14 +134,35 @@ public class MovePerformer implements Serializable
 		final Collection<Unit>[] arrivingUnits = new Collection[1];
 		final IExecutable fireAA = new IExecutable()
 		{
+			private static final long serialVersionUID = -3780228078499895244L;
+			
 			public void execute(final ExecutionStack stack, final IDelegateBridge bridge)
 			{
 				final Collection<Unit> aaCasualties = fireAA(route, units);
-				arrivingUnits[0] = Util.difference(units, aaCasualties);
+				final Set<Unit> aaCasualtiesWithDependents = new HashSet<Unit>();
+				// need to remove any dependents here
+				if (aaCasualties != null)
+				{
+					aaCasualtiesWithDependents.addAll(aaCasualties);
+					final Map<Unit, Collection<Unit>> dependencies = new TransportTracker().transporting(units, units);
+					for (final Unit u : aaCasualties)
+					{
+						final Collection<Unit> dependents = dependencies.get(u);
+						if (dependents != null)
+							aaCasualtiesWithDependents.addAll(dependents);
+						// we might have new dependents too (ie: paratroopers)
+						final Collection<Unit> newDependents = m_newDependents.get(u);
+						if (newDependents != null)
+							aaCasualtiesWithDependents.addAll(newDependents);
+					}
+				}
+				arrivingUnits[0] = Util.difference(units, aaCasualtiesWithDependents);
 			}
 		};
 		final IExecutable postAAFire = new IExecutable()
 		{
+			private static final long serialVersionUID = 670783657414493643L;
+			
 			public void execute(final ExecutionStack stack, final IDelegateBridge bridge)
 			{
 				// if any non enemy territories on route
@@ -149,25 +174,40 @@ public class MovePerformer implements Serializable
 				mustFightThrough.add(Matches.isTerritoryEnemyAndNotUnownedWaterOrImpassibleOrRestricted(id, data));
 				mustFightThrough.add(Matches.territoryHasNonSubmergedEnemyUnits(id, data));
 				mustFightThrough.add(Matches.territoryIsOwnedByPlayerWhosRelationshipTypeCanTakeOverOwnedTerritoryAndPassableAndNotWater(id));
-				final Collection<Unit> arrived = Util.intersection(units, arrivingUnits[0]);
+				final Collection<Unit> arrived = Collections.unmodifiableList(Util.intersection(units, arrivingUnits[0]));
+				final Collection<Unit> arrivedCopyForBattles = new ArrayList<Unit>(arrived);
 				final Map<Unit, Unit> transporting = MoveDelegate.mapTransports(route, arrived, transportsToLoad);
+				// If we have paratrooper land units being carried by air units, they should be dropped off in the last territory. This means they are still dependent during the middle steps of the route.
+				final Collection<Unit> dependentOnSomethingTilTheEndOfRoute = new ArrayList<Unit>();
+				final Collection<Unit> airTransports = Match.getMatches(arrived, Matches.UnitIsAirTransport);
+				final Collection<Unit> paratroops = Match.getMatches(arrived, Matches.UnitIsAirTransportable);
+				if (!airTransports.isEmpty() && !paratroops.isEmpty())
+				{
+					final Map<Unit, Unit> transportingAir = MoveDelegate.mapAirTransports(route, paratroops, airTransports, true, id);
+					dependentOnSomethingTilTheEndOfRoute.addAll(transportingAir.keySet());
+				}
+				final Collection<Unit> presentFromStartTilEnd = new ArrayList<Unit>(arrived);
+				presentFromStartTilEnd.removeAll(dependentOnSomethingTilTheEndOfRoute);
 				markTransportsMovement(arrived, transporting, route);
-				if (route.someMatch(mustFightThrough) && arrivingUnits[0].size() != 0)
+				if (route.someMatch(mustFightThrough) && arrived.size() != 0)
 				{
 					boolean bombing = false;
 					boolean ignoreBattle = false;
 					// could it be a bombing raid
 					final Collection<Unit> enemyUnits = route.getEnd().getUnits().getMatches(Matches.enemyUnit(id, data));
-					final Collection<Unit> enemyTargets = Match.getMatches(enemyUnits, Matches.UnitIsAtMaxDamageOrNotCanBeDamaged(route.getEnd()).invert());
+					final Collection<Unit> enemyTargetsTotal = Match.getMatches(enemyUnits, Matches.UnitIsAtMaxDamageOrNotCanBeDamaged(route.getEnd()).invert());
 					final CompositeMatchOr<Unit> allBombingRaid = new CompositeMatchOr<Unit>(Matches.UnitIsStrategicBomber);
-					final boolean canCreateAirBattle = (Match.someMatch(enemyUnits, StrategicBombingRaidPreBattle.defendingInterceptors(id, data)) && !enemyTargets.isEmpty()
+					final boolean canCreateAirBattle = (Match.someMatch(enemyUnits, StrategicBombingRaidPreBattle.defendingInterceptors(id, data)) && !enemyTargetsTotal.isEmpty()
 								&& games.strategy.triplea.Properties.getRaidsMayBePreceededByAirBattles(data));
 					if (canCreateAirBattle)
 						allBombingRaid.add(Matches.unitCanEscort);
 					final boolean allCanBomb = Match.allMatch(arrived, allBombingRaid);
+					final Collection<Unit> enemyTargets = Match.getMatches(enemyTargetsTotal,
+								Matches.unitIsOfTypes(UnitAttachment.getAllowedBombingTargetsIntersection(Match.getMatches(arrived, Matches.UnitIsStrategicBomber), data)));
+					final boolean targetsOrEscort = !enemyTargets.isEmpty() || (!enemyTargetsTotal.isEmpty() && canCreateAirBattle && Match.allMatch(arrived, Matches.unitCanEscort));
 					boolean targetedAttack = false;
 					// if it's all bombers and there's something to bomb
-					if (allCanBomb && !enemyTargets.isEmpty())
+					if (allCanBomb && targetsOrEscort && !MoveDelegate.isNonCombat(m_bridge))
 					{
 						bombing = getRemotePlayer().shouldBomberBomb(route.getEnd());
 						// if bombing and there's something to target- ask what to bomb
@@ -178,9 +218,11 @@ public class MovePerformer implements Serializable
 							Unit target;
 							if (enemyTargets.size() > 1 && games.strategy.triplea.Properties.getDamageFromBombingDoneToUnitsInsteadOfTerritories(data)
 										&& !canCreateAirBattle)
-								target = getRemotePlayer().whatShouldBomberBomb(route.getEnd(), enemyTargets);
-							else
+								target = getRemotePlayer().whatShouldBomberBomb(route.getEnd(), enemyTargets, arrived);
+							else if (!enemyTargets.isEmpty())
 								target = enemyTargets.iterator().next();
+							else
+								target = enemyTargetsTotal.iterator().next(); // in case we are escorts only
 							if (target == null)
 							{
 								bombing = false;
@@ -190,8 +232,8 @@ public class MovePerformer implements Serializable
 							{
 								targetedAttack = true;
 								final HashMap<Unit, HashSet<Unit>> targets = new HashMap<Unit, HashSet<Unit>>();
-								targets.put(target, new HashSet<Unit>(arrivingUnits[0]));
-								getBattleTracker().addBattle(route, arrivingUnits[0], bombing, id, m_bridge, m_currentMove, targets, false);
+								targets.put(target, new HashSet<Unit>(arrived));
+								getBattleTracker().addBattle(route, arrivedCopyForBattles, bombing, id, m_bridge, m_currentMove, dependentOnSomethingTilTheEndOfRoute, targets, false);
 							}
 						}
 					}
@@ -206,30 +248,33 @@ public class MovePerformer implements Serializable
 					}
 					if (!ignoreBattle && !MoveDelegate.isNonCombat(m_bridge) && !targetedAttack)
 					{
-						getBattleTracker().addBattle(route, arrivingUnits[0], bombing, id, m_bridge, m_currentMove);
+						getBattleTracker().addBattle(route, arrivedCopyForBattles, bombing, id, m_bridge, m_currentMove, dependentOnSomethingTilTheEndOfRoute);
 					}
-					if (!ignoreBattle && MoveDelegate.isNonCombat(m_bridge) && !targetedAttack && route.allMatch(Matches.isTerritoryEnemy(id, data).invert())
-								&& route.allMatch(Matches.territoryHasNoEnemyUnits(id, data)) && Match.someMatch(arrivingUnits[0], Matches.UnitIsLand)
-								&& Match.noneMatch(arrivingUnits[0], Matches.UnitIsSea))
+					if (!ignoreBattle && MoveDelegate.isNonCombat(m_bridge) && !targetedAttack)
 					{
 						// We are in non-combat move phase, and we are taking over friendly territories. No need for a battle. (This could get really difficult if we want these recorded in battle records).
 						for (final Territory t : route.getMatches(new CompositeMatchAnd<Territory>(
 									Matches.territoryIsOwnedByPlayerWhosRelationshipTypeCanTakeOverOwnedTerritoryAndPassableAndNotWater(id),
 									Matches.TerritoryIsBlitzable(id, data))))
 						{
-							getBattleTracker().takeOver(t, id, bridge, m_currentMove, arrivingUnits[0]);
+							if (Matches.isTerritoryEnemy(id, data).match(t) || Matches.territoryHasEnemyUnits(id, data).match(t))
+								continue;
+							if ((t.equals(route.getEnd()) && Match.allMatch(arrivedCopyForBattles, Matches.UnitIsAir))
+										|| (!t.equals(route.getEnd()) && Match.allMatch(presentFromStartTilEnd, Matches.UnitIsAir)))
+								continue;
+							getBattleTracker().takeOver(t, id, bridge, m_currentMove, arrivedCopyForBattles);
 						}
 					}
 				}
 				// mark movement
-				final Change moveChange = markMovementChange(arrived, route);
+				final Change moveChange = markMovementChange(arrived, route, id);
 				final CompositeChange change = new CompositeChange(moveChange);
 				// actually move the units
 				Change remove = null;
 				Change add = null;
 				if (route.getStart() != null && route.getEnd() != null)
 				{
-					ChangeFactory.addUnits(route.getEnd(), arrivingUnits[0]);
+					// ChangeFactory.addUnits(route.getEnd(), arrived);
 					remove = ChangeFactory.removeUnits(route.getStart(), units);
 					add = ChangeFactory.addUnits(route.getEnd(), arrived);
 					change.add(add, remove);
@@ -253,8 +298,9 @@ public class MovePerformer implements Serializable
 		return ChangeFactory.removeResourceCollection(id, Route.getMovementCharge(units, route));
 	}
 	
-	private Change markMovementChange(final Collection<Unit> units, final Route route)
+	private Change markMovementChange(final Collection<Unit> units, final Route route, final PlayerID id)
 	{
+		final GameData data = m_bridge.getData();
 		final CompositeChange change = new CompositeChange();
 		final Territory routeStart = route.getStart();
 		final TerritoryAttachment taRouteStart = TerritoryAttachment.get(routeStart);
@@ -262,8 +308,8 @@ public class MovePerformer implements Serializable
 		TerritoryAttachment taRouteEnd = null;
 		if (routeEnd != null)
 			taRouteEnd = TerritoryAttachment.get(routeEnd);
-		Iterator<Unit> iter = units.iterator();
-		final RelationshipTracker relationshipTracker = m_bridge.getData().getRelationshipTracker();
+		final Iterator<Unit> iter = units.iterator();
+		final RelationshipTracker relationshipTracker = data.getRelationshipTracker();
 		while (iter.hasNext())
 		{
 			final TripleAUnit unit = (TripleAUnit) iter.next();
@@ -282,11 +328,17 @@ public class MovePerformer implements Serializable
 		// if entered a non blitzed conquered territory, mark with 0 movement
 		if (!MoveDelegate.isNonCombat(m_bridge) && (MoveDelegate.getEmptyNeutral(route).size() != 0 || hasConqueredNonBlitzed(route)))
 		{
-			final Collection<Unit> land = Match.getMatches(units, Matches.UnitIsLand);
-			iter = land.iterator();
-			while (iter.hasNext())
+			for (final Unit unit : Match.getMatches(units, Matches.UnitIsLand))
+			{
+				change.add(ChangeFactory.markNoMovementChange(Collections.singleton(unit)));
+			}
+		}
+		if (routeEnd != null && games.strategy.triplea.Properties.getSubsCanEndNonCombatMoveWithEnemies(data) && MoveDelegate.isNonCombat(m_bridge)
+					&& routeEnd.getUnits().someMatch(new CompositeMatchAnd<Unit>(Matches.unitIsEnemyOf(data, id), Matches.UnitIsDestroyer)))
+		{
+			// if we are allowed to have our subs enter any sea zone with enemies during noncombat, we want to make sure we can't keep moving them if there is an enemy destroyer there
+			for (final Unit unit : Match.getMatches(units, new CompositeMatchAnd<Unit>(Matches.UnitIsSub, Matches.UnitIsAir.invert())))
 			{
-				final Unit unit = iter.next();
 				change.add(ChangeFactory.markNoMovementChange(Collections.singleton(unit)));
 			}
 		}
@@ -304,9 +356,20 @@ public class MovePerformer implements Serializable
 		paratroopNAirTransports.add(Matches.UnitIsAirTransport);
 		paratroopNAirTransports.add(Matches.UnitIsAirTransportable);
 		final boolean paratroopsLanding = Match.someMatch(arrived, paratroopNAirTransports) && MoveValidator.allLandUnitsAreBeingParatroopered(arrived, route, m_player);
-		Map<Unit, Collection<Unit>> dependentAirTransportableUnits = MoveValidator.getDependents(Match.getMatches(arrived, Matches.UnitCanTransport), m_bridge.getData());
-		if (dependentAirTransportableUnits.isEmpty())
-			dependentAirTransportableUnits = m_newDependents;
+		final Map<Unit, Collection<Unit>> dependentAirTransportableUnits = MoveValidator.getDependents(Match.getMatches(arrived, Matches.UnitCanTransport), m_bridge.getData());
+		// add newly created dependents
+		if (m_newDependents != null)
+		{
+			for (final Entry<Unit, Collection<Unit>> entry : m_newDependents.entrySet())
+			{
+				Collection<Unit> dependents = dependentAirTransportableUnits.get(entry.getKey());
+				if (dependents != null)
+					dependents.addAll(entry.getValue());
+				else
+					dependents = entry.getValue();
+				dependentAirTransportableUnits.put(entry.getKey(), dependents);
+			}
+		}
 		// If paratroops moved normally (within their normal movement) remove their dependency to the airTransports
 		// So they can all continue to move normally
 		if (!paratroopsLanding && !dependentAirTransportableUnits.isEmpty())
@@ -360,15 +423,20 @@ public class MovePerformer implements Serializable
 					units.addAll(dependentAirTransportableUnits.get(airTransport));
 				}
 			}
-			final Iterator<Unit> iter = units.iterator();
 			// any pending battles in the unloading zone?
 			final BattleTracker tracker = getBattleTracker();
 			final boolean pendingBattles = tracker.getPendingBattle(route.getStart(), false) != null;
+			final Iterator<Unit> iter = units.iterator();
 			while (iter.hasNext())
 			{
 				final Unit unit = iter.next();
 				if (paratroopsLanding && Matches.UnitIsAirTransport.match(unit))
 					continue;
+				final Unit transportedBy = ((TripleAUnit) unit).getTransportedBy();
+				// we will unload our paratroopers after they land in battle (after aa guns fire)
+				if (paratroopsLanding && transportedBy != null && Matches.UnitIsAirTransport.match(transportedBy) && !AbstractMoveDelegate.isNonCombat(m_bridge)
+							&& Matches.territoryHasNonSubmergedEnemyUnits(m_player, m_bridge.getData()).match(route.getEnd()))
+					continue;
 				// unload the transports
 				Change change = m_moveDelegate.getTransportTracker().unloadTransportChange((TripleAUnit) unit, m_currentMove.getRoute().getEnd(), m_player, pendingBattles);
 				m_currentMove.addChange(change);
