@@ -16,7 +16,7 @@
  * 
  * Created on November 9, 2001, 4:05 PM
  * 
- * @version $LastChangedDate: 2012-04-04 01:46:51 +0800 (Wed, 04 Apr 2012) $
+ * @version $LastChangedDate: 2012-08-18 01:57:47 +0800 (Sat, 18 Aug 2012) $
  */
 package games.strategy.triplea.delegate;
 
@@ -66,6 +66,7 @@ public class MoveValidator
 {
 	public static final String TRANSPORT_HAS_ALREADY_UNLOADED_UNITS_IN_A_PREVIOUS_PHASE = "Transport has already unloaded units in a previous phase";
 	public static final String TRANSPORT_MAY_NOT_UNLOAD_TO_FRIENDLY_TERRITORIES_UNTIL_AFTER_COMBAT_IS_RESOLVED = "Transport may not unload to friendly territories until after combat is resolved";
+	public static final String ENEMY_SUBMARINE_PREVENTING_UNESCORTED_AMPHIBIOUS_ASSAULT_LANDING = "Enemy Submarine Preventing Unescorted Amphibious Assault Landing";
 	public static final String TRANSPORT_HAS_ALREADY_UNLOADED_UNITS_TO = "Transport has already unloaded units to ";
 	public static final String CANNOT_LOAD_AND_UNLOAD_AN_ALLIED_TRANSPORT_IN_THE_SAME_ROUND = "Cannot load and unload an allied transport in the same round";
 	public static final String CANT_MOVE_THROUGH_IMPASSIBLE = "Can't move through impassible territories";
@@ -83,52 +84,10 @@ public class MoveValidator
 		final MoveValidationResult result = new MoveValidationResult();
 		if (route.hasNoSteps())
 			return result;
-		if (!units.isEmpty() && !getEditMode(data)
-					&& !Match.allMatch(Match.getMatches(units, Matches.unitIsBeingTransportedByOrIsDependentOfSomeUnitInThisList(units, route, player, data).invert()), Matches.unitIsOwnedBy(player)))
-		{
-			result.setError("Player, " + player.getName() + ", is not owner of all the units: " + MyFormatter.unitsToTextNoOwner(units));
-			return result;
-		}
-		// this should never happen
-		if (new HashSet<Unit>(units).size() != units.size())
-		{
-			result.setError("Not all units unique, units:" + units + " unique:" + new HashSet<Unit>(units));
-			return result;
-		}
-		if (!data.getMap().isValidRoute(route))
-		{
-			result.setError("Invalid route:" + route);
-			return result;
-		}
-		if (validateMovementRestrictedByTerritory(data, units, route, player, result).getError() != null)
+		if (validateFirst(data, units, route, player, result).getError() != null)
 		{
 			return result;
 		}
-		// can not enter territories owned by a player to which we are neutral towards
-		final Collection<Territory> landOnRoute = route.getMatches(Matches.TerritoryIsLand);
-		if (!landOnRoute.isEmpty())
-		{
-			// TODO: if this ever changes, we need to also update getBestRoute(), because getBestRoute is also checking to make sure we avoid land territories owned by nations with these 2 relationship type attachment options
-			for (final Territory t : landOnRoute)
-			{
-				if (Match.someMatch(units, Matches.UnitIsLand))
-				{
-					if (!data.getRelationshipTracker().canMoveLandUnitsOverOwnedLand(player, t.getOwner()))
-					{
-						result.setError(player.getName() + " may not move land units over land owned by " + t.getOwner().getName());
-						return result;
-					}
-				}
-				if (Match.someMatch(units, Matches.UnitIsAir))
-				{
-					if (!data.getRelationshipTracker().canMoveAirUnitsOverOwnedLand(player, t.getOwner()))
-					{
-						result.setError(player.getName() + " may not move air units over land owned by " + t.getOwner().getName());
-						return result;
-					}
-				}
-			}
-		}
 		if (isNonCombat)
 		{
 			if (validateNonCombat(data, units, route, player, result).getError() != null)
@@ -183,7 +142,70 @@ public class MoveValidator
 		return result;
 	}
 	
-	private static MoveValidationResult validateFuel(final GameData data, final Collection<Unit> units, final Route route, final PlayerID player, final MoveValidationResult result)
+	static MoveValidationResult validateFirst(final GameData data, final Collection<Unit> units, final Route route, final PlayerID player, final MoveValidationResult result)
+	{
+		if (!units.isEmpty()
+					&& !getEditMode(data)
+					&& !Match.allMatch(Match.getMatches(units, Matches.unitIsBeingTransportedByOrIsDependentOfSomeUnitInThisList(units, route, player, data, true).invert()),
+								Matches.unitIsOwnedBy(player)))
+		{
+			result.setError("Player, " + player.getName() + ", is not owner of all the units: " + MyFormatter.unitsToTextNoOwner(units));
+			return result;
+		}
+		// this should never happen
+		if (new HashSet<Unit>(units).size() != units.size())
+		{
+			result.setError("Not all units unique, units:" + units + " unique:" + new HashSet<Unit>(units));
+			return result;
+		}
+		if (!data.getMap().isValidRoute(route))
+		{
+			result.setError("Invalid route:" + route);
+			return result;
+		}
+		if (validateMovementRestrictedByTerritory(data, units, route, player, result).getError() != null)
+		{
+			return result;
+		}
+		// can not enter territories owned by a player to which we are neutral towards
+		final Collection<Territory> landOnRoute = route.getMatches(Matches.TerritoryIsLand);
+		if (!landOnRoute.isEmpty())
+		{
+			// TODO: if this ever changes, we need to also update getBestRoute(), because getBestRoute is also checking to make sure we avoid land territories owned by nations with these 2 relationship type attachment options
+			for (final Territory t : landOnRoute)
+			{
+				if (Match.someMatch(units, Matches.UnitIsLand))
+				{
+					if (!data.getRelationshipTracker().canMoveLandUnitsOverOwnedLand(player, t.getOwner()))
+					{
+						result.setError(player.getName() + " may not move land units over land owned by " + t.getOwner().getName());
+						return result;
+					}
+				}
+				if (Match.someMatch(units, Matches.UnitIsAir))
+				{
+					if (!data.getRelationshipTracker().canMoveAirUnitsOverOwnedLand(player, t.getOwner()))
+					{
+						result.setError(player.getName() + " may not move air units over land owned by " + t.getOwner().getName());
+						return result;
+					}
+				}
+			}
+		}
+		if (units.size() == 0)
+			return result.setErrorReturnResult("No units");
+		for (final Unit unit : units)
+		{
+			if (TripleAUnit.get(unit).getSubmerged())
+				result.addDisallowedUnit("Cannot move submerged units", unit);
+		}
+		// make sure all units are actually in the start territory
+		if (!route.getStart().getUnits().containsAll(units))
+			return result.setErrorReturnResult("Not enough units in starting territory");
+		return result;
+	}
+	
+	static MoveValidationResult validateFuel(final GameData data, final Collection<Unit> units, final Route route, final PlayerID player, final MoveValidationResult result)
 	{
 		if (getEditMode(data))
 			return result;
@@ -243,7 +265,7 @@ public class MoveValidator
 			{
 				if (current.isWater())
 					continue;
-				if (!data.getRelationshipTracker().isAllied(current.getOwner(), player) || MoveDelegate.getBattleTracker(data).wasConquered(current))
+				if (data.getRelationshipTracker().isAtWar(current.getOwner(), player) || MoveDelegate.getBattleTracker(data).wasConquered(current))
 				{
 					enemyCount++;
 					allEnemyBlitzable &= Matches.TerritoryIsBlitzable(player, data).match(current);
@@ -254,7 +276,7 @@ public class MoveValidator
 				if (nonParatroopersPresent(player, units, route))
 					return result.setErrorReturnResult("Cannot blitz on that route");
 			}
-			else if (enemyCount >= 0 && allEnemyBlitzable && !(route.getStart().isWater() || route.getEnd().isWater()))
+			else if (allEnemyBlitzable && !(route.getStart().isWater() || route.getEnd().isWater()))
 			{
 				final Match<Unit> blitzingUnit = new CompositeMatchOr<Unit>(Matches.UnitCanBlitz, Matches.UnitIsAir);
 				final Match<Unit> nonBlitzing = new InverseMatch<Unit>(blitzingUnit);
@@ -277,7 +299,7 @@ public class MoveValidator
 						continue;
 					final TripleAUnit tAUnit = (TripleAUnit) unit;
 					if (wasStartFoughtOver || tAUnit.getWasInCombat() || route.someMatch(notEndOrFriendlyTerrs) || route.someMatch(notEndWasFought))
-						result.addDisallowedUnit("Not all units can blitz", unit);
+						result.addDisallowedUnit(NOT_ALL_UNITS_CAN_BLITZ, unit);
 				}
 				
 			}
@@ -362,7 +384,10 @@ public class MoveValidator
 			friendlyOrSubmerged.add(Matches.enemyUnit(player, data).invert());
 			friendlyOrSubmerged.add(Matches.unitIsSubmerged(data));
 			if (!route.getEnd().getUnits().allMatch(friendlyOrSubmerged) && !(Match.allMatch(units, Matches.UnitIsAir) && route.getEnd().isWater()))
-				return result.setErrorReturnResult("Cannot advance to battle in non combat");
+			{
+				if (!Match.allMatch(units, Matches.UnitIsSub) || !games.strategy.triplea.Properties.getSubsCanEndNonCombatMoveWithEnemies(data))
+					return result.setErrorReturnResult("Cannot advance to battle in non combat");
+			}
 		}
 		if (Match.allMatch(units, Matches.UnitIsAir))
 		{
@@ -372,14 +397,12 @@ public class MoveValidator
 		}
 		else
 		{
-			final CompositeMatch<Territory> neutralOrEnemy = new CompositeMatchOr<Territory>(Matches.TerritoryIsNeutralButNotWater, Matches.isTerritoryEnemyAndNotUnownedWaterOrImpassibleOrRestricted(
-						player,
-						data));
+			final CompositeMatch<Territory> neutralOrEnemy = new CompositeMatchOr<Territory>(Matches.TerritoryIsNeutralButNotWater,
+						Matches.isTerritoryEnemyAndNotUnownedWaterOrImpassibleOrRestricted(player, data));
 			if (route.someMatch(neutralOrEnemy))
 			{
-				if (!(!navalMayNotNonComIntoControlled && route.allMatch(Matches.TerritoryIsWater) && MoveValidator.noEnemyUnitsOnPathMiddleSteps(route, player, data) && !Matches
-							.territoryHasEnemyUnits(
-										player, data).match(route.getEnd())))
+				if ((!(!navalMayNotNonComIntoControlled && route.allMatch(Matches.TerritoryIsWater))) && MoveValidator.noEnemyUnitsOnPathMiddleSteps(route, player, data) &&
+							!Matches.territoryHasEnemyUnits(player, data).match(route.getEnd()))
 				{
 					if (!route.allMatch(new CompositeMatchOr<Territory>(Matches.TerritoryIsWater, new CompositeMatchAnd<Territory>(Matches.TerritoryIsPassableAndNotRestricted(player, data), Matches
 								.isTerritoryAllied(player, data), Matches.TerritoryIsLand))) || nonParatroopersPresent(player, units, route))
@@ -391,7 +414,7 @@ public class MoveValidator
 	}
 	
 	// Added to handle restriction of movement to listed territories
-	private static MoveValidationResult validateMovementRestrictedByTerritory(final GameData data, final Collection<Unit> units, final Route route, final PlayerID player,
+	static MoveValidationResult validateMovementRestrictedByTerritory(final GameData data, final Collection<Unit> units, final Route route, final PlayerID player,
 				final MoveValidationResult result)
 	{
 		if (getEditMode(data))
@@ -432,7 +455,8 @@ public class MoveValidator
 		// if we are all air, then its ok
 		if (Match.allMatch(units, Matches.UnitIsAir))
 			return result;
-		if (isSubmersibleSubsAllowed(data) && Match.allMatch(units, Matches.UnitIsSub))
+		// subs may possibly carry units...
+		if (isSubmersibleSubsAllowed(data) && Match.allMatch(Match.getMatches(units, Matches.unitIsBeingTransported().invert()), Matches.UnitIsSub))
 		{
 			// this is ok unless there are destroyer on the path
 			if (MoveValidator.enemyDestroyerOnPath(route, player, data))
@@ -452,16 +476,6 @@ public class MoveValidator
 				final Collection<Unit> transportsToLoad, final Map<Unit, Collection<Unit>> newDependents, final MoveValidationResult result)
 	{
 		final boolean isEditMode = getEditMode(data);
-		if (units.size() == 0)
-			return result.setErrorReturnResult("No units");
-		for (final Unit unit : units)
-		{
-			if (TripleAUnit.get(unit).getSubmerged())
-				result.addDisallowedUnit("Cannot move submerged units", unit);
-		}
-		// make sure all units are actually in the start territory
-		if (!route.getStart().getUnits().containsAll(units))
-			return result.setErrorReturnResult("Not enough units in starting territory");
 		// make sure transports in the destination
 		if (route.getEnd() != null && !route.getEnd().getUnits().containsAll(transportsToLoad) && !units.containsAll(transportsToLoad))
 			return result.setErrorReturnResult("Transports not found in route end");
@@ -627,11 +641,6 @@ public class MoveValidator
 		return result;
 	}
 	
-	private static boolean areNeutralsPassableByAir(final GameData data)
-	{
-		return (games.strategy.triplea.Properties.getNeutralFlyoverAllowed(data) && !isNeutralsImpassable(data));
-	}
-	
 	/**
 	 * Tests the given collection of units to see if they have the movement necessary
 	 * to move.
@@ -722,7 +731,7 @@ public class MoveValidator
 	 */
 	public static boolean noEnemyUnitsOnPathMiddleSteps(final Route route, final PlayerID player, final GameData data)
 	{
-		final CompositeMatch<Unit> alliedOrNonCombat = new CompositeMatchOr<Unit>(Matches.UnitIsFactoryOrIsInfrastructure, Matches.enemyUnit(player, data).invert(), Matches.unitIsSubmerged(data));
+		final CompositeMatch<Unit> alliedOrNonCombat = new CompositeMatchOr<Unit>(Matches.UnitIsInfrastructure, Matches.enemyUnit(player, data).invert(), Matches.unitIsSubmerged(data));
 		// Submerged units do not interfere with movement
 		for (final Territory current : route.getMiddleSteps())
 		{
@@ -738,10 +747,10 @@ public class MoveValidator
 	 */
 	public static boolean onlyIgnoredUnitsOnPath(final Route route, final PlayerID player, final GameData data, final boolean ignoreRouteEnd)
 	{
-		final CompositeMatch<Unit> subOnly = new CompositeMatchOr<Unit>(Matches.UnitIsFactoryOrIsInfrastructure, Matches.UnitIsSub, Matches.enemyUnit(player, data).invert());
-		final CompositeMatch<Unit> transportOnly = new CompositeMatchOr<Unit>(Matches.UnitIsFactoryOrIsInfrastructure, Matches.UnitIsTransportButNotCombatTransport, Matches.UnitIsLand,
+		final CompositeMatch<Unit> subOnly = new CompositeMatchOr<Unit>(Matches.UnitIsInfrastructure, Matches.UnitIsSub, Matches.enemyUnit(player, data).invert());
+		final CompositeMatch<Unit> transportOnly = new CompositeMatchOr<Unit>(Matches.UnitIsInfrastructure, Matches.UnitIsTransportButNotCombatTransport, Matches.UnitIsLand,
 					Matches.enemyUnit(player, data).invert());
-		final CompositeMatch<Unit> transportOrSubOnly = new CompositeMatchOr<Unit>(Matches.UnitIsFactoryOrIsInfrastructure, Matches.UnitIsTransportButNotCombatTransport, Matches.UnitIsLand,
+		final CompositeMatch<Unit> transportOrSubOnly = new CompositeMatchOr<Unit>(Matches.UnitIsInfrastructure, Matches.UnitIsTransportButNotCombatTransport, Matches.UnitIsLand,
 					Matches.UnitIsSub, Matches.enemyUnit(player, data).invert());
 		final boolean getIgnoreTransportInMovement = isIgnoreTransportInMovement(data);
 		final boolean getIgnoreSubInMovement = isIgnoreSubInMovement(data);
@@ -1007,54 +1016,6 @@ public class MoveValidator
 		return sum;
 	}
 	
-	private static boolean isWW2V2(final GameData data)
-	{
-		return games.strategy.triplea.Properties.getWW2V2(data);
-	}
-	
-	private static boolean isNeutralsImpassable(final GameData data)
-	{
-		return games.strategy.triplea.Properties.getNeutralsImpassable(data);
-	}
-	
-	private static boolean isNeutralsBlitzable(final GameData data)
-	{
-		return games.strategy.triplea.Properties.getNeutralsBlitzable(data) && !isNeutralsImpassable(data);
-	}
-	
-	private static boolean isWW2V3(final GameData data)
-	{
-		return games.strategy.triplea.Properties.getWW2V3(data);
-	}
-	
-	private static boolean isMultipleAAPerTerritory(final GameData data)
-	{
-		return games.strategy.triplea.Properties.getMultipleAAPerTerritory(data);
-	}
-	
-	/**
-	 * @return
-	 */
-	private static boolean isMovementByTerritoryRestricted(final GameData data)
-	{
-		return games.strategy.triplea.Properties.getMovementByTerritoryRestricted(data);
-	}
-	
-	private static boolean isParatroopersCanMoveDuringNonCombat(final GameData data)
-	{
-		return games.strategy.triplea.Properties.getParatroopersCanMoveDuringNonCombat(data);
-	}
-	
-	private static int getNeutralCharge(final GameData data, final Route route)
-	{
-		return getNeutralCharge(data, MoveDelegate.getEmptyNeutral(route).size());
-	}
-	
-	private static int getNeutralCharge(final GameData data, final int numberOfTerritories)
-	{
-		return numberOfTerritories * games.strategy.triplea.Properties.getNeutralCharge(data);
-	}
-	
 	// Determines whether we can pay the neutral territory charge for a
 	// given route for air units. We can't cross neutral territories
 	// in WW2V2.
@@ -1105,17 +1066,42 @@ public class MoveValidator
 			for (final Unit unit : transportTracker.getUnitsLoadedOnAlliedTransportsThisTurn(units))
 				result.addDisallowedUnit(CANNOT_LOAD_AND_UNLOAD_AN_ALLIED_TRANSPORT_IN_THE_SAME_ROUND, unit);
 			final Collection<Unit> transports = MoveDelegate.mapTransports(route, units, null).values();
+			final boolean isScramblingOrKamikazeAttacksEnabled = games.strategy.triplea.Properties.getScramble_Rules_In_Effect(data)
+						|| games.strategy.triplea.Properties.getUseKamikazeSuicideAttacks(data);
+			final boolean submarinesPreventUnescortedAmphibAssaults = games.strategy.triplea.Properties.getSubmarinesPreventUnescortedAmphibiousAssaults(data);
+			final Match<Unit> enemySubmarineMatch = new CompositeMatchAnd<Unit>(Matches.unitIsEnemyOf(data, player), Matches.UnitIsSub);
+			final Match<Unit> ownedSeaNonTransportMatch = new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(player), Matches.UnitIsSea, Matches.UnitIsNotTransportButCouldBeCombatTransport);
 			for (final Unit transport : transports)
 			{
-				// Unloading a transport from a sea zone with a battle, to a friendly land territory, during combat move phase, is illegal
-				// and in addition to being illegal, it is also causing problems if the sea transports get stuck (the land units are not dying)
-				// TODO: should we use the battle tracker for this instead?
-				if (!isNonCombat && route.numberOfStepsIncludingStart() == 2 && (
-							!(Matches.territoryHasEnemyUnits(player, data).match(routeEnd) || Matches.isTerritoryEnemyAndNotUnownedWater(player, data).match(routeEnd))
-							&& (Matches.territoryHasEnemyUnits(player, data).match(routeStart))))
+				if (!isNonCombat && route.numberOfStepsIncludingStart() == 2)
 				{
-					for (final Unit unit : transportTracker.transporting(transport))
-						result.addDisallowedUnit(TRANSPORT_MAY_NOT_UNLOAD_TO_FRIENDLY_TERRITORIES_UNTIL_AFTER_COMBAT_IS_RESOLVED, unit);
+					if (Matches.territoryHasEnemyUnits(player, data).match(routeEnd) || Matches.isTerritoryEnemyAndNotUnownedWater(player, data).match(routeEnd))
+					{
+						// this is an amphibious assault
+						if (submarinesPreventUnescortedAmphibAssaults && !Matches.territoryHasUnitsThatMatch(ownedSeaNonTransportMatch).match(routeStart) &&
+									Matches.territoryHasUnitsThatMatch(enemySubmarineMatch).match(routeStart))
+						{
+							// we must have at least one warship (non-transport) unit, otherwise the enemy sub stops our unloading for amphibious assault
+							for (final Unit unit : transportTracker.transporting(transport))
+							{
+								result.addDisallowedUnit(ENEMY_SUBMARINE_PREVENTING_UNESCORTED_AMPHIBIOUS_ASSAULT_LANDING, unit);
+							}
+						}
+					}
+					else if (!MoveDelegate.getBattleTracker(data).wasConquered(routeEnd))
+					{
+						// this is an unload to a friendly territory
+						if (isScramblingOrKamikazeAttacksEnabled || Matches.territoryHasEnemyUnits(player, data).match(routeStart))
+						{
+							// Unloading a transport from a sea zone with a battle, to a friendly land territory, during combat move phase, is illegal
+							// and in addition to being illegal, it is also causing problems if the sea transports get killed (the land units are not dying)
+							// TODO: should we use the battle tracker for this instead?
+							for (final Unit unit : transportTracker.transporting(transport))
+							{
+								result.addDisallowedUnit(TRANSPORT_MAY_NOT_UNLOAD_TO_FRIENDLY_TERRITORIES_UNTIL_AFTER_COMBAT_IS_RESOLVED, unit);
+							}
+						}
+					}
 				}
 				// TODO This is very sensitive to the order of the transport collection. The users may
 				// need to modify the order in which they perform their actions.
@@ -1194,8 +1180,13 @@ public class MoveValidator
 				return result.setErrorReturnResult("Units cannot move before loading onto transports");
 			final CompositeMatch<Unit> enemyNonSubmerged = new CompositeMatchAnd<Unit>(Matches.enemyUnit(player, data), new InverseMatch<Unit>(Matches.unitIsSubmerged(data)));
 			if (route.getEnd().getUnits().someMatch(enemyNonSubmerged) && nonParatroopersPresent(player, landAndAir, route))
+			{
 				if (!onlyIgnoredUnitsOnPath(route, player, data, false))
-					return result.setErrorReturnResult("Cannot load when enemy sea units are present");
+				{
+					if (!MoveDelegate.getBattleTracker(data).didAllThesePlayersJustGoToWarThisTurn(player, route.getEnd().getUnits().getUnits(), data))
+						return result.setErrorReturnResult("Cannot load when enemy sea units are present");
+				}
+			}
 			final Map<Unit, Unit> unitsToTransports = MoveDelegate.mapTransports(route, land, transportsToLoad);
 			final Iterator<Unit> iter = land.iterator();
 			// CompositeMatch<Unit> landUnitsAtSea = new CompositeMatchOr<Unit>(Matches.unitIsLandAndOwnedBy(player), Matches.UnitCanBeTransported);
@@ -1696,7 +1687,7 @@ public class MoveValidator
 		}
 		// we don't want to look at the dependents
 		final Collection<Unit> unitsWhichAreNotBeingTransportedOrDependent = new ArrayList<Unit>(Match.getMatches(units,
-					Matches.unitIsBeingTransportedByOrIsDependentOfSomeUnitInThisList(units, defaultRoute, player, data).invert()));
+					Matches.unitIsBeingTransportedByOrIsDependentOfSomeUnitInThisList(units, defaultRoute, player, data, true).invert()));
 		boolean mustGoLand = false;
 		boolean mustGoSea = false;
 		// If start and end are land, try a land route.
@@ -1762,57 +1753,86 @@ public class MoveValidator
 		return defaultRoute;
 	}
 	
-	/**
-	 * @return
-	 */
+	private static boolean areNeutralsPassableByAir(final GameData data)
+	{
+		return (games.strategy.triplea.Properties.getNeutralFlyoverAllowed(data) && !isNeutralsImpassable(data));
+	}
+	
+	private static boolean isWW2V2(final GameData data)
+	{
+		return games.strategy.triplea.Properties.getWW2V2(data);
+	}
+	
+	private static boolean isNeutralsImpassable(final GameData data)
+	{
+		return games.strategy.triplea.Properties.getNeutralsImpassable(data);
+	}
+	
+	private static boolean isNeutralsBlitzable(final GameData data)
+	{
+		return games.strategy.triplea.Properties.getNeutralsBlitzable(data) && !isNeutralsImpassable(data);
+	}
+	
+	private static boolean isWW2V3(final GameData data)
+	{
+		return games.strategy.triplea.Properties.getWW2V3(data);
+	}
+	
+	private static boolean isMultipleAAPerTerritory(final GameData data)
+	{
+		return games.strategy.triplea.Properties.getMultipleAAPerTerritory(data);
+	}
+	
+	private static int getNeutralCharge(final GameData data, final Route route)
+	{
+		return getNeutralCharge(data, MoveDelegate.getEmptyNeutral(route).size());
+	}
+	
+	private static boolean isMovementByTerritoryRestricted(final GameData data)
+	{
+		return games.strategy.triplea.Properties.getMovementByTerritoryRestricted(data);
+	}
+	
+	private static boolean isParatroopersCanMoveDuringNonCombat(final GameData data)
+	{
+		return games.strategy.triplea.Properties.getParatroopersCanMoveDuringNonCombat(data);
+	}
+	
+	private static int getNeutralCharge(final GameData data, final int numberOfTerritories)
+	{
+		return numberOfTerritories * games.strategy.triplea.Properties.getNeutralCharge(data);
+	}
+	
 	private static boolean isSubmersibleSubsAllowed(final GameData data)
 	{
 		return games.strategy.triplea.Properties.getSubmersible_Subs(data);
 	}
 	
-	/**
-	 * @return
-	 */
 	private static boolean isKamikazeAircraft(final GameData data)
 	{
 		return games.strategy.triplea.Properties.getKamikaze_Airplanes(data);
 	}
 	
-	/**
-	 * @return
-	 */
 	private static boolean isAlliedAirDependents(final GameData data)
 	{
 		return games.strategy.triplea.Properties.getAlliedAirDependents(data);
 	}
 	
-	/**
-	 * @return
-	 */
 	private static boolean isIgnoreTransportInMovement(final GameData data)
 	{
 		return games.strategy.triplea.Properties.getIgnoreTransportInMovement(data);
 	}
 	
-	/**
-	 * @return
-	 */
 	private static boolean isIgnoreSubInMovement(final GameData data)
 	{
 		return games.strategy.triplea.Properties.getIgnoreSubInMovement(data);
 	}
 	
-	/**
-	 * @return
-	 */
 	private static boolean isSubControlSeaZoneRestricted(final GameData data)
 	{
 		return games.strategy.triplea.Properties.getSubControlSeaZoneRestricted(data);
 	}
 	
-	/**
-	 * @return
-	 */
 	private static boolean isTransportControlSeaZone(final GameData data)
 	{
 		return games.strategy.triplea.Properties.getTransportControlSeaZone(data);
