@@ -26,6 +26,9 @@ import games.strategy.engine.data.RelationshipType;
 import games.strategy.engine.data.Resource;
 import games.strategy.engine.data.Territory;
 import games.strategy.engine.delegate.IDelegateBridge;
+import games.strategy.engine.random.IRandomStats.DiceType;
+import games.strategy.sound.ClipPlayer;
+import games.strategy.sound.SoundPath;
 import games.strategy.triplea.Constants;
 import games.strategy.triplea.attatchments.ICondition;
 import games.strategy.triplea.attatchments.PoliticalActionAttachment;
@@ -317,6 +320,11 @@ public class PoliticsDelegate extends BaseDelegate implements IPoliticsDelegate
 			final Change charge = ChangeFactory.changeResourcesChange(m_bridge.getPlayerID(), PUs, -cost);
 			m_bridge.addChange(charge);
 		}
+		else
+		{
+			final String transcriptText = m_bridge.getPlayerID().getName() + " takes Political Action: " + MyFormatter.attachmentNameToText(paa.getName());
+			m_bridge.getHistoryWriter().startEvent(transcriptText); // we must start an event anyway
+		}
 	}
 	
 	/**
@@ -341,7 +349,7 @@ public class PoliticsDelegate extends BaseDelegate implements IPoliticsDelegate
 	private void notifyFailure(final PoliticalActionAttachment paa)
 	{
 		final String transcriptText = m_bridge.getPlayerID().getName() + " fails on action: " + MyFormatter.attachmentNameToText(paa.getName());
-		m_bridge.getHistoryWriter().startEvent(transcriptText);
+		m_bridge.getHistoryWriter().addChildToEvent(transcriptText);
 		sendNotification(m_player, PoliticsText.getInstance().getNotificationFailure(paa.getText()));
 		notifyOtherPlayers(paa, PoliticsText.getInstance().getNotificationFailureOthers(paa.getText()));
 	}
@@ -354,6 +362,8 @@ public class PoliticsDelegate extends BaseDelegate implements IPoliticsDelegate
 	 */
 	private void notifySuccess(final PoliticalActionAttachment paa)
 	{
+		// play a sound
+		ClipPlayer.play(SoundPath.CLIP_POLITICAL_ACTION_SUCCESSFUL);
 		sendNotification(m_player, PoliticsText.getInstance().getNotificationSucccess(paa.getText()));
 		notifyOtherPlayers(paa, PoliticsText.getInstance().getNotificationSuccessOthers(paa.getText()));
 	}
@@ -407,9 +417,10 @@ public class PoliticsDelegate extends BaseDelegate implements IPoliticsDelegate
 			if (oldRelation.equals(newRelation))
 				continue;
 			change.add(ChangeFactory.relationshipChange(player1, player2, oldRelation, newRelation));
-			m_bridge.getHistoryWriter().startEvent(
+			m_bridge.getHistoryWriter().addChildToEvent(
 						m_bridge.getPlayerID().getName() + " succeeds on action: " + MyFormatter.attachmentNameToText(paa.getName()) + ": Changing Relationship for " + player1.getName() + " and "
 									+ player2.getName() + " from " + oldRelation.getName() + " to " + newRelation.getName());
+			MoveDelegate.getBattleTracker(getData()).addRelationshipChangesThisTurn(player1, player2, oldRelation, newRelation);
 			/* creation of new battles is handled at the beginning of the battle delegate, in "setupUnitsInSameTerritoryBattles", not here.
 			if (Matches.RelationshipTypeIsAtWar.match(newRelation))
 				TriggerAttachment.triggerMustFightBattle(player1, player2, m_bridge);*/
@@ -428,11 +439,11 @@ public class PoliticsDelegate extends BaseDelegate implements IPoliticsDelegate
 	{
 		if (paa.diceSides() == paa.toHit())
 			return true;
-		final int rollResult = m_bridge.getRandom(paa.diceSides(), "Attempting the PoliticalAction: " + MyFormatter.attachmentNameToText(paa.getName())) + 1;
+		final int rollResult = m_bridge.getRandom(paa.diceSides(), m_player, DiceType.NONCOMBAT, "Attempting the PoliticalAction: " + MyFormatter.attachmentNameToText(paa.getName())) + 1;
 		final boolean success = rollResult <= paa.toHit();
 		final String notificationMessage = "rolling (" + paa.toHit() + " out of " + paa.diceSides() + ") result: " + rollResult + " = " + (success ? "Success!" : "Failure!");
 		sendNotification(m_player, notificationMessage);
-		m_bridge.getHistoryWriter().startEvent(MyFormatter.attachmentNameToText(paa.getName()) + " : " + notificationMessage);
+		m_bridge.getHistoryWriter().addChildToEvent(MyFormatter.attachmentNameToText(paa.getName()) + " : " + notificationMessage);
 		return success;
 	}
 	
@@ -478,7 +489,8 @@ public class PoliticsDelegate extends BaseDelegate implements IPoliticsDelegate
 					if (!currentOther.equals(newType))
 					{
 						change.add(ChangeFactory.relationshipChange(p3, player, currentOther, newType));
-						aBridge.getHistoryWriter().startEvent(player.getName() + " and " + p3.getName() + " sign a " + newType.getName() + " treaty");
+						aBridge.getHistoryWriter().addChildToEvent(player.getName() + " and " + p3.getName() + " sign a " + newType.getName() + " treaty");
+						MoveDelegate.getBattleTracker(data).addRelationshipChangesThisTurn(p3, player, currentOther, newType);
 					}
 				}
 			}
@@ -522,7 +534,8 @@ public class PoliticsDelegate extends BaseDelegate implements IPoliticsDelegate
 						if (!currentOther.equals(newType) && Matches.RelationshipTypeIsAtWar.match(currentOther))
 						{
 							change.add(ChangeFactory.relationshipChange(p3, p4, currentOther, newType));
-							aBridge.getHistoryWriter().startEvent(p3.getName() + " and " + p4.getName() + " sign a " + newType.getName() + " treaty");
+							aBridge.getHistoryWriter().addChildToEvent(p3.getName() + " and " + p4.getName() + " sign a " + newType.getName() + " treaty");
+							MoveDelegate.getBattleTracker(data).addRelationshipChangesThisTurn(p3, p4, currentOther, newType);
 						}
 					}
 				}
@@ -565,8 +578,10 @@ public class PoliticsDelegate extends BaseDelegate implements IPoliticsDelegate
 			{
 				if (!data.getRelationshipTracker().getRelationshipType(p1, p3).equals(alliedType))
 				{
-					aBridge.addChange(ChangeFactory.relationshipChange(p1, p3, data.getRelationshipTracker().getRelationshipType(p1, p3), alliedType));
-					aBridge.getHistoryWriter().startEvent(p1.getName() + " and " + p3.getName() + " are joined together in an " + alliedType.getName() + " treaty");
+					final RelationshipType current = data.getRelationshipTracker().getRelationshipType(p1, p3);
+					aBridge.addChange(ChangeFactory.relationshipChange(p1, p3, current, alliedType));
+					aBridge.getHistoryWriter().addChildToEvent(p1.getName() + " and " + p3.getName() + " are joined together in an " + alliedType.getName() + " treaty");
+					MoveDelegate.getBattleTracker(data).addRelationshipChangesThisTurn(p1, p3, current, alliedType);
 				}
 			}
 		}
@@ -588,8 +603,10 @@ public class PoliticsDelegate extends BaseDelegate implements IPoliticsDelegate
 			{
 				if (!data.getRelationshipTracker().getRelationshipType(p1, p3).equals(warType))
 				{
-					aBridge.addChange(ChangeFactory.relationshipChange(p1, p3, data.getRelationshipTracker().getRelationshipType(p1, p3), warType));
-					aBridge.getHistoryWriter().startEvent(p1.getName() + " and " + p3.getName() + " declare " + warType.getName() + " on each other");
+					final RelationshipType current = data.getRelationshipTracker().getRelationshipType(p1, p3);
+					aBridge.addChange(ChangeFactory.relationshipChange(p1, p3, current, warType));
+					aBridge.getHistoryWriter().addChildToEvent(p1.getName() + " and " + p3.getName() + " declare " + warType.getName() + " on each other");
+					MoveDelegate.getBattleTracker(data).addRelationshipChangesThisTurn(p1, p3, current, warType);
 				}
 			}
 		}
@@ -631,9 +648,9 @@ public class PoliticsDelegate extends BaseDelegate implements IPoliticsDelegate
 }
 
 
-@SuppressWarnings("serial")
 class PoliticsExtendedDelegateState implements Serializable
 {
+	private static final long serialVersionUID = -3829812751864156598L;
 	Serializable superState;
 	// add other variables here:
 	// public HashMap<ICondition, Boolean> m_testedConditions = null;
