@@ -36,7 +36,7 @@ import games.strategy.engine.message.IRemote;
 import games.strategy.triplea.Constants;
 import games.strategy.triplea.TripleAUnit;
 import games.strategy.triplea.attatchments.ICondition;
-import games.strategy.triplea.attatchments.TechAttachment;
+import games.strategy.triplea.attatchments.TechAbilityAttachment;
 import games.strategy.triplea.attatchments.TerritoryAttachment;
 import games.strategy.triplea.attatchments.TriggerAttachment;
 import games.strategy.triplea.attatchments.UnitAttachment;
@@ -48,6 +48,7 @@ import games.strategy.util.CompositeMatchAnd;
 import games.strategy.util.CompositeMatchOr;
 import games.strategy.util.IntegerMap;
 import games.strategy.util.Match;
+import games.strategy.util.Util;
 
 import java.io.Serializable;
 import java.util.ArrayList;
@@ -264,62 +265,70 @@ public class PurchaseDelegate extends BaseDelegate implements IPurchaseDelegate
 		}
 		// Get the map of the factories that were repaired and how much for each
 		final Map<Unit, Integer> repairMap = getTerritoryRepairs(repairRules);
-		if (!repairMap.isEmpty())
+		if (repairMap.isEmpty())
+			return null;
+		
+		final boolean SBRaffectsUnitProduction = games.strategy.triplea.Properties.getSBRAffectsUnitProduction(getData());
+		final boolean damageFromBombingDoneToUnitsInsteadOfTerritories = games.strategy.triplea.Properties.getDamageFromBombingDoneToUnitsInsteadOfTerritories(getData());
+		final Collection<Unit> repairUnits = new ArrayList<Unit>(repairMap.keySet());
+		for (final Unit u : repairUnits)
 		{
-			final Collection<Unit> repairUnits = repairMap.keySet();
-			for (final Unit u : repairUnits)
+			if (SBRaffectsUnitProduction)
 			{
-				if (games.strategy.triplea.Properties.getSBRAffectsUnitProduction(getData()))
+				final int repairCount = repairMap.get(u);
+				// Display appropriate damaged/repaired factory and factory damage totals
+				if (repairCount > 0)
 				{
-					final int repairCount = repairMap.get(u);
-					// Display appropriate damaged/repaired factory and factory damage totals
-					if (repairCount > 0)
+					final Territory terr = u.getTerritoryUnitIsIn();
+					final TerritoryAttachment ta = TerritoryAttachment.get(terr);
+					final int currentDamage = ta.getUnitProduction();
+					final IntegerMap<Unit> hits = new IntegerMap<Unit>();
+					final int newDamageTotal = ta.getProduction() - (currentDamage + repairCount);
+					if (newDamageTotal < 0)
 					{
-						final Territory terr = u.getTerritoryUnitIsIn();
-						final TerritoryAttachment ta = TerritoryAttachment.get(terr);
-						final int currentDamage = ta.getUnitProduction();
-						final IntegerMap<Unit> hits = new IntegerMap<Unit>();
-						final int newDamageTotal = ta.getProduction() - (currentDamage + repairCount);
-						if (newDamageTotal < 0)
-						{
-							return "You cannot repair more than a territory has been hit";
-						}
-						hits.put(u, newDamageTotal);
-						changes.add(ChangeFactory.unitsHit(hits));
-						changes.add(ChangeFactory.attachmentPropertyChange(ta, Integer.toString(currentDamage + repairCount), "unitProduction"));
+						return "You cannot repair more than a territory has been hit";
 					}
+					hits.put(u, newDamageTotal);
+					changes.add(ChangeFactory.unitsHit(hits));
+					changes.add(ChangeFactory.attachmentPropertyChange(ta, Integer.toString(currentDamage + repairCount), "unitProduction"));
 				}
-				else
-				// if (games.strategy.triplea.Properties.getDamageFromBombingDoneToUnitsInsteadOfTerritories(m_data))
+			}
+			else
+			// if (damageFromBombingDoneToUnitsInsteadOfTerritories)
+			{
+				final int repairCount = repairMap.get(u);
+				// Display appropriate damaged/repaired factory and factory damage totals
+				if (repairCount > 0)
 				{
-					final int repairCount = repairMap.get(u);
-					// Display appropriate damaged/repaired factory and factory damage totals
-					if (repairCount > 0)
+					final IntegerMap<Unit> hits = new IntegerMap<Unit>();
+					final TripleAUnit taUnit = (TripleAUnit) u;
+					final int newDamageTotal = taUnit.getUnitDamage() - repairCount;
+					if (newDamageTotal < 0)
 					{
-						final IntegerMap<Unit> hits = new IntegerMap<Unit>();
-						final TripleAUnit taUnit = (TripleAUnit) u;
-						final int newDamageTotal = taUnit.getUnitDamage() - repairCount;
-						if (newDamageTotal < 0)
-						{
-							return "You cannot repair more than a unit has been hit";
-						}
-						hits.put(u, newDamageTotal);
-						changes.add(ChangeFactory.unitsHit(hits));
-						changes.add(ChangeFactory.unitPropertyChange(u, newDamageTotal, TripleAUnit.UNIT_DAMAGE));
+						return "You cannot repair more than a unit has been hit";
 					}
+					hits.put(u, newDamageTotal);
+					changes.add(ChangeFactory.unitsHit(hits));
+					changes.add(ChangeFactory.unitPropertyChange(u, newDamageTotal, TripleAUnit.UNIT_DAMAGE));
 				}
 			}
 		}
-		else
-		{
-			return null;
-			// return "m_repairCount is empty";
-		}
+		
 		// add changes for spent resources
 		final String remaining = removeFromPlayer(m_player, costs, changes, totalUnits);
 		addHistoryEvent(totalUnits, remaining, true);
 		// commit changes
 		m_bridge.addChange(changes);
+		if (damageFromBombingDoneToUnitsInsteadOfTerritories)
+		{
+			for (final Territory element : getData().getMap().getTerritories())
+			{
+				if (Util.someIntersect(element.getUnits().getUnits(), repairUnits))
+				{
+					element.notifyChanged();
+				}
+			}
+		}
 		return null;
 	}
 	
@@ -370,8 +379,7 @@ public class PurchaseDelegate extends BaseDelegate implements IPurchaseDelegate
 			else
 				transcriptText = m_player.getName() + " buy nothing; " + remainingText;
 		}
-		m_bridge.getHistoryWriter().startEvent(transcriptText);
-		m_bridge.getHistoryWriter().setRenderingData(totalUnits);
+		m_bridge.getHistoryWriter().startEvent(transcriptText, totalUnits);
 	}
 	
 	private IntegerMap<Resource> getCosts(final IntegerMap<ProductionRule> productionRules, final PlayerID player)
@@ -401,13 +409,9 @@ public class PurchaseDelegate extends BaseDelegate implements IPurchaseDelegate
 				costs.addMultiple(rule.getCosts(), repairRules.get(u).getInt(rule));
 			}
 		}
-		if (isIncreasedFactoryProduction(player))
-		{
-			// UnitCategory unitCategory = categorized.iterator().next();
-			// if(unitCategory.getType().getName().endsWith("_hit"))
-			// cost = (int) (Math.round(quantity/2));
-			costs.multiplyAllValuesBy((float) 0.5, 3);
-		}
+		final float discount = TechAbilityAttachment.getRepairDiscount(player, getData());
+		if (discount != 1.0F)
+			costs.multiplyAllValuesBy(discount, 3);
 		return costs;
 	}
 	
@@ -478,14 +482,16 @@ public class PurchaseDelegate extends BaseDelegate implements IPurchaseDelegate
 		if (!m_player.isAI())
 			return;
 		final int currentPUs = m_player.getResources().getQuantity(Constants.PUS);
-		if (currentPUs == 0)
+		if (currentPUs <= 0)
 			return;
+		int toGive = 0;
 		final int bonusPercent = games.strategy.triplea.Properties.getAIBonusIncomePercentage(getData());
-		if (bonusPercent == 0)
-			return;
-		int toGive = (int) Math.round(((double) currentPUs * (double) bonusPercent / 100));
-		if (toGive == 0 && bonusPercent > 0 && currentPUs > 0)
-			toGive = 1;
+		if (bonusPercent != 0)
+		{
+			toGive += (int) Math.round(((double) currentPUs * (double) bonusPercent / 100));
+			if (toGive == 0 && bonusPercent > 0 && currentPUs > 0)
+				toGive += 1;
+		}
 		toGive += games.strategy.triplea.Properties.getAIBonusIncomeFlatRate(getData());
 		if (toGive + currentPUs < 0)
 			toGive = currentPUs * -1;
@@ -494,20 +500,12 @@ public class PurchaseDelegate extends BaseDelegate implements IPurchaseDelegate
 		m_bridge.getHistoryWriter().startEvent("Giving AI player bonus income modifier of " + toGive + MyFormatter.pluralize(" PU", toGive));
 		m_bridge.addChange(ChangeFactory.changeResourcesChange(m_player, getData().getResourceList().getResource(Constants.PUS), toGive));
 	}
-	
-	private boolean isIncreasedFactoryProduction(final PlayerID player)
-	{
-		final TechAttachment ta = (TechAttachment) player.getAttachment(Constants.TECH_ATTACHMENT_NAME);
-		if (ta == null)
-			return false;
-		return ta.getIncreasedFactoryProduction();
-	}
 }
 
 
-@SuppressWarnings("serial")
 class PurchaseExtendedDelegateState implements Serializable
 {
+	private static final long serialVersionUID = 2326864364534284490L;
 	Serializable superState;
 	// add other variables here:
 	public boolean m_needToInitialize;
