@@ -20,10 +20,15 @@ import games.strategy.engine.data.Resource;
 import games.strategy.engine.data.Route;
 import games.strategy.engine.data.Territory;
 import games.strategy.engine.data.Unit;
+import games.strategy.engine.data.UnitType;
 import games.strategy.engine.delegate.IDelegateBridge;
+import games.strategy.engine.random.IRandomStats.DiceType;
+import games.strategy.sound.ClipPlayer;
+import games.strategy.sound.SoundPath;
 import games.strategy.triplea.Constants;
 import games.strategy.triplea.Properties;
 import games.strategy.triplea.TripleAUnit;
+import games.strategy.triplea.attatchments.TechAbilityAttachment;
 import games.strategy.triplea.attatchments.TerritoryAttachment;
 import games.strategy.triplea.attatchments.UnitAttachment;
 import games.strategy.triplea.formatter.MyFormatter;
@@ -55,13 +60,11 @@ public class RocketsFireHelper
 		return games.strategy.triplea.Properties.getAllRocketsAttack(data);
 	}
 	
-	/*private boolean isRocketsCanFlyOverImpassables(GameData data)
+	private boolean isRocketsCanFlyOverImpassables(final GameData data)
 	{
-	    return games.strategy.triplea.Properties.getRocketsCanFlyOverImpassables(data);
-	}*/
-	/**
-	 * @return
-	 */
+		return games.strategy.triplea.Properties.getRocketsCanFlyOverImpassables(data);
+	}
+	
 	private boolean isSBRAffectsUnitProduction(final GameData data)
 	{
 		return games.strategy.triplea.Properties.getSBRAffectsUnitProduction(data);
@@ -89,7 +92,7 @@ public class RocketsFireHelper
 	
 	private boolean isLimitRocketDamageToProduction(final GameData data)
 	{
-		return games.strategy.triplea.Properties.getLimitRocketDamageToProduction(data);
+		return games.strategy.triplea.Properties.getLimitRocketAndSBRDamageToProduction(data);
 	}
 	
 	public RocketsFireHelper()
@@ -105,8 +108,7 @@ public class RocketsFireHelper
 			getRemote(bridge).reportMessage("No rockets to fire", "No rockets to fire");
 			return;
 		}
-		// TODO this is weird! Check the parens
-		if ((isWW2V2(data) || isAllRocketsAttack(data)) || isOneRocketAttackPerFactory(data))
+		if (isWW2V2(data) || isAllRocketsAttack(data))
 			fireWW2V2(bridge, player, rocketTerritories);
 		else
 			fireWW2V1(bridge, player, rocketTerritories);
@@ -116,16 +118,19 @@ public class RocketsFireHelper
 	{
 		final GameData data = bridge.getData();
 		final Set<Territory> attackedTerritories = new HashSet<Territory>();
+		final boolean oneAttackPerTerritory = isOneRocketAttackPerFactory(data);
 		for (final Territory territory : rocketTerritories)
 		{
 			final Set<Territory> targets = getTargetsWithinRange(territory, data, player);
-			targets.removeAll(attackedTerritories);
+			if (oneAttackPerTerritory)
+				targets.removeAll(attackedTerritories);
 			if (targets.isEmpty())
 				continue;
 			final Territory target = getTarget(targets, player, bridge, territory);
 			if (target != null)
 			{
-				attackedTerritories.add(target);
+				if (oneAttackPerTerritory)
+					attackedTerritories.add(target);
 				fireRocket(player, target, bridge, territory);
 			}
 		}
@@ -152,14 +157,12 @@ public class RocketsFireHelper
 	Set<Territory> getTerritoriesWithRockets(final GameData data, final PlayerID player)
 	{
 		final Set<Territory> territories = new HashSet<Territory>();
-		final CompositeMatch<Unit> ownedRockets = new CompositeMatchAnd<Unit>();
-		ownedRockets.add(Matches.UnitIsRocket);
-		ownedRockets.add(Matches.unitIsOwnedBy(player));
+		final CompositeMatch<Unit> ownedRockets = rocketMatch(player, data);
 		final BattleTracker tracker = MoveDelegate.getBattleTracker(data);
 		for (final Territory current : data.getMap())
 		{
-			if (current.isWater())
-				continue;
+			// if (current.isWater())
+			// continue;
 			if (tracker.wasConquered(current))
 				continue;
 			if (current.getUnits().someMatch(ownedRockets))
@@ -168,17 +171,24 @@ public class RocketsFireHelper
 		return territories;
 	}
 	
+	CompositeMatch<Unit> rocketMatch(final PlayerID player, final GameData data)
+	{
+		return new CompositeMatchAnd<Unit>(Matches.UnitIsRocket, Matches.unitIsOwnedBy(player), Matches.UnitIsDisabled().invert(),
+					Matches.unitIsBeingTransported().invert(), Matches.unitIsSubmerged(data).invert(), Matches.unitHasNotMoved);
+	}
+	
 	private Set<Territory> getTargetsWithinRange(final Territory territory, final GameData data, final PlayerID player)
 	{
-		final Collection<Territory> possible = data.getMap().getNeighbors(territory, 3);
+		final int maxDistance = TechAbilityAttachment.getRocketDistance(player, data);
+		final Collection<Territory> possible = data.getMap().getNeighbors(territory, maxDistance);
 		final Set<Territory> hasFactory = new HashSet<Territory>();
-		// boolean rocketsOverImpassables = isRocketsCanFlyOverImpassables(data);
-		final Match<Territory> impassable = Matches.TerritoryIsNotImpassable;
+		final CompositeMatchAnd<Territory> allowed = new CompositeMatchAnd<Territory>(Matches.territoryAllowsRocketsCanFlyOver(player, data));
+		if (isRocketsCanFlyOverImpassables(data))
+			allowed.add(Matches.TerritoryIsNotImpassable);
 		for (final Territory current : possible)
 		{
-			final Route route = data.getMap().getRoute(territory, current, impassable);
-			// TODO EW: this assumes range 3 territories for Rockets, doesn't take movementCost into account. //TODO veq: make new unit attachment for rocket range, defaults to 3 movement cost.
-			if (route != null && route.numberOfSteps() <= 3)
+			final Route route = data.getMap().getRoute(territory, current, allowed);
+			if (route != null && route.numberOfSteps() <= maxDistance)
 			{
 				if (current.getUnits().someMatch(new CompositeMatchAnd<Unit>(Matches.enemyUnit(player, data), Matches.UnitIsAtMaxDamageOrNotCanBeDamaged(current).invert())))
 					hasFactory.add(current);
@@ -189,8 +199,7 @@ public class RocketsFireHelper
 	
 	private Territory getTarget(final Collection<Territory> targets, final PlayerID player, final IDelegateBridge bridge, final Territory from)
 	{
-		// ask even if there is only once choice
-		// that will allow the user to not attack if he doesnt want to
+		// ask even if there is only once choice, that will allow the user to not attack if he doesn't want to
 		return ((ITripleaPlayer) bridge.getRemote()).whereShouldRocketsAttack(targets, from);
 	}
 	
@@ -199,64 +208,173 @@ public class RocketsFireHelper
 		final GameData data = bridge.getData();
 		final PlayerID attacked = attackedTerritory.getOwner();
 		final Resource PUs = data.getResourceList().getResource(Constants.PUS);
-		// int cost = bridge.getRandom(Constants.MAX_DICE);
 		final boolean SBRAffectsUnitProd = isSBRAffectsUnitProduction(data);
 		final boolean DamageFromBombingDoneToUnits = isDamageFromBombingDoneToUnitsInsteadOfTerritories(data);
 		// unit damage vs territory damage
 		final Collection<Unit> enemyUnits = attackedTerritory.getUnits().getMatches(Matches.enemyUnit(player, data));
-		final Collection<Unit> enemyTargets = Match.getMatches(enemyUnits, Matches.UnitIsAtMaxDamageOrNotCanBeDamaged(attackedTerritory).invert());
+		final Collection<Unit> enemyTargetsTotal = Match.getMatches(enemyUnits, Matches.UnitIsAtMaxDamageOrNotCanBeDamaged(attackedTerritory).invert());
 		final Collection<Unit> targets = new ArrayList<Unit>();
+		final Collection<Unit> rockets;
+		// attackFrom could be null if WW2V1
+		if (attackFrom == null)
+			rockets = null;
+		else
+			rockets = new ArrayList<Unit>(Match.getMatches(attackFrom.getUnits().getUnits(), rocketMatch(player, data)));
+		final int numberOfAttacks = (rockets == null ? 1 : Math.min(TechAbilityAttachment.getRocketNumberPerTerritory(player, data), TechAbilityAttachment.getRocketDiceNumber(rockets, data)));
+		if (numberOfAttacks <= 0)
+			return;
+		final String transcript;
 		if (!SBRAffectsUnitProd && DamageFromBombingDoneToUnits)
 		{
-			Unit target;
+			// TODO: rockets needs to be completely redone to allow for multiple rockets to fire at different targets, etc etc.
+			final HashSet<UnitType> legalTargetsForTheseRockets = new HashSet<UnitType>();
+			if (rockets == null)
+				legalTargetsForTheseRockets.addAll(data.getUnitTypeList().getAllUnitTypes());
+			else
+			{
+				// a hack for now, we let the rockets fire at anyone who could be targetted by any rocket
+				for (final Unit r : rockets)
+				{
+					legalTargetsForTheseRockets.addAll(UnitAttachment.get(r.getType()).getBombingTargets(data));
+				}
+			}
+			final Collection<Unit> enemyTargets = Match.getMatches(enemyTargetsTotal, Matches.unitIsOfTypes(legalTargetsForTheseRockets));
+			if (enemyTargets.isEmpty())
+				return; // TODO: this sucks
+			Unit target = null;
 			if (enemyTargets.size() == 1)
 				target = enemyTargets.iterator().next();
 			else
 			{
-				final ITripleaPlayer iplayer = (ITripleaPlayer) bridge.getRemote(player);
-				target = iplayer.whatShouldBomberBomb(attackedTerritory, enemyTargets);
+				while (target == null)
+				{
+					final ITripleaPlayer iplayer = (ITripleaPlayer) bridge.getRemote(player);
+					target = iplayer.whatShouldBomberBomb(attackedTerritory, enemyTargets, rockets);
+				}
 			}
 			if (target == null)
 				throw new IllegalStateException("No Targets in " + attackedTerritory.getName());
 			targets.add(target);
 		}
+		final boolean doNotUseBombingBonus = !games.strategy.triplea.Properties.getUseBombingMaxDiceSidesAndBonus(data) || rockets == null;
 		int cost = 0;
 		if (!games.strategy.triplea.Properties.getLL_DAMAGE_ONLY(data))
-			cost = bridge.getRandom(data.getDiceSides(), "Rocket fired by " + player.getName() + " at " + attacked.getName());
-		else
 		{
-			final CompositeMatch<Unit> ownedRockets = new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(player), Matches.UnitIsRocket);
-			final Collection<Unit> rockets = new ArrayList<Unit>(Match.getMatches(attackFrom.getUnits().getUnits(), ownedRockets));
-			int highestMaxDice = 0;
-			int highestBonus = 0;
-			final int diceSides = data.getDiceSides();
-			for (final Unit u : rockets)
+			if (doNotUseBombingBonus)
 			{
-				final UnitAttachment ua = UnitAttachment.get(u.getType());
-				int maxDice = ua.getBombingMaxDieSides();
-				int bonus = ua.getBombingBonus();
-				if (maxDice < 0 && bonus < 0 && diceSides >= 5)
+				// no low luck, and no bonus, so just roll based on the map's dice sides
+				final int[] rolls = bridge.getRandom(data.getDiceSides(), numberOfAttacks, player, DiceType.BOMBING, "Rocket fired by " + player.getName() + " at " + attacked.getName());
+				for (final int r : rolls)
 				{
-					maxDice = (diceSides + 1) / 3;
-					bonus = (diceSides + 1) / 3;
+					cost += r + 1; // we are zero based
 				}
-				if (bonus < 0)
-					bonus = 0;
-				if (maxDice < 0)
-					maxDice = diceSides;
-				if ((bonus + (maxDice + 1) / 2) > (highestBonus + (highestMaxDice + 1) / 2))
+				transcript = "Rockets " + (attackFrom == null ? "" : "in " + attackFrom.getName()) + " roll: " + MyFormatter.asDice(rolls);
+			}
+			else
+			{
+				// we must use bombing bonus
+				int highestMaxDice = 0;
+				int highestBonus = 0;
+				final int diceSides = data.getDiceSides();
+				for (final Unit u : rockets)
 				{
-					highestMaxDice = maxDice;
-					highestBonus = bonus;
+					final UnitAttachment ua = UnitAttachment.get(u.getType());
+					int maxDice = ua.getBombingMaxDieSides();
+					int bonus = ua.getBombingBonus();
+					// both could be -1, meaning they were not set. if they were not set, then we use default dice sides for the map, and zero for the bonus.
+					if (maxDice < 0)
+						maxDice = diceSides;
+					if (bonus < 0)
+						bonus = 0;
+					// we only roll once for rockets, so if there are other rockets here we just roll for the best rocket
+					if ((bonus + ((maxDice + 1) / 2)) > (highestBonus + ((highestMaxDice + 1) / 2)))
+					{
+						highestMaxDice = maxDice;
+						highestBonus = bonus;
+					}
+				}
+				// now we roll, or don't if there is nothing to roll.
+				if (highestMaxDice > 0)
+				{
+					final int[] rolls = bridge.getRandom(highestMaxDice, numberOfAttacks, player, DiceType.BOMBING, "Rocket fired by " + player.getName() + " at " + attacked.getName());
+					for (int i = 0; i < rolls.length; i++)
+					{
+						final int r = rolls[i] + highestBonus;
+						rolls[i] = r;
+						cost += r + 1; // we are zero based
+					}
+					transcript = "Rockets " + (attackFrom == null ? "" : "in " + attackFrom.getName()) + " roll: " + MyFormatter.asDice(rolls);
+				}
+				else
+				{
+					cost = highestBonus * numberOfAttacks;
+					transcript = "Rockets " + (attackFrom == null ? "" : "in " + attackFrom.getName()) + " do " + highestBonus + " damage for each rocket";
+				}
+			}
+		}
+		else
+		{
+			if (doNotUseBombingBonus)
+			{
+				// no bonus, so just roll based on the map's dice sides, but modify for LL
+				final int maxDice = (data.getDiceSides() + 1) / 3;
+				final int bonus = (data.getDiceSides() + 1) / 3;
+				final int[] rolls = bridge.getRandom(maxDice, numberOfAttacks, player, DiceType.BOMBING, "Rocket fired by " + player.getName() + " at " + attacked.getName());
+				for (int i = 0; i < rolls.length; i++)
+				{
+					final int r = rolls[i] + bonus;
+					rolls[i] = r;
+					cost += r + 1; // we are zero based
+				}
+				transcript = "Rockets " + (attackFrom == null ? "" : "in " + attackFrom.getName()) + " roll: " + MyFormatter.asDice(rolls);
+			}
+			else
+			{
+				int highestMaxDice = 0;
+				int highestBonus = 0;
+				final int diceSides = data.getDiceSides();
+				for (final Unit u : rockets)
+				{
+					final UnitAttachment ua = UnitAttachment.get(u.getType());
+					int maxDice = ua.getBombingMaxDieSides();
+					int bonus = ua.getBombingBonus();
+					// both could be -1, meaning they were not set. if they were not set, then we use default dice sides for the map, and zero for the bonus.
+					if (maxDice < 0 || doNotUseBombingBonus)
+						maxDice = diceSides;
+					if (bonus < 0 || doNotUseBombingBonus)
+						bonus = 0;
+					// now, regardless of whether they were set or not, we have to apply "low luck" to them, meaning in this case that we reduce the luck by 2/3.
+					if (maxDice >= 5)
+					{
+						bonus += (maxDice + 1) / 3;
+						maxDice = (maxDice + 1) / 3;
+					}
+					// we only roll once for rockets, so if there are other rockets here we just roll for the best rocket
+					if ((bonus + ((maxDice + 1) / 2)) > (highestBonus + ((highestMaxDice + 1) / 2)))
+					{
+						highestMaxDice = maxDice;
+						highestBonus = bonus;
+					}
+				}
+				// now we roll, or don't if there is nothing to roll.
+				if (highestMaxDice > 0)
+				{
+					final int[] rolls = bridge.getRandom(highestMaxDice, numberOfAttacks, player, DiceType.BOMBING, "Rocket fired by " + player.getName() + " at " + attacked.getName());
+					for (int i = 0; i < rolls.length; i++)
+					{
+						final int r = rolls[i] + highestBonus;
+						rolls[i] = r;
+						cost += r + 1; // we are zero based
+					}
+					transcript = "Rockets " + (attackFrom == null ? "" : "in " + attackFrom.getName()) + " roll: " + MyFormatter.asDice(rolls);
+				}
+				else
+				{
+					cost = highestBonus * numberOfAttacks;
+					transcript = "Rockets " + (attackFrom == null ? "" : "in " + attackFrom.getName()) + " do " + highestBonus + " damage for each rocket";
 				}
 			}
-			if (highestMaxDice > 0)
-				cost = bridge.getRandom(highestMaxDice, "Rocket fired by " + player.getName() + " at " + attacked.getName()) + highestBonus;
-			else
-				cost = highestBonus;
 		}
-		// account for 0 base
-		cost++;
 		final TerritoryAttachment ta = TerritoryAttachment.get(attackedTerritory);
 		int territoryProduction = ta.getProduction();
 		int unitProduction = 0;
@@ -271,7 +389,7 @@ public class RocketsFireHelper
 			cost = Math.min(cost, limit);
 			// Record production lost
 			// DelegateFinder.moveDelegate(data).PUsLost(attackedTerritory, cost);
-			final Collection<Unit> damagedFactory = Match.getMatches(attackedTerritory.getUnits().getUnits(), Matches.UnitIsFactoryOrCanBeDamaged);
+			final Collection<Unit> damagedFactory = Match.getMatches(attackedTerritory.getUnits().getUnits(), Matches.UnitCanBeDamaged);
 			final IntegerMap<Unit> hits = new IntegerMap<Unit>();
 			for (final Unit factory : damagedFactory)
 			{
@@ -301,6 +419,8 @@ public class RocketsFireHelper
 			// taUnit.setUnitDamage(totalDamage);
 			bridge.addChange(ChangeFactory.unitsHit(hits));
 			bridge.addChange(change);
+			attackedTerritory.notifyChanged();
+			
 		}
 		// in WW2V2, limit rocket attack cost to production value of factory.
 		else if (isWW2V2(data) || isLimitRocketDamageToProduction(data))
@@ -346,14 +466,14 @@ public class RocketsFireHelper
 			final Change rocketCharge = ChangeFactory.changeResourcesChange(attacked, PUs, -cost);
 			bridge.addChange(rocketCharge);
 		}
+		bridge.getHistoryWriter().addChildToEvent(transcript, rockets);
 		// this is null in WW2V1
 		if (attackFrom != null)
 		{
-			final List<Unit> units = attackFrom.getUnits().getMatches(new CompositeMatchAnd<Unit>(Matches.UnitIsRocket, Matches.unitIsOwnedBy(player)));
-			if (units.size() > 0)
+			if (!rockets.isEmpty())
 			{
-				// only one fired
-				final Change change = ChangeFactory.markNoMovementChange(Collections.singleton(units.get(0)));
+				// TODO: only a certain number fired...
+				final Change change = ChangeFactory.markNoMovementChange(Collections.singleton(rockets.iterator().next()));
 				bridge.addChange(change);
 			}
 			else
@@ -375,6 +495,9 @@ public class RocketsFireHelper
 				bridge.addChange(removeDead);
 			}
 		}
+		// play a sound
+		if (cost > 0)
+			ClipPlayer.play(SoundPath.CLIP_ROCKET);
 	}
 	
 	private ITripleaPlayer getRemote(final IDelegateBridge bridge)
