@@ -27,17 +27,21 @@ import games.strategy.engine.data.Territory;
 import games.strategy.engine.data.Unit;
 import games.strategy.engine.data.UnitType;
 import games.strategy.engine.delegate.IDelegateBridge;
+import games.strategy.engine.random.IRandomStats.DiceType;
 import games.strategy.triplea.Constants;
 import games.strategy.triplea.Properties;
 import games.strategy.triplea.TripleAUnit;
 import games.strategy.triplea.attatchments.PlayerAttachment;
+import games.strategy.triplea.attatchments.TechAbilityAttachment;
 import games.strategy.triplea.attatchments.TerritoryAttachment;
 import games.strategy.triplea.attatchments.UnitAttachment;
-import games.strategy.triplea.delegate.dataObjects.BattleRecords;
+import games.strategy.triplea.delegate.Die.DieType;
+import games.strategy.triplea.delegate.dataObjects.BattleRecord;
 import games.strategy.triplea.delegate.dataObjects.CasualtyDetails;
 import games.strategy.triplea.formatter.MyFormatter;
 import games.strategy.triplea.oddsCalculator.ta.BattleResults;
 import games.strategy.triplea.player.ITripleaPlayer;
+import games.strategy.util.CompositeMatchAnd;
 import games.strategy.util.CompositeMatchOr;
 import games.strategy.util.IntegerMap;
 import games.strategy.util.Match;
@@ -94,15 +98,17 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 	protected void updateDefendingUnits()
 	{
 		// fill in defenders
-		final Match<Unit> defenders = new CompositeMatchOr<Unit>(Matches.UnitIsAtMaxDamageOrNotCanBeDamaged(m_battleSite).invert(), Matches.UnitIsAAthatCanFire(m_attackingUnits, m_attacker,
-					Matches.UnitIsAAforBombingThisUnitOnly, m_data));
+		final HashMap<String, HashSet<UnitType>> airborneTechTargetsAllowed = TechAbilityAttachment.getAirborneTargettedByAA(m_attacker, m_data);
+		final Match<Unit> defenders = new CompositeMatchOr<Unit>(Matches.UnitIsAtMaxDamageOrNotCanBeDamaged(m_battleSite).invert(), Matches.UnitIsAAthatCanFire(m_attackingUnits,
+					airborneTechTargetsAllowed, m_attacker, Matches.UnitIsAAforBombingThisUnitOnly, m_data));
 		if (m_targets.isEmpty())
 		{
 			m_defendingUnits = Match.getMatches(m_battleSite.getUnits().getUnits(), defenders);
 		}
 		else
 		{
-			final List<Unit> targets = Match.getMatches(m_battleSite.getUnits().getUnits(), Matches.UnitIsAAthatCanFire(m_attackingUnits, m_attacker, Matches.UnitIsAAforBombingThisUnitOnly, m_data));
+			final List<Unit> targets = Match.getMatches(m_battleSite.getUnits().getUnits(),
+						Matches.UnitIsAAthatCanFire(m_attackingUnits, airborneTechTargetsAllowed, m_attacker, Matches.UnitIsAAforBombingThisUnitOnly, m_data));
 			targets.addAll(m_targets.keySet());
 			m_defendingUnits = targets;
 		}
@@ -173,11 +179,11 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 		// We update Defending Units twice: first time when the battle is created, and second time before the battle begins.
 		// The reason is because when the battle is created, there are no attacking units yet in it, meaning that m_targets is empty. We need to update right as battle begins to know we have the full list of targets.
 		updateDefendingUnits();
-		bridge.getHistoryWriter().startEvent("Strategic bombing raid in " + m_battleSite);
-		bridge.getHistoryWriter().setRenderingData(m_battleSite);
+		bridge.getHistoryWriter().startEvent("Strategic bombing raid in " + m_battleSite, m_battleSite);
 		BattleCalculator.sortPreBattle(m_attackingUnits, m_data);
 		// TODO: determine if the target has the property, not just any unit with the property isAAforBombingThisUnitOnly
-		m_defendingAA = m_battleSite.getUnits().getMatches(Matches.UnitIsAAthatCanFire(m_attackingUnits, m_attacker, Matches.UnitIsAAforBombingThisUnitOnly, m_data));
+		final HashMap<String, HashSet<UnitType>> airborneTechTargetsAllowed = TechAbilityAttachment.getAirborneTargettedByAA(m_attacker, m_data);
+		m_defendingAA = m_battleSite.getUnits().getMatches(Matches.UnitIsAAthatCanFire(m_attackingUnits, airborneTechTargetsAllowed, m_attacker, Matches.UnitIsAAforBombingThisUnitOnly, m_data));
 		m_AAtypes = UnitAttachment.getAllOfTypeAAs(m_defendingAA); // TODO: order this list in some way
 		final boolean hasAA = m_defendingAA.size() > 0;
 		m_steps = new ArrayList<String>();
@@ -203,14 +209,13 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 			public void execute(final ExecutionStack stack, final IDelegateBridge bridge)
 			{
 				getDisplay(bridge).gotoBattleStep(m_battleID, RAID);
-				m_battleTracker.removeBattle(StrategicBombingRaidBattle.this);
 				if (isSBRAffectsUnitProduction())
-					bridge.getHistoryWriter().addChildToEvent("AA raid costs " + m_bombingRaidTotal + " " + " production in " + m_battleSite.getName());
+					bridge.getHistoryWriter().addChildToEvent("Bombing raid costs " + m_bombingRaidTotal + " " + " production in " + m_battleSite.getName());
 				else if (isDamageFromBombingDoneToUnitsInsteadOfTerritories())
 					bridge.getHistoryWriter().addChildToEvent("Bombing raid in " + m_battleSite.getName() + " causes " + m_bombingRaidTotal + " damage total. " +
-								(m_bombingRaidDamage.size() > 1 ? ("\r\n Damaged units is as follows: " + MyFormatter.integerUnitMapToString(m_bombingRaidDamage)) : ""));
+								(m_bombingRaidDamage.size() > 1 ? (" Damaged units is as follows: " + MyFormatter.integerUnitMapToString(m_bombingRaidDamage)) : ""));
 				else
-					bridge.getHistoryWriter().addChildToEvent("AA raid costs " + m_bombingRaidTotal + " " + MyFormatter.pluralize("PU", m_bombingRaidTotal));
+					bridge.getHistoryWriter().addChildToEvent("Bombing raid costs " + m_bombingRaidTotal + " " + MyFormatter.pluralize("PU", m_bombingRaidTotal));
 				// TODO remove the reference to the constant.japanese- replace with a rule
 				if (isPacificTheater() || isSBRVictoryPoints())
 				{
@@ -222,7 +227,7 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 						{
 							changeVP = ChangeFactory.attachmentPropertyChange(pa, ((-(m_bombingRaidTotal / 10)) + pa.getVps()), "vps");
 							bridge.addChange(changeVP);
-							bridge.getHistoryWriter().addChildToEvent("AA raid costs " + (m_bombingRaidTotal / 10) + " " + MyFormatter.pluralize("vp", (m_bombingRaidTotal / 10)));
+							bridge.getHistoryWriter().addChildToEvent("Bombing raid costs " + (m_bombingRaidTotal / 10) + " " + MyFormatter.pluralize("vp", (m_bombingRaidTotal / 10)));
 						}
 					}
 				}
@@ -287,16 +292,17 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 		if (m_bombingRaidTotal > 0)
 		{
 			m_whoWon = WhoWon.ATTACKER;
-			m_battleResultDescription = BattleRecords.BattleResultDescription.BOMBED;
+			m_battleResultDescription = BattleRecord.BattleResultDescription.BOMBED;
 		}
 		else
 		{
 			m_whoWon = WhoWon.DEFENDER;
-			m_battleResultDescription = BattleRecords.BattleResultDescription.LOST;
+			m_battleResultDescription = BattleRecord.BattleResultDescription.LOST;
 		}
-		m_battleTracker.getBattleRecords().addResultToBattle(m_attacker, m_battleID, m_defender, m_attackerLostTUV, m_defenderLostTUV, m_battleResultDescription, new BattleResults(this),
-					m_bombingRaidTotal);
+		m_battleTracker.getBattleRecords(m_data).addResultToBattle(m_attacker, m_battleID, m_defender, m_attackerLostTUV, m_defenderLostTUV, m_battleResultDescription,
+					new BattleResults(this, m_data), m_bombingRaidTotal);
 		m_isOver = true;
+		m_battleTracker.removeBattle(StrategicBombingRaidBattle.this);
 	}
 	
 	private void showBattle(final IDelegateBridge bridge)
@@ -316,11 +322,15 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 		
 		public void execute(final ExecutionStack stack, final IDelegateBridge bridge)
 		{
+			// TODO: is this even allowed? I think we shouldn't have nested executables, cus it doesn't make sense...
 			final boolean isEditMode = EditDelegate.getEditMode(bridge.getData());
 			for (final String currentTypeAA : m_AAtypes)
 			{
 				final Collection<Unit> currentPossibleAA = Match.getMatches(m_defendingAA, Matches.UnitIsAAofTypeAA(currentTypeAA));
 				final Set<UnitType> targetUnitTypesForThisTypeAA = UnitAttachment.get(currentPossibleAA.iterator().next().getType()).getTargetsAA(m_data);
+				final Set<UnitType> airborneTypesTargettedToo = TechAbilityAttachment.getAirborneTargettedByAA(m_attacker, m_data).get(currentTypeAA);
+				final Collection<Unit> validAttackingUnitsForThisRoll = Match.getMatches(m_attackingUnits, new CompositeMatchOr<Unit>(
+							Matches.unitIsOfTypes(targetUnitTypesForThisTypeAA), new CompositeMatchAnd<Unit>(Matches.UnitIsAirborne, Matches.unitIsOfTypes(airborneTypesTargettedToo))));
 				
 				final IExecutable roll = new IExecutable()
 				{
@@ -328,7 +338,7 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 					
 					public void execute(final ExecutionStack stack, final IDelegateBridge bridge)
 					{
-						m_dice = DiceRoll.rollAA(m_attackingUnits, currentPossibleAA, targetUnitTypesForThisTypeAA, bridge, m_battleSite);
+						m_dice = DiceRoll.rollAA(validAttackingUnitsForThisRoll, currentPossibleAA, bridge, m_battleSite);
 					}
 				};
 				final IExecutable calculateCasualties = new IExecutable()
@@ -337,7 +347,7 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 					
 					public void execute(final ExecutionStack stack, final IDelegateBridge bridge)
 					{
-						m_casualties = calculateCasualties(m_attackingUnits, currentPossibleAA, targetUnitTypesForThisTypeAA, bridge, m_dice);
+						m_casualties = calculateCasualties(validAttackingUnitsForThisRoll, currentPossibleAA, bridge, m_dice);
 					}
 				};
 				final IExecutable notifyCasualties = new IExecutable()
@@ -385,7 +395,7 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 	
 	private boolean isLimitSBRDamageToProduction()
 	{
-		return games.strategy.triplea.Properties.getLimitSBRDamageToProduction(m_data);
+		return games.strategy.triplea.Properties.getLimitRocketAndSBRDamageToProduction(m_data);
 	}
 	
 	private boolean isLimitSBRDamagePerTurn(final GameData data)
@@ -408,17 +418,14 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 		return games.strategy.triplea.Properties.getPacificTheater(m_data);
 	}
 	
-	private Collection<Unit> calculateCasualties(final Collection<Unit> attackingUnitsAll, final Collection<Unit> defendingAA, final Set<UnitType> targetUnitTypesForThisTypeAA,
-				final IDelegateBridge bridge, final DiceRoll dice)
+	private Collection<Unit> calculateCasualties(final Collection<Unit> validAttackingUnitsForThisRoll, final Collection<Unit> defendingAA, final IDelegateBridge bridge, final DiceRoll dice)
 	{
-		final Collection<Unit> validAttackingUnitsForThisRoll = Match.getMatches(attackingUnitsAll, Matches.unitIsOfTypes(targetUnitTypesForThisTypeAA));
 		final boolean isEditMode = EditDelegate.getEditMode(m_data);
 		if (isEditMode)
 		{
 			final String text = "AA guns fire";
 			final CasualtyDetails casualtySelection = BattleCalculator.selectCasualties(RAID, m_attacker, validAttackingUnitsForThisRoll, bridge, text, /* dice */null,/* defending */false,
-						m_battleID, /* head-less */
-						false, 0);
+						m_battleID, /* head-less */false, 0);
 			return casualtySelection.getKilled();
 		}
 		final Collection<Unit> casualties = BattleCalculator.getAACasualties(validAttackingUnitsForThisRoll, defendingAA, dice, bridge, m_defender, m_attacker, m_battleID, m_battleSite);
@@ -505,7 +512,7 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 		
 		private void rollDice(final IDelegateBridge bridge)
 		{
-			final int rollCount = BattleCalculator.getRolls(m_attackingUnits, m_battleSite, m_attacker, false);
+			final int rollCount = BattleCalculator.getRolls(m_attackingUnits, m_battleSite, m_attacker, false, m_territoryEffects);
 			if (rollCount == 0)
 			{
 				m_dice = null;
@@ -521,37 +528,112 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 			}
 			else
 			{
+				final boolean doNotUseBombingBonus = !games.strategy.triplea.Properties.getUseBombingMaxDiceSidesAndBonus(m_data);
 				final String annotation = m_attacker.getName() + " rolling to allocate cost of strategic bombing raid against " + m_defender.getName() + " in " + m_battleSite.getName();
 				if (!games.strategy.triplea.Properties.getLL_DAMAGE_ONLY(m_data))
-					m_dice = bridge.getRandom(m_data.getDiceSides(), rollCount, annotation);
+				{
+					if (doNotUseBombingBonus)
+					{
+						// no low luck, and no bonus, so just roll based on the map's dice sides
+						m_dice = bridge.getRandom(m_data.getDiceSides(), rollCount, m_attacker, DiceType.BOMBING, annotation);
+					}
+					else
+					{
+						// we must use bombing bonus
+						int i = 0;
+						final int diceSides = m_data.getDiceSides();
+						for (final Unit u : m_attackingUnits)
+						{
+							final int rolls = BattleCalculator.getRolls(u, m_battleSite, m_attacker, false, m_territoryEffects);
+							if (rolls < 1)
+								continue;
+							final UnitAttachment ua = UnitAttachment.get(u.getType());
+							int maxDice = ua.getBombingMaxDieSides();
+							int bonus = ua.getBombingBonus();
+							// both could be -1, meaning they were not set. if they were not set, then we use default dice sides for the map, and zero for the bonus.
+							if (maxDice < 0)
+								maxDice = diceSides;
+							if (bonus < 0)
+								bonus = 0;
+							// now we roll, or don't if there is nothing to roll.
+							if (maxDice > 0)
+							{
+								final int[] dicerolls = bridge.getRandom(maxDice, rolls, m_attacker, DiceType.BOMBING, annotation);
+								for (final int die : dicerolls)
+								{
+									m_dice[i] = die + bonus;
+									i++;
+								}
+							}
+							else
+							{
+								for (int j = 0; j < rolls; j++)
+								{
+									m_dice[i] = bonus;
+									i++;
+								}
+							}
+						}
+					}
+				}
 				else
 				{
 					int i = 0;
 					final int diceSides = m_data.getDiceSides();
 					for (final Unit u : m_attackingUnits)
 					{
+						final int rolls = BattleCalculator.getRolls(u, m_battleSite, m_attacker, false, m_territoryEffects);
+						if (rolls < 1)
+							continue;
 						final UnitAttachment ua = UnitAttachment.get(u.getType());
 						int maxDice = ua.getBombingMaxDieSides();
 						int bonus = ua.getBombingBonus();
-						if (maxDice < 0 && bonus < 0 && diceSides >= 5)
-						{
-							maxDice = (diceSides + 1) / 3;
-							bonus = (diceSides + 1) / 3;
-						}
-						if (bonus < 0)
-							bonus = 0;
-						if (maxDice < 0)
+						// both could be -1, meaning they were not set. if they were not set, then we use default dice sides for the map, and zero for the bonus.
+						if (maxDice < 0 || doNotUseBombingBonus)
 							maxDice = diceSides;
+						if (bonus < 0 || doNotUseBombingBonus)
+							bonus = 0;
+						// now, regardless of whether they were set or not, we have to apply "low luck" to them, meaning in this case that we reduce the luck by 2/3.
+						if (maxDice >= 5)
+						{
+							bonus += (maxDice + 1) / 3;
+							maxDice = (maxDice + 1) / 3;
+						}
+						// now we roll, or don't if there is nothing to roll.
 						if (maxDice > 0)
-							m_dice[i] = bridge.getRandom(maxDice, annotation) + bonus;
+						{
+							final int[] dicerolls = bridge.getRandom(maxDice, rolls, m_attacker, DiceType.BOMBING, annotation);
+							for (final int die : dicerolls)
+							{
+								m_dice[i] = die + bonus;
+								i++;
+							}
+						}
 						else
-							m_dice[i] = bonus;
-						i++;
+						{
+							for (int j = 0; j < rolls; j++)
+							{
+								m_dice[i] = bonus;
+								i++;
+							}
+						}
 					}
 				}
 			}
 		}
 		
+		private void addToTargetDiceMap(final Unit attackerUnit, final Die roll, final HashMap<Unit, List<Die>> targetToDiceMap)
+		{
+			if (m_targets == null || m_targets.isEmpty())
+				return;
+			final Unit target = getTarget(attackerUnit);
+			List<Die> current = targetToDiceMap.get(target);
+			if (current == null)
+				current = new ArrayList<Die>();
+			current.add(roll);
+			targetToDiceMap.put(target, current);
+		}
+		
 		private void findCost(final IDelegateBridge bridge)
 		{
 			// if no planes left after aa fires, this is possible
@@ -561,38 +643,63 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 			}
 			final TerritoryAttachment ta = TerritoryAttachment.get(m_battleSite);
 			int cost = 0;
-			final boolean lhtrHeavyBombers = games.strategy.triplea.Properties.getLHTR_Heavy_Bombers(m_data);
-			// boolean lhtrHeavyBombers = m_data.getProperties().get(Constants.LHTR_HEAVY_BOMBERS, false);
+			final boolean lhtrBombers = games.strategy.triplea.Properties.getLHTR_Heavy_Bombers(m_data);
 			int damageLimit = ta.getProduction();
-			final Iterator<Unit> iter = m_attackingUnits.iterator();
 			int index = 0;
 			final Boolean limitDamage = isWW2V2() || isLimitSBRDamageToProduction();
+			final List<Die> dice = new ArrayList<Die>();
+			final HashMap<Unit, List<Die>> targetToDiceMap = new HashMap<Unit, List<Die>>();
 			// limit to maxDamage
-			while (iter.hasNext())
+			for (final Unit attacker : m_attackingUnits)
 			{
-				final Unit attacker = iter.next();
+				final UnitAttachment ua = UnitAttachment.get(attacker.getType());
 				int rolls;
-				rolls = BattleCalculator.getRolls(attacker, m_battleSite, m_attacker, false);
+				rolls = BattleCalculator.getRolls(attacker, m_battleSite, m_attacker, false, m_territoryEffects);
 				int costThisUnit = 0;
-				if (lhtrHeavyBombers && rolls > 1)
+				if (rolls > 1 && (lhtrBombers || ua.getChooseBestRoll()))
 				{
+					// LHTR means we select the best Dice roll for the unit
 					int max = 0;
+					int maxIndex = index;
+					int startIndex = index;
 					for (int i = 0; i < rolls; i++)
 					{
-						// +2 since 0 based (LHTR adds +1 to base roll)
-						max = Math.max(max, m_dice[index] + 2);
+						// +1 since 0 based
+						if (m_dice[index] + 1 > max)
+						{
+							max = m_dice[index] + 1;
+							maxIndex = index;
+						}
 						index++;
 					}
 					costThisUnit = max;
+					// for show
+					final Die best = new Die(m_dice[maxIndex]);
+					dice.add(best);
+					addToTargetDiceMap(attacker, best, targetToDiceMap);
+					for (int i = 0; i < rolls; i++)
+					{
+						if (startIndex != maxIndex)
+						{
+							final Die notBest = new Die(m_dice[startIndex], -1, DieType.IGNORED);
+							dice.add(notBest);
+							addToTargetDiceMap(attacker, notBest, targetToDiceMap);
+						}
+						startIndex++;
+					}
 				}
 				else
 				{
 					for (int i = 0; i < rolls; i++)
 					{
 						costThisUnit += m_dice[index] + 1;
+						final Die die = new Die(m_dice[index]);
+						dice.add(die);
+						addToTargetDiceMap(attacker, die, targetToDiceMap);
 						index++;
 					}
 				}
+				costThisUnit = Math.max(0, (costThisUnit + TechAbilityAttachment.getBombingBonus(attacker.getType(), attacker.getOwner(), m_data)));
 				if (limitDamage)
 					costThisUnit = Math.min(costThisUnit, damageLimit);
 				cost += costThisUnit;
@@ -635,7 +742,7 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 					}
 					final int totalDamage = taUnit.getUnitDamage() + currentUnitCost;
 					// display the results
-					getDisplay(bridge).bombingResults(m_battleID, m_dice, currentUnitCost);
+					getDisplay(bridge).bombingResults(m_battleID, dice, currentUnitCost);
 					// Record production lost
 					DelegateFinder.moveDelegate(m_data).PUsLost(m_battleSite, currentUnitCost);
 					// apply the hits to the targets
@@ -646,9 +753,10 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 					// taUnit.setUnitDamage(totalDamage);
 					bridge.addChange(ChangeFactory.unitsHit(hits));
 					bridge.addChange(change);
-					bridge.getHistoryWriter().startEvent("Bombing raid in " + m_battleSite.getName() + " causes: " + currentUnitCost + " damage to unit: " + current.getType().getName());
-					getRemote(bridge).reportMessage("Bombing raid in " + m_battleSite.getName() + " causes: " + currentUnitCost + " damage to unit: " + current.getType().getName(),
-								"Bombing raid causes " + currentUnitCost + " damage to " + current.getType().getName());
+					bridge.getHistoryWriter().addChildToEvent("Bombing raid in " + m_battleSite.getName() + " rolls: " + MyFormatter.asDice(targetToDiceMap.get(current)) + " and causes: "
+								+ currentUnitCost + " damage to unit: " + current.getType().getName());
+					getRemote(bridge).reportMessage("Bombing raid in " + m_battleSite.getName() + " rolls: " + MyFormatter.asDice(targetToDiceMap.get(current)) + " and causes: " + currentUnitCost
+								+ " damage to unit: " + current.getType().getName(), "Bombing raid causes " + currentUnitCost + " damage to " + current.getType().getName());
 				}
 			}
 			else if (isSBRAffectsUnitProduction())
@@ -660,10 +768,10 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 				final int alreadyLost = damageLimit - unitProduction;
 				final int limit = 2 * damageLimit - alreadyLost;
 				cost = Math.min(cost, limit);
-				getDisplay(bridge).bombingResults(m_battleID, m_dice, cost);
+				getDisplay(bridge).bombingResults(m_battleID, dice, cost);
 				// Record production lost
 				DelegateFinder.moveDelegate(m_data).PUsLost(m_battleSite, cost);
-				final Collection<Unit> damagedFactory = Match.getMatches(m_battleSite.getUnits().getUnits(), Matches.UnitIsFactoryOrCanBeDamaged);
+				final Collection<Unit> damagedFactory = Match.getMatches(m_battleSite.getUnits().getUnits(), Matches.UnitCanBeDamaged);
 				final IntegerMap<Unit> hits = new IntegerMap<Unit>();
 				for (final Unit factory : damagedFactory)
 				{
@@ -675,8 +783,8 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 				// decrease the unitProduction capacity of the territory
 				final Change change = ChangeFactory.attachmentPropertyChange(ta, newProduction.toString(), "unitProduction");
 				bridge.addChange(change);
-				bridge.getHistoryWriter().startEvent("Bombing raid in " + m_battleSite.getName() + " costs: " + cost + " production.");
-				getRemote(bridge).reportMessage("Bombing raid in " + m_battleSite.getName() + " costs: " + cost + " production.",
+				bridge.getHistoryWriter().addChildToEvent("Bombing raid in " + m_battleSite.getName() + " rolls: " + MyFormatter.asDice(m_dice) + " and costs: " + cost + " production.");
+				getRemote(bridge).reportMessage("Bombing raid in " + m_battleSite.getName() + " rolls: " + MyFormatter.asDice(m_dice) + " and costs: " + cost + " production.",
 							"Bombing raid in " + m_battleSite.getName() + " costs: " + cost + " production.");
 			}
 			else
@@ -684,13 +792,15 @@ public class StrategicBombingRaidBattle extends AbstractBattle
 				// Record PUs lost
 				DelegateFinder.moveDelegate(m_data).PUsLost(m_battleSite, cost);
 				cost *= Properties.getPU_Multiplier(m_data);
-				getDisplay(bridge).bombingResults(m_battleID, m_dice, cost);
+				getDisplay(bridge).bombingResults(m_battleID, dice, cost);
 				// get resources
 				final Resource PUs = m_data.getResourceList().getResource(Constants.PUS);
 				final int have = m_defender.getResources().getQuantity(PUs);
 				final int toRemove = Math.min(cost, have);
 				final Change change = ChangeFactory.changeResourcesChange(m_defender, PUs, -toRemove);
 				bridge.addChange(change);
+				bridge.getHistoryWriter().addChildToEvent("Bombing raid in " + m_battleSite.getName() + " rolls: " + MyFormatter.asDice(m_dice) + " and costs: " + cost
+							+ " " + MyFormatter.pluralize("PU", cost) + ".");
 			}
 			m_bombingRaidTotal = cost;
 		}
