@@ -27,6 +27,9 @@ import games.strategy.engine.data.PlayerID;
 import games.strategy.engine.data.Resource;
 import games.strategy.engine.data.TechnologyFrontier;
 import games.strategy.engine.delegate.IDelegateBridge;
+import games.strategy.engine.random.IRandomStats.DiceType;
+import games.strategy.sound.ClipPlayer;
+import games.strategy.sound.SoundPath;
 import games.strategy.triplea.Constants;
 import games.strategy.triplea.attatchments.ICondition;
 import games.strategy.triplea.attatchments.TriggerAttachment;
@@ -36,6 +39,7 @@ import games.strategy.triplea.formatter.MyFormatter;
 import games.strategy.triplea.player.ITripleaPlayer;
 import games.strategy.util.CompositeMatchAnd;
 import games.strategy.util.CompositeMatchOr;
+import games.strategy.util.IntegerMap;
 import games.strategy.util.Match;
 import games.strategy.util.Util;
 
@@ -48,6 +52,7 @@ import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+import java.util.Map.Entry;
 
 /**
  * Logic for dealing with player tech rolls. This class requires the
@@ -163,20 +168,20 @@ public class TechnologyDelegate extends BaseDelegate implements ITechDelegate
 		return games.strategy.triplea.Properties.getLL_TECH_ONLY(getData());
 	}
 	
-	public TechResults rollTech(final int techRolls, final TechnologyFrontier techToRollFor, final int newTokens)
+	public TechResults rollTech(final int techRolls, final TechnologyFrontier techToRollFor, final int newTokens, final IntegerMap<PlayerID> whoPaysHowMuch)
 	{
 		int rollCount = techRolls;
 		if (isWW2V3TechModel())
 			rollCount = newTokens;
-		final boolean canPay = checkEnoughMoney(rollCount);
+		final boolean canPay = checkEnoughMoney(rollCount, whoPaysHowMuch);
 		if (!canPay)
 			return new TechResults("Not enough money to pay for that many tech rolls.");
-		chargeForTechRolls(rollCount);
+		chargeForTechRolls(rollCount, whoPaysHowMuch);
 		int m_currTokens = 0;
 		if (isWW2V3TechModel())
 			m_currTokens = m_player.getResources().getQuantity(Constants.TECH_TOKENS);
 		final GameData data = getData();
-		if (getAvailableTechs().isEmpty())
+		if (getAvailableTechs(m_player, data).isEmpty())
 		{
 			if (isWW2V3TechModel())
 			{
@@ -205,40 +210,36 @@ public class TechnologyDelegate extends BaseDelegate implements ITechDelegate
 			remainder = techRolls % diceSides;
 			if (remainder > 0)
 			{
-				random = m_bridge.getRandom(diceSides, 1, annotation);
+				random = m_bridge.getRandom(diceSides, 1, m_player, DiceType.TECH, annotation);
 				if (random[0] + 1 <= remainder)
 					techHits++;
 			}
 			else
 			{
-				random = m_bridge.getRandom(diceSides, 1, annotation);
+				random = m_bridge.getRandom(diceSides, 1, m_player, DiceType.TECH, annotation);
 				remainder = diceSides;
 			}
 		}
 		else
 		{
-			random = m_bridge.getRandom(diceSides, techRolls, annotation);
+			random = m_bridge.getRandom(diceSides, techRolls, m_player, DiceType.TECH, annotation);
 			techHits = getTechHits(random);
 		}
 		final boolean isRevisedModel = isWW2V2() || (isSelectableTechRoll() && !isWW2V3TechModel());
 		final String directedTechInfo = isRevisedModel ? " for " + techToRollFor.getTechs().get(0) : "";
-		m_bridge.getHistoryWriter().startEvent(
-					m_player.getName() + (random.hashCode() > 0 ? " roll " : " rolls : ") + MyFormatter.asDice(random) + directedTechInfo + " and gets " + techHits + " "
-								+ MyFormatter.pluralize("hit", techHits));
-		if (techHits > 0 && isWW2V3TechModel())
+		final DiceRoll renderDice = (isLL_TECH_ONLY() ? new DiceRoll(random, techHits, remainder, false) : new DiceRoll(random, techHits, diceSides - 1, true));
+		m_bridge.getHistoryWriter().startEvent(m_player.getName() + (random.hashCode() > 0 ? " roll " : " rolls : ") + MyFormatter.asDice(random) + directedTechInfo
+					+ " and gets " + techHits + " " + MyFormatter.pluralize("hit", techHits), renderDice);
+		if (isWW2V3TechModel() && (techHits > 0 || games.strategy.triplea.Properties.getRemoveAllTechTokensAtEndOfTurn(data)))
 		{
 			m_techCategory = techToRollFor;
 			// remove all the tokens
 			final Resource techTokens = data.getResourceList().getResource(Constants.TECH_TOKENS);
-			final String transcriptText = m_player.getName() + " removing all Technology Tokens after successful research.";
+			final String transcriptText = m_player.getName() + " removing all Technology Tokens after " + (techHits > 0 ? "successful" : "unsuccessful") + " research.";
 			m_bridge.getHistoryWriter().startEvent(transcriptText);
 			final Change removeTokens = ChangeFactory.changeResourcesChange(m_bridge.getPlayerID(), techTokens, -m_currTokens);
 			m_bridge.addChange(removeTokens);
 		}
-		if (isLL_TECH_ONLY())
-			m_bridge.getHistoryWriter().setRenderingData(new DiceRoll(random, techHits, remainder, false));
-		else
-			m_bridge.getHistoryWriter().setRenderingData(new DiceRoll(random, techHits, diceSides - 1, true));
 		Collection<TechAdvance> advances;
 		if (isRevisedModel)
 		{
@@ -270,42 +271,64 @@ public class TechnologyDelegate extends BaseDelegate implements ITechDelegate
 		}
 		final String transcriptText = m_player.getName() + " discover " + text.toString();
 		if (advances.size() > 0)
+		{
 			m_bridge.getHistoryWriter().startEvent(transcriptText);
+			// play a sound
+			ClipPlayer.play(SoundPath.CLIP_TECH);
+		}
 		return new TechResults(random, remainder, techHits, advancesAsString, m_player);
 	}
 	
-	private List<TechAdvance> getAvailableTechs()
+	boolean checkEnoughMoney(final int rolls, final IntegerMap<PlayerID> whoPaysHowMuch)
 	{
-		final GameData data = getData();
-		data.acquireReadLock();
-		try
+		final Resource PUs = getData().getResourceList().getResource(Constants.PUS);
+		final int cost = rolls * getTechCost();
+		if (whoPaysHowMuch == null || whoPaysHowMuch.isEmpty())
 		{
-			final Collection<TechAdvance> currentAdvances = TechTracker.getTechAdvances(m_player, data);
-			final Collection<TechAdvance> allAdvances = TechAdvance.getTechAdvances(data, m_player);
-			return Util.difference(allAdvances, currentAdvances);
-		} finally
+			final int has = m_bridge.getPlayerID().getResources().getQuantity(PUs);
+			return has >= cost;
+		}
+		else
 		{
-			data.releaseReadLock();
+			int runningTotal = 0;
+			for (final Entry<PlayerID, Integer> entry : whoPaysHowMuch.entrySet())
+			{
+				final int has = entry.getKey().getResources().getQuantity(PUs);
+				final int paying = entry.getValue();
+				if (paying > has)
+					return false;
+				runningTotal += paying;
+			}
+			return runningTotal >= cost;
 		}
 	}
 	
-	boolean checkEnoughMoney(final int rolls)
+	private void chargeForTechRolls(final int rolls, final IntegerMap<PlayerID> whoPaysHowMuch)
 	{
 		final Resource PUs = getData().getResourceList().getResource(Constants.PUS);
-		final int cost = rolls * getTechCost();
-		final int has = m_bridge.getPlayerID().getResources().getQuantity(PUs);
-		return has >= cost;
-	}
-	
-	private void chargeForTechRolls(final int rolls)
-	{
-		final Resource PUs = getData().getResourceList().getResource(Constants.PUS);
-		// TODO techCost
-		final int cost = rolls * getTechCost();
-		final String transcriptText = m_bridge.getPlayerID().getName() + " spend " + cost + " on tech rolls";
-		m_bridge.getHistoryWriter().startEvent(transcriptText);
-		final Change charge = ChangeFactory.changeResourcesChange(m_bridge.getPlayerID(), PUs, -cost);
-		m_bridge.addChange(charge);
+		int cost = rolls * getTechCost();
+		if (whoPaysHowMuch == null || whoPaysHowMuch.isEmpty())
+		{
+			final String transcriptText = m_bridge.getPlayerID().getName() + " spend " + cost + " on tech rolls";
+			m_bridge.getHistoryWriter().startEvent(transcriptText);
+			final Change charge = ChangeFactory.changeResourcesChange(m_bridge.getPlayerID(), PUs, -cost);
+			m_bridge.addChange(charge);
+		}
+		else
+		{
+			for (final Entry<PlayerID, Integer> entry : whoPaysHowMuch.entrySet())
+			{
+				final PlayerID p = entry.getKey();
+				final int pays = Math.min(cost, entry.getValue());
+				if (pays <= 0)
+					continue;
+				cost -= pays;
+				final String transcriptText = p.getName() + " spend " + pays + " on tech rolls";
+				m_bridge.getHistoryWriter().startEvent(transcriptText);
+				final Change charge = ChangeFactory.changeResourcesChange(p, PUs, -pays);
+				m_bridge.addChange(charge);
+			}
+		}
 		if (isWW2V3TechModel())
 		{
 			final Resource tokens = getData().getResourceList().getResource(Constants.TECH_TOKENS);
@@ -359,7 +382,7 @@ public class TechnologyDelegate extends BaseDelegate implements ITechDelegate
 			// hits guaranteed to be less than available at this point.
 			for (int i = 0; i < hits; i++)
 			{
-				int roll = m_bridge.getRandom(available.size() - i, annotation);
+				int roll = m_bridge.getRandom(available.size() - i, null, DiceType.ENGINE, annotation);
 				for (final int r : rolled)
 				{
 					if (roll >= r)
@@ -386,17 +409,20 @@ public class TechnologyDelegate extends BaseDelegate implements ITechDelegate
 	
 	private List<TechAdvance> getAvailableAdvances()
 	{
-		// too many
-		final Collection<TechAdvance> allAdvances = TechAdvance.getTechAdvances(getData(), m_bridge.getPlayerID());
-		final Collection<TechAdvance> playersAdvances = TechTracker.getTechAdvances(m_bridge.getPlayerID(), getData());
-		final List<TechAdvance> available = Util.difference(allAdvances, playersAdvances);
-		return available;
+		return getAvailableTechs(m_bridge.getPlayerID(), getData());
+	}
+	
+	public static List<TechAdvance> getAvailableTechs(final PlayerID player, final GameData data)
+	{
+		final Collection<TechAdvance> currentAdvances = TechTracker.getCurrentTechAdvances(player, data);
+		final Collection<TechAdvance> allAdvances = TechAdvance.getTechAdvances(data, player);
+		return Util.difference(allAdvances, currentAdvances);
 	}
 	
 	private List<TechAdvance> getAvailableAdvancesForCategory(final TechnologyFrontier techCategory)
 	{
 		// Collection<TechAdvance> allAdvances = TechAdvance.getTechAdvances(m_data, techCategory);
-		final Collection<TechAdvance> playersAdvances = TechTracker.getTechAdvances(m_bridge.getPlayerID(), getData());
+		final Collection<TechAdvance> playersAdvances = TechTracker.getCurrentTechAdvances(m_bridge.getPlayerID(), getData());
 		final List<TechAdvance> available = Util.difference(techCategory.getTechs(), playersAdvances);
 		return available;
 	}
@@ -418,9 +444,9 @@ public class TechnologyDelegate extends BaseDelegate implements ITechDelegate
 }
 
 
-@SuppressWarnings("serial")
 class TechnologyExtendedDelegateState implements Serializable
 {
+	private static final long serialVersionUID = -1375328472343199099L;
 	Serializable superState;
 	// add other variables here:
 	public boolean m_needToInitialize;
