@@ -20,10 +20,12 @@ import games.strategy.engine.data.Route;
 import games.strategy.engine.data.Territory;
 import games.strategy.engine.data.Unit;
 import games.strategy.engine.delegate.IDelegateBridge;
+import games.strategy.triplea.attatchments.UnitAttachment;
 import games.strategy.triplea.delegate.dataObjects.MoveDescription;
 import games.strategy.triplea.player.ITripleaPlayer;
 import games.strategy.triplea.ui.MovePanel;
 import games.strategy.util.CompositeMatchAnd;
+import games.strategy.util.Match;
 import games.strategy.util.Util;
 
 import java.util.Collection;
@@ -39,9 +41,9 @@ import java.util.Set;
  * 
  * @author Erik von der Osten
  */
-@SuppressWarnings("serial")
 public class UndoableMove extends AbstractUndoableMove
 {
+	private static final long serialVersionUID = 8490182214651531358L;
 	private String m_reasonCantUndo;
 	private String m_description;
 	// this move is dependent on these moves
@@ -158,11 +160,18 @@ public class UndoableMove extends AbstractUndoableMove
 					if (routeUnitUsedToMove != null && routeUnitUsedToMove.getEnd() != null)
 					{
 						final Territory end = routeUnitUsedToMove.getEnd();
-						final Collection<Unit> enemyTargets = end.getUnits().getMatches(
+						final Collection<Unit> enemyTargetsTotal = end.getUnits().getMatches(
 									new CompositeMatchAnd<Unit>(Matches.enemyUnit(bridge.getPlayerID(), data), Matches.UnitIsAtMaxDamageOrNotCanBeDamaged(end).invert()));
+						final Collection<Unit> enemyTargets = Match.getMatches(enemyTargetsTotal,
+									Matches.unitIsOfTypes(UnitAttachment.getAllowedBombingTargetsIntersection(Match.getMatches(Collections.singleton(unit), Matches.UnitIsStrategicBomber), data)));
 						if (enemyTargets.size() > 1 && games.strategy.triplea.Properties.getDamageFromBombingDoneToUnitsInsteadOfTerritories(data)
 									&& !games.strategy.triplea.Properties.getRaidsMayBePreceededByAirBattles(data))
-							target = ((ITripleaPlayer) bridge.getRemote(bridge.getPlayerID())).whatShouldBomberBomb(end, enemyTargets);
+						{
+							while (target == null)
+							{
+								target = ((ITripleaPlayer) bridge.getRemote(bridge.getPlayerID())).whatShouldBomberBomb(end, enemyTargets, Collections.singletonList(unit));
+							}
+						}
 						else if (!enemyTargets.isEmpty())
 							target = enemyTargets.iterator().next();
 						if (target != null)
@@ -213,6 +222,22 @@ public class UndoableMove extends AbstractUndoableMove
 		}
 	}
 	
+	// for use with airborne moving
+	public void addDependency(final List<UndoableMove> undoableMoves)
+	{
+		for (final UndoableMove other : undoableMoves)
+		{
+			addDependency(other);
+		}
+	}
+	
+	// for use with airborne moving
+	public void addDependency(final UndoableMove undoableMove)
+	{
+		m_iDependOn.add(undoableMove);
+		undoableMove.m_dependOnMe.add(this);
+	}
+	
 	public boolean wasTransportUnloaded(final Unit transport)
 	{
 		return m_unloaded.contains(transport);
@@ -241,6 +266,11 @@ public class UndoableMove extends AbstractUndoableMove
 		return m_route.getEnd();
 	}
 	
+	public final Territory getStart()
+	{
+		return m_route.getStart();
+	}
+	
 	@Override
 	protected final MoveDescription getDescriptionObject()
 	{
