@@ -18,6 +18,8 @@ import games.strategy.engine.data.Territory;
 import games.strategy.engine.data.Unit;
 import games.strategy.engine.delegate.IPersistentDelegate;
 import games.strategy.engine.message.IRemote;
+import games.strategy.triplea.delegate.TechAdvance;
+import games.strategy.util.IntegerMap;
 
 import java.util.Collection;
 
@@ -42,5 +44,13 @@ public interface IEditDelegate extends IRemote, IPersistentDelegate
 	
 	public String changeTechTokens(PlayerID player, int tokens);
 	
+	public String addTechAdvance(PlayerID player, TechAdvance advance);
+	
+	public String removeTechAdvance(PlayerID player, TechAdvance advance);
+	
+	public String changeUnitHitDamage(final IntegerMap<Unit> unitDamageMap, final Territory territory);
+	
+	public String changeUnitBombingDamage(final IntegerMap<Unit> unitDamageMap, final Territory territory);
+	
 	public String addComment(String message);
 }
