@@ -25,6 +25,7 @@ import games.strategy.engine.data.Unit;
 import games.strategy.engine.data.UnitType;
 import games.strategy.triplea.Constants;
 import games.strategy.triplea.delegate.DiceRoll;
+import games.strategy.triplea.delegate.Die;
 import games.strategy.util.IntegerMap;
 
 import java.util.ArrayList;
@@ -172,7 +173,7 @@ public class MyFormatter
 		if (attachmentGetName.startsWith(Constants.RELATIONSHIPTYPE_ATTACHMENT_NAME))
 			toText = attachmentGetName.replaceFirst(Constants.RELATIONSHIPTYPE_ATTACHMENT_NAME, "Relationship Type ");
 		else if (attachmentGetName.startsWith(Constants.TECH_ATTACHMENT_NAME))
-			toText = attachmentGetName.replaceFirst(Constants.TECH_ATTACHMENT_NAME, "Player Tech Properties ");
+			toText = attachmentGetName.replaceFirst(Constants.TECH_ATTACHMENT_NAME, "Player Techs ");
 		else if (attachmentGetName.startsWith(Constants.UNIT_ATTACHMENT_NAME))
 			toText = attachmentGetName.replaceFirst(Constants.UNIT_ATTACHMENT_NAME, "Unit Type Properties ");
 		else if (attachmentGetName.startsWith(Constants.TERRITORY_ATTACHMENT_NAME))
@@ -195,6 +196,8 @@ public class MyFormatter
 			toText = attachmentGetName.replaceFirst(Constants.PLAYER_ATTACHMENT_NAME, "Player Properties ");
 		else if (attachmentGetName.startsWith(Constants.POLITICALACTION_ATTACHMENT_PREFIX))
 			toText = attachmentGetName.replaceFirst(Constants.POLITICALACTION_ATTACHMENT_PREFIX, "Political Action ");
+		else if (attachmentGetName.startsWith(Constants.TECH_ABILITY_ATTACHMENT_NAME))
+			toText = attachmentGetName.replaceFirst(Constants.TECH_ABILITY_ATTACHMENT_NAME, "Tech Properties ");
 		toText = toText.replaceAll("_", " ");
 		toText = toText.replaceAll("  ", " ");
 		toText = toText.trim();
@@ -266,6 +269,20 @@ public class MyFormatter
 		return buf.toString();
 	}
 	
+	public static String asDice(final List<Die> rolls)
+	{
+		if (rolls == null || rolls.size() == 0)
+			return "none";
+		final StringBuilder buf = new StringBuilder(rolls.size() * 2);
+		for (int i = 0; i < rolls.size(); i++)
+		{
+			buf.append(rolls.get(i).getValue() + 1);
+			if (i + 1 < rolls.size())
+				buf.append(",");
+		}
+		return buf.toString();
+	}
+	
 	/**
 	 * For use with any DefaultNamed (this includes any NamedAttachable, like PlayerID, UnitType, etc.)
 	 * 
