@@ -7,6 +7,7 @@ import games.strategy.engine.data.CompositeChange;
 import games.strategy.engine.data.GameData;
 import games.strategy.engine.data.PlayerID;
 import games.strategy.engine.data.Territory;
+import games.strategy.engine.data.TerritoryEffect;
 import games.strategy.engine.data.Unit;
 import games.strategy.engine.data.UnitHitsChange;
 import games.strategy.engine.delegate.IDelegateBridge;
@@ -16,6 +17,7 @@ import games.strategy.engine.history.DelegateHistoryWriter;
 import games.strategy.engine.history.IDelegateHistoryWriter;
 import games.strategy.engine.message.IChannelSubscribor;
 import games.strategy.engine.message.IRemote;
+import games.strategy.engine.random.IRandomStats.DiceType;
 import games.strategy.engine.random.PlainRandomSource;
 import games.strategy.net.GUID;
 import games.strategy.triplea.ai.AIUtils;
@@ -53,6 +55,7 @@ public class OddsCalculator
 	private Collection<Unit> m_attackingUnits = new ArrayList<Unit>();
 	private Collection<Unit> m_defendingUnits = new ArrayList<Unit>();
 	private Collection<Unit> m_bombardingUnits = new ArrayList<Unit>();
+	private Collection<TerritoryEffect> m_territoryEffects = new ArrayList<TerritoryEffect>();
 	private boolean m_keepOneAttackingLandUnit = false;
 	private volatile boolean m_cancelled = false;
 	
@@ -62,12 +65,13 @@ public class OddsCalculator
 	
 	@SuppressWarnings("unchecked")
 	public AggregateResults calculate(final GameData data, final PlayerID attacker, final PlayerID defender, final Territory location, final Collection<Unit> attacking,
-				final Collection<Unit> defending, final Collection<Unit> bombarding, final int runCount)
+				final Collection<Unit> defending, final Collection<Unit> bombarding, final Collection<TerritoryEffect> territoryEffects, final int runCount)
 	{
 		m_data = GameDataUtils.cloneGameData(data, false);
 		m_attacker = m_data.getPlayerList().getPlayerID(attacker.getName());
 		m_defender = m_data.getPlayerList().getPlayerID(defender.getName());
 		m_location = m_data.getMap().getTerritory(location.getName());
+		m_territoryEffects = territoryEffects;
 		m_attackingUnits = (Collection<Unit>) GameDataUtils.translateIntoOtherGameData(attacking, m_data);
 		m_defendingUnits = (Collection<Unit>) GameDataUtils.translateIntoOtherGameData(defending, m_data);
 		m_bombardingUnits = (Collection<Unit>) GameDataUtils.translateIntoOtherGameData(bombarding, m_data);
@@ -96,9 +100,9 @@ public class OddsCalculator
 			final TripleADelegateBridge bridge = new TripleADelegateBridge(bridge1);
 			final MustFightBattle battle = new MustFightBattle(m_location, m_attacker, m_data, battleTracker);
 			battle.setHeadless(true);
-			battle.setUnits(m_defendingUnits, m_attackingUnits, m_bombardingUnits, m_defender);
+			battle.setUnits(m_defendingUnits, m_attackingUnits, m_bombardingUnits, m_defender, m_territoryEffects);
 			battle.fight(bridge);
-			rVal.addResult(new BattleResults(battle));
+			rVal.addResult(new BattleResults(battle, m_data));
 			// restore the game to its original state
 			new ChangePerformer(m_data).perform(allChanges.invert());
 			battleTracker.clear();
@@ -171,12 +175,12 @@ class DummyDelegateBridge implements IDelegateBridge
 		return m_attackingPlayer;
 	}
 	
-	public int[] getRandom(final int max, final int count, final String annotation)
+	public int[] getRandom(final int max, final int count, final PlayerID player, final DiceType diceType, final String annotation)
 	{
 		return m_randomSource.getRandom(max, count, annotation);
 	}
 	
-	public int getRandom(final int max, final String annotation)
+	public int getRandom(final int max, final PlayerID player, final DiceType diceType, final String annotation)
 	{
 		return m_randomSource.getRandom(max, annotation);
 	}
@@ -224,10 +228,10 @@ class DummyGameModifiedChannel implements IGameModifiedChannel
 	{
 	}
 	
-	public void setRenderingData(final Object renderingData)
+	/*public void setRenderingData(final Object renderingData)
 	{
-	}
-	
+	}*/
+
 	public void shutDown()
 	{
 	}
@@ -239,6 +243,10 @@ class DummyGameModifiedChannel implements IGameModifiedChannel
 	public void stepChanged(final String stepName, final String delegateName, final PlayerID player, final int round, final String displayName, final boolean loadedFromSavedGame)
 	{
 	}
+	
+	public void startHistoryEvent(final String event, final Object renderingData)
+	{
+	}
 }
 
 
@@ -282,7 +290,7 @@ class DummyPlayer extends AbstractAI
 		throw new UnsupportedOperationException();
 	}
 	
-	public Territory retreatQuery(final GUID battleID, final boolean submerge, final Collection<Territory> possibleTerritories, final String message)
+	public Territory retreatQuery(final GUID battleID, final boolean submerge, final Territory battleSite, final Collection<Territory> possibleTerritories, final String message)
 	{
 		// no retreat, no surrender
 		return null;
@@ -294,7 +302,7 @@ class DummyPlayer extends AbstractAI
 		return null;
 	}*/
 
-	public HashMap<Territory, Collection<Unit>> scrambleUnitsQuery(final Territory scrambleTo, final Map<Territory, Tuple<Integer, Collection<Unit>>> possibleScramblers)
+	public HashMap<Territory, Collection<Unit>> scrambleUnitsQuery(final Territory scrambleTo, final Map<Territory, Tuple<Collection<Unit>, Collection<Unit>>> possibleScramblers)
 	{
 		return null;
 	}
@@ -353,7 +361,7 @@ class DummyPlayer extends AbstractAI
 		throw new UnsupportedOperationException();
 	}
 	
-	public Unit whatShouldBomberBomb(final Territory territory, final Collection<Unit> units)
+	public Unit whatShouldBomberBomb(final Territory territory, final Collection<Unit> potentialTargets, final Collection<Unit> bombers)
 	{
 		throw new UnsupportedOperationException();
 	}
