@@ -6,11 +6,14 @@ import games.strategy.engine.data.PlayerID;
 import games.strategy.engine.data.ProductionFrontier;
 import games.strategy.engine.data.ProductionRule;
 import games.strategy.engine.data.Territory;
+import games.strategy.engine.data.TerritoryEffect;
 import games.strategy.engine.data.Unit;
 import games.strategy.engine.data.UnitType;
 import games.strategy.engine.framework.ui.background.WaitDialog;
+import games.strategy.triplea.TripleAUnit;
 import games.strategy.triplea.attatchments.UnitAttachment;
 import games.strategy.triplea.delegate.Matches;
+import games.strategy.triplea.delegate.TerritoryEffectHelper;
 import games.strategy.triplea.ui.UIContext;
 import games.strategy.triplea.util.UnitCategory;
 import games.strategy.triplea.util.UnitSeperator;
@@ -32,10 +35,12 @@ import java.awt.event.ActionListener;
 import java.text.DecimalFormat;
 import java.text.NumberFormat;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashSet;
+import java.util.Hashtable;
 import java.util.List;
 import java.util.Set;
 import java.util.Vector;
@@ -53,10 +58,12 @@ import javax.swing.JLabel;
 import javax.swing.JList;
 import javax.swing.JPanel;
 import javax.swing.JScrollPane;
+import javax.swing.ListSelectionModel;
 import javax.swing.SwingUtilities;
 
 public class OddsCalculatorPanel extends JPanel
 {
+	private static final long serialVersionUID = -3559687618320469183L;
 	private final Window m_parent;
 	private JLabel m_attackerWin;
 	private JLabel m_defenderWin;
@@ -81,15 +88,20 @@ public class OddsCalculatorPanel extends JPanel
 	private JCheckBox m_landBattle;
 	private JButton m_clearButton;
 	private JLabel m_time;
+	private Territory m_location = null;
+	private JList m_territoryEffectsJList;
+	private static final String NO_EFFECTS = "*None*";
 	
 	public OddsCalculatorPanel(final GameData data, final UIContext context, final Territory location, final Window parent)
 	{
 		m_data = data;
 		m_context = context;
+		m_location = location;
 		createComponents();
 		layoutComponents();
 		setupListeners();
 		m_parent = parent;
+		// use the one passed, not the one we found:
 		if (location != null)
 		{
 			m_data.acquireReadLock();
@@ -245,6 +257,8 @@ public class OddsCalculatorPanel extends JPanel
 		final OddsCalculator calculator = new OddsCalculator();
 		final WaitDialog dialog = new WaitDialog(this, "Calculating Odds", new AbstractAction()
 		{
+			private static final long serialVersionUID = -2148507015083214974L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				calculator.cancel();
@@ -260,14 +274,19 @@ public class OddsCalculatorPanel extends JPanel
 				{
 					// find a territory to fight in
 					Territory location = null;
-					for (final Territory t : m_data.getMap())
+					if (m_location == null || m_location.isWater() == isLand())
 					{
-						if (t.isWater() == !isLand())
+						for (final Territory t : m_data.getMap())
 						{
-							location = t;
-							break;
+							if (t.isWater() == !isLand())
+							{
+								location = t;
+								break;
+							}
 						}
 					}
+					else
+						location = m_location;
 					if (location == null)
 						throw new IllegalStateException("No territory found that is land:" + isLand());
 					final List<Unit> defending = m_defendingUnitsPanel.getUnits();
@@ -282,7 +301,34 @@ public class OddsCalculatorPanel extends JPanel
 						calculator.setKeepOneAttackingLandUnit(true);
 					else
 						calculator.setKeepOneAttackingLandUnit(false);
-					results.set(calculator.calculate(m_data, getAttacker(), getDefender(), location, attacking, defending, bombarding, m_numRuns.getValue()));
+					final Collection<TerritoryEffect> territoryEffects = new ArrayList<TerritoryEffect>();
+					if (m_territoryEffectsJList != null)
+					{
+						final List<Object> selectedObjects = Arrays.asList(m_territoryEffectsJList.getSelectedValues());
+						final List<String> selected = new ArrayList<String>();
+						for (final Object obj : selectedObjects)
+						{
+							selected.add((String) obj);
+						}
+						m_data.acquireReadLock();
+						try
+						{
+							final Hashtable<String, TerritoryEffect> allTerritoryEffects = m_data.getTerritoryEffectList();
+							for (final String selection : selected)
+							{
+								if (selection.equals(NO_EFFECTS))
+								{
+									territoryEffects.clear();
+									break;
+								}
+								territoryEffects.add(allTerritoryEffects.get(selection));
+							}
+						} finally
+						{
+							m_data.releaseReadLock();
+						}
+					}
+					results.set(calculator.calculate(m_data, getAttacker(), getDefender(), location, attacking, defending, bombarding, territoryEffects, m_numRuns.getValue()));
 				} finally
 				{
 					SwingUtilities.invokeLater(new Runnable()
@@ -328,7 +374,7 @@ public class OddsCalculatorPanel extends JPanel
 	{
 		if (units == null)
 			units = Collections.emptyList();
-		units = Match.getMatches(units, Matches.UnitCanBeInBattle(false, m_data));
+		units = Match.getMatches(units, Matches.UnitCanBeInBattle(false, m_data, false, false));
 		m_defendingUnitsPanel.init(getDefender(), units, isLand());
 	}
 	
@@ -336,7 +382,7 @@ public class OddsCalculatorPanel extends JPanel
 	{
 		if (units == null)
 			units = Collections.emptyList();
-		units = Match.getMatches(units, Matches.UnitCanBeInBattle(true, m_data));
+		units = Match.getMatches(units, Matches.UnitCanBeInBattle(true, m_data, false, false));
 		m_attackingUnitsPanel.init(getAttacker(), units, isLand());
 	}
 	
@@ -403,10 +449,13 @@ public class OddsCalculatorPanel extends JPanel
 		resultsText.add(m_numRunsLabel, new GridBagConstraints(0, 7, 1, 1, 0, 0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(35, 0, 0, 0), 0, 0));
 		resultsText.add(m_numRuns, new GridBagConstraints(1, 7, 1, 1, 0, 0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(35, 5, 0, 0), 0, 0));
 		resultsText.add(m_keepOneAttackingLandUnitCombo, new GridBagConstraints(0, 8, 2, 1, 0, 0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(5, 5, 5, 5), 0, 0));
-		resultsText.add(m_landBattle, new GridBagConstraints(0, 9, 1, 1, 0, 0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(0, 5, 0, 0), 0, 0));
-		resultsText.add(m_clearButton, new GridBagConstraints(0, 10, 2, 1, 0, 0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(10, 5, 5, 5), 0, 0));
-		resultsText.add(m_calculateButton, new GridBagConstraints(0, 11, 2, 1, 0, 0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(25, 5, 5, 5), 0, 0));
-		resultsText.add(m_SwapSidesButton, new GridBagConstraints(0, 12, 2, 1, 0, 0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(25, 5, 5, 5), 0, 0));
+		resultsText.add(m_landBattle, new GridBagConstraints(0, 9, 1, 1, 0, 0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(0, 5, 5, 5), 0, 0));
+		int row = 10;
+		if (m_territoryEffectsJList != null)
+			resultsText.add(new JScrollPane(m_territoryEffectsJList), new GridBagConstraints(0, row++, 2, 1, 0, 0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(10, 5, 5, 5), 0, 0));
+		resultsText.add(m_clearButton, new GridBagConstraints(0, row++, 2, 1, 0, 0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(25, 5, 5, 5), 0, 0));
+		resultsText.add(m_calculateButton, new GridBagConstraints(0, row++, 2, 1, 0, 0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(25, 5, 5, 5), 0, 0));
+		resultsText.add(m_SwapSidesButton, new GridBagConstraints(0, row++, 2, 1, 0, 0, GridBagConstraints.EAST, GridBagConstraints.NONE, new Insets(25, 5, 5, 5), 0, 0));
 		m_resultsPanel.add(resultsText);
 		main.add(m_resultsPanel, BorderLayout.EAST);
 		final JPanel south = new JPanel();
@@ -429,6 +478,34 @@ public class OddsCalculatorPanel extends JPanel
 			m_attackerCombo = new JComboBox(new Vector<PlayerID>(playerList));
 			m_defenderCombo = new JComboBox(new Vector<PlayerID>(playerList));
 			m_SwapSidesCombo = new JComboBox(new Vector<PlayerID>(playerList));
+			final Hashtable<String, TerritoryEffect> allTerritoryEffects = m_data.getTerritoryEffectList();
+			if (allTerritoryEffects == null || allTerritoryEffects.isEmpty())
+				m_territoryEffectsJList = null;
+			else
+			{
+				final Vector<String> effectNames = new Vector<String>();
+				effectNames.add(NO_EFFECTS);
+				effectNames.addAll(allTerritoryEffects.keySet());
+				m_territoryEffectsJList = new JList(effectNames);
+				m_territoryEffectsJList.setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);
+				m_territoryEffectsJList.setLayoutOrientation(JList.VERTICAL);
+				m_territoryEffectsJList.setVisibleRowCount(3);
+				if (m_location != null)
+				{
+					final Collection<TerritoryEffect> currentEffects = TerritoryEffectHelper.getEffects(m_location);
+					if (!currentEffects.isEmpty())
+					{
+						final int[] selectedIndexes = new int[currentEffects.size()];
+						int currentIndex = 0;
+						for (final TerritoryEffect te : currentEffects)
+						{
+							selectedIndexes[currentIndex] = effectNames.indexOf(te.getName());
+							currentIndex++;
+						}
+						m_territoryEffectsJList.setSelectedIndices(selectedIndexes);
+					}
+				}
+			}
 		} finally
 		{
 			m_data.releaseReadLock();
@@ -469,6 +546,8 @@ public class OddsCalculatorPanel extends JPanel
 	
 	class PlayerRenderer extends DefaultListCellRenderer
 	{
+		private static final long serialVersionUID = -7639128794342607309L;
+		
 		@Override
 		public Component getListCellRendererComponent(final JList list, final Object value, final int index, final boolean isSelected, final boolean cellHasFocus)
 		{
@@ -502,6 +581,7 @@ public class OddsCalculatorPanel extends JPanel
 
 class PlayerUnitsPanel extends JPanel
 {
+	private static final long serialVersionUID = -1206338960403314681L;
 	private final GameData m_data;
 	private final UIContext m_context;
 	private final boolean m_defender;
@@ -635,7 +715,7 @@ class PlayerUnitsPanel extends JPanel
 		}
 		// we want to filter out anything like factories, or units that have no combat ability AND can not be taken casualty.
 		// in addition, as of right now AA guns can not fire on the offensive side, so we want to take them out too, unless they have other combat abilities.
-		rVal = Match.getMatches(rVal, Matches.UnitTypeCanBeInBattle(!m_defender, player, m_data));
+		rVal = Match.getMatches(rVal, Matches.UnitTypeCanBeInBattle(!m_defender, player, m_data, false, false));
 		return rVal;
 	}
 }
@@ -643,6 +723,7 @@ class PlayerUnitsPanel extends JPanel
 
 class UnitPanel extends JPanel
 {
+	private static final long serialVersionUID = 1509643150038705671L;
 	private final UIContext m_context;
 	private final UnitCategory m_category;
 	private final ScrollableTextField m_textField;
@@ -667,7 +748,28 @@ class UnitPanel extends JPanel
 	
 	public List<Unit> getUnits()
 	{
-		return m_category.getType().create(m_textField.getValue(), m_category.getOwner(), true);
+		final List<Unit> units = m_category.getType().create(m_textField.getValue(), m_category.getOwner(), true);
+		if (!units.isEmpty())
+		{
+			// creating the unit just makes it, we want to make sure it is damaged if the category says it is damaged
+			if (m_category.isTwoHit() && m_category.getDamaged())
+			{
+				// we do not need to use bridge and change factory here because this is not sent over the network. these are just some temporary units for the battle calc.
+				for (final Unit u : units)
+				{
+					u.setHits(1);
+				}
+			}
+			if (m_category.getDisabled() && Matches.UnitTypeCanBeDamaged.match(m_category.getType()))
+			{
+				final int uDamage = Math.max(0, 1 + UnitAttachment.get(m_category.getType()).getMaxOperationalDamage()); // add 1 because it is the max operational damage and we want to disable it
+				for (final Unit u : units)
+				{
+					((TripleAUnit) u).setUnitDamage(uDamage);
+				}
+			}
+		}
+		return units;
 	}
 	
 	public int getCount()
