@@ -150,7 +150,7 @@ public interface ITripleaPlayer extends IRemote
 	 * One or more bombers have just moved into a territory where a strategic bombing
 	 * raid can be conducted, what should the bomber bomb?
 	 */
-	public Unit whatShouldBomberBomb(Territory territory, Collection<Unit> units);
+	public Unit whatShouldBomberBomb(Territory territory, final Collection<Unit> potentialTargets, final Collection<Unit> bombers);
 	
 	/**
 	 * Choose where my rockets should fire
@@ -218,7 +218,7 @@ public interface ITripleaPlayer extends IRemote
 	 *            - user displayable message
 	 * @return the territory to retreat to, or null if the player doesnt wish to retreat
 	 */
-	public Territory retreatQuery(GUID battleID, boolean submerge, Collection<Territory> possibleTerritories, String message);
+	public Territory retreatQuery(GUID battleID, boolean submerge, Territory battleTerritory, Collection<Territory> possibleTerritories, String message);
 	
 	/*
 	 * 
@@ -242,7 +242,7 @@ public interface ITripleaPlayer extends IRemote
 	 *            - possible units which we could scramble, with where they are from and how many allowed from that location
 	 * @return a list of units to scramble mapped to where they are coming from
 	 */
-	public HashMap<Territory, Collection<Unit>> scrambleUnitsQuery(Territory scrambleTo, Map<Territory, Tuple<Integer, Collection<Unit>>> possibleScramblers);
+	public HashMap<Territory, Collection<Unit>> scrambleUnitsQuery(Territory scrambleTo, Map<Territory, Tuple<Collection<Unit>, Collection<Unit>>> possibleScramblers);
 	
 	/**
 	 * Ask the player which if any units they want to select.
@@ -264,7 +264,7 @@ public interface ITripleaPlayer extends IRemote
 	
 	public void confirmOwnCasualties(GUID battleId, String message);
 	
-	public PlayerID getID();
+	public PlayerID getPlayerID();
 	
 	/**
 	 * Does the player accept the proposed political action?
