@@ -26,6 +26,7 @@ import games.strategy.engine.data.Territory;
 import games.strategy.engine.data.Unit;
 import games.strategy.engine.gamePlayer.IPlayerBridge;
 import games.strategy.triplea.attatchments.PoliticalActionAttachment;
+import games.strategy.triplea.delegate.AbstractMoveDelegate.MoveType;
 import games.strategy.triplea.delegate.dataObjects.FightBattleDetails;
 import games.strategy.triplea.delegate.dataObjects.MoveDescription;
 import games.strategy.triplea.delegate.dataObjects.TechRoll;
@@ -48,6 +49,7 @@ import javax.swing.SwingUtilities;
  */
 public class ActionButtons extends JPanel
 {
+	private static final long serialVersionUID = 2175685892863042399L;
 	private final CardLayout m_layout = new CardLayout();
 	private BattlePanel m_battlePanel;
 	private MovePanel m_movePanel;
@@ -56,6 +58,7 @@ public class ActionButtons extends JPanel
 	private PlacePanel m_placePanel;
 	private TechPanel m_techPanel;
 	private EndTurnPanel m_endTurnPanel;
+	private MoveForumPosterPanel m_moveForumPosterPanel;
 	private ActionPanel m_current;
 	private PoliticsPanel m_politicsPanel;
 	
@@ -69,6 +72,7 @@ public class ActionButtons extends JPanel
 		m_placePanel = new PlacePanel(data, map, parent);
 		m_techPanel = new TechPanel(data, map);
 		m_endTurnPanel = new EndTurnPanel(data, map);
+		m_moveForumPosterPanel = new MoveForumPosterPanel(data, map);
 		m_politicsPanel = new PoliticsPanel(data, map, parent);
 		m_current = m_techPanel;
 		setLayout(m_layout);
@@ -80,6 +84,7 @@ public class ActionButtons extends JPanel
 		add(m_placePanel, m_placePanel.toString());
 		add(m_techPanel, m_techPanel.toString());
 		add(m_endTurnPanel, m_endTurnPanel.toString());
+		add(m_moveForumPosterPanel, m_moveForumPosterPanel.toString());
 		add(m_politicsPanel, m_politicsPanel.toString());
 		// this should not be necceessary
 		// but it makes tracking down garbage leaks easier
@@ -102,6 +107,7 @@ public class ActionButtons extends JPanel
 				m_placePanel.removeAll();
 				m_techPanel.removeAll();
 				m_endTurnPanel.removeAll();
+				m_moveForumPosterPanel.removeAll();
 				m_politicsPanel.removeAll();
 				m_battlePanel = null;
 				m_movePanel = null;
@@ -110,14 +116,19 @@ public class ActionButtons extends JPanel
 				m_placePanel = null;
 				m_techPanel = null;
 				m_endTurnPanel = null;
+				m_moveForumPosterPanel = null;
 				m_politicsPanel = null;
 			}
 		});
 	}
 	
-	public void changeToMove(final PlayerID id, final boolean nonCombat)
+	public void changeToMove(final PlayerID id, final boolean nonCombat, final String stepName)
 	{
 		m_movePanel.setNonCombat(nonCombat);
+		final boolean airBorne = stepName.endsWith("AirborneCombatMove");
+		final String displayText = (airBorne ? " Airborne" : (nonCombat ? " Non" : ""));
+		m_movePanel.setDisplayText(displayText + " Combat Move");
+		m_movePanel.setMoveType(airBorne ? MoveType.SPECIAL : MoveType.DEFAULT);
 		changeTo(id, m_movePanel);
 	}
 	
@@ -161,6 +172,11 @@ public class ActionButtons extends JPanel
 		changeTo(id, m_endTurnPanel);
 	}
 	
+	public void changeToMoveForumPosterPanel(final PlayerID id)
+	{
+		changeTo(id, m_moveForumPosterPanel);
+	}
+	
 	private void changeTo(final PlayerID id, final ActionPanel newCurrent)
 	{
 		m_current.setActive(false);
@@ -247,6 +263,11 @@ public class ActionButtons extends JPanel
 		m_endTurnPanel.waitForEndTurn(frame, bridge);
 	}
 	
+	public void waitForMoveForumPosterPanel(final TripleAFrame frame, final IPlayerBridge bridge)
+	{
+		m_moveForumPosterPanel.waitForDone(frame, bridge);
+	}
+	
 	/**
 	 * Blocks until the user selects a battle to fight.
 	 */
@@ -289,4 +310,9 @@ public class ActionButtons extends JPanel
 	{
 		return m_endTurnPanel;
 	}
+	
+	public MoveForumPosterPanel getMoveForumPosterPanel()
+	{
+		return m_moveForumPosterPanel;
+	}
 }
