@@ -14,6 +14,7 @@ package games.strategy.triplea.ui;
 import games.strategy.engine.data.GameData;
 import games.strategy.engine.data.PlayerID;
 import games.strategy.engine.data.Territory;
+import games.strategy.engine.data.TerritoryEffect;
 import games.strategy.engine.data.Unit;
 import games.strategy.engine.data.UnitType;
 import games.strategy.engine.framework.GameRunner;
@@ -25,6 +26,7 @@ import games.strategy.triplea.attatchments.UnitAttachment;
 import games.strategy.triplea.attatchments.UnitSupportAttachment;
 import games.strategy.triplea.delegate.BattleCalculator;
 import games.strategy.triplea.delegate.DiceRoll;
+import games.strategy.triplea.delegate.Die;
 import games.strategy.triplea.delegate.IBattle.BattleType;
 import games.strategy.triplea.delegate.Matches;
 import games.strategy.triplea.delegate.TerritoryEffectHelper;
@@ -94,9 +96,9 @@ import javax.swing.table.TableCellRenderer;
 /**
  * Displays a running battle
  */
-@SuppressWarnings("serial")
 public class BattleDisplay extends JPanel
 {
+	private static final long serialVersionUID = -7939993104972562765L;
 	private static final String DICE_KEY = "D";
 	private static final String CASUALTIES_KEY = "C";
 	private static final String MESSAGE_KEY = "M";
@@ -125,6 +127,8 @@ public class BattleDisplay extends JPanel
 	private final JLabel m_messageLabel = new JLabel();
 	private final Action m_nullAction = new AbstractAction(" ")
 	{
+		private static final long serialVersionUID = 3308067665313935111L;
+		
 		public void actionPerformed(final ActionEvent e)
 		{
 		}
@@ -140,9 +144,10 @@ public class BattleDisplay extends JPanel
 		m_location = territory;
 		m_mapPanel = mapPanel;
 		m_data = data;
-		m_defenderModel = new BattleModel(m_data, defendingUnits, m_location, false, m_mapPanel.getUIContext(), battleType);
+		final Collection<TerritoryEffect> territoryEffects = TerritoryEffectHelper.getEffects(territory);
+		m_defenderModel = new BattleModel(m_data, defendingUnits, m_location, false, m_mapPanel.getUIContext(), battleType, territoryEffects);
 		m_defenderModel.refresh();
-		m_attackerModel = new BattleModel(m_data, attackingUnits, m_location, true, m_mapPanel.getUIContext(), battleType);
+		m_attackerModel = new BattleModel(m_data, attackingUnits, m_location, true, m_mapPanel.getUIContext(), battleType, territoryEffects);
 		m_attackerModel.refresh();
 		m_uiContext = mapPanel.getUIContext();
 		m_casualties = new CasualtyNotificationPanel(data, m_mapPanel.getUIContext());
@@ -186,7 +191,7 @@ public class BattleDisplay extends JPanel
 		return m_battleID;
 	}
 	
-	public void bombingResults(final int[] dice, final int cost)
+	public void bombingResults(final List<Die> dice, final int cost)
 	{
 		ClipPlayer.play(SoundPath.CLIP_BOMB); // play sound
 		m_dicePanel.setDiceRollForBombing(dice, cost);
@@ -493,6 +498,8 @@ public class BattleDisplay extends JPanel
 			{
 				m_actionButton.setAction(new AbstractAction(message)
 				{
+					private static final long serialVersionUID = 4489826259192394858L;
+					
 					public void actionPerformed(final ActionEvent e)
 					{
 						continueLatch.countDown();
@@ -525,6 +532,8 @@ public class BattleDisplay extends JPanel
 		m_steps.walkToLastStep();
 		final Action close = new AbstractAction(message + " : (Press Space to close)")
 		{
+			private static final long serialVersionUID = 4219274012228245826L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				enclosingFrame.setVisible(false);
@@ -567,6 +576,8 @@ public class BattleDisplay extends JPanel
 		final CountDownLatch latch = new CountDownLatch(1);
 		final Action action = new AbstractAction("Submerge Subs?")
 		{
+			private static final long serialVersionUID = -1962843804675586562L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				final String ok = "Submerge";
@@ -635,6 +646,8 @@ public class BattleDisplay extends JPanel
 		final CountDownLatch latch = new CountDownLatch(1);
 		final Action action = new AbstractAction("Retreat?")
 		{
+			private static final long serialVersionUID = -1276337628464642219L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				final String yes = "Retreat";
@@ -703,6 +716,7 @@ public class BattleDisplay extends JPanel
 	
 	private class RetreatComponent extends JPanel
 	{
+		private static final long serialVersionUID = 3855054934860687832L;
 		private final JList m_list;
 		private final JLabel m_retreatTerritory = new JLabel("");
 		
@@ -835,6 +849,7 @@ public class BattleDisplay extends JPanel
 				final String btnText = hit.getName() + ", press space to select " + countStr + (plural ? " casualties" : " casualty");
 				m_actionButton.setAction(new AbstractAction(btnText)
 				{
+					private static final long serialVersionUID = -2156028313292233568L;
 					private UnitChooser chooser;
 					private JScrollPane chooserScrollPane;
 					
@@ -959,6 +974,8 @@ public class BattleDisplay extends JPanel
 		setDefaultWidths(attackerTable);
 		final Action continueAction = new AbstractAction()
 		{
+			private static final long serialVersionUID = -7893664767396697489L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				final Action a = m_actionButton.getAction();
@@ -1038,9 +1055,10 @@ public class BattleDisplay extends JPanel
 }
 
 
-@SuppressWarnings("serial")
 class BattleTable extends JTable
 {
+	private static final long serialVersionUID = 6737857639382012817L;
+	
 	BattleTable(final BattleModel model)
 	{
 		super(model);
@@ -1054,9 +1072,9 @@ class BattleTable extends JTable
 }
 
 
-@SuppressWarnings("serial")
 class BattleModel extends DefaultTableModel
 {
+	private static final long serialVersionUID = 6913324191512043963L;
 	private final UIContext m_uiContext;
 	private final GameData m_data;
 	// is the player the agressor?
@@ -1064,6 +1082,7 @@ class BattleModel extends DefaultTableModel
 	private final Collection<Unit> m_units;
 	private final Territory m_location;
 	private final BattleType m_battleType;
+	private final Collection<TerritoryEffect> m_territoryEffects;
 	
 	private static String[] varDiceArray(final GameData data)
 	{
@@ -1081,7 +1100,8 @@ class BattleModel extends DefaultTableModel
 		return diceColumns;
 	}
 	
-	BattleModel(final GameData data, final Collection<Unit> units, final Territory battleLocation, final boolean attack, final UIContext uiContext, final BattleType battleType)
+	BattleModel(final GameData data, final Collection<Unit> units, final Territory battleLocation, final boolean attack, final UIContext uiContext, final BattleType battleType,
+				final Collection<TerritoryEffect> territoryEffects)
 	{
 		super(new Object[0][0], varDiceArray(data));
 		m_uiContext = uiContext;
@@ -1091,6 +1111,7 @@ class BattleModel extends DefaultTableModel
 		m_units = new ArrayList<Unit>(units);
 		m_location = battleLocation;
 		m_battleType = battleType;
+		m_territoryEffects = territoryEffects;
 	}
 	
 	public void notifyRetreat(final Collection<Unit> retreating)
@@ -1174,7 +1195,7 @@ class BattleModel extends DefaultTableModel
 							m_data.releaseReadLock();
 						}
 					}
-					strength += TerritoryEffectHelper.getTerritoryCombatBonus(category.getType(), m_location, !m_attack);
+					strength += TerritoryEffectHelper.getTerritoryCombatBonus(category.getType(), m_territoryEffects, !m_attack);
 				}
 				strength = Math.min(Math.max(strength, 0), m_data.getDiceSides());
 				shift[strength]++;
@@ -1307,9 +1328,9 @@ class TableData
 }
 
 
-@SuppressWarnings("serial")
 class CasualtyNotificationPanel extends JPanel
 {
+	private static final long serialVersionUID = -8254027929090027450L;
 	private final DicePanel m_dice;
 	private final JPanel m_killed = new JPanel();
 	private final JPanel m_damaged = new JPanel();
