@@ -28,6 +28,7 @@ import games.strategy.engine.gamePlayer.IGamePlayer;
 import games.strategy.net.GUID;
 import games.strategy.triplea.TripleAPlayer;
 import games.strategy.triplea.delegate.DiceRoll;
+import games.strategy.triplea.delegate.Die;
 import games.strategy.triplea.delegate.IBattle.BattleType;
 import games.strategy.triplea.delegate.dataObjects.CasualtyDetails;
 import games.strategy.triplea.delegate.dataObjects.CasualtyList;
@@ -71,9 +72,9 @@ import javax.swing.WindowConstants;
  * @author Sean Bridges
  * @version 1.0
  */
-@SuppressWarnings("serial")
 public class BattlePanel extends ActionPanel
 {
+	private static final long serialVersionUID = 5304208569738042592L;
 	private final JLabel m_actionLabel = new JLabel();
 	private FightBattleDetails m_fightBattleMessage;
 	private volatile BattleDisplay m_battleDisplay;
@@ -322,7 +323,8 @@ public class BattlePanel extends ActionPanel
 						boolean foundHumanInBattle = false;
 						for (final IGamePlayer gamePlayer : getMap().getUIContext().getPlayerList())
 						{
-							if ((gamePlayer.getID().equals(attacker) && gamePlayer instanceof TripleAPlayer) || (gamePlayer.getID().equals(defender) && gamePlayer instanceof TripleAPlayer))
+							if ((gamePlayer.getPlayerID().equals(attacker) && gamePlayer instanceof TripleAPlayer)
+										|| (gamePlayer.getPlayerID().equals(defender) && gamePlayer instanceof TripleAPlayer))
 							{
 								foundHumanInBattle = true;
 								break;
@@ -566,7 +568,7 @@ public class BattlePanel extends ActionPanel
 		return m_battleDisplay.getScramble(bridge, message, possible, player);
 	}*/
 
-	public void bombingResults(final GUID battleID, final int[] dice, final int cost)
+	public void bombingResults(final GUID battleID, final List<Die> dice, final int cost)
 	{
 		SwingUtilities.invokeLater(new Runnable()
 		{
@@ -584,6 +586,7 @@ public class BattlePanel extends ActionPanel
 	
 	class CenterBattleAction extends AbstractAction
 	{
+		private static final long serialVersionUID = -5071133874755970334L;
 		Territory m_territory;
 		
 		CenterBattleAction(final Territory battleSite)
@@ -644,6 +647,7 @@ public class BattlePanel extends ActionPanel
 
 	class FightBattleAction extends AbstractAction
 	{
+		private static final long serialVersionUID = 5510976406003707776L;
 		Territory m_territory;
 		boolean m_bomb;
 		
@@ -672,6 +676,7 @@ public class BattlePanel extends ActionPanel
 	
 	private class BombardComponent extends JPanel
 	{
+		private static final long serialVersionUID = -2388895995673156507L;
 		private final JList m_list;
 		
 		BombardComponent(final Unit unit, final Territory unitTerritory, final Collection<Territory> territories, final boolean noneAvailable)
