@@ -18,7 +18,6 @@ import games.strategy.triplea.delegate.DiceRoll;
 import games.strategy.triplea.delegate.Die;
 
 import java.awt.Dimension;
-import java.util.ArrayList;
 import java.util.List;
 
 import javax.swing.Box;
@@ -32,6 +31,7 @@ import javax.swing.SwingUtilities;
 
 public class DicePanel extends JPanel
 {
+	private static final long serialVersionUID = -7544999867518263506L;
 	private final UIContext m_uiContext;
 	private final GameData m_data;
 	
@@ -47,14 +47,9 @@ public class DicePanel extends JPanel
 		removeAll();
 	}
 	
-	public void setDiceRollForBombing(final int[] random, final int cost)
+	public void setDiceRollForBombing(final List<Die> dice, final int cost)
 	{
 		removeAll();
-		final List<Die> dice = new ArrayList<Die>(random.length);
-		for (int i = 0; i < random.length; i++)
-		{
-			dice.add(new Die(random[i]));
-		}
 		add(create(dice, -1));
 		add(Box.createVerticalGlue());
 		add(new JLabel("Cost:" + cost));
