@@ -25,12 +25,19 @@ import games.strategy.triplea.Constants;
 import games.strategy.triplea.TripleAUnit;
 import games.strategy.triplea.attatchments.TerritoryAttachment;
 import games.strategy.triplea.attatchments.UnitAttachment;
+import games.strategy.triplea.delegate.BattleCalculator;
+import games.strategy.triplea.delegate.Matches;
 import games.strategy.triplea.delegate.MoveValidator;
+import games.strategy.triplea.delegate.TechAdvance;
+import games.strategy.triplea.delegate.TechTracker;
+import games.strategy.triplea.delegate.TechnologyDelegate;
+import games.strategy.triplea.delegate.UnitBattleComparator;
 import games.strategy.triplea.delegate.dataObjects.MustMoveWithDetails;
 import games.strategy.triplea.formatter.MyFormatter;
 import games.strategy.triplea.util.UnitSeperator;
 import games.strategy.util.IntegerMap;
 import games.strategy.util.Match;
+import games.strategy.util.Triple;
 
 import java.awt.Color;
 import java.awt.Point;
@@ -41,9 +48,11 @@ import java.util.Collections;
 import java.util.Comparator;
 import java.util.HashMap;
 import java.util.HashSet;
+import java.util.Iterator;
 import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Set;
+import java.util.Vector;
 
 import javax.swing.AbstractAction;
 import javax.swing.Action;
@@ -51,18 +60,25 @@ import javax.swing.Box;
 import javax.swing.BoxLayout;
 import javax.swing.JButton;
 import javax.swing.JLabel;
+import javax.swing.JList;
 import javax.swing.JOptionPane;
 import javax.swing.JScrollPane;
 import javax.swing.JTextField;
+import javax.swing.ListSelectionModel;
 import javax.swing.SwingUtilities;
 import javax.swing.border.EmptyBorder;
 
 public class EditPanel extends ActionPanel
 {
+	private static final long serialVersionUID = 5043639777373556106L;
 	private TripleAFrame m_frame;
 	private Action m_addUnitsAction;
 	private Action m_delUnitsAction;
 	private Action m_changePUsAction;
+	private Action m_addTechAction;
+	private Action m_removeTechAction;
+	private Action m_changeUnitHitDamageAction;
+	private Action m_changeUnitBombingDamageAction;
 	private Action m_changeTerritoryOwnerAction;
 	private Action m_currentAction = null;
 	private JLabel m_actionLabel;
@@ -81,6 +97,8 @@ public class EditPanel extends ActionPanel
 		m_actionLabel = new JLabel();
 		m_addUnitsAction = new AbstractAction("Add Units")
 		{
+			private static final long serialVersionUID = 2205085537962024476L;
+			
 			public void actionPerformed(final ActionEvent event)
 			{
 				m_currentAction = this;
@@ -91,6 +109,8 @@ public class EditPanel extends ActionPanel
 		};
 		m_delUnitsAction = new AbstractAction("Remove Selected Units")
 		{
+			private static final long serialVersionUID = 5127470604727907906L;
+			
 			public void actionPerformed(final ActionEvent event)
 			{
 				m_currentAction = this;
@@ -151,6 +171,8 @@ public class EditPanel extends ActionPanel
 		};
 		m_changeTerritoryOwnerAction = new AbstractAction("Change Territory Owner")
 		{
+			private static final long serialVersionUID = 8547635747553626362L;
+			
 			public void actionPerformed(final ActionEvent event)
 			{
 				m_currentAction = this;
@@ -171,10 +193,16 @@ public class EditPanel extends ActionPanel
 				int option;
 				option = JOptionPane.showOptionDialog(getTopLevelAncestor(), playerChooser, "Select owner of PUs to change", JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, null, null, null);
 				if (option != JOptionPane.OK_OPTION)
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
 					return;
+				}
 				final PlayerID player = playerChooser.getSelected();
 				if (player == null)
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
 					return;
+				}
 				Resource PUs = null;
 				getData().acquireReadLock();
 				try
@@ -185,7 +213,10 @@ public class EditPanel extends ActionPanel
 					getData().releaseReadLock();
 				}
 				if (PUs == null)
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
 					return;
+				}
 				final int oldTotal = player.getResources().getQuantity(PUs);
 				int newTotal = oldTotal;
 				final JTextField PUsField = new JTextField(String.valueOf(oldTotal), 4);
@@ -193,7 +224,10 @@ public class EditPanel extends ActionPanel
 				option = JOptionPane.showOptionDialog(getTopLevelAncestor(), new JScrollPane(PUsField), "Select new number of PUs", JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, null,
 								null, null);
 				if (option != JOptionPane.OK_OPTION)
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
 					return;
+				}
 				try
 				{
 					newTotal = Integer.parseInt(PUsField.getText());
@@ -206,6 +240,229 @@ public class EditPanel extends ActionPanel
 				CANCEL_EDIT_ACTION.actionPerformed(null);
 			}
 		};
+		m_addTechAction = new AbstractAction("Add Technology")
+		{
+			private static final long serialVersionUID = -5536151512828077755L;
+			
+			public void actionPerformed(final ActionEvent event)
+			{
+				m_currentAction = this;
+				setWidgetActivation();
+				final PlayerChooser playerChooser = new PlayerChooser(getData().getPlayerList(), getMap().getUIContext(), false);
+				int option;
+				option = JOptionPane.showOptionDialog(getTopLevelAncestor(), playerChooser, "Select player to get technology", JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, null, null,
+							null);
+				if (option != JOptionPane.OK_OPTION)
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
+					return;
+				}
+				final PlayerID player = playerChooser.getSelected();
+				if (player == null)
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
+					return;
+				}
+				Vector<TechAdvance> techs = null;
+				getData().acquireReadLock();
+				try
+				{
+					techs = new Vector<TechAdvance>(TechnologyDelegate.getAvailableTechs(player, data));
+				} finally
+				{
+					getData().releaseReadLock();
+				}
+				if (techs == null || techs.isEmpty())
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
+					return;
+				}
+				@SuppressWarnings({ "unchecked", "rawtypes" })
+				final JList techList = new JList(techs);
+				techList.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
+				techList.setLayoutOrientation(JList.VERTICAL);
+				techList.setVisibleRowCount(10);
+				final JScrollPane scroll = new JScrollPane(techList);
+				option = JOptionPane.showOptionDialog(getTopLevelAncestor(), scroll, "Select tech to add", JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, null, null, null);
+				if (option != JOptionPane.OK_OPTION)
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
+					return;
+				}
+				TechAdvance advance = null;
+				try
+				{
+					advance = (TechAdvance) techList.getSelectedValue();
+				} catch (final Exception e)
+				{
+				}
+				final String result = m_frame.getEditDelegate().addTechAdvance(player, advance);
+				if (result != null)
+					JOptionPane.showMessageDialog(getTopLevelAncestor(), result, "Could not perform edit", JOptionPane.ERROR_MESSAGE);
+				CANCEL_EDIT_ACTION.actionPerformed(null);
+			}
+		};
+		m_removeTechAction = new AbstractAction("Remove Technology")
+		{
+			private static final long serialVersionUID = -2456111915025687825L;
+			
+			public void actionPerformed(final ActionEvent event)
+			{
+				m_currentAction = this;
+				setWidgetActivation();
+				final PlayerChooser playerChooser = new PlayerChooser(getData().getPlayerList(), getMap().getUIContext(), false);
+				int option;
+				option = JOptionPane.showOptionDialog(getTopLevelAncestor(), playerChooser, "Select player to remove technology", JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, null, null,
+							null);
+				if (option != JOptionPane.OK_OPTION)
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
+					return;
+				}
+				final PlayerID player = playerChooser.getSelected();
+				if (player == null)
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
+					return;
+				}
+				Vector<TechAdvance> techs = null;
+				getData().acquireReadLock();
+				try
+				{
+					techs = new Vector<TechAdvance>(TechTracker.getCurrentTechAdvances(player, data));
+					// there is no way to "undo" these two techs, so do not allow them to be removed
+					final Iterator<TechAdvance> iter = techs.iterator();
+					while (iter.hasNext())
+					{
+						final TechAdvance ta = iter.next();
+						if (ta.getProperty().equals(TechAdvance.TECH_PROPERTY_IMPROVED_SHIPYARDS) || ta.getProperty().equals(TechAdvance.TECH_PROPERTY_INDUSTRIAL_TECHNOLOGY))
+							iter.remove();
+					}
+				} finally
+				{
+					getData().releaseReadLock();
+				}
+				if (techs == null || techs.isEmpty())
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
+					return;
+				}
+				@SuppressWarnings({ "unchecked", "rawtypes" })
+				final JList techList = new JList(techs);
+				techList.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
+				techList.setLayoutOrientation(JList.VERTICAL);
+				techList.setVisibleRowCount(10);
+				final JScrollPane scroll = new JScrollPane(techList);
+				option = JOptionPane.showOptionDialog(getTopLevelAncestor(), scroll, "Select tech to remove", JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, null, null, null);
+				if (option != JOptionPane.OK_OPTION)
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
+					return;
+				}
+				TechAdvance advance = null;
+				try
+				{
+					advance = (TechAdvance) techList.getSelectedValue();
+				} catch (final Exception e)
+				{
+				}
+				final String result = m_frame.getEditDelegate().removeTechAdvance(player, advance);
+				if (result != null)
+					JOptionPane.showMessageDialog(getTopLevelAncestor(), result, "Could not perform edit", JOptionPane.ERROR_MESSAGE);
+				CANCEL_EDIT_ACTION.actionPerformed(null);
+			}
+		};
+		m_changeUnitHitDamageAction = new AbstractAction("Change Unit Hit Damage")
+		{
+			private static final long serialVersionUID = 1835547345902760810L;
+			
+			public void actionPerformed(final ActionEvent event)
+			{
+				m_currentAction = this;
+				setWidgetActivation();
+				final List<Unit> units = Match.getMatches(m_selectedUnits, Matches.UnitIsTwoHit);
+				if (units == null || units.isEmpty() || !m_selectedTerritory.getUnits().getUnits().containsAll(units))
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
+					return;
+				}
+				// all owned by one player
+				units.retainAll(Match.getMatches(units, Matches.unitIsOwnedBy(units.iterator().next().getOwner())));
+				if (units.isEmpty())
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
+					return;
+				}
+				sortUnitsToRemove(units, m_selectedTerritory);
+				Collections.sort(units, new UnitBattleComparator(false, BattleCalculator.getCostsForTuvForAllPlayersMergedAndAveraged(getData()), getData(), false));
+				Collections.reverse(units);
+				// unit mapped to <max, min, current>
+				final HashMap<Unit, Triple<Integer, Integer, Integer>> currentDamageMap = new HashMap<Unit, Triple<Integer, Integer, Integer>>();
+				for (final Unit u : units)
+				{
+					currentDamageMap.put(u, new Triple<Integer, Integer, Integer>(1, 0, u.getHits()));
+				}
+				final IndividualUnitPanel unitPanel = new IndividualUnitPanel(currentDamageMap, "Change Unit Hit Damage", getData(), getMap().getUIContext(), -1, true, true, null);
+				final JScrollPane scroll = new JScrollPane(unitPanel);
+				final int option = JOptionPane.showOptionDialog(getTopLevelAncestor(), scroll, "Change Unit Hit Damage", JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, null, null, null);
+				if (option != JOptionPane.OK_OPTION)
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
+					return;
+				}
+				final IntegerMap<Unit> newDamageMap = unitPanel.getSelected();
+				final String result = m_frame.getEditDelegate().changeUnitHitDamage(newDamageMap, m_selectedTerritory);
+				if (result != null)
+					JOptionPane.showMessageDialog(getTopLevelAncestor(), result, "Could not perform edit", JOptionPane.ERROR_MESSAGE);
+				CANCEL_EDIT_ACTION.actionPerformed(null);
+			}
+		};
+		m_changeUnitBombingDamageAction = new AbstractAction("Change Unit Bombing Damage")
+		{
+			private static final long serialVersionUID = 6975869192911780860L;
+			
+			public void actionPerformed(final ActionEvent event)
+			{
+				m_currentAction = this;
+				setWidgetActivation();
+				final List<Unit> units = Match.getMatches(m_selectedUnits, Matches.UnitCanBeDamaged);
+				if (units == null || units.isEmpty() || !m_selectedTerritory.getUnits().getUnits().containsAll(units))
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
+					return;
+				}
+				// all owned by one player
+				units.retainAll(Match.getMatches(units, Matches.unitIsOwnedBy(units.iterator().next().getOwner())));
+				if (units.isEmpty())
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
+					return;
+				}
+				sortUnitsToRemove(units, m_selectedTerritory);
+				Collections.sort(units, new UnitBattleComparator(false, BattleCalculator.getCostsForTuvForAllPlayersMergedAndAveraged(getData()), getData(), false));
+				Collections.reverse(units);
+				// unit mapped to <max, min, current>
+				final HashMap<Unit, Triple<Integer, Integer, Integer>> currentDamageMap = new HashMap<Unit, Triple<Integer, Integer, Integer>>();
+				for (final Unit u : units)
+				{
+					currentDamageMap
+								.put(u, new Triple<Integer, Integer, Integer>(((TripleAUnit) u).getHowMuchDamageCanThisUnitTakeTotal(u, m_selectedTerritory), 0, ((TripleAUnit) u).getUnitDamage()));
+				}
+				final IndividualUnitPanel unitPanel = new IndividualUnitPanel(currentDamageMap, "Change Unit Bombing Damage", getData(), getMap().getUIContext(), -1, true, true, null);
+				final JScrollPane scroll = new JScrollPane(unitPanel);
+				final int option = JOptionPane.showOptionDialog(getTopLevelAncestor(), scroll, "Change Unit Bombing Damage", JOptionPane.OK_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, null, null, null);
+				if (option != JOptionPane.OK_OPTION)
+				{
+					CANCEL_EDIT_ACTION.actionPerformed(null);
+					return;
+				}
+				final IntegerMap<Unit> newDamageMap = unitPanel.getSelected();
+				final String result = m_frame.getEditDelegate().changeUnitBombingDamage(newDamageMap, m_selectedTerritory);
+				if (result != null)
+					JOptionPane.showMessageDialog(getTopLevelAncestor(), result, "Could not perform edit", JOptionPane.ERROR_MESSAGE);
+				CANCEL_EDIT_ACTION.actionPerformed(null);
+			}
+		};
 		m_actionLabel.setText("Edit Mode Actions");
 		setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
 		setBorder(new EmptyBorder(5, 5, 0, 0));
@@ -214,6 +471,24 @@ public class EditPanel extends ActionPanel
 		add(new JButton(m_delUnitsAction));
 		add(new JButton(m_changeTerritoryOwnerAction));
 		add(new JButton(m_changePUsAction));
+		if (games.strategy.triplea.Properties.getTechDevelopment(getData()))
+		{
+			add(new JButton(m_addTechAction));
+			add(new JButton(m_removeTechAction));
+		}
+		data.acquireReadLock();
+		try
+		{
+			final Set<UnitType> allUnitTypes = data.getUnitTypeList().getAllUnitTypes();
+			if (Match.someMatch(allUnitTypes, Matches.UnitTypeIsTwoHit))
+				add(new JButton(m_changeUnitHitDamageAction));
+			if ((games.strategy.triplea.Properties.getDamageFromBombingDoneToUnitsInsteadOfTerritories(data) || games.strategy.triplea.Properties.getSBRAffectsUnitProduction(data))
+						&& Match.someMatch(allUnitTypes, Matches.UnitTypeCanBeDamaged))
+				add(new JButton(m_changeUnitBombingDamageAction));
+		} finally
+		{
+			data.releaseReadLock();
+		}
 		add(Box.createVerticalStrut(15));
 		setWidgetActivation();
 	}
@@ -273,6 +548,10 @@ public class EditPanel extends ActionPanel
 			m_delUnitsAction.setEnabled(false);
 			m_changeTerritoryOwnerAction.setEnabled(false);
 			m_changePUsAction.setEnabled(false);
+			m_addTechAction.setEnabled(false);
+			m_removeTechAction.setEnabled(false);
+			m_changeUnitHitDamageAction.setEnabled(false);
+			m_changeUnitBombingDamageAction.setEnabled(false);
 		}
 		else
 		{
@@ -280,6 +559,10 @@ public class EditPanel extends ActionPanel
 			m_delUnitsAction.setEnabled(!m_selectedUnits.isEmpty());
 			m_changeTerritoryOwnerAction.setEnabled(m_currentAction == null && m_selectedUnits.isEmpty());
 			m_changePUsAction.setEnabled(m_currentAction == null && m_selectedUnits.isEmpty());
+			m_addTechAction.setEnabled(m_currentAction == null && m_selectedUnits.isEmpty());
+			m_removeTechAction.setEnabled(m_currentAction == null && m_selectedUnits.isEmpty());
+			m_changeUnitHitDamageAction.setEnabled(!m_selectedUnits.isEmpty());
+			m_changeUnitBombingDamageAction.setEnabled(!m_selectedUnits.isEmpty());
 		}
 	}
 	
@@ -363,7 +646,7 @@ public class EditPanel extends ActionPanel
 			// no unit selected, deselect the most recent
 			if (units.isEmpty())
 			{
-				if (md.isControlDown() || t != m_selectedTerritory)
+				if (md.isControlDown() || t != m_selectedTerritory || m_selectedUnits.isEmpty())
 					m_selectedUnits.clear();
 				else
 					// remove the last element
@@ -561,6 +844,8 @@ public class EditPanel extends ActionPanel
 	};
 	private final AbstractAction CANCEL_EDIT_ACTION = new AbstractAction("Cancel")
 	{
+		private static final long serialVersionUID = 6394987295241603443L;
+		
 		public void actionPerformed(final ActionEvent e)
 		{
 			m_selectedTerritory = null;
