@@ -29,6 +29,7 @@ import games.strategy.engine.data.events.TerritoryListener;
 import games.strategy.thread.LockUtil;
 import games.strategy.triplea.Constants;
 import games.strategy.triplea.image.UnitImageFactory;
+import games.strategy.triplea.ui.screen.IDrawable.OptionalExtraBorderLevel;
 import games.strategy.triplea.ui.screen.SmallMapImageManager;
 import games.strategy.triplea.ui.screen.Tile;
 import games.strategy.triplea.ui.screen.TileManager;
@@ -52,6 +53,7 @@ import java.awt.Graphics2D;
 import java.awt.Image;
 import java.awt.Point;
 import java.awt.Rectangle;
+import java.awt.RenderingHints;
 import java.awt.event.MouseAdapter;
 import java.awt.event.MouseEvent;
 import java.awt.event.MouseListener;
@@ -84,6 +86,7 @@ import javax.swing.SwingUtilities;
  */
 public class MapPanel extends ImageScrollerLargeView
 {
+	private static final long serialVersionUID = -3571551538356292556L;
 	private static Logger s_logger = Logger.getLogger(MapPanel.class.getName());
 	private final ListenerList<MapSelectionListener> m_mapSelectionListeners = new ListenerList<MapSelectionListener>();
 	private final ListenerList<UnitSelectionListener> m_unitSelectionListeners = new ListenerList<UnitSelectionListener>();
@@ -362,12 +365,16 @@ public class MapPanel extends ImageScrollerLargeView
 	
 	private final MouseListener MOUSE_LISTENER = new MouseAdapter()
 	{
+		/*public void mouseEntered(MouseEvent e) {
+			MOUSE_MOTION_LISTENER.mouseMoved(e);
+		};*/
 		/**
 		 * Invoked when the mouse exits a component.
 		 */
 		@Override
 		public void mouseExited(final MouseEvent e)
 		{
+			// m_currentTerritory = null;
 			if (unitsChanged(null))
 			{
 				final MouseDetails md = convert(e);
@@ -797,6 +804,19 @@ public class MapPanel extends ImageScrollerLargeView
 		super.setScale(newScale);
 		// setScale will check bounds, and normalize the scale correctly
 		final double normalizedScale = m_scale;
+		final OptionalExtraBorderLevel drawBorderOption = m_uiContext.getDrawTerritoryBordersAgain();
+		// so what is happening here is that when we zoom out, the territory borders get blurred or even removed
+		// so we have a special setter to have them be drawn a second time, on top of the relief tiles
+		if (normalizedScale >= 1)
+		{
+			if (drawBorderOption != OptionalExtraBorderLevel.LOW)
+				m_uiContext.resetDrawTerritoryBordersAgain();
+		}
+		else
+		{
+			if (drawBorderOption == OptionalExtraBorderLevel.LOW)
+				m_uiContext.setDrawTerritoryBordersAgainToMedium();
+		}
 		m_uiContext.setScale(normalizedScale);
 		recreateTiles(getData(), m_uiContext);
 		repaint();
@@ -836,6 +856,9 @@ public class MapPanel extends ImageScrollerLargeView
 		final BufferedImage img = Util.createImage(categories.size() * (xSpace + icon_width), UnitImageFactory.UNIT_ICON_HEIGHT, true);
 		final Graphics2D g = (Graphics2D) img.getGraphics();
 		g.setComposite(AlphaComposite.getInstance(AlphaComposite.SRC_OVER, 0.6f));
+		g.setRenderingHint(RenderingHints.KEY_RENDERING, RenderingHints.VALUE_RENDER_QUALITY);
+		g.setRenderingHint(RenderingHints.KEY_ALPHA_INTERPOLATION, RenderingHints.VALUE_ALPHA_INTERPOLATION_QUALITY);
+		g.setRenderingHint(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_BICUBIC);
 		final Rectangle bounds = new Rectangle(0, 0, 0, 0);
 		getData().acquireReadLock();
 		try
