@@ -28,6 +28,8 @@ import games.strategy.triplea.Constants;
 import games.strategy.triplea.TripleAUnit;
 import games.strategy.triplea.attatchments.TechAttachment;
 import games.strategy.triplea.attatchments.UnitAttachment;
+import games.strategy.triplea.delegate.AbstractMoveDelegate;
+import games.strategy.triplea.delegate.AbstractMoveDelegate.MoveType;
 import games.strategy.triplea.delegate.EditDelegate;
 import games.strategy.triplea.delegate.Matches;
 import games.strategy.triplea.delegate.MoveDelegate;
@@ -72,9 +74,9 @@ import javax.swing.JOptionPane;
  * @author Sean Bridges, modified by Erik von der Osten
  * @version 1.1
  */
-@SuppressWarnings("serial")
 public class MovePanel extends AbstractMovePanel
 {
+	private static final long serialVersionUID = 5004515340964828564L;
 	private static final int s_defaultMinTransportCost = 5;
 	/**
 	 * @param s_deselectNumber
@@ -102,6 +104,8 @@ public class MovePanel extends AbstractMovePanel
 	private Image m_currentCursorImage;
 	private TransportTracker m_transportTracker = null;
 	private Route m_routeCached = null;
+	private String m_displayText = "Combat Move";
+	private MoveType m_moveType = MoveType.DEFAULT;
 	
 	/** Creates new MovePanel */
 	public MovePanel(final GameData data, final MapPanel map, final TripleAFrame frame)
@@ -113,9 +117,9 @@ public class MovePanel extends AbstractMovePanel
 		m_currentCursorImage = null;
 	}
 	
-	// TODO: oh my fucking god this code is aweful. only the local computer has access to the UI. why the fuck did someone think they could do this?
+	// TODO: oh my fucking god this code is awefull. only the local computer has access to the UI. why the fuck did someone think they could do this?
 	// The host has no access to the client's UI, and therefore does not know what dependent units there are.
-	// TODO: rewrite this fucking garbage! None of this s_dependentUnits shit should be in the move panel!
+	// TODO: rewrite this fucking garbage! None of this s_dependentUnits shit should be in the move panel! (fixed by sending a copy of this with the move details)
 	private static Map<Unit, Collection<Unit>> getDependents()
 	{
 		return s_dependentUnits;
@@ -139,6 +143,11 @@ public class MovePanel extends AbstractMovePanel
 		s_dependentUnits.clear();
 	}
 	
+	public void setMoveType(final MoveType moveType)
+	{
+		m_moveType = moveType;
+	}
+	
 	private PlayerID getUnitOwner(final Collection<Unit> units)
 	{
 		if (EditDelegate.getEditMode(getData()) && units != null && !units.isEmpty())
@@ -503,7 +512,7 @@ public class MovePanel extends AbstractMovePanel
 		getData().acquireReadLock();
 		try
 		{
-			allResults = MoveValidator.validateMove(bestWithDependents, route, getCurrentPlayer(), transportsToLoad, s_dependentUnits, m_nonCombat, getUndoableMoves(), getData());
+			allResults = AbstractMoveDelegate.validateMove(m_moveType, bestWithDependents, route, getCurrentPlayer(), transportsToLoad, s_dependentUnits, m_nonCombat, getUndoableMoves(), getData());
 		} finally
 		{
 			getData().releaseReadLock();
@@ -516,13 +525,15 @@ public class MovePanel extends AbstractMovePanel
 			{
 				best = Match.getMatches(best, Matches.UnitCanInvade);
 				bestWithDependents = addMustMoveWith(best);
-				lastResults = MoveValidator.validateMove(bestWithDependents, route, getCurrentPlayer(), transportsToLoad, s_dependentUnits, m_nonCombat, getUndoableMoves(), getData());
+				lastResults = AbstractMoveDelegate.validateMove(m_moveType, bestWithDependents, route, getCurrentPlayer(), transportsToLoad, s_dependentUnits, m_nonCombat, getUndoableMoves(),
+							getData());
 			}
 			while (!best.isEmpty() && !lastResults.isMoveValid())
 			{
 				best = best.subList(1, best.size());
 				bestWithDependents = addMustMoveWith(best);
-				lastResults = MoveValidator.validateMove(bestWithDependents, route, getCurrentPlayer(), transportsToLoad, s_dependentUnits, m_nonCombat, getUndoableMoves(), getData());
+				lastResults = AbstractMoveDelegate.validateMove(m_moveType, bestWithDependents, route, getCurrentPlayer(), transportsToLoad, s_dependentUnits, m_nonCombat, getUndoableMoves(),
+							getData());
 			}
 		}
 		if (allResults.isMoveValid())
@@ -1231,7 +1242,7 @@ public class MovePanel extends AbstractMovePanel
 			final Route route = getRoute(getFirstSelectedTerritory(), territory, m_selectedUnits);
 			final List<Unit> units = m_unitsThatCanMoveOnRoute;
 			setSelectedEndpointTerritory(territory);
-			if (units.isEmpty())
+			if (units.isEmpty() || route == null)
 			{
 				cancelMove();
 				return;
@@ -1393,7 +1404,10 @@ public class MovePanel extends AbstractMovePanel
 		{
 			if (!getListening())
 				return;
-			final Match<Unit> match = new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(getUnitOwner(m_selectedUnits)), Matches.UnitIsNotFactory);
+			final PlayerID owner = getUnitOwner(m_selectedUnits);
+			final CompositeMatchAnd<Unit> match = new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(owner)/*, Matches.UnitIsNotFactory*/);
+			if (true)
+				match.add(Matches.UnitCanMove);
 			final boolean someOwned = Match.someMatch(units, match);
 			final boolean isCorrectTerritory = m_firstSelectedTerritory == null || m_firstSelectedTerritory == territory;
 			if (someOwned && isCorrectTerritory)
@@ -1558,11 +1572,16 @@ public class MovePanel extends AbstractMovePanel
 		m_nonCombat = nonCombat;
 	}
 	
+	public final void setDisplayText(final String displayText)
+	{
+		m_displayText = displayText;
+	}
+	
 	@Override
 	public final void display(final PlayerID id)
 	{
 		m_transportTracker = new TransportTracker();
-		super.display(id, (m_nonCombat ? " non combat" : " combat") + " move");
+		super.display(id, m_displayText);
 	}
 	
 	/**
@@ -1608,9 +1627,9 @@ public class MovePanel extends AbstractMovePanel
  * Avoid holding a strong reference to the action
  * fixes a memory leak in swing.
  */
-@SuppressWarnings("serial")
 class WeakAction extends AbstractAction
 {
+	private static final long serialVersionUID = 8931357243476123862L;
 	private final WeakReference<Action> m_delegate;
 	
 	WeakAction(final String name, final Action delegate)
