@@ -28,7 +28,7 @@ import games.strategy.engine.data.Unit;
 import games.strategy.engine.data.UnitType;
 import games.strategy.triplea.Constants;
 import games.strategy.triplea.TripleAUnit;
-import games.strategy.triplea.attatchments.TechAttachment;
+import games.strategy.triplea.attatchments.TechAbilityAttachment;
 import games.strategy.triplea.attatchments.TerritoryAttachment;
 import games.strategy.triplea.delegate.Matches;
 import games.strategy.ui.ScrollableTextField;
@@ -69,6 +69,7 @@ import javax.swing.border.EtchedBorder;
  */
 public class ProductionRepairPanel extends JPanel
 {
+	private static final long serialVersionUID = -6344711064699083729L;
 	private JFrame m_owner;
 	private JDialog m_dialog;
 	private final UIContext m_uiContext;
@@ -125,6 +126,8 @@ public class ProductionRepairPanel extends JPanel
 		m_dialog.getContentPane().add(this);
 		final Action closeAction = new AbstractAction("")
 		{
+			private static final long serialVersionUID = 2832491642574528614L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				m_dialog.setVisible(false);
@@ -151,7 +154,7 @@ public class ProductionRepairPanel extends JPanel
 		try
 		{
 			m_id = player;
-			final CompositeMatchAnd<Unit> myPotentiallyDamagedUnits = new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(player), Matches.UnitIsFactoryOrCanBeDamaged);
+			final CompositeMatchAnd<Unit> myPotentiallyDamagedUnits = new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(player), Matches.UnitCanBeDamaged);
 			final CompositeMatchAnd<Unit> myDamagedUnits = new CompositeMatchAnd<Unit>(Matches.unitIsOwnedBy(player), Matches.UnitHasSomeUnitDamage());
 			final Collection<Territory> terrsWithPotentiallyDamagedUnits = Match.getMatches(data.getMap().getTerritories(), Matches.territoryHasUnitsThatMatch(myPotentiallyDamagedUnits));
 			for (final RepairRule repairRule : player.getRepairFrontier())
@@ -177,7 +180,6 @@ public class ProductionRepairPanel extends JPanel
 								// initialQuantity = initialPurchase.get(repairRule).getInt(repairRule);
 								rule.setQuantity(initialQuantity);
 								rule.setMax(PUProduction - unitProduction);
-								rule.setUnit(u);
 								rule.setName(u.toString());
 								m_rules.add(rule);
 							}
@@ -199,7 +201,6 @@ public class ProductionRepairPanel extends JPanel
 							// initialQuantity = initialPurchase.get(repairRule).getInt(repairRule);
 							rule.setQuantity(initialQuantity);
 							rule.setMax(taUnit.getHowMuchCanThisUnitBeRepaired(u, terr));
-							rule.setUnit(u);
 							rule.setName(u.toString());
 							m_rules.add(rule);
 						}
@@ -235,16 +236,10 @@ public class ProductionRepairPanel extends JPanel
 		m_left.setText("<html>You have " + left + " left.<br>Out of " + total + "</html>");
 	}
 	
-	private boolean isIncreasedFactoryProduction(final PlayerID player)
-	{
-		final TechAttachment ta = (TechAttachment) player.getAttachment(Constants.TECH_ATTACHMENT_NAME);
-		if (ta == null)
-			return false;
-		return ta.getIncreasedFactoryProduction();
-	}
-	
 	Action m_done_action = new AbstractAction("Done")
 	{
+		private static final long serialVersionUID = 8547016018558520143L;
+		
 		public void actionPerformed(final ActionEvent e)
 		{
 			m_dialog.setVisible(false);
@@ -271,19 +266,25 @@ public class ProductionRepairPanel extends JPanel
 	
 	protected void calculateLimits()
 	{
-		final IntegerMap<Resource> cost;
+		// final IntegerMap<Resource> cost;
 		final ResourceCollection resources = getResources();
 		final ResourceCollection spent = new ResourceCollection(m_data);
 		for (final Rule current : m_rules)
 		{
 			spent.add(current.getCost(), current.getQuantity());
 		}
+		final float discount = TechAbilityAttachment.getRepairDiscount(m_id, m_data);
+		if (discount != 1.0F)
+			spent.discount(discount);
 		final ResourceCollection leftToSpend = resources.difference(spent);
 		setLeft(leftToSpend);
-		
 		for (final Rule current : m_rules)
 		{
 			int max = leftToSpend.fitsHowOften(current.getCost());
+			if (discount != 1.0F)
+			{
+				max = (int) (max / discount);
+			}
 			max += current.getQuantity();
 			current.setMax(max);
 		}
@@ -307,23 +308,23 @@ public class ProductionRepairPanel extends JPanel
 	}
 	
 	
-	@SuppressWarnings("serial")
 	public class Rule extends JPanel
 	{
+		private static final long serialVersionUID = -6781214135310064908L;
 		private final ScrollableTextField m_text = new ScrollableTextField(0, Integer.MAX_VALUE);
 		private final IntegerMap<Resource> m_cost;
 		private final RepairRule m_rule;
-		private Unit m_unit;
+		private final Unit m_unit;
+		private final int m_maxRepairAmount;
 		
 		Rule(final RepairRule rule, final PlayerID id, final UIContext uiContext, final Unit repairUnit)
 		{
 			setLayout(new GridBagLayout());
+			m_unit = repairUnit;
 			m_rule = rule;
 			m_cost = rule.getCosts();
-			if (isIncreasedFactoryProduction(id))
-				m_cost.multiplyAllValuesBy(0.5f, 2);
+			final Territory territoryUnitIsIn = repairUnit.getTerritoryUnitIsIn();
 			final UnitType type = (UnitType) rule.getResults().keySet().iterator().next();
-			
 			if (!type.equals(repairUnit.getType()))
 				throw new IllegalStateException("Rule unit type " + type.getName() + " does not match " + repairUnit.toString() + ".  Please make sure your maps are up to date!");
 			final TripleAUnit taUnit = (TripleAUnit) repairUnit;
@@ -334,9 +335,9 @@ public class ProductionRepairPanel extends JPanel
 				icon = m_uiContext.getUnitImageFactory().getIcon(type, id, m_data, Matches.UnitHasSomeUnitDamage().match(repairUnit), Matches.UnitIsDisabled().match(repairUnit));
 			final String text = "<html> x " + ResourceCollection.toStringForHTML(m_cost) + "</html>";
 			final JLabel label = new JLabel(text, icon, SwingConstants.LEFT);
-			final JLabel info = new JLabel(repairUnit.getTerritoryUnitIsIn().getName());
-			final int toRepair = taUnit.getHowMuchCanThisUnitBeRepaired(repairUnit, repairUnit.getTerritoryUnitIsIn());
-			final JLabel remaining = new JLabel("Production left to repair: " + toRepair);
+			final JLabel info = new JLabel(territoryUnitIsIn.getName());
+			m_maxRepairAmount = taUnit.getHowMuchCanThisUnitBeRepaired(repairUnit, territoryUnitIsIn);
+			final JLabel remaining = new JLabel("Production left to repair: " + m_maxRepairAmount);
 			final int space = 8;
 			this.add(new JLabel(type.getName()), new GridBagConstraints(0, 0, 1, 1, 1, 1, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(2, 0, 0, 0), 0, 0));
 			this.add(label, new GridBagConstraints(0, 1, 1, 1, 1, 1, GridBagConstraints.CENTER, GridBagConstraints.NONE, new Insets(5, space, space, space), 0, 0));
@@ -369,18 +370,13 @@ public class ProductionRepairPanel extends JPanel
 		
 		void setMax(final int max)
 		{
-			m_text.setMax(max);
+			m_text.setMax(Math.min(max, m_maxRepairAmount));
 		}
 		
 		public Unit getUnit()
 		{
 			return m_unit;
 		}
-		
-		void setUnit(final Unit unit)
-		{
-			m_unit = unit;
-		}
 	}
 	
 	private final ScrollableTextFieldListener m_listener = new ScrollableTextFieldListener()
