@@ -64,9 +64,9 @@ import javax.swing.table.TableColumn;
  * 
  * @author Sean Bridges
  */
-@SuppressWarnings("serial")
 public class StatPanel extends JPanel
 {
+	private static final long serialVersionUID = 4340684166664492498L;
 	final private StatTableModel m_dataModel;
 	final private TechTableModel m_techModel;
 	protected IStat[] m_stats;
@@ -90,6 +90,8 @@ public class StatPanel extends JPanel
 		
 		m_statsTable = new JTable(m_dataModel)
 		{
+			private static final long serialVersionUID = -5516554955307630864L;
+			
 			@Override
 			public void print(final Graphics g)
 			{
@@ -166,6 +168,7 @@ public class StatPanel extends JPanel
 	 */
 	class StatTableModel extends AbstractTableModel implements GameDataChangeListener
 	{
+		private static final long serialVersionUID = -6156153062049822444L;
 		/* Flag to indicate whether data needs to be recalculated */
 		private boolean m_isDirty = true;
 		/* Column Header Names */
@@ -311,6 +314,7 @@ public class StatPanel extends JPanel
 
 	class TechTableModel extends AbstractTableModel implements GameDataChangeListener
 	{
+		private static final long serialVersionUID = -4612476336419396081L;
 		/* Flag to indicate whether data needs to be recalculated */
 		private boolean isDirty = true;
 		/* Column Header Names */
@@ -341,11 +345,11 @@ public class StatPanel extends JPanel
 			if (m_data.getResourceList().getResource(Constants.TECH_TOKENS) != null)
 			{
 				useTech = true;
-				data = new String[TechAdvance.getTechAdvances(m_data, null).size() + 1][colList.length + 2];
+				data = new String[TechAdvance.getTechAdvances(m_data).size() + 1][colList.length + 2];
 			}
 			else
 			{
-				data = new String[TechAdvance.getTechAdvances(m_data, null).size()][colList.length + 1];
+				data = new String[TechAdvance.getTechAdvances(m_data).size()][colList.length + 1];
 			}
 			/* Load the technology -> row mapping */
 			rowMap = new HashMap<String, Integer>();
@@ -411,7 +415,19 @@ public class StatPanel extends JPanel
 						final Integer tokens = pid.getResources().getQuantity(Constants.TECH_TOKENS);
 						data[row][col] = tokens.toString();
 					}
-					Iterator<TechAdvance> advances = TechTracker.getTechAdvances(pid, m_data).iterator();
+					final Iterator<TechAdvance> advancesAll = TechAdvance.getTechAdvances(m_data).iterator();
+					final List<TechAdvance> has = TechAdvance.getTechAdvances(m_data, pid);
+					while (advancesAll.hasNext())
+					{
+						final TechAdvance advance = advancesAll.next();
+						// if(!pid.getTechnologyFrontierList().getAdvances().contains(advance)){
+						if (!has.contains(advance))
+						{
+							row = rowMap.get(advance.getName()).intValue();
+							data[row][col] = "-";
+						}
+					}
+					final Iterator<TechAdvance> advances = TechTracker.getCurrentTechAdvances(pid, m_data).iterator();
 					while (advances.hasNext())
 					{
 						final TechAdvance advance = advances.next();
@@ -420,18 +436,6 @@ public class StatPanel extends JPanel
 						data[row][col] = "X";
 						// data[row][col] = colList[col].substring(0, 1);
 					}
-					advances = TechAdvance.getTechAdvances(m_data, null).iterator();
-					final List<TechAdvance> has = TechAdvance.getTechAdvances(m_data, pid);
-					while (advances.hasNext())
-					{
-						final TechAdvance advance = advances.next();
-						// if(!pid.getTechnologyFrontierList().getAdvances().contains(advance)){
-						if (!has.contains(advance))
-						{
-							row = rowMap.get(advance.getName()).intValue();
-							data[row][col] = "-";
-						}
-					}
 				}
 			} finally
 			{
