@@ -54,6 +54,7 @@ import javax.swing.JTabbedPane;
  */
 public class TabbedProductionPanel extends ProductionPanel
 {
+	private static final long serialVersionUID = 3481282212500641144L;
 	private int m_rows;
 	private int m_columns;
 	
@@ -79,8 +80,7 @@ public class TabbedProductionPanel extends ProductionPanel
 		totalWithoutTechTokensOrVPs.removeAllOfResource(m_data.getResourceList().getResource(Constants.TECH_TOKENS));
 		m_data.releaseReadLock();
 		add(new JLabel("<html>Attack/Defense/Movement. &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; (Total Resources: " + totalWithoutTechTokensOrVPs.toString() + ")</html>"),
-					new GridBagConstraints(0, 0, 1,
-								1, 1, 1, GridBagConstraints.EAST, GridBagConstraints.HORIZONTAL, new Insets(8, 8, 8, 0), 0, 0));
+					new GridBagConstraints(0, 0, 1, 1, 1, 1, GridBagConstraints.EAST, GridBagConstraints.HORIZONTAL, new Insets(8, 8, 8, 0), 0, 0));
 		final JTabbedPane tabs = new JTabbedPane();
 		add(tabs, new GridBagConstraints(0, 1, 1, 1, 100, 100, GridBagConstraints.EAST, GridBagConstraints.BOTH, new Insets(8, 8, 8, 0), 0, 0));
 		final ProductionTabsProperties properties = ProductionTabsProperties.getInstance(m_id, m_rules);
@@ -183,7 +183,7 @@ public class TabbedProductionPanel extends ProductionPanel
 			allRules.add(rule);
 			if (attach.getConsumesUnits() != null && attach.getConsumesUnits().totalValues() >= 1)
 				upgradeConsumesRules.add(rule);
-			if (attach.getIsConstruction() || attach.getIsFactory())
+			if (attach.getIsConstruction())
 			{ // canproduceUnits isn't checked on purpose, since this category is for units that can be placed anywhere (placed without needing a factory).
 				constructRules.add(rule);
 			}
