@@ -57,6 +57,7 @@ import games.strategy.triplea.attatchments.PoliticalActionAttachment;
 import games.strategy.triplea.attatchments.TerritoryAttachment;
 import games.strategy.triplea.delegate.AirThatCantLandUtil;
 import games.strategy.triplea.delegate.BattleCalculator;
+import games.strategy.triplea.delegate.BattleDelegate;
 import games.strategy.triplea.delegate.EditDelegate;
 import games.strategy.triplea.delegate.Matches;
 import games.strategy.triplea.delegate.UnitBattleComparator;
@@ -83,6 +84,7 @@ import java.awt.Color;
 import java.awt.Dimension;
 import java.awt.FlowLayout;
 import java.awt.Font;
+import java.awt.Frame;
 import java.awt.Graphics;
 import java.awt.Graphics2D;
 import java.awt.GridBagConstraints;
@@ -97,6 +99,8 @@ import java.awt.event.WindowEvent;
 import java.awt.event.WindowListener;
 import java.awt.geom.AffineTransform;
 import java.awt.image.BufferedImage;
+import java.beans.PropertyChangeEvent;
+import java.beans.PropertyChangeListener;
 import java.io.File;
 import java.io.FileOutputStream;
 import java.io.IOException;
@@ -123,6 +127,7 @@ import javax.swing.BoxLayout;
 import javax.swing.ButtonModel;
 import javax.swing.ImageIcon;
 import javax.swing.JComponent;
+import javax.swing.JDialog;
 import javax.swing.JFileChooser;
 import javax.swing.JLabel;
 import javax.swing.JList;
@@ -155,6 +160,7 @@ import javax.swing.table.DefaultTableCellRenderer;
  */
 public class TripleAFrame extends MainGameFrame // extends JFrame
 {
+	private static final long serialVersionUID = 7640069668264418976L;
 	private GameData m_data;
 	private IGame m_game;
 	private MapPanel m_mapPanel;
@@ -332,6 +338,8 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 		// set up the edit mode overlay text
 		this.setGlassPane(new JComponent()
 		{
+			private static final long serialVersionUID = 6724687534214427291L;
+			
 			@Override
 			protected void paintComponent(final Graphics g)
 			{
@@ -359,6 +367,8 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 		((JComponent) getContentPane()).getInputMap(JComponent.WHEN_IN_FOCUSED_WINDOW).put(KeyStroke.getKeyStroke('=', java.awt.event.InputEvent.CTRL_MASK), zoom_map_in);
 		((JComponent) getContentPane()).getActionMap().put(zoom_map_in, new AbstractAction(zoom_map_in)
 		{
+			private static final long serialVersionUID = -7565304172320049817L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				if (getScale() < 100)
@@ -370,6 +380,8 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 		((JComponent) getContentPane()).getInputMap(JComponent.WHEN_IN_FOCUSED_WINDOW).put(KeyStroke.getKeyStroke('-', java.awt.event.InputEvent.CTRL_MASK), zoom_map_out);
 		((JComponent) getContentPane()).getActionMap().put(zoom_map_out, new AbstractAction(zoom_map_out)
 		{
+			private static final long serialVersionUID = 7677111833274819304L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				if (getScale() > 16)
@@ -612,9 +624,9 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 		return m_actionButtons.waitForRepair(bid);
 	}
 	
-	public MoveDescription getMove(final PlayerID player, final IPlayerBridge bridge, final boolean nonCombat)
+	public MoveDescription getMove(final PlayerID player, final IPlayerBridge bridge, final boolean nonCombat, final String stepName)
 	{
-		m_actionButtons.changeToMove(player, nonCombat);
+		m_actionButtons.changeToMove(player, nonCombat, stepName);
 		// workaround for panel not receiving focus at beginning of n/c move phase
 		if (!getBattlePanel().getBattleFrame().isVisible())
 		{
@@ -650,6 +662,12 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 		return m_actionButtons.waitForPlace(bid, bridge);
 	}
 	
+	public void waitForMoveForumPoster(final PlayerID player, final IPlayerBridge bridge)
+	{
+		m_actionButtons.changeToMoveForumPosterPanel(player);
+		m_actionButtons.waitForMoveForumPosterPanel(this, bridge);
+	}
+	
 	public void waitForEndTurn(final PlayerID player, final IPlayerBridge bridge)
 	{
 		m_actionButtons.changeToEndTurn(player);
@@ -748,23 +766,25 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 		return choice == 0;
 	}
 	
-	public Unit getStrategicBombingRaidTarget(final Territory territory, final Collection<Unit> units)
+	public Unit getStrategicBombingRaidTarget(final Territory territory, final Collection<Unit> potentialTargets, final Collection<Unit> bombers)
 	{
-		if (units == null || units.size() == 0)
+		if (potentialTargets == null || potentialTargets.size() == 0)
 			return null;
-		if (units.size() == 1)
-			return units.iterator().next();
+		if (potentialTargets.size() == 1)
+			return potentialTargets.iterator().next();
 		final AtomicReference<Unit> selected = new AtomicReference<Unit>();
 		final String message = "Select bombing target in " + territory.getName();
 		final Tuple<JPanel, JList> comps = Util.runInSwingEventThread(new Util.Task<Tuple<JPanel, JList>>()
 		{
 			public Tuple<JPanel, JList> run()
 			{
-				final JList list = new JList(new Vector<Unit>(units));
+				final JList list = new JList(new Vector<Unit>(potentialTargets));
 				list.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
 				list.setSelectedIndex(0);
 				final JPanel panel = new JPanel();
 				panel.setLayout(new BorderLayout());
+				if (bombers != null)
+					panel.add(new JLabel("For Units: " + MyFormatter.unitsToTextNoOwner(bombers)), BorderLayout.NORTH);
 				final JScrollPane scroll = new JScrollPane(list);
 				panel.add(scroll, BorderLayout.CENTER);
 				return new Tuple<JPanel, JList>(panel, list);
@@ -856,42 +876,72 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 				final IndividualUnitPanelGrouped unitPanel = new IndividualUnitPanelGrouped(possibleUnitsToAttackStringForm, m_data, m_uiContext, "Select Units to Suicide Attack using "
 							+ attackResourceToken.getName(), maxNumberOfAttacksAllowed, true, false);
 				unitPanels.add(unitPanel);
-				final Object[] options = { "Attack", "None", "Wait" };
-				final int option = JOptionPane.showOptionDialog(getParent(), unitPanel, "Select units to Suicide Attack using " + attackResourceToken.getName(), JOptionPane.YES_NO_CANCEL_OPTION,
-							JOptionPane.PLAIN_MESSAGE, null, options, options[2]);
-				if (option == JOptionPane.NO_OPTION)
+				final String optionAttack = "Attack";
+				final String optionNone = "None";
+				final String optionWait = "Wait";
+				final Object[] options = { optionAttack, optionNone, optionWait };
+				final JOptionPane optionPane = new JOptionPane(unitPanel, JOptionPane.PLAIN_MESSAGE, JOptionPane.YES_NO_CANCEL_OPTION, null, options, options[2]);
+				final JDialog dialog = new JDialog((Frame) getParent(), "Select units to Suicide Attack using " + attackResourceToken.getName());
+				dialog.setContentPane(optionPane);
+				dialog.setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
+				dialog.setLocationRelativeTo(getParent());
+				dialog.setAlwaysOnTop(true);
+				dialog.pack();
+				dialog.setVisible(true);
+				dialog.requestFocusInWindow();
+				// final int option = JOptionPane.showOptionDialog(getParent(), unitPanel, "Select units to Suicide Attack using " + attackResourceToken.getName(), JOptionPane.YES_NO_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, null, options, options[2]);
+				optionPane.addPropertyChangeListener(new PropertyChangeListener()
 				{
-					unitPanels.clear();
-					selection.clear();
-					continueLatch.countDown();
-					return;
-				}
-				else if (option == JOptionPane.CANCEL_OPTION)
-				{
-					try
+					public void propertyChange(final PropertyChangeEvent e)
 					{
-						Thread.sleep(6000);
-					} catch (final InterruptedException e)
-					{
-						e.printStackTrace();
-					}
-					unitPanels.clear();
-					selection.clear();
-					run();
-				}
-				else
-				{
-					if (unitPanels.size() != 1)
-						throw new IllegalStateException("unitPanels should only contain 1 entry");
-					for (final IndividualUnitPanelGrouped terrChooser : unitPanels)
-					{
-						for (final Entry<String, IntegerMap<Unit>> entry : terrChooser.getSelected().entrySet())
+						if (!dialog.isVisible())
+							return;
+						final String option = ((String) optionPane.getValue());
+						if (option.equals(optionNone))
 						{
-							selection.put(m_data.getMap().getTerritory(entry.getKey()), entry.getValue());
+							unitPanels.clear();
+							selection.clear();
+							dialog.setVisible(false);
+							dialog.removeAll();
+							dialog.dispose();
+							continueLatch.countDown();
+							return;
+						}
+						else if (option.equals(optionAttack))
+						{
+							if (unitPanels.size() != 1)
+								throw new IllegalStateException("unitPanels should only contain 1 entry");
+							for (final IndividualUnitPanelGrouped terrChooser : unitPanels)
+							{
+								for (final Entry<String, IntegerMap<Unit>> entry : terrChooser.getSelected().entrySet())
+								{
+									selection.put(m_data.getMap().getTerritory(entry.getKey()), entry.getValue());
+								}
+							}
+							dialog.setVisible(false);
+							dialog.removeAll();
+							dialog.dispose();
+							continueLatch.countDown();
+						}
+						else
+						// if (option.equals(optionWait))
+						{
+							unitPanels.clear();
+							selection.clear();
+							dialog.setVisible(false);
+							dialog.removeAll();
+							dialog.dispose();
+							try
+							{
+								Thread.sleep(500);
+							} catch (final InterruptedException e2)
+							{
+								e2.printStackTrace();
+							}
+							run();
 						}
 					}
-					continueLatch.countDown();
-				}
+				});
 			}
 		});
 		try
@@ -904,7 +954,7 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 		return selection;
 	}
 	
-	public HashMap<Territory, Collection<Unit>> scrambleUnitsQuery(final Territory scrambleTo, final Map<Territory, Tuple<Integer, Collection<Unit>>> possibleScramblers)
+	public HashMap<Territory, Collection<Unit>> scrambleUnitsQuery(final Territory scrambleTo, final Map<Territory, Tuple<Collection<Unit>, Collection<Unit>>> possibleScramblers)
 	{
 		if (SwingUtilities.isEventDispatchThread())
 		{
@@ -919,7 +969,13 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 			{
 				m_mapPanel.centerOn(scrambleTo);
 				final JPanel panel = new JPanel();
-				panel.setLayout(new FlowLayout());
+				panel.setLayout(new BorderLayout());
+				final JLabel whereTo = new JLabel("Scramble To: " + scrambleTo.getName());
+				whereTo.setFont(new Font("Arial", Font.ITALIC, 12));
+				panel.add(whereTo, BorderLayout.NORTH);
+				final JPanel panel2 = new JPanel();
+				panel2.setBorder(BorderFactory.createEmptyBorder());
+				panel2.setLayout(new FlowLayout());
 				for (final Territory from : possibleScramblers.keySet())
 				{
 					JScrollPane chooserScrollPane;
@@ -932,45 +988,76 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 					panelChooser.add(whereFrom);
 					panelChooser.add(new JLabel(" "));
 					final Collection<Unit> possible = possibleScramblers.get(from).getSecond();
-					final int maxAllowed = Math.min(possibleScramblers.get(from).getFirst(), possible.size());
+					final int maxAllowed = Math.min(BattleDelegate.getMaxScrambleCount(possibleScramblers.get(from).getFirst()), possible.size());
 					final UnitChooser chooser = new UnitChooser(possible, Collections.<Unit, Collection<Unit>> emptyMap(), m_data, false, m_uiContext);
 					chooser.setMaxAndShowMaxButton(maxAllowed);
 					choosers.add(new Tuple<Territory, UnitChooser>(from, chooser));
 					panelChooser.add(chooser);
 					chooserScrollPane = new JScrollPane(panelChooser);
-					panel.add(chooserScrollPane);
+					panel2.add(chooserScrollPane);
 				}
-				final Object[] options = { "Scramble", "None", "Wait" };
-				final int option = JOptionPane.showOptionDialog(getParent(), panel, "Select units to scramble to " + scrambleTo.getName(), JOptionPane.YES_NO_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE,
-							null, options, options[2]);
-				if (option == JOptionPane.NO_OPTION)
+				panel.add(panel2, BorderLayout.CENTER);
+				final String optionScramble = "Scramble";
+				final String optionNone = "None";
+				final String optionWait = "Wait";
+				final Object[] options = { optionScramble, optionNone, optionWait };
+				final JOptionPane optionPane = new JOptionPane(panel, JOptionPane.PLAIN_MESSAGE, JOptionPane.YES_NO_CANCEL_OPTION, null, options, options[2]);
+				final JDialog dialog = new JDialog((Frame) getParent(), "Select units to scramble to " + scrambleTo.getName());
+				dialog.setContentPane(optionPane);
+				dialog.setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
+				dialog.setLocationRelativeTo(getParent());
+				dialog.setAlwaysOnTop(true);
+				dialog.pack();
+				dialog.setVisible(true);
+				dialog.requestFocusInWindow();
+				// final int option = JOptionPane.showOptionDialog(getParent(), panel, "Select units to scramble to " + scrambleTo.getName(), JOptionPane.YES_NO_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, null, options, options[2]);
+				optionPane.addPropertyChangeListener(new PropertyChangeListener()
 				{
-					choosers.clear();
-					selection.clear();
-					continueLatch.countDown();
-					return;
-				}
-				else if (option == JOptionPane.CANCEL_OPTION)
-				{
-					try
+					public void propertyChange(final PropertyChangeEvent e)
 					{
-						Thread.sleep(6000);
-					} catch (final InterruptedException e)
-					{
-						e.printStackTrace();
+						if (!dialog.isVisible())
+							return;
+						final String option = ((String) optionPane.getValue());
+						if (option.equals(optionNone))
+						{
+							choosers.clear();
+							selection.clear();
+							dialog.setVisible(false);
+							dialog.removeAll();
+							dialog.dispose();
+							continueLatch.countDown();
+							return;
+						}
+						else if (option.equals(optionScramble))
+						{
+							for (final Tuple<Territory, UnitChooser> terrChooser : choosers)
+							{
+								selection.put(terrChooser.getFirst(), terrChooser.getSecond().getSelected());
+							}
+							dialog.setVisible(false);
+							dialog.removeAll();
+							dialog.dispose();
+							continueLatch.countDown();
+						}
+						else
+						// if (option.equals(optionWait))
+						{
+							choosers.clear();
+							selection.clear();
+							dialog.setVisible(false);
+							dialog.removeAll();
+							dialog.dispose();
+							try
+							{
+								Thread.sleep(500);
+							} catch (final InterruptedException e2)
+							{
+								e2.printStackTrace();
+							}
+							run();
+						}
 					}
-					choosers.clear();
-					selection.clear();
-					run();
-				}
-				else
-				{
-					for (final Tuple<Territory, UnitChooser> terrChooser : choosers)
-					{
-						selection.put(terrChooser.getFirst(), terrChooser.getSecond().getSelected());
-					}
-					continueLatch.countDown();
-				}
+				});
 			}
 		});
 		try
@@ -997,7 +1084,10 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 			{
 				m_mapPanel.centerOn(current);
 				final JPanel panel = new JPanel();
-				panel.setLayout(new FlowLayout());
+				panel.setLayout(new BorderLayout());
+				final JLabel messageLabel = new JLabel(message);
+				messageLabel.setFont(new Font("Arial", Font.ITALIC, 12));
+				panel.add(messageLabel, BorderLayout.NORTH);
 				JScrollPane chooserScrollPane;
 				final JPanel panelChooser = new JPanel();
 				panelChooser.setLayout(new BoxLayout(panelChooser, BoxLayout.Y_AXIS));
@@ -1012,32 +1102,63 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 				chooser.setMaxAndShowMaxButton(maxAllowed);
 				panelChooser.add(chooser);
 				chooserScrollPane = new JScrollPane(panelChooser);
-				panel.add(chooserScrollPane);
-				final Object[] options = { "Select", "None", "Wait" };
-				final int option = JOptionPane.showOptionDialog(getParent(), panel, "Select units" + message, JOptionPane.YES_NO_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, null, options, options[2]);
-				if (option == JOptionPane.NO_OPTION)
+				panel.add(chooserScrollPane, BorderLayout.CENTER);
+				final String optionSelect = "Select";
+				final String optionNone = "None";
+				final String optionWait = "Wait";
+				final Object[] options = { optionSelect, optionNone, optionWait };
+				final JOptionPane optionPane = new JOptionPane(panel, JOptionPane.PLAIN_MESSAGE, JOptionPane.YES_NO_CANCEL_OPTION, null, options, options[2]);
+				final JDialog dialog = new JDialog((Frame) getParent(), message);
+				dialog.setContentPane(optionPane);
+				dialog.setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
+				dialog.setLocationRelativeTo(getParent());
+				dialog.setAlwaysOnTop(true);
+				dialog.pack();
+				dialog.setVisible(true);
+				dialog.requestFocusInWindow();
+				// final int option = JOptionPane.showOptionDialog(getParent(), panel, message, JOptionPane.YES_NO_CANCEL_OPTION, JOptionPane.PLAIN_MESSAGE, null, options, options[2]);
+				optionPane.addPropertyChangeListener(new PropertyChangeListener()
 				{
-					selection.clear();
-					continueLatch.countDown();
-					return;
-				}
-				else if (option == JOptionPane.CANCEL_OPTION)
-				{
-					try
+					public void propertyChange(final PropertyChangeEvent e)
 					{
-						Thread.sleep(6000);
-					} catch (final InterruptedException e)
-					{
-						e.printStackTrace();
+						if (!dialog.isVisible())
+							return;
+						final String option = ((String) optionPane.getValue());
+						if (option.equals(optionNone))
+						{
+							selection.clear();
+							dialog.setVisible(false);
+							dialog.removeAll();
+							dialog.dispose();
+							continueLatch.countDown();
+							return;
+						}
+						else if (option.equals(optionSelect))
+						{
+							selection.addAll(chooser.getSelected());
+							dialog.setVisible(false);
+							dialog.removeAll();
+							dialog.dispose();
+							continueLatch.countDown();
+						}
+						else
+						// if (option.equals(optionWait))
+						{
+							selection.clear();
+							dialog.setVisible(false);
+							dialog.removeAll();
+							dialog.dispose();
+							try
+							{
+								Thread.sleep(500);
+							} catch (final InterruptedException e2)
+							{
+								e2.printStackTrace();
+							}
+							run();
+						}
 					}
-					selection.clear();
-					run();
-				}
-				else
-				{
-					selection.addAll(chooser.getSelected());
-					continueLatch.countDown();
-				}
+				});
 			}
 		});
 		try
@@ -1160,7 +1281,7 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 			return false;
 		for (final IGamePlayer gamePlayer : m_localPlayers)
 		{
-			if (gamePlayer.getID().equals(id) && gamePlayer instanceof TripleAPlayer)
+			if (gamePlayer.getPlayerID().equals(id) && gamePlayer instanceof TripleAPlayer)
 			{
 				return true;
 			}
@@ -1450,6 +1571,8 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 		final JPopupMenu popup = new JPopupMenu();
 		popup.add(new AbstractAction("Show Summary Log")
 		{
+			private static final long serialVersionUID = -6730966512179268157L;
+			
 			public void actionPerformed(final ActionEvent ae)
 			{
 				final HistoryLog historyLog = new HistoryLog();
@@ -1462,6 +1585,8 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 		});
 		popup.add(new AbstractAction("Show Detailed Log")
 		{
+			private static final long serialVersionUID = -8709762764495294671L;
+			
 			public void actionPerformed(final ActionEvent ae)
 			{
 				final HistoryLog historyLog = new HistoryLog();
@@ -1474,6 +1599,8 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 		});
 		popup.add(new AbstractAction("Save Screenshot")
 		{
+			private static final long serialVersionUID = 1222760138263428443L;
+			
 			public void actionPerformed(final ActionEvent ae)
 			{
 				saveScreenshot(m_historyPanel.getCurrentPopupNode());
@@ -1710,6 +1837,8 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 				// create a custom renderer that paints selected cells transparently
 				final DefaultTableCellRenderer renderer = new DefaultTableCellRenderer()
 				{
+					private static final long serialVersionUID = 1978774284876746635L;
+					
 					{
 						setOpaque(false);
 					}
@@ -1916,6 +2045,8 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 	
 	private AbstractAction m_showCommentLogAction = new AbstractAction()
 	{
+		private static final long serialVersionUID = 3964381772343872268L;
+		
 		public void actionPerformed(final ActionEvent ae)
 		{
 			if (((ButtonModel) ae.getSource()).isSelected())
@@ -1966,6 +2097,8 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 	};
 	private AbstractAction m_showHistoryAction = new AbstractAction("Show history")
 	{
+		private static final long serialVersionUID = -3960551522512897374L;
+		
 		public void actionPerformed(final ActionEvent e)
 		{
 			showHistory();
@@ -1974,6 +2107,8 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 	};
 	private AbstractAction m_showGameAction = new AbstractAction("Show current game")
 	{
+		private static final long serialVersionUID = -7551760679570164254L;
+		
 		{
 			setEnabled(false);
 		}
@@ -1986,6 +2121,8 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 	};
 	private AbstractAction m_showMapOnlyAction = new AbstractAction("Show map only")
 	{
+		private static final long serialVersionUID = -6621157075878333141L;
+		
 		public void actionPerformed(final ActionEvent e)
 		{
 			showMapOnly();
@@ -1994,6 +2131,8 @@ public class TripleAFrame extends MainGameFrame // extends JFrame
 	};
 	private final AbstractAction m_saveScreenshotAction = new AbstractAction("Export Screenshot...")
 	{
+		private static final long serialVersionUID = -5908032486008953815L;
+		
 		public void actionPerformed(final ActionEvent e)
 		{
 			HistoryNode curNode = null;
