@@ -39,6 +39,7 @@ import games.strategy.triplea.delegate.EndRoundDelegate;
 import games.strategy.triplea.image.TileImageFactory;
 import games.strategy.triplea.oddsCalculator.ta.OddsCalculatorDialog;
 import games.strategy.triplea.printgenerator.SetupFrame;
+import games.strategy.triplea.ui.screen.IDrawable.OptionalExtraBorderLevel;
 import games.strategy.triplea.util.PlayerOrderComparator;
 import games.strategy.ui.IntTextField;
 import games.strategy.util.EventThreadJOptionPane;
@@ -71,7 +72,6 @@ import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-import java.util.TreeSet;
 import java.util.Vector;
 
 import javax.swing.AbstractAction;
@@ -92,6 +92,7 @@ import javax.swing.JMenuBar;
 import javax.swing.JMenuItem;
 import javax.swing.JOptionPane;
 import javax.swing.JPanel;
+import javax.swing.JRadioButton;
 import javax.swing.JRadioButtonMenuItem;
 import javax.swing.JScrollPane;
 import javax.swing.JSpinner;
@@ -99,6 +100,8 @@ import javax.swing.JTextField;
 import javax.swing.LookAndFeel;
 import javax.swing.SpinnerNumberModel;
 import javax.swing.UIManager;
+import javax.swing.event.MenuEvent;
+import javax.swing.event.MenuListener;
 import javax.swing.plaf.metal.MetalLookAndFeel;
 import javax.swing.tree.DefaultMutableTreeNode;
 
@@ -109,9 +112,9 @@ import javax.swing.tree.DefaultMutableTreeNode;
  * @author sgb
  * 
  */
-@SuppressWarnings("serial")
 public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 {
+	private static final long serialVersionUID = 987243661147503593L;
 	private JCheckBoxMenuItem showMapDetails;
 	private JCheckBoxMenuItem showMapBlends;
 	
@@ -139,6 +142,8 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 	{
 		parentMenu.add(new AbstractAction("Movement/Selection help...")
 		{
+			private static final long serialVersionUID = 6388976622644695135L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				// html formatted string
@@ -238,6 +243,7 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 		addMapSkinsMenu(menuView);
 		addShowMapDetails(menuView);
 		addShowMapBlends(menuView);
+		addDrawTerritoryBordersAgain(menuView);
 		addChatTimeMenu(menuView);
 		addShowCommentLog(menuView);
 		// The menuItem to turn TabbedProduction on or off
@@ -252,6 +258,78 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 		return version.indexOf("1.5") == -1;
 	}
 	
+	private static boolean isJavaGreatThan6()
+	{
+		final String version = System.getProperties().getProperty("java.version");
+		return version.indexOf("1.5") == -1 && version.indexOf("1.6") == -1;
+	}
+	
+	public static List<String> getLookAndFeelAvailableList()
+	{
+		final List<String> substanceLooks = new ArrayList<String>(Arrays.asList(new String[] {
+					UIManager.getSystemLookAndFeelClassName(),
+					MetalLookAndFeel.class.getName(),
+					UIManager.getCrossPlatformLookAndFeelClassName()
+		}));
+		if (isJavaGreatThan5())
+		{
+			substanceLooks.addAll(new ArrayList<String>(Arrays.asList(new String[] {
+						UIManager.getSystemLookAndFeelClassName(),
+						MetalLookAndFeel.class.getName(),
+						UIManager.getCrossPlatformLookAndFeelClassName(),
+						// Substance 5.x
+						"org.jvnet.substance.skin.SubstanceAutumnLookAndFeel",
+						"org.jvnet.substance.skin.SubstanceChallengerDeepLookAndFeel",
+						"org.jvnet.substance.skin.SubstanceCremeCoffeeLookAndFeel",
+						"org.jvnet.substance.skin.SubstanceCremeLookAndFeel",
+						"org.jvnet.substance.skin.SubstanceDustCoffeeLookAndFeel",
+						"org.jvnet.substance.skin.SubstanceDustLookAndFeel",
+						"org.jvnet.substance.skin.SubstanceEmeraldDuskLookAndFeel",
+						"org.jvnet.substance.skin.SubstanceMagmaLookAndFeel",
+						"org.jvnet.substance.skin.SubstanceMistAquaLookAndFeel",
+						"org.jvnet.substance.skin.SubstanceModerateLookAndFeel",
+						"org.jvnet.substance.skin.SubstanceNebulaLookAndFeel",
+						"org.jvnet.substance.skin.SubstanceRavenGraphiteGlassLookAndFeel",
+						"org.jvnet.substance.skin.SubstanceRavenGraphiteLookAndFeel",
+						"org.jvnet.substance.skin.SubstanceRavenLookAndFeel",
+						"org.jvnet.substance.skin.SubstanceTwilightLookAndFeel"
+
+			/* Substance (insubstantial) 7.x
+			"org.pushingpixels.substance.api.skin.SubstanceAutumnLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceBusinessBlackSteelLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceBusinessBlueSteelLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceBusinessLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceCeruleanLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceChallengerDeepLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceCremeCoffeeLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceCremeLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceDustCoffeeLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceDustLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceEmeraldDuskLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceGeminiLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceGraphiteAquaLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceGraphiteGlassLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceGraphiteLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceMagellanLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceMarinerLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceMistAquaLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceMistSilverLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceModerateLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceNebulaBrickWallLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceNebulaLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceOfficeBlack2007LookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceOfficeBlue2007LookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceOfficeSilver2007LookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceRavenLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceSaharaLookAndFeel",
+			"org.pushingpixels.substance.api.skin.SubstanceTwilightLookAndFeel"*/
+			})));
+		}
+		if (isJavaGreatThan6())
+			substanceLooks.add("javax.swing.plaf.nimbus.NimbusLookAndFeel");
+		return substanceLooks;
+	}
+	
 	/**
 	 * First is our JList, second is our LookAndFeels string -> class map, third is our 'current' look and feel.
 	 * 
@@ -260,32 +338,25 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 	public static Triple<JList, Map<String, String>, String> getLookAndFeelList()
 	{
 		final Map<String, String> lookAndFeels = new LinkedHashMap<String, String>();
-		lookAndFeels.put("Original", UIManager.getSystemLookAndFeelClassName());
-		lookAndFeels.put("Metal", MetalLookAndFeel.class.getName());
-		lookAndFeels.put("Platform Independent", UIManager.getCrossPlatformLookAndFeelClassName());
-		if (isJavaGreatThan5())
+		try
 		{
-			try
+			final List<String> substanceLooks = getLookAndFeelAvailableList();
+			for (final String s : substanceLooks)
 			{
-				final List<String> substanceLooks = Arrays.asList(new String[] { "org.jvnet.substance.skin.SubstanceAutumnLookAndFeel",
-							"org.jvnet.substance.skin.SubstanceChallengerDeepLookAndFeel", "org.jvnet.substance.skin.SubstanceCremeCoffeeLookAndFeel",
-							"org.jvnet.substance.skin.SubstanceCremeLookAndFeel", "org.jvnet.substance.skin.SubstanceDustCoffeeLookAndFeel",
-							"org.jvnet.substance.skin.SubstanceDustLookAndFeel", "org.jvnet.substance.skin.SubstanceEmeraldDuskLookAndFeel",
-							"org.jvnet.substance.skin.SubstanceMagmaLookAndFeel", "org.jvnet.substance.skin.SubstanceMistAquaLookAndFeel",
-							"org.jvnet.substance.skin.SubstanceModerateLookAndFeel", "org.jvnet.substance.skin.SubstanceNebulaLookAndFeel",
-							"org.jvnet.substance.skin.SubstanceRavenGraphiteGlassLookAndFeel", "org.jvnet.substance.skin.SubstanceRavenGraphiteLookAndFeel",
-							"org.jvnet.substance.skin.SubstanceRavenLookAndFeel", "org.jvnet.substance.skin.SubstanceTwilightLookAndFeel", });
-				for (final String s : substanceLooks)
-				{
-					@SuppressWarnings("rawtypes")
-					final Class c = Class.forName(s);
-					final LookAndFeel lf = (LookAndFeel) c.newInstance();
-					lookAndFeels.put(lf.getName(), s);
-				}
-			} catch (final Exception t)
-			{
-				t.printStackTrace();
+				@SuppressWarnings("rawtypes")
+				final Class c = Class.forName(s);
+				final LookAndFeel lf = (LookAndFeel) c.newInstance();
+				lookAndFeels.put(lf.getName(), s);
 			}
+			
+		} catch (final Exception t)
+		{
+			t.printStackTrace();
+			// we know all machines have these 3, so use them
+			lookAndFeels.clear();
+			lookAndFeels.put("Original", UIManager.getSystemLookAndFeelClassName());
+			lookAndFeels.put("Metal", MetalLookAndFeel.class.getName());
+			lookAndFeels.put("Platform Independent", UIManager.getCrossPlatformLookAndFeelClassName());
 		}
 		final JList list = new JList(new Vector<String>(lookAndFeels.keySet()));
 		String currentKey = null;
@@ -306,6 +377,8 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 	{
 		menuView.add(new AbstractAction("Set Look and Feel...")
 		{
+			private static final long serialVersionUID = 379919988820952164L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				final Triple<JList, Map<String, String>, String> lookAndFeel = getLookAndFeelList();
@@ -334,6 +407,8 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 	{
 		menuView.add(new AbstractAction("Game UUID...")
 		{
+			private static final long serialVersionUID = 119615303846107510L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				final String id = (String) getData().getProperties().get(GameData.GAME_UUID);
@@ -378,6 +453,8 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 	{
 		final Action mapZoom = new AbstractAction("Map Zoom...")
 		{
+			private static final long serialVersionUID = 1114072913279994047L;
+			
 			public void actionPerformed(final ActionEvent arg0)
 			{
 				final SpinnerNumberModel model = new SpinnerNumberModel();
@@ -445,6 +522,8 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 	{
 		final Action showVerifiedDice = new AbstractAction("Show Verified Dice..")
 		{
+			private static final long serialVersionUID = -2753073276162734526L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				new VerifiedRandomNumbersDialog(m_frame.getRootPane()).setVisible(true);
@@ -481,6 +560,8 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 		showEnemyCasualties.setSelected(BattleDisplay.getShowEnemyCasualtyNotification());
 		showEnemyCasualties.addActionListener(new AbstractAction()
 		{
+			private static final long serialVersionUID = -7445092411530581715L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				BattleDisplay.setShowEnemyCasualtyNotification(showEnemyCasualties.isSelected());
@@ -495,6 +576,8 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 		tabbedProduction.setSelected(PurchasePanel.isTabbedProduction());
 		tabbedProduction.addActionListener(new AbstractAction()
 		{
+			private static final long serialVersionUID = -352890957050498753L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				PurchasePanel.setTabbedProduction(tabbedProduction.isSelected());
@@ -512,6 +595,8 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 		{
 			final AbstractAction optionsAction = new AbstractAction("View Game Options...")
 			{
+				private static final long serialVersionUID = 8937205081994328616L;
+				
 				public void actionPerformed(final ActionEvent e)
 				{
 					final PropertiesUI ui = new PropertiesUI(getGame().getData().getProperties().getEditableProperties(), false);
@@ -532,6 +617,8 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 	{
 		final AbstractAction politicsAction = new AbstractAction("Show Politics Panel")
 		{
+			private static final long serialVersionUID = 7880136597816371478L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				final PoliticalStateOverview ui = new PoliticalStateOverview(getData(), getUIContext());
@@ -567,6 +654,77 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 		parentMenu.add(showUnitsBox);
 	}
 	
+	private void addDrawTerritoryBordersAgain(final JMenu parentMenu)
+	{
+		final JMenu drawBordersMenu = new JMenu();
+		drawBordersMenu.setText("Draw Borders On Top");
+		final JRadioButton noneButton = new JRadioButton("Low");
+		final JRadioButton mediumButton = new JRadioButton("Medium");
+		final JRadioButton highButton = new JRadioButton("High");
+		final ButtonGroup group = new ButtonGroup();
+		group.add(noneButton);
+		group.add(mediumButton);
+		group.add(highButton);
+		drawBordersMenu.addMenuListener(new MenuListener()
+		{
+			public void menuSelected(final MenuEvent e)
+			{
+				final OptionalExtraBorderLevel current = getUIContext().getDrawTerritoryBordersAgain();
+				if (current == OptionalExtraBorderLevel.LOW)
+					noneButton.setSelected(true);
+				else if (current == OptionalExtraBorderLevel.MEDIUM)
+					mediumButton.setSelected(true);
+				else if (current == OptionalExtraBorderLevel.HIGH)
+					highButton.setSelected(true);
+			}
+			
+			public void menuDeselected(final MenuEvent e)
+			{
+			}
+			
+			public void menuCanceled(final MenuEvent e)
+			{
+			}
+		});
+		noneButton.addActionListener(new ActionListener()
+		{
+			public void actionPerformed(final ActionEvent e)
+			{
+				if (noneButton.isSelected() && getUIContext().getDrawTerritoryBordersAgain() != OptionalExtraBorderLevel.LOW)
+				{
+					getUIContext().setDrawTerritoryBordersAgain(OptionalExtraBorderLevel.LOW);
+					m_frame.getMapPanel().resetMap();
+				}
+			}
+		});
+		mediumButton.addActionListener(new ActionListener()
+		{
+			public void actionPerformed(final ActionEvent e)
+			{
+				if (mediumButton.isSelected() && getUIContext().getDrawTerritoryBordersAgain() != OptionalExtraBorderLevel.MEDIUM)
+				{
+					getUIContext().setDrawTerritoryBordersAgain(OptionalExtraBorderLevel.MEDIUM);
+					m_frame.getMapPanel().resetMap();
+				}
+			}
+		});
+		highButton.addActionListener(new ActionListener()
+		{
+			public void actionPerformed(final ActionEvent e)
+			{
+				if (highButton.isSelected() && getUIContext().getDrawTerritoryBordersAgain() != OptionalExtraBorderLevel.HIGH)
+				{
+					getUIContext().setDrawTerritoryBordersAgain(OptionalExtraBorderLevel.HIGH);
+					m_frame.getMapPanel().resetMap();
+				}
+			}
+		});
+		drawBordersMenu.add(noneButton);
+		drawBordersMenu.add(mediumButton);
+		drawBordersMenu.add(highButton);
+		parentMenu.add(drawBordersMenu);
+	}
+	
 	private void addShowTerritoryEffects(final JMenu parentMenu)
 	{
 		final JCheckBoxMenuItem territoryEffectsBox = new JCheckBoxMenuItem("Show TerritoryEffects");
@@ -633,6 +791,8 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 			parentMenu.addSeparator();
 			parentMenu.add(new AbstractAction("Change Dynamix AI Settings")
 			{
+				private static final long serialVersionUID = 2257295609477283292L;
+				
 				public void actionPerformed(final ActionEvent e)
 				{
 					Dynamix_AI.ShowSettingsWindow();
@@ -675,27 +835,13 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 	{
 		final Action showDiceStats = new AbstractAction("Show Dice Stats...")
 		{
+			private static final long serialVersionUID = 5530880208301800861L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				final IRandomStats randomStats = (IRandomStats) getGame().getRemoteMessenger().getRemote(IRandomStats.RANDOM_STATS_REMOTE_NAME);
-				final RandomStatsDetails stats = randomStats.getRandomStats();
-				final JPanel panel = new JPanel();
-				final BoxLayout layout = new BoxLayout(panel, BoxLayout.Y_AXIS);
-				panel.setLayout(layout);
-				for (final Integer key : new TreeSet<Integer>(stats.getData().keySet()))
-				{
-					final int value = stats.getData().getInt(key);
-					final JLabel label = new JLabel(key + " was rolled " + value + " times");
-					panel.add(label);
-				}
-				panel.add(new JLabel("  "));
-				final DecimalFormat format = new DecimalFormat("#0.000");
-				panel.add(new JLabel("Average roll : " + format.format(stats.getAverage())));
-				panel.add(new JLabel("Median : " + format.format(stats.getMedian())));
-				panel.add(new JLabel("Variance : " + format.format(stats.getVariance())));
-				panel.add(new JLabel("Standard Deviation : " + format.format(stats.getStdDeviation())));
-				panel.add(new JLabel("Total rolls : " + stats.getTotal()));
-				JOptionPane.showMessageDialog(m_frame, panel, "Random Stats", JOptionPane.INFORMATION_MESSAGE);
+				final RandomStatsDetails stats = randomStats.getRandomStats(getData().getDiceSides());
+				JOptionPane.showMessageDialog(m_frame, new JScrollPane(stats.getAllStats()), "Random Stats", JOptionPane.INFORMATION_MESSAGE);
 			}
 		};
 		parentMenu.add(showDiceStats);
@@ -752,6 +898,8 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 	{
 		final Action showBattleMenu = new AbstractAction("Battle Calculator...")
 		{
+			private static final long serialVersionUID = 6211814774301020553L;
+			
 			public void actionPerformed(final ActionEvent arg0)
 			{
 				OddsCalculatorDialog.show(m_frame, null);
@@ -765,14 +913,13 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 	{
 		final Action exportXML = new AbstractAction("Export game.xml file (Beta)...")
 		{
+			private static final long serialVersionUID = 8379478036021948990L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				exportXMLFile();
 			}
 			
-			/**
-             *
-             */
 			private void exportXMLFile()
 			{
 				final JFileChooser chooser = new JFileChooser();
@@ -814,6 +961,8 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 	{
 		final Action showDiceStats = new AbstractAction("Export Full Game Stats...")
 		{
+			private static final long serialVersionUID = -1732417863580400806L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				createAndSaveStats(true);
@@ -829,6 +978,8 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 	{
 		final Action showDiceStats = new AbstractAction("Export Short Game Stats...")
 		{
+			private static final long serialVersionUID = 8196345604657706754L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				createAndSaveStats(false);
@@ -1233,6 +1384,8 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 	{
 		final JMenuItem menuFileExport = new JMenuItem(new AbstractAction("Export Setup Charts...")
 		{
+			private static final long serialVersionUID = 1596267069546601864L;
+			
 			public void actionPerformed(final ActionEvent e)
 			{
 				final JFrame frame = new JFrame("Export Setup Files");
@@ -1266,6 +1419,7 @@ public class TripleaMenu extends BasicGameMenuBar<TripleAFrame>
 		// This is the action listener used
 		class UnitSizeAction extends AbstractAction
 		{
+			private static final long serialVersionUID = -6280511505686687867L;
 			private final double m_scaleFactor;
 			
 			public UnitSizeAction(final double scaleFactor)
