@@ -8,10 +8,13 @@ import games.strategy.engine.history.HistoryNode;
 import games.strategy.engine.history.Renderable;
 import games.strategy.engine.history.Round;
 import games.strategy.engine.history.Step;
+import games.strategy.engine.random.IRandomStats;
+import games.strategy.engine.random.RandomStatsDetails;
 import games.strategy.triplea.Constants;
 import games.strategy.triplea.attatchments.TerritoryAttachment;
 import games.strategy.triplea.delegate.DiceRoll;
 import games.strategy.triplea.delegate.Matches;
+import games.strategy.triplea.delegate.MoveDelegate;
 import games.strategy.triplea.delegate.OriginalOwnerTracker;
 import games.strategy.triplea.delegate.dataObjects.MoveDescription;
 import games.strategy.triplea.formatter.MyFormatter;
@@ -37,13 +40,14 @@ import javax.swing.tree.TreePath;
 
 public class HistoryLog extends JFrame
 {
+	private static final long serialVersionUID = 4880602702815333376L;
 	private final JTextArea m_textArea;
 	private final StringWriter m_stringWriter;
 	private final PrintWriter m_printWriter;
 	
 	public HistoryLog()
 	{
-		m_textArea = new JTextArea(50, 50);
+		m_textArea = new JTextArea(40, 80);
 		m_textArea.setEditable(false);
 		final JScrollPane scrollingArea = new JScrollPane(m_textArea);
 		// ... Get the content pane, set layout, add to center
@@ -165,9 +169,10 @@ public class HistoryLog extends JFrame
 				if (node instanceof Renderable)
 				{
 					final Object details = ((Renderable) node).getRenderingData();
-					// flush move list
-					// support conquering territory on combat move
-					if (moving && !(details instanceof MoveDescription || title.matches("\\w+ takes? .*? from \\w+")))
+					
+					// TODO: why is this here when the one above seems to take care of it just fine? I am commenting out because it is causing MAJOR issues with PBEM posts (fatal error, because if the person does some moves, then for example turns on edit mode and does something then turns it off, then later undo's a move, and the move list is now empty, then we are have a fatal crash at end of the turn when we try to make the history post)
+					// flush move list (but support conquering territory on combat move)
+					/*if (moving && (title.equals(MoveDelegate.CLEANING_UP_AFTER_MOVEMENT_PHASES)) && !(details instanceof MoveDescription)) // && !title.matches("\\w+ takes? .*? from \\w+") && !title.indexOf(EditDelegate.EDITMODE_ON) != -1 && title.indexOf(EditDelegate.EDITMODE_OFF) != -1))
 					{
 						final Iterator<String> moveIter = moveList.iterator();
 						while (moveIter.hasNext())
@@ -176,7 +181,7 @@ public class HistoryLog extends JFrame
 							moveIter.remove();
 						}
 						moving = false;
-					}
+					}*/
 					if (details instanceof DiceRoll)
 					{
 						if (!verbose)
@@ -313,7 +318,28 @@ public class HistoryLog extends JFrame
 						if (title.equals("Adding original owners"))
 						{
 						}
-						else if (title.equals("Cleaning up after movement phases"))
+						else if (title.equals(MoveDelegate.CLEANING_UP_AFTER_MOVEMENT_PHASES))
+						{
+						}
+						else if (title.equals("Game Loaded"))
+						{
+						}
+						else if (title.indexOf("now being played by") != -1)
+						{
+						}
+						else if (title.indexOf("Turn Summary") != -1 || title.indexOf("Move Summary") != -1)
+						{
+						}
+						else if (title.indexOf("Setting uses for triggers used") != -1)
+						{
+						}
+						else if (title.equals("Giving bonus movement to units"))
+						{
+						}
+						else if (title.equals("Recording Battle Statistics"))
+						{
+						}
+						else if (title.equals("Preparing Airbases for Possible Scrambling"))
 						{
 						}
 						else if (title.matches("\\w+ collect \\d+ PUs?.*"))
@@ -393,6 +419,18 @@ public class HistoryLog extends JFrame
 			} // while (nodeEnum.hasMoreElements())
 			curNode = curNode.getNextSibling();
 		} while ((curNode instanceof Step) && ((Step) curNode).getPlayerID().equals(curPlayer));
+		// if we are mid-phase, this might not get flushed
+		if (moving && !moveList.isEmpty())
+		{
+			final Iterator<String> moveIter = moveList.iterator();
+			while (moveIter.hasNext())
+			{
+				logWriter.println(moveIter.next());
+				moveIter.remove();
+			}
+			moving = false;
+		}
+		logWriter.println();
 		logWriter.println();
 		m_textArea.setText(m_stringWriter.toString());
 	}
@@ -422,17 +460,34 @@ public class HistoryLog extends JFrame
 			if (t == null || ta == null)
 				hasFlag = false;
 			else
-				hasFlag = t.getOwner().equals(player) && !ta.getOriginalOwner().equals(player);
+				hasFlag = t.getOwner() != null && t.getOwner().equals(player) && (ta.getOriginalOwner() == null || !ta.getOriginalOwner().equals(player));
 			if (hasFlag || !ownedUnits.isEmpty())
 			{
 				logWriter.print("    " + t.getName() + " : ");
-				if (hasFlag)
+				if (hasFlag && ownedUnits.isEmpty())
+					logWriter.println("1 flag");
+				else
 					logWriter.print("1 flag, ");
 				if (!ownedUnits.isEmpty())
 					logWriter.println(MyFormatter.unitsToTextNoOwner(ownedUnits));
 			}
 		}
 		logWriter.println();
+		logWriter.println();
+		m_textArea.setText(m_stringWriter.toString());
+	}
+	
+	public void printDiceStatistics(final GameData data, final IRandomStats randomStats)
+	{
+		final PrintWriter logWriter = m_printWriter;
+		final RandomStatsDetails stats = randomStats.getRandomStats(data.getDiceSides());
+		final String diceStats = stats.getAllStatsString("    ");
+		if (diceStats.length() > 0)
+		{
+			logWriter.println(diceStats);
+			logWriter.println();
+			logWriter.println();
+		}
 		m_textArea.setText(m_stringWriter.toString());
 	}
 	
@@ -456,6 +511,7 @@ public class HistoryLog extends JFrame
 			logWriter.println("    " + player.getName() + " : " + production + " / " + PUs);
 		}
 		logWriter.println();
+		logWriter.println();
 		m_textArea.setText(m_stringWriter.toString());
 	}
 	
