@@ -23,6 +23,7 @@ import games.strategy.triplea.attatchments.TerritoryAttachment;
 import games.strategy.triplea.delegate.TerritoryEffectHelper;
 import games.strategy.triplea.ui.MapData;
 import games.strategy.triplea.ui.UIContext;
+import games.strategy.triplea.ui.screen.IDrawable.OptionalExtraBorderLevel;
 import games.strategy.triplea.ui.screen.TerritoryOverLayDrawable.OP;
 import games.strategy.triplea.util.UnitCategory;
 import games.strategy.triplea.util.UnitSeperator;
@@ -36,6 +37,7 @@ import java.awt.Image;
 import java.awt.Point;
 import java.awt.Polygon;
 import java.awt.Rectangle;
+import java.awt.RenderingHints;
 import java.awt.geom.Rectangle2D;
 import java.util.ArrayList;
 import java.util.Collection;
@@ -286,6 +288,11 @@ public class TileManager
 			}
 			drawing.add(new SeaZoneOutlineDrawable(territory.getName()));
 		}
+		final OptionalExtraBorderLevel optionalBorderLevel = m_uiContext.getDrawTerritoryBordersAgain();
+		if (optionalBorderLevel != OptionalExtraBorderLevel.LOW)
+		{
+			drawing.add(new OptionalExtraTerritoryBordersDrawable(territory.getName(), optionalBorderLevel));
+		}
 		drawing.add(new TerritoryNameDrawable(territory.getName(), m_uiContext));
 		final TerritoryAttachment ta = TerritoryAttachment.get(territory);
 		if (ta != null && ta.isCapital() && mapData.drawCapitolMarkers())
@@ -455,6 +462,9 @@ public class TileManager
 				throw new IllegalStateException("NOt equal");
 			final Image rVal = Util.createImage(bounds.width, bounds.height, false);
 			final Graphics2D graphics = (Graphics2D) rVal.getGraphics();
+			graphics.setRenderingHint(RenderingHints.KEY_RENDERING, RenderingHints.VALUE_RENDER_QUALITY);
+			graphics.setRenderingHint(RenderingHints.KEY_ALPHA_INTERPOLATION, RenderingHints.VALUE_ALPHA_INTERPOLATION_QUALITY);
+			graphics.setRenderingHint(RenderingHints.KEY_INTERPOLATION, RenderingHints.VALUE_INTERPOLATION_BICUBIC);
 			if (bounds.x < 0)
 			{
 				bounds.x += mapData.getMapDimensions().width;
