@@ -80,6 +80,16 @@ public class ValidateAttachmentsTest extends TestCase
 		assertTrue(errors.contains("doesn't have a clear method"));
 	}
 	
+	/**
+	 * Tests that the algorithm will find invalid clear method
+	 */
+	public void testInvalidResetMethod()
+	{
+		final String errors = validateAttachment(InvalidResetExample.class);
+		assertTrue(errors.length() > 0);
+		assertTrue(errors.contains("doesn't have a resetter method"));
+	}
+	
 	/**
 	 * Tests that the algorithm will find adders that doesn't have type IntegerMap
 	 */
@@ -115,6 +125,7 @@ public class ValidateAttachmentsTest extends TestCase
 		sb.append(validateAttachment(games.strategy.triplea.attatchments.TriggerAttachment.class));
 		sb.append(validateAttachment(games.strategy.triplea.attatchments.UnitAttachment.class));
 		sb.append(validateAttachment(games.strategy.triplea.attatchments.UnitSupportAttachment.class));
+		sb.append(validateAttachment(games.strategy.triplea.attatchments.TechAbilityAttachment.class));
 		if (sb.toString().length() > 0)
 		{
 			System.out.println(sb.toString());
@@ -311,6 +322,21 @@ public class ValidateAttachmentsTest extends TestCase
 				continue;
 			}
 			
+			final String resetterName = "reset" + capitalizeFirstLetter(propertyName);
+			Method resetterMethod = null;
+			try
+			{
+				resetterMethod = clazz.getMethod(resetterName);
+				if (!resetterMethod.getReturnType().equals(void.class))
+				{
+					sb.append("Class " + clazz.getCanonicalName() + " has a reset method " + resetterMethod.getName() + " that doesn't return void\n");
+				}
+			} catch (final NoSuchMethodException e)
+			{
+				sb.append("Class " + clazz.getCanonicalName() + " doesn't have a resetter method for property: " + propertyName + "\n");
+				continue;
+			}
+			
 			final String getterName = "get" + capitalizeFirstLetter(propertyName);
 			try
 			{
