@@ -6,6 +6,7 @@ import games.strategy.engine.data.GameData;
 import games.strategy.engine.data.ITestDelegateBridge;
 import games.strategy.engine.data.PlayerID;
 import games.strategy.engine.data.Territory;
+import games.strategy.engine.data.TerritoryEffect;
 import games.strategy.engine.data.Unit;
 import games.strategy.engine.data.UnitType;
 import games.strategy.engine.data.properties.BooleanProperty;
@@ -17,7 +18,9 @@ import games.strategy.triplea.attatchments.TechAttachment;
 import games.strategy.triplea.attatchments.UnitAttachment;
 import games.strategy.triplea.delegate.Die.DieType;
 import games.strategy.triplea.xml.LoadGameUtil;
+import games.strategy.util.Match;
 
+import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
 
@@ -52,21 +55,22 @@ public class DiceRollTest extends TestCase
 		final ITestDelegateBridge bridge = getDelegateBridge(russians);
 		final UnitType infantryType = m_data.getUnitTypeList().getUnitType("infantry");
 		final List<Unit> infantry = infantryType.create(1, russians);
+		final Collection<TerritoryEffect> territoryEffects = TerritoryEffectHelper.getEffects(westRussia);
 		// infantry defends and hits at 1 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 1 }));
-		final DiceRoll roll = DiceRoll.rollDice(infantry, true, russians, bridge, battle, "");
+		final DiceRoll roll = DiceRoll.rollDice(infantry, true, russians, bridge, battle, "", territoryEffects);
 		assertEquals(1, roll.getHits());
 		// infantry does not hit at 2 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 2 }));
-		final DiceRoll roll2 = DiceRoll.rollDice(infantry, true, russians, bridge, battle, "");
+		final DiceRoll roll2 = DiceRoll.rollDice(infantry, true, russians, bridge, battle, "", territoryEffects);
 		assertEquals(0, roll2.getHits());
 		// infantry attacks and hits at 0 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 0 }));
-		final DiceRoll roll3 = DiceRoll.rollDice(infantry, false, russians, bridge, battle, "");
+		final DiceRoll roll3 = DiceRoll.rollDice(infantry, false, russians, bridge, battle, "", territoryEffects);
 		assertEquals(1, roll3.getHits());
 		// infantry attack does not hit at 1 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 1 }));
-		final DiceRoll roll4 = DiceRoll.rollDice(infantry, false, russians, bridge, battle, "");
+		final DiceRoll roll4 = DiceRoll.rollDice(infantry, false, russians, bridge, battle, "", territoryEffects);
 		assertEquals(0, roll4.getHits());
 	}
 	
@@ -79,21 +83,22 @@ public class DiceRollTest extends TestCase
 		final ITestDelegateBridge bridge = getDelegateBridge(russians);
 		final UnitType infantryType = m_data.getUnitTypeList().getUnitType("infantry");
 		final List<Unit> infantry = infantryType.create(1, russians);
+		final Collection<TerritoryEffect> territoryEffects = TerritoryEffectHelper.getEffects(westRussia);
 		// infantry defends and hits at 1 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 1 }));
-		final DiceRoll roll = DiceRoll.rollDice(infantry, true, russians, bridge, battle, "");
+		final DiceRoll roll = DiceRoll.rollDice(infantry, true, russians, bridge, battle, "", territoryEffects);
 		assertEquals(1, roll.getHits());
 		// infantry does not hit at 2 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 2 }));
-		final DiceRoll roll2 = DiceRoll.rollDice(infantry, true, russians, bridge, battle, "");
+		final DiceRoll roll2 = DiceRoll.rollDice(infantry, true, russians, bridge, battle, "", territoryEffects);
 		assertEquals(0, roll2.getHits());
 		// infantry attacks and hits at 0 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 0 }));
-		final DiceRoll roll3 = DiceRoll.rollDice(infantry, false, russians, bridge, battle, "");
+		final DiceRoll roll3 = DiceRoll.rollDice(infantry, false, russians, bridge, battle, "", territoryEffects);
 		assertEquals(1, roll3.getHits());
 		// infantry attack does not hit at 1 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 1 }));
-		final DiceRoll roll4 = DiceRoll.rollDice(infantry, false, russians, bridge, battle, "");
+		final DiceRoll roll4 = DiceRoll.rollDice(infantry, false, russians, bridge, battle, "", territoryEffects);
 		assertEquals(0, roll4.getHits());
 	}
 	
@@ -109,7 +114,7 @@ public class DiceRollTest extends TestCase
 		units.addAll(artillery.create(1, russians));
 		// artillery supported infantry and art attack at 1 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 1, 1 }));
-		final DiceRoll roll = DiceRoll.rollDice(units, false, russians, bridge, battle, "");
+		final DiceRoll roll = DiceRoll.rollDice(units, false, russians, bridge, battle, "", TerritoryEffectHelper.getEffects(westRussia));
 		assertEquals(2, roll.getHits());
 	}
 	
@@ -133,7 +138,7 @@ public class DiceRollTest extends TestCase
 		units.addAll(infantryType.create(2, russians));
 		// artillery supported infantry and art attack at 1 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 1, 1, 1 }));
-		final DiceRoll roll = DiceRoll.rollDice(units, false, russians, bridge, battle, "");
+		final DiceRoll roll = DiceRoll.rollDice(units, false, russians, bridge, battle, "", TerritoryEffectHelper.getEffects(westRussia));
 		assertEquals(3, roll.getHits());
 	}
 	
@@ -148,7 +153,7 @@ public class DiceRollTest extends TestCase
 		final List<Unit> units = infantryType.create(3, russians);
 		// 3 infantry on defense should produce exactly one hit, without rolling the dice
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { ScriptedRandomSource.ERROR }));
-		final DiceRoll roll = DiceRoll.rollDice(units, true, russians, bridge, battle, "");
+		final DiceRoll roll = DiceRoll.rollDice(units, true, russians, bridge, battle, "", TerritoryEffectHelper.getEffects(westRussia));
 		assertEquals(1, roll.getHits());
 	}
 	
@@ -191,7 +196,7 @@ public class DiceRollTest extends TestCase
 		final MockBattle battle = new MockBattle(algeria);
 		battle.setAmphibiousLandAttackers(attackers);
 		battle.setIsAmphibious(true);
-		final DiceRoll roll = DiceRoll.rollDice(attackers, false, americans, bridge, battle, "");
+		final DiceRoll roll = DiceRoll.rollDice(attackers, false, americans, bridge, battle, "", TerritoryEffectHelper.getEffects(algeria));
 		assertEquals(1, roll.getHits());
 	}
 	
@@ -208,7 +213,7 @@ public class DiceRollTest extends TestCase
 		final MockBattle battle = new MockBattle(algeria);
 		battle.setAmphibiousLandAttackers(attackers);
 		battle.setIsAmphibious(true);
-		final DiceRoll roll = DiceRoll.rollDice(attackers, false, americans, bridge, battle, "");
+		final DiceRoll roll = DiceRoll.rollDice(attackers, false, americans, bridge, battle, "", TerritoryEffectHelper.getEffects(algeria));
 		assertEquals(1, roll.getHits());
 	}
 	
@@ -224,7 +229,7 @@ public class DiceRollTest extends TestCase
 		final MockBattle battle = new MockBattle(algeria);
 		battle.setAmphibiousLandAttackers(Collections.<Unit> emptyList());
 		battle.setIsAmphibious(true);
-		final DiceRoll roll = DiceRoll.rollDice(attackers, false, americans, bridge, battle, "");
+		final DiceRoll roll = DiceRoll.rollDice(attackers, false, americans, bridge, battle, "", TerritoryEffectHelper.getEffects(algeria));
 		assertEquals(0, roll.getHits());
 	}
 	
@@ -240,11 +245,11 @@ public class DiceRollTest extends TestCase
 		final List<Unit> bombers = bomber(m_data).create(1, british(m_data));
 		// aa hits at 0 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 0 }));
-		final DiceRoll hit = DiceRoll.rollAA(bomber(m_data).create(1, british(m_data)), aaGunList, UnitAttachment.get(aaGunList.iterator().next().getType()).getTargetsAA(m_data), bridge, westRussia);
+		final DiceRoll hit = DiceRoll.rollAA(bomber(m_data).create(1, british(m_data)), aaGunList, bridge, westRussia);
 		assertEquals(hit.getHits(), 1);
 		// aa missses at 1 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 1 }));
-		final DiceRoll miss = DiceRoll.rollAA(bombers, aaGunList, UnitAttachment.get(aaGunList.iterator().next().getType()).getTargetsAA(m_data), bridge, westRussia);
+		final DiceRoll miss = DiceRoll.rollAA(bombers, aaGunList, bridge, westRussia);
 		assertEquals(miss.getHits(), 0);
 	}
 	
@@ -262,16 +267,19 @@ public class DiceRollTest extends TestCase
 		final ITestDelegateBridge bridge = getDelegateBridge(russians);
 		// aa hits at 0 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 0 }));
-		final DiceRoll hit = DiceRoll.rollAA(fighterList, aaGunList, UnitAttachment.get(aaGunList.iterator().next().getType()).getTargetsAA(m_data), bridge, westRussia);
+		final DiceRoll hit = DiceRoll.rollAA(Match.getMatches(fighterList, Matches.unitIsOfTypes(UnitAttachment.get(aaGunList.iterator().next().getType()).getTargetsAA(m_data))), aaGunList, bridge,
+					westRussia);
 		assertEquals(hit.getHits(), 1);
 		// aa missses at 1 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 1 }));
-		final DiceRoll miss = DiceRoll.rollAA(fighterList, aaGunList, UnitAttachment.get(aaGunList.iterator().next().getType()).getTargetsAA(m_data), bridge, westRussia);
+		final DiceRoll miss = DiceRoll.rollAA(Match.getMatches(fighterList, Matches.unitIsOfTypes(UnitAttachment.get(aaGunList.iterator().next().getType()).getTargetsAA(m_data))), aaGunList, bridge,
+					westRussia);
 		assertEquals(miss.getHits(), 0);
 		// 6 bombers, 1 should hit, and nothing should be rolled
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { ScriptedRandomSource.ERROR }));
 		fighterList = fighterType.create(6, russians);
-		final DiceRoll hitNoRoll = DiceRoll.rollAA(fighterList, aaGunList, UnitAttachment.get(aaGunList.iterator().next().getType()).getTargetsAA(m_data), bridge, westRussia);
+		final DiceRoll hitNoRoll = DiceRoll.rollAA(Match.getMatches(fighterList, Matches.unitIsOfTypes(UnitAttachment.get(aaGunList.iterator().next().getType()).getTargetsAA(m_data))), aaGunList,
+					bridge, westRussia);
 		assertEquals(hitNoRoll.getHits(), 1);
 	}
 	
@@ -290,35 +298,40 @@ public class DiceRollTest extends TestCase
 		final ITestDelegateBridge bridge = getDelegateBridge(russians);
 		// aa hits at 0 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { ScriptedRandomSource.ERROR }));
-		final DiceRoll hit = DiceRoll.rollAA(fighterList, aaGunList, UnitAttachment.get(aaGunList.iterator().next().getType()).getTargetsAA(m_data), bridge, westRussia);
+		final DiceRoll hit = DiceRoll.rollAA(Match.getMatches(fighterList, Matches.unitIsOfTypes(UnitAttachment.get(aaGunList.iterator().next().getType()).getTargetsAA(m_data))), aaGunList, bridge,
+					westRussia);
 		assertEquals(hit.getHits(), 1);
 	}
 	
 	public void testAALowLuckWithRadar()
 	{
+		m_data = LoadGameUtil.loadGame("AA50", "ww2v3_1941.xml");
 		makeGameLowLuck();
-		final Territory westRussia = m_data.getMap().getTerritory("West Russia");
+		final Territory finnland = m_data.getMap().getTerritory("Finland");
 		final PlayerID russians = m_data.getPlayerList().getPlayerID("Russians");
 		final PlayerID germans = m_data.getPlayerList().getPlayerID("Germans");
 		final UnitType aaGunType = m_data.getUnitTypeList().getUnitType("aaGun");
 		final List<Unit> aaGunList = aaGunType.create(1, germans);
-		GameDataTestUtil.addTo(westRussia, aaGunList);
+		GameDataTestUtil.addTo(finnland, aaGunList);
 		final UnitType fighterType = m_data.getUnitTypeList().getUnitType("fighter");
 		List<Unit> fighterList = fighterType.create(1, russians);
 		TechAttachment.get(germans).setAARadar("true");
 		final ITestDelegateBridge bridge = getDelegateBridge(russians);
 		// aa radar hits at 1 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 1 }));
-		final DiceRoll hit = DiceRoll.rollAA(fighterList, aaGunList, UnitAttachment.get(aaGunList.iterator().next().getType()).getTargetsAA(m_data), bridge, westRussia);
+		final DiceRoll hit = DiceRoll.rollAA(Match.getMatches(fighterList, Matches.unitIsOfTypes(UnitAttachment.get(aaGunList.iterator().next().getType()).getTargetsAA(m_data))), aaGunList, bridge,
+					finnland);
 		assertEquals(hit.getHits(), 1);
 		// aa missses at 2 (0 based)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 2 }));
-		final DiceRoll miss = DiceRoll.rollAA(fighterList, aaGunList, UnitAttachment.get(aaGunList.iterator().next().getType()).getTargetsAA(m_data), bridge, westRussia);
+		final DiceRoll miss = DiceRoll.rollAA(Match.getMatches(fighterList, Matches.unitIsOfTypes(UnitAttachment.get(aaGunList.iterator().next().getType()).getTargetsAA(m_data))), aaGunList, bridge,
+					finnland);
 		assertEquals(miss.getHits(), 0);
 		// 6 bombers, 2 should hit, and nothing should be rolled
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { ScriptedRandomSource.ERROR }));
 		fighterList = fighterType.create(6, russians);
-		final DiceRoll hitNoRoll = DiceRoll.rollAA(fighterList, aaGunList, UnitAttachment.get(aaGunList.iterator().next().getType()).getTargetsAA(m_data), bridge, westRussia);
+		final DiceRoll hitNoRoll = DiceRoll.rollAA(Match.getMatches(fighterList, Matches.unitIsOfTypes(UnitAttachment.get(aaGunList.iterator().next().getType()).getTargetsAA(m_data))), aaGunList,
+					bridge, finnland);
 		assertEquals(hitNoRoll.getHits(), 2);
 	}
 	
@@ -327,10 +340,11 @@ public class DiceRollTest extends TestCase
 		m_data = LoadGameUtil.loadGame("classic", "iron_blitz.xml");
 		final PlayerID british = m_data.getPlayerList().getPlayerID("British");
 		final ITestDelegateBridge testDelegateBridge = getDelegateBridge(british);
-		TechTracker.addAdvance(british, testDelegateBridge, TechAdvance.HEAVY_BOMBER);
+		TechTracker.addAdvance(british, testDelegateBridge, TechAdvance.findAdvance(TechAdvance.TECH_PROPERTY_HEAVY_BOMBER, m_data, british));
 		final List<Unit> bombers = m_data.getMap().getTerritory("United Kingdom").getUnits().getMatches(Matches.UnitIsStrategicBomber);
 		testDelegateBridge.setRandomSource(new ScriptedRandomSource(new int[] { 2, 3 }));
-		final DiceRoll dice = DiceRoll.rollDice(bombers, false, british, testDelegateBridge, new MockBattle(m_data.getMap().getTerritory("Germany")), "");
+		final Territory germany = m_data.getMap().getTerritory("Germany");
+		final DiceRoll dice = DiceRoll.rollDice(bombers, false, british, testDelegateBridge, new MockBattle(germany), "", TerritoryEffectHelper.getEffects(germany));
 		assertEquals(Die.DieType.HIT, dice.getRolls(4).get(0).getType());
 		assertEquals(Die.DieType.HIT, dice.getRolls(4).get(1).getType());
 	}
@@ -340,10 +354,11 @@ public class DiceRollTest extends TestCase
 		m_data = LoadGameUtil.loadGame("classic", "iron_blitz.xml");
 		final PlayerID british = m_data.getPlayerList().getPlayerID("British");
 		final ITestDelegateBridge testDelegateBridge = getDelegateBridge(british);
-		TechTracker.addAdvance(british, testDelegateBridge, TechAdvance.HEAVY_BOMBER);
+		TechTracker.addAdvance(british, testDelegateBridge, TechAdvance.findAdvance(TechAdvance.TECH_PROPERTY_HEAVY_BOMBER, m_data, british));
 		final List<Unit> bombers = m_data.getMap().getTerritory("United Kingdom").getUnits().getMatches(Matches.UnitIsStrategicBomber);
 		testDelegateBridge.setRandomSource(new ScriptedRandomSource(new int[] { 0, 1 }));
-		final DiceRoll dice = DiceRoll.rollDice(bombers, true, british, testDelegateBridge, new MockBattle(m_data.getMap().getTerritory("Germany")), "");
+		final Territory germany = m_data.getMap().getTerritory("Germany");
+		final DiceRoll dice = DiceRoll.rollDice(bombers, true, british, testDelegateBridge, new MockBattle(germany), "", TerritoryEffectHelper.getEffects(germany));
 		assertEquals(1, dice.getRolls(1).size());
 		assertEquals(Die.DieType.HIT, dice.getRolls(1).get(0).getType());
 	}
@@ -355,7 +370,8 @@ public class DiceRollTest extends TestCase
 		final ITestDelegateBridge testDelegateBridge = getDelegateBridge(british);
 		final List<Unit> bombers = m_data.getMap().getTerritory("United Kingdom").getUnits().getMatches(Matches.UnitIsStrategicBomber);
 		testDelegateBridge.setRandomSource(new ScriptedRandomSource(new int[] { 0, 1 }));
-		final DiceRoll dice = DiceRoll.rollDice(bombers, true, british, testDelegateBridge, new MockBattle(m_data.getMap().getTerritory("Germany")), "");
+		final Territory germany = m_data.getMap().getTerritory("Germany");
+		final DiceRoll dice = DiceRoll.rollDice(bombers, true, british, testDelegateBridge, new MockBattle(germany), "", TerritoryEffectHelper.getEffects(germany));
 		assertEquals(1, dice.getRolls(1).size());
 		assertEquals(Die.DieType.HIT, dice.getRolls(1).get(0).getType());
 	}
@@ -365,10 +381,11 @@ public class DiceRollTest extends TestCase
 		m_data.getProperties().set(Constants.LHTR_HEAVY_BOMBERS, Boolean.TRUE);
 		final PlayerID british = m_data.getPlayerList().getPlayerID("British");
 		final ITestDelegateBridge testDelegateBridge = getDelegateBridge(british);
-		TechTracker.addAdvance(british, testDelegateBridge, TechAdvance.HEAVY_BOMBER);
+		TechTracker.addAdvance(british, testDelegateBridge, TechAdvance.findAdvance(TechAdvance.TECH_PROPERTY_HEAVY_BOMBER, m_data, british));
 		final List<Unit> bombers = m_data.getMap().getTerritory("United Kingdom").getUnits().getMatches(Matches.UnitIsStrategicBomber);
 		testDelegateBridge.setRandomSource(new ScriptedRandomSource(new int[] { 2, 3 }));
-		final DiceRoll dice = DiceRoll.rollDice(bombers, false, british, testDelegateBridge, new MockBattle(m_data.getMap().getTerritory("Germany")), "");
+		final Territory germany = m_data.getMap().getTerritory("Germany");
+		final DiceRoll dice = DiceRoll.rollDice(bombers, false, british, testDelegateBridge, new MockBattle(germany), "", TerritoryEffectHelper.getEffects(germany));
 		assertEquals(Die.DieType.HIT, dice.getRolls(4).get(0).getType());
 		assertEquals(Die.DieType.IGNORED, dice.getRolls(4).get(1).getType());
 		assertEquals(1, dice.getHits());
@@ -379,10 +396,11 @@ public class DiceRollTest extends TestCase
 		m_data.getProperties().set(Constants.LHTR_HEAVY_BOMBERS, Boolean.TRUE);
 		final PlayerID british = m_data.getPlayerList().getPlayerID("British");
 		final ITestDelegateBridge testDelegateBridge = getDelegateBridge(british);
-		TechTracker.addAdvance(british, testDelegateBridge, TechAdvance.HEAVY_BOMBER);
+		TechTracker.addAdvance(british, testDelegateBridge, TechAdvance.findAdvance(TechAdvance.TECH_PROPERTY_HEAVY_BOMBER, m_data, british));
 		final List<Unit> bombers = m_data.getMap().getTerritory("United Kingdom").getUnits().getMatches(Matches.UnitIsStrategicBomber);
 		testDelegateBridge.setRandomSource(new ScriptedRandomSource(new int[] { 3, 2 }));
-		final DiceRoll dice = DiceRoll.rollDice(bombers, false, british, testDelegateBridge, new MockBattle(m_data.getMap().getTerritory("Germany")), "");
+		final Territory germany = m_data.getMap().getTerritory("Germany");
+		final DiceRoll dice = DiceRoll.rollDice(bombers, false, british, testDelegateBridge, new MockBattle(germany), "", TerritoryEffectHelper.getEffects(germany));
 		assertEquals(Die.DieType.HIT, dice.getRolls(4).get(0).getType());
 		assertEquals(Die.DieType.IGNORED, dice.getRolls(4).get(1).getType());
 		assertEquals(1, dice.getHits());
@@ -393,10 +411,11 @@ public class DiceRollTest extends TestCase
 		m_data.getProperties().set(Constants.LHTR_HEAVY_BOMBERS, Boolean.TRUE);
 		final PlayerID british = m_data.getPlayerList().getPlayerID("British");
 		final ITestDelegateBridge testDelegateBridge = getDelegateBridge(british);
-		TechTracker.addAdvance(british, testDelegateBridge, TechAdvance.HEAVY_BOMBER);
+		TechTracker.addAdvance(british, testDelegateBridge, TechAdvance.findAdvance(TechAdvance.TECH_PROPERTY_HEAVY_BOMBER, m_data, british));
 		final List<Unit> bombers = m_data.getMap().getTerritory("United Kingdom").getUnits().getMatches(Matches.UnitIsStrategicBomber);
 		testDelegateBridge.setRandomSource(new ScriptedRandomSource(new int[] { 0, 1 }));
-		final DiceRoll dice = DiceRoll.rollDice(bombers, true, british, testDelegateBridge, new MockBattle(m_data.getMap().getTerritory("Germany")), "");
+		final Territory germany = m_data.getMap().getTerritory("Germany");
+		final DiceRoll dice = DiceRoll.rollDice(bombers, true, british, testDelegateBridge, new MockBattle(germany), "", TerritoryEffectHelper.getEffects(germany));
 		assertEquals(2, dice.getRolls(1).size());
 		assertEquals(1, dice.getHits());
 		assertEquals(Die.DieType.HIT, dice.getRolls(1).get(0).getType());
@@ -408,18 +427,21 @@ public class DiceRollTest extends TestCase
 		final PlayerID british = m_data.getPlayerList().getPlayerID("British");
 		final Territory location = m_data.getMap().getTerritory("United Kingdom");
 		final Unit bombers = m_data.getMap().getTerritory("United Kingdom").getUnits().getMatches(Matches.UnitIsStrategicBomber).get(0);
+		final Collection<TerritoryEffect> territoryEffects = TerritoryEffectHelper.getEffects(location);
 		// default 1 roll
-		assertEquals(1, BattleCalculator.getRolls(bombers, location, british, false));
-		assertEquals(1, BattleCalculator.getRolls(bombers, location, british, true));
+		assertEquals(1, BattleCalculator.getRolls(bombers, location, british, false, territoryEffects));
+		assertEquals(1, BattleCalculator.getRolls(bombers, location, british, true, territoryEffects));
 		// hb, for revised 2 on attack, 1 on defence
 		final ITestDelegateBridge testDelegateBridge = getDelegateBridge(british);
-		TechTracker.addAdvance(british, testDelegateBridge, TechAdvance.HEAVY_BOMBER);
-		m_data.getProperties().set(Constants.LHTR_HEAVY_BOMBERS, Boolean.FALSE);
-		assertEquals(2, BattleCalculator.getRolls(bombers, location, british, false));
-		assertEquals(1, BattleCalculator.getRolls(bombers, location, british, true));
+		TechTracker.addAdvance(british, testDelegateBridge, TechAdvance.findAdvance(TechAdvance.TECH_PROPERTY_HEAVY_BOMBER, m_data, british));
 		// lhtr hb, 2 for both
 		m_data.getProperties().set(Constants.LHTR_HEAVY_BOMBERS, Boolean.TRUE);
-		assertEquals(2, BattleCalculator.getRolls(bombers, location, british, false));
-		assertEquals(2, BattleCalculator.getRolls(bombers, location, british, true));
+		assertEquals(2, BattleCalculator.getRolls(bombers, location, british, false, territoryEffects));
+		assertEquals(2, BattleCalculator.getRolls(bombers, location, british, true, territoryEffects));
+		// non-lhtr, only 1 for defense.
+		// m_data.getProperties().set(Constants.LHTR_HEAVY_BOMBERS, Boolean.FALSE);
+		// assertEquals(2, BattleCalculator.getRolls(bombers, location, british, false));
+		// assertEquals(1, BattleCalculator.getRolls(bombers, location, british, true));
+		// this last bit can not be tested because with the new way tech works, changing the game option once the game starts does not remove or add the extra die roll
 	}
 }
