@@ -17,6 +17,7 @@ import games.strategy.engine.data.ITestDelegateBridge;
 import games.strategy.engine.data.PlayerID;
 import games.strategy.engine.data.Route;
 import games.strategy.engine.data.Territory;
+import games.strategy.engine.data.TerritoryEffect;
 import games.strategy.engine.data.Unit;
 import games.strategy.engine.data.UnitType;
 import games.strategy.engine.random.ScriptedRandomSource;
@@ -154,19 +155,20 @@ public class PacificTest extends DelegateTest
 		bridge.setStepName("NotJapanAttack");
 		// Defending US infantry hit on a 2 (0 base)
 		final List<Unit> infantryUS = infantry.create(1, americans);
+		final Collection<TerritoryEffect> territoryEffects = TerritoryEffectHelper.getEffects(queensland);
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 1 }));
-		DiceRoll roll = DiceRoll.rollDice(infantryUS, true, americans, bridge, new MockBattle(queensland), "");
+		DiceRoll roll = DiceRoll.rollDice(infantryUS, true, americans, bridge, new MockBattle(queensland), "", territoryEffects);
 		assertEquals(1, roll.getHits());
 		// Defending US marines hit on a 2 (0 base)
 		final List<Unit> marineUS = marine.create(1, americans);
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 1 }));
-		roll = DiceRoll.rollDice(marineUS, true, americans, bridge, new MockBattle(queensland), "");
+		roll = DiceRoll.rollDice(marineUS, true, americans, bridge, new MockBattle(queensland), "", territoryEffects);
 		assertEquals(1, roll.getHits());
 		// Chinese units
 		// Defending Chinese infantry hit on a 2 (0 base)
 		final List<Unit> infantryChina = infantry.create(1, chinese);
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 1 }));
-		roll = DiceRoll.rollDice(infantryChina, true, chinese, bridge, new MockBattle(queensland), "");
+		roll = DiceRoll.rollDice(infantryChina, true, chinese, bridge, new MockBattle(queensland), "", territoryEffects);
 		assertEquals(1, roll.getHits());
 	}
 	
@@ -180,33 +182,34 @@ public class PacificTest extends DelegateTest
 		// >>> After patch normal to-hits will miss <<<
 		// Defending US infantry miss on a 2 (0 base)
 		final List<Unit> infantryUS = infantry.create(1, americans);
+		final Collection<TerritoryEffect> territoryEffects = TerritoryEffectHelper.getEffects(queensland);
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 1 }));
-		DiceRoll roll = DiceRoll.rollDice(infantryUS, true, americans, bridge, new MockBattle(queensland), "");
+		DiceRoll roll = DiceRoll.rollDice(infantryUS, true, americans, bridge, new MockBattle(queensland), "", territoryEffects);
 		assertEquals(0, roll.getHits());
 		// Defending US marines miss on a 2 (0 base)
 		final List<Unit> marineUS = marine.create(1, americans);
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 1 }));
-		roll = DiceRoll.rollDice(marineUS, true, americans, bridge, new MockBattle(queensland), "");
+		roll = DiceRoll.rollDice(marineUS, true, americans, bridge, new MockBattle(queensland), "", territoryEffects);
 		assertEquals(0, roll.getHits());
 		//
 		// Chinese units
 		// Defending Chinese infantry still hit on a 2 (0 base)
 		final List<Unit> infantryChina = infantry.create(1, chinese);
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 1 }));
-		roll = DiceRoll.rollDice(infantryChina, true, chinese, bridge, new MockBattle(queensland), "");
+		roll = DiceRoll.rollDice(infantryChina, true, chinese, bridge, new MockBattle(queensland), "", territoryEffects);
 		assertEquals(1, roll.getHits());
 		// Defending US infantry hit on a 1 (0 base)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 0 }));
-		roll = DiceRoll.rollDice(infantryUS, true, americans, bridge, new MockBattle(queensland), "");
+		roll = DiceRoll.rollDice(infantryUS, true, americans, bridge, new MockBattle(queensland), "", territoryEffects);
 		assertEquals(1, roll.getHits());
 		// Defending US marines hit on a 1 (0 base)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 0 }));
-		roll = DiceRoll.rollDice(marineUS, true, americans, bridge, new MockBattle(queensland), "");
+		roll = DiceRoll.rollDice(marineUS, true, americans, bridge, new MockBattle(queensland), "", territoryEffects);
 		assertEquals(1, roll.getHits());
 		// Chinese units
 		// Defending Chinese infantry still hit on a 2 (0 base)
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 1 }));
-		roll = DiceRoll.rollDice(infantryChina, true, chinese, bridge, new MockBattle(queensland), "");
+		roll = DiceRoll.rollDice(infantryChina, true, chinese, bridge, new MockBattle(queensland), "", territoryEffects);
 		assertEquals(1, roll.getHits());
 	}
 	
