@@ -135,7 +135,7 @@ public class RevisedTest extends TestCase
 		assertEquals(2, attachment.getDefense(japanese));
 		assertEquals(2, attachment.getAttack(japanese));
 		final ITestDelegateBridge bridge = getDelegateBridge(japanese);
-		TechTracker.addAdvance(japanese, bridge, TechAdvance.SUPER_SUBS);
+		TechTracker.addAdvance(japanese, bridge, TechAdvance.findAdvance(TechAdvance.TECH_PROPERTY_SUPER_SUBS, m_data, japanese));
 		// after tech advance, this is now 3
 		assertEquals(2, attachment.getDefense(japanese));
 		assertEquals(3, attachment.getAttack(japanese));
@@ -854,7 +854,7 @@ public class RevisedTest extends TestCase
 		final List<Unit> bombers = uk.getUnits().getMatches(Matches.UnitIsStrategicBomber);
 		addTo(germany, bombers);
 		battle.addAttackChange(m_data.getMap().getRoute(uk, germany), bombers, null);
-		tracker.getBattleRecords().addBattle(british, battle.getBattleID(), germany, battle.getBattleType());
+		tracker.getBattleRecords(m_data).addBattle(british, battle.getBattleID(), germany, battle.getBattleType(), m_data);
 		final ITestDelegateBridge bridge = getDelegateBridge(british);
 		bridge.setRemote(getDummyPlayer());
 		// aa guns rolls 0 and hits
@@ -880,7 +880,7 @@ public class RevisedTest extends TestCase
 		final List<Unit> bombers = bomber(m_data).create(2, british);
 		addTo(germany, bombers);
 		battle.addAttackChange(m_data.getMap().getRoute(uk, germany), bombers, null);
-		tracker.getBattleRecords().addBattle(british, battle.getBattleID(), germany, battle.getBattleType());
+		tracker.getBattleRecords(m_data).addBattle(british, battle.getBattleID(), germany, battle.getBattleType(), m_data);
 		final ITestDelegateBridge bridge = getDelegateBridge(british);
 		bridge.setRemote(getDummyPlayer());
 		// should be exactly 3 rolls total. would be exactly 2 rolls if the number of units being shot at = max dice side of the AA gun, because the casualty selection roll would not happen in LL
@@ -907,7 +907,7 @@ public class RevisedTest extends TestCase
 		final List<Unit> bombers = bomber(m_data).create(7, british);
 		addTo(germany, bombers);
 		battle.addAttackChange(m_data.getMap().getRoute(uk, germany), bombers, null);
-		tracker.getBattleRecords().addBattle(british, battle.getBattleID(), germany, battle.getBattleType());
+		tracker.getBattleRecords(m_data).addBattle(british, battle.getBattleID(), germany, battle.getBattleType(), m_data);
 		final ITestDelegateBridge bridge = getDelegateBridge(british);
 		bridge.setRemote(getDummyPlayer());
 		// aa guns rolls 0 and hits, next 5 dice are for the bombing raid cost for the
@@ -930,9 +930,9 @@ public class RevisedTest extends TestCase
 		final BattleTracker tracker = new BattleTracker();
 		final StrategicBombingRaidBattle battle = new StrategicBombingRaidBattle(germany, m_data, british, tracker);
 		battle.addAttackChange(m_data.getMap().getRoute(uk, germany), uk.getUnits().getMatches(Matches.UnitIsStrategicBomber), null);
-		tracker.getBattleRecords().addBattle(british, battle.getBattleID(), germany, battle.getBattleType());
+		tracker.getBattleRecords(m_data).addBattle(british, battle.getBattleID(), germany, battle.getBattleType(), m_data);
 		final ITestDelegateBridge bridge = getDelegateBridge(british);
-		TechTracker.addAdvance(british, bridge, TechAdvance.HEAVY_BOMBER);
+		TechTracker.addAdvance(british, bridge, TechAdvance.findAdvance(TechAdvance.TECH_PROPERTY_HEAVY_BOMBER, m_data, british));
 		// aa guns rolls 3, misses, bomber rolls 2 dice at 3
 		bridge.setRandomSource(new ScriptedRandomSource(new int[] { 3, 2, 2 }));
 		// if we try to move aa, then the game will ask us if we want to move
@@ -1284,21 +1284,21 @@ public class RevisedTest extends TestCase
 		final TechAttachment ta = TechAttachment.get(germans);
 		// PlayerAttachment pa = PlayerAttachment.get(germans);
 		final TechnologyFrontier rockets = new TechnologyFrontier("", m_data);
-		rockets.addAdvance(TechAdvance.ROCKETS);
+		rockets.addAdvance(TechAdvance.findAdvance(TechAdvance.TECH_PROPERTY_ROCKETS, m_data, null));
 		final TechnologyFrontier jet = new TechnologyFrontier("", m_data);
-		jet.addAdvance(TechAdvance.JET_POWER);
+		jet.addAdvance(TechAdvance.findAdvance(TechAdvance.TECH_PROPERTY_JET_POWER, m_data, null));
 		// Check to make sure it was successful
 		final int initPUs = germans.getResources().getQuantity("PUs");
 		// Fail the roll
 		delegateBridge.setRandomSource(new ScriptedRandomSource(new int[] { 3, 4 }));
-		final TechResults roll = techDelegate.rollTech(2, rockets, 0);
+		final TechResults roll = techDelegate.rollTech(2, rockets, 0, null);
 		// Check to make sure it failed
 		assertEquals(0, roll.getHits());
 		final int midPUs = germans.getResources().getQuantity("PUs");
 		assertEquals(initPUs - 10, midPUs);
 		// Make a Successful roll
 		delegateBridge.setRandomSource(new ScriptedRandomSource(new int[] { 5 }));
-		final TechResults roll2 = techDelegate.rollTech(1, rockets, 0);
+		final TechResults roll2 = techDelegate.rollTech(1, rockets, 0, null);
 		// Check to make sure it succeeded
 		assertEquals(1, roll2.getHits());
 		final int finalPUs = germans.getResources().getQuantity("PUs");
@@ -1306,7 +1306,7 @@ public class RevisedTest extends TestCase
 		// Test the variable tech cost
 		ta.setTechCost("6");// Make a Successful roll
 		delegateBridge.setRandomSource(new ScriptedRandomSource(new int[] { 5 }));
-		final TechResults roll3 = techDelegate.rollTech(1, jet, 0);
+		final TechResults roll3 = techDelegate.rollTech(1, jet, 0, null);
 		// Check to make sure it succeeded
 		assertEquals(1, roll3.getHits());
 		final int VariablePUs = germans.getResources().getQuantity("PUs");
