@@ -60,7 +60,7 @@ public class DummyTripleAPlayer implements ITripleaPlayer
 	{
 	}
 	
-	public PlayerID getID()
+	public PlayerID getPlayerID()
 	{
 		return null;
 	}
@@ -87,7 +87,7 @@ public class DummyTripleAPlayer implements ITripleaPlayer
 		return true;
 	}
 	
-	public Territory retreatQuery(final GUID battleID, final boolean submerge, final Collection<Territory> possibleTerritories, final String message)
+	public Territory retreatQuery(final GUID battleID, final boolean submerge, final Territory battleSite, final Collection<Territory> possibleTerritories, final String message)
 	{
 		return null;
 	}
@@ -97,7 +97,7 @@ public class DummyTripleAPlayer implements ITripleaPlayer
 		return null;
 	}*/
 
-	public HashMap<Territory, Collection<Unit>> scrambleUnitsQuery(final Territory scrambleTo, final Map<Territory, Tuple<Integer, Collection<Unit>>> possibleScramblers)
+	public HashMap<Territory, Collection<Unit>> scrambleUnitsQuery(final Territory scrambleTo, final Map<Territory, Tuple<Collection<Unit>, Collection<Unit>>> possibleScramblers)
 	{
 		return null;
 	}
@@ -148,9 +148,14 @@ public class DummyTripleAPlayer implements ITripleaPlayer
 		return false;
 	}
 	
-	public Unit whatShouldBomberBomb(final Territory territory, final Collection<Unit> units)
+	public Unit whatShouldBomberBomb(final Territory territory, final Collection<Unit> potentialTargets, final Collection<Unit> bombers)
 	{
-		return (Unit) Match.getNMatches(units, 1, Matches.UnitIsFactory);
+		if (potentialTargets == null || potentialTargets.isEmpty())
+			return null; // is null even allowed?
+		final Collection<Unit> typicalFactories = Match.getMatches(potentialTargets, Matches.UnitCanProduceUnitsAndCanBeDamaged);
+		if (typicalFactories.isEmpty())
+			return potentialTargets.iterator().next();
+		return typicalFactories.iterator().next();
 	}
 	
 	public Territory whereShouldRocketsAttack(final Collection<Territory> candidates, final Territory from)
